@@ -1,5 +1,7 @@
 var NAVTREEINDEX10 =
 {
+"_samples.html#tutorial02":[3,0,34],
+"_samples.html#tutorial03":[3,0,35],
 "_samples.html#tutorial04":[3,0,36],
 "_samples.html#tutorial05":[3,0,37],
 "_samples.html#tutorial06":[3,0,38],
@@ -81,28 +83,28 @@ var NAVTREEINDEX10 =
 "azdo.html#V2AndV1Objects":[3,10,0],
 "azdo.html#V2AndV1ObjectsV1Longevity":[3,10,0,0],
 "azdo.html#VaoMaanger":[3,10,2],
-"class_display.html":[7,0,5],
-"class_not_pointer_atom.html":[7,0,9],
+"class_display.html":[7,0,6],
+"class_not_pointer_atom.html":[7,0,10],
 "class_ogre_1_1_a_p_k_file_system_archive.html":[7,0,0,22],
 "class_ogre_1_1_a_p_k_file_system_archive.html":[6,0,0,49],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a0d8c6606a0574f6e0a1909c5cb4e0ba3":[7,0,0,22,25],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a0d8c6606a0574f6e0a1909c5cb4e0ba3":[6,0,0,49,25],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a0d8c6606a0574f6e0a1909c5cb4e0ba3":[7,0,0,22,25],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,49,17],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,22,17],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a2674d48fac32a3db65c7acd7811d244d":[7,0,0,22,9],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a2674d48fac32a3db65c7acd7811d244d":[6,0,0,49,9],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a3229d2fd6c8d3236f68f7a3f1baedeec":[7,0,0,22,10],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a2674d48fac32a3db65c7acd7811d244d":[7,0,0,22,9],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a3229d2fd6c8d3236f68f7a3f1baedeec":[6,0,0,49,10],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a370bbf433be7cda33f045ad2e70215a3":[7,0,0,22,1],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a3229d2fd6c8d3236f68f7a3f1baedeec":[7,0,0,22,10],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a370bbf433be7cda33f045ad2e70215a3":[6,0,0,49,1],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a370bbf433be7cda33f045ad2e70215a3":[7,0,0,22,1],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a3bf1d801c67ee89e48d8a3299cfc0a7e":[6,0,0,49,6],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a3bf1d801c67ee89e48d8a3299cfc0a7e":[7,0,0,22,6],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a485335b676e26fd6570a40213273b549":[7,0,0,22,0],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a485335b676e26fd6570a40213273b549":[6,0,0,49,0],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,49,19],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,22,19],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,49,22],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,49,19],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,22,22],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,49,22],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a6fde30e44c6eae7c922fcc9ae21e4d7c":[7,0,0,22,12],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a6fde30e44c6eae7c922fcc9ae21e4d7c":[6,0,0,49,12],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,22,15],
@@ -111,32 +113,32 @@ var NAVTREEINDEX10 =
 "class_ogre_1_1_a_p_k_file_system_archive.html#a8bc93ec9170e9504de6293096585d8a7":[6,0,0,49,11],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a92ad2416e5441af919314a6334f009f9":[7,0,0,22,3],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a92ad2416e5441af919314a6334f009f9":[6,0,0,49,3],
-"class_ogre_1_1_a_p_k_file_system_archive.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,49,18],
 "class_ogre_1_1_a_p_k_file_system_archive.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,22,18],
+"class_ogre_1_1_a_p_k_file_system_archive.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,49,18],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aab0eeb38f3941f9aedd66c858d86fc8a":[7,0,0,22,26],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aab0eeb38f3941f9aedd66c858d86fc8a":[6,0,0,49,26],
-"class_ogre_1_1_a_p_k_file_system_archive.html#aafaac74ffb9b0b5563215a6b9f825a2f":[7,0,0,22,5],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aafaac74ffb9b0b5563215a6b9f825a2f":[6,0,0,49,5],
+"class_ogre_1_1_a_p_k_file_system_archive.html#aafaac74ffb9b0b5563215a6b9f825a2f":[7,0,0,22,5],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ab13cace971069f901cd80e73da8f8cc6":[7,0,0,22,2],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ab13cace971069f901cd80e73da8f8cc6":[6,0,0,49,2],
-"class_ogre_1_1_a_p_k_file_system_archive.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,49,21],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,22,21],
-"class_ogre_1_1_a_p_k_file_system_archive.html#ab63e6a2843a2db30eef7855616ff3440":[7,0,0,22,8],
+"class_ogre_1_1_a_p_k_file_system_archive.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,49,21],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ab63e6a2843a2db30eef7855616ff3440":[6,0,0,49,8],
+"class_ogre_1_1_a_p_k_file_system_archive.html#ab63e6a2843a2db30eef7855616ff3440":[7,0,0,22,8],
 "class_ogre_1_1_a_p_k_file_system_archive.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,49,16],
 "class_ogre_1_1_a_p_k_file_system_archive.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,22,16],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,49,20],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,22,20],
 "class_ogre_1_1_a_p_k_file_system_archive.html#adbc3d0a51af61ffeb3f330064d6c4d73":[7,0,0,22,13],
 "class_ogre_1_1_a_p_k_file_system_archive.html#adbc3d0a51af61ffeb3f330064d6c4d73":[6,0,0,49,13],
-"class_ogre_1_1_a_p_k_file_system_archive.html#adce32528577d71b228692df906ecd17c":[7,0,0,22,23],
 "class_ogre_1_1_a_p_k_file_system_archive.html#adce32528577d71b228692df906ecd17c":[6,0,0,49,23],
+"class_ogre_1_1_a_p_k_file_system_archive.html#adce32528577d71b228692df906ecd17c":[7,0,0,22,23],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ae0182ce37e2f1e05799760ad7d997b41":[6,0,0,49,14],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ae0182ce37e2f1e05799760ad7d997b41":[7,0,0,22,14],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ae31318ec0679e136a0e79016c8aba26b":[7,0,0,22,4],
 "class_ogre_1_1_a_p_k_file_system_archive.html#ae31318ec0679e136a0e79016c8aba26b":[6,0,0,49,4],
-"class_ogre_1_1_a_p_k_file_system_archive.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,22,24],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,49,24],
+"class_ogre_1_1_a_p_k_file_system_archive.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,22,24],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aee650b957194abaf771ea81b41da36fe":[6,0,0,49,7],
 "class_ogre_1_1_a_p_k_file_system_archive.html#aee650b957194abaf771ea81b41da36fe":[7,0,0,22,7],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html":[6,0,0,50],
@@ -145,14 +147,14 @@ var NAVTREEINDEX10 =
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[7,0,0,23,3],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,50,9],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,23,9],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a3479b271af0b6a05d3126bd6d7bfbeb0":[6,0,0,50,2],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a3479b271af0b6a05d3126bd6d7bfbeb0":[7,0,0,23,2],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a3479b271af0b6a05d3126bd6d7bfbeb0":[6,0,0,50,2],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a49d76c0adee87f3761b47ba3f9423a95":[6,0,0,50,1],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a49d76c0adee87f3761b47ba3f9423a95":[7,0,0,23,1],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a4d5cddcc806fd73f22987db34c14e9c9":[6,0,0,50,5],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a4d5cddcc806fd73f22987db34c14e9c9":[7,0,0,23,5],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,50,11],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,23,11],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,50,11],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,23,14],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,50,14],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a6a325ed3acfc868300befde9a2270ff4":[7,0,0,23,0],
@@ -161,8 +163,8 @@ var NAVTREEINDEX10 =
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,23,7],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,23,10],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,50,10],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#aac6ff8be0211440930ff787558b9be5a":[7,0,0,23,6],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#aac6ff8be0211440930ff787558b9be5a":[6,0,0,50,6],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#aac6ff8be0211440930ff787558b9be5a":[7,0,0,23,6],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,23,13],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,50,13],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,23,8],
@@ -173,44 +175,44 @@ var NAVTREEINDEX10 =
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#adce32528577d71b228692df906ecd17c":[6,0,0,50,15],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#ae826041f38f1896e6a5f800f35aaa638":[6,0,0,50,4],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#ae826041f38f1896e6a5f800f35aaa638":[7,0,0,23,4],
-"class_ogre_1_1_a_p_k_file_system_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,50,16],
 "class_ogre_1_1_a_p_k_file_system_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,23,16],
+"class_ogre_1_1_a_p_k_file_system_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,50,16],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html":[6,0,0,51],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html":[7,0,0,24],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[7,0,0,24,5],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[6,0,0,51,5],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a08586d13d121b5639de009b73ec28e82":[7,0,0,24,5],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,51,11],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,24,11],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a2ce05ec837366adb88a8b9f573085478":[6,0,0,51,19],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a2ce05ec837366adb88a8b9f573085478":[7,0,0,24,19],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a2ce05ec837366adb88a8b9f573085478":[6,0,0,51,19],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,51,13],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,24,13],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,24,16],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,51,16],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,24,16],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a6a5765a963cb0c13df4df82f356960e0":[7,0,0,24,2],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a6a5765a963cb0c13df4df82f356960e0":[6,0,0,51,2],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a6daf2b72dc3cb321c51ea3a09b3c0162":[6,0,0,51,6],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a6daf2b72dc3cb321c51ea3a09b3c0162":[7,0,0,24,6],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a6daf2b72dc3cb321c51ea3a09b3c0162":[6,0,0,51,6],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a7d9d8eab82dfeb8f1ee47fb83379bd6d":[7,0,0,24,8],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a7d9d8eab82dfeb8f1ee47fb83379bd6d":[6,0,0,51,8],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,51,9],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,24,9],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a84f0bbc7ca53b6e525a9a774a03341fe":[7,0,0,24,7],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a84f0bbc7ca53b6e525a9a774a03341fe":[6,0,0,51,7],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,24,12],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a84f0bbc7ca53b6e525a9a774a03341fe":[7,0,0,24,7],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,51,12],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,24,12],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a9ef899ac1ebf7ab54f115c8ced9ff433":[7,0,0,24,0],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#a9ef899ac1ebf7ab54f115c8ced9ff433":[6,0,0,51,0],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#aa2c388afbb8ff7dfb301bbe95495ed6b":[7,0,0,24,3],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#aa2c388afbb8ff7dfb301bbe95495ed6b":[6,0,0,51,3],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#aa2c388afbb8ff7dfb301bbe95495ed6b":[7,0,0,24,3],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,24,15],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,51,15],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#ab985302e640d95d40059570ace8b7759":[7,0,0,24,4],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#ab985302e640d95d40059570ace8b7759":[6,0,0,51,4],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#ac6b4ff7bd7d6d755fd806c6b2bd7600f":[6,0,0,51,1],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#ac6b4ff7bd7d6d755fd806c6b2bd7600f":[7,0,0,24,1],
-"class_ogre_1_1_a_p_k_zip_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,24,10],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,51,10],
+"class_ogre_1_1_a_p_k_zip_archive_factory.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,24,10],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,24,14],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,51,14],
 "class_ogre_1_1_a_p_k_zip_archive_factory.html#adce32528577d71b228692df906ecd17c":[6,0,0,51,17],
@@ -247,7 +249,5 @@ var NAVTREEINDEX10 =
 "class_ogre_1_1_a_s_t_c_codec.html#ad9072a8530d43873924eb02ebae91569":[5,2,3,0,17],
 "class_ogre_1_1_a_s_t_c_codec.html#adce32528577d71b228692df906ecd17c":[5,2,3,0,26],
 "class_ogre_1_1_a_s_t_c_codec.html#ae5b74cfd0cb797a2ac139b4adb7ac557":[5,2,3,0,15],
-"class_ogre_1_1_a_s_t_c_codec.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,3,0,27],
-"class_ogre_1_1_a_s_t_c_codec.html#aedb803489bfc3bcbf600ee6dfa2caf8a":[5,2,3,0,9],
-"class_ogre_1_1_a_s_t_c_codec.html#af1c042a5f0846bff06d46cd0ad2ad0a4":[5,2,3,0,7]
+"class_ogre_1_1_a_s_t_c_codec.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,3,0,27]
 };
