@@ -1,81 +1,83 @@
 var NAVTREEINDEX100 =
 {
+"class_ogre_1_1_g_l3_plus_texture.html#ae012db59f5ea781c74f881daf2f081cb":[6,0,0,400,3],
+"class_ogre_1_1_g_l3_plus_texture.html#ae012db59f5ea781c74f881daf2f081cb":[7,0,0,373,3],
 "class_ogre_1_1_g_l3_plus_texture.html#ae0a0007de944eb3c2f933a372a752b35":[7,0,0,373,82],
 "class_ogre_1_1_g_l3_plus_texture.html#ae0a0007de944eb3c2f933a372a752b35":[6,0,0,400,82],
-"class_ogre_1_1_g_l3_plus_texture.html#ae229b1f58092109adef55bfc6f864d79":[6,0,0,400,101],
 "class_ogre_1_1_g_l3_plus_texture.html#ae229b1f58092109adef55bfc6f864d79":[7,0,0,373,101],
-"class_ogre_1_1_g_l3_plus_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[7,0,0,373,91],
+"class_ogre_1_1_g_l3_plus_texture.html#ae229b1f58092109adef55bfc6f864d79":[6,0,0,400,101],
 "class_ogre_1_1_g_l3_plus_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[6,0,0,400,91],
-"class_ogre_1_1_g_l3_plus_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[7,0,0,373,90],
+"class_ogre_1_1_g_l3_plus_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[7,0,0,373,91],
 "class_ogre_1_1_g_l3_plus_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[6,0,0,400,90],
+"class_ogre_1_1_g_l3_plus_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[7,0,0,373,90],
 "class_ogre_1_1_g_l3_plus_texture.html#ae356913ccefbebc4f0119a0599a406fc":[6,0,0,400,95],
 "class_ogre_1_1_g_l3_plus_texture.html#ae356913ccefbebc4f0119a0599a406fc":[7,0,0,373,95],
 "class_ogre_1_1_g_l3_plus_texture.html#ae67e44696cde3c7d4e8fec157ca4f498":[7,0,0,373,84],
 "class_ogre_1_1_g_l3_plus_texture.html#ae67e44696cde3c7d4e8fec157ca4f498":[6,0,0,400,84],
-"class_ogre_1_1_g_l3_plus_texture.html#aec390502f63927ed9470ba423ea66f64":[6,0,0,400,83],
 "class_ogre_1_1_g_l3_plus_texture.html#aec390502f63927ed9470ba423ea66f64":[7,0,0,373,83],
+"class_ogre_1_1_g_l3_plus_texture.html#aec390502f63927ed9470ba423ea66f64":[6,0,0,400,83],
 "class_ogre_1_1_g_l3_plus_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,400,78],
 "class_ogre_1_1_g_l3_plus_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,373,78],
-"class_ogre_1_1_g_l3_plus_texture.html#aee3fd3170df592c3cc679cc38d3d9f60":[7,0,0,373,49],
 "class_ogre_1_1_g_l3_plus_texture.html#aee3fd3170df592c3cc679cc38d3d9f60":[6,0,0,400,49],
-"class_ogre_1_1_g_l3_plus_texture.html#aee52bded52fe34f8322ecd3fa1790028":[7,0,0,373,20],
+"class_ogre_1_1_g_l3_plus_texture.html#aee3fd3170df592c3cc679cc38d3d9f60":[7,0,0,373,49],
 "class_ogre_1_1_g_l3_plus_texture.html#aee52bded52fe34f8322ecd3fa1790028":[6,0,0,400,20],
+"class_ogre_1_1_g_l3_plus_texture.html#aee52bded52fe34f8322ecd3fa1790028":[7,0,0,373,20],
 "class_ogre_1_1_g_l3_plus_texture.html#af745587ede1e8482b1edac167fbf82fd":[7,0,0,373,87],
 "class_ogre_1_1_g_l3_plus_texture.html#af745587ede1e8482b1edac167fbf82fd":[6,0,0,400,87],
-"class_ogre_1_1_g_l3_plus_texture.html#afcb4a61b965600a67ca2c2f060821db9":[6,0,0,400,4],
 "class_ogre_1_1_g_l3_plus_texture.html#afcb4a61b965600a67ca2c2f060821db9":[7,0,0,373,4],
+"class_ogre_1_1_g_l3_plus_texture.html#afcb4a61b965600a67ca2c2f060821db9":[6,0,0,400,4],
 "class_ogre_1_1_g_l3_plus_texture.html#afefa465095dd97cf22d0a43531171b51":[7,0,0,373,28],
 "class_ogre_1_1_g_l3_plus_texture.html#afefa465095dd97cf22d0a43531171b51":[6,0,0,400,28],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html":[6,0,0,401],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html":[7,0,0,374],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a00ea3e542d7ef9c1e223d12b99d24d0b":[6,0,0,401,23],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a00ea3e542d7ef9c1e223d12b99d24d0b":[7,0,0,374,23],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a030fd6e8824a9b23948bdfce7f0a1211":[7,0,0,374,36],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a030fd6e8824a9b23948bdfce7f0a1211":[6,0,0,401,36],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a03e2b3a27c5827b5f063fa6669f8e161":[7,0,0,374,55],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a030fd6e8824a9b23948bdfce7f0a1211":[7,0,0,374,36],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a03e2b3a27c5827b5f063fa6669f8e161":[6,0,0,401,55],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a06df44c12f039dfb40a60f6aacc94495":[7,0,0,374,32],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a03e2b3a27c5827b5f063fa6669f8e161":[7,0,0,374,55],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a06df44c12f039dfb40a60f6aacc94495":[6,0,0,401,32],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a0729d200bede23e29f5a88f0b9dcb3f6":[6,0,0,401,102],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a06df44c12f039dfb40a60f6aacc94495":[7,0,0,374,32],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a0729d200bede23e29f5a88f0b9dcb3f6":[7,0,0,374,102],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a0ccfb3ab941842233e28a216e337e28e":[6,0,0,401,78],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a0729d200bede23e29f5a88f0b9dcb3f6":[6,0,0,401,102],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a0ccfb3ab941842233e28a216e337e28e":[7,0,0,374,78],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a0df37fcb72b47849df985a18828f2e97":[6,0,0,401,10],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a0ccfb3ab941842233e28a216e337e28e":[6,0,0,401,78],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a0df37fcb72b47849df985a18828f2e97":[7,0,0,374,10],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a107372aa3256baf8a80484b7f2412dd6":[6,0,0,401,48],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a0df37fcb72b47849df985a18828f2e97":[6,0,0,401,10],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a107372aa3256baf8a80484b7f2412dd6":[7,0,0,374,48],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a17e910251ab52c86bf2dd902c60c8c0a":[6,0,0,401,19],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a107372aa3256baf8a80484b7f2412dd6":[6,0,0,401,48],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a17e910251ab52c86bf2dd902c60c8c0a":[7,0,0,374,19],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a1a1403e76b6775c08d2cb7b0c7d1398d":[6,0,0,401,25],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a17e910251ab52c86bf2dd902c60c8c0a":[6,0,0,401,19],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a1a1403e76b6775c08d2cb7b0c7d1398d":[7,0,0,374,25],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a1b6dd0d57c28fe017e8a83877bea0c5f":[6,0,0,401,22],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a1a1403e76b6775c08d2cb7b0c7d1398d":[6,0,0,401,25],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a1b6dd0d57c28fe017e8a83877bea0c5f":[7,0,0,374,22],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a1b6dd0d57c28fe017e8a83877bea0c5f":[6,0,0,401,22],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,401,91],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,374,91],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a1f960e2ffea97ad43308c23ce1efb4b1":[6,0,0,401,52],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a1f960e2ffea97ad43308c23ce1efb4b1":[7,0,0,374,52],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a23c32548e36eee7661d2da4c58f09f80":[7,0,0,374,76],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a23c32548e36eee7661d2da4c58f09f80":[6,0,0,401,76],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a2afd94abec3a7a91c656188fc6d7cdf5":[6,0,0,401,75],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a2afd94abec3a7a91c656188fc6d7cdf5":[7,0,0,374,75],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a2afd94abec3a7a91c656188fc6d7cdf5":[6,0,0,401,75],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a2e45ab2f1617d1d51c45f687d9ebee8c":[7,0,0,374,59],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a2e45ab2f1617d1d51c45f687d9ebee8c":[6,0,0,401,59],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a2e6b84b89e2080bb7103d4778641d86e":[7,0,0,374,99],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a2e6b84b89e2080bb7103d4778641d86e":[6,0,0,401,99],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a31a1ba96b03d3bab1a3c5943d03531fc":[7,0,0,374,79],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a2e6b84b89e2080bb7103d4778641d86e":[7,0,0,374,99],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a31a1ba96b03d3bab1a3c5943d03531fc":[6,0,0,401,79],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a359fd32c4f8c31cdd4db4baf72c1b70c":[7,0,0,374,81],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a31a1ba96b03d3bab1a3c5943d03531fc":[7,0,0,374,79],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a359fd32c4f8c31cdd4db4baf72c1b70c":[6,0,0,401,81],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a37e063590ddf3677c87852e3107b4e45":[7,0,0,374,44],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a359fd32c4f8c31cdd4db4baf72c1b70c":[7,0,0,374,81],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a37e063590ddf3677c87852e3107b4e45":[6,0,0,401,44],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a3866a77dfd74f1b70fdd31f42382c544":[6,0,0,401,105],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a37e063590ddf3677c87852e3107b4e45":[7,0,0,374,44],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a3866a77dfd74f1b70fdd31f42382c544":[7,0,0,374,105],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a3866a77dfd74f1b70fdd31f42382c544":[6,0,0,401,105],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a392c0d59b4956c9a361e82514cba0427":[6,0,0,401,64],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a392c0d59b4956c9a361e82514cba0427":[7,0,0,374,64],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a3bd2fb8a2ce598268c8813f5f230ddd8":[6,0,0,401,111],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a3bd2fb8a2ce598268c8813f5f230ddd8":[7,0,0,374,111],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a3db88cd9e4286f47a56fe7f507cd5c1b":[6,0,0,401,101],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a3bd2fb8a2ce598268c8813f5f230ddd8":[6,0,0,401,111],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a3db88cd9e4286f47a56fe7f507cd5c1b":[7,0,0,374,101],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a3db88cd9e4286f47a56fe7f507cd5c1b":[6,0,0,401,101],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a3ed2bdf11740fd262b9311a33e33f935":[7,0,0,374,118],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a3ed2bdf11740fd262b9311a33e33f935":[6,0,0,401,118],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4044404f7783aea108e986336caaedf6":[6,0,0,401,17],
@@ -86,168 +88,166 @@ var NAVTREEINDEX100 =
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a43888e98f84f5c9eb9ded14dd0deb34d":[6,0,0,401,119],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a472f6a92131325af1a8f5ba2b78b86eb":[7,0,0,374,29],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a472f6a92131325af1a8f5ba2b78b86eb":[6,0,0,401,29],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4766a70699416dd6dc2a51ad28307a19":[7,0,0,374,38],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4766a70699416dd6dc2a51ad28307a19":[6,0,0,401,38],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4766a70699416dd6dc2a51ad28307a19":[7,0,0,374,38],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a47e1fcc0e8d7a092a55c79ace4564a4a":[7,0,0,374,5],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a47e1fcc0e8d7a092a55c79ace4564a4a":[6,0,0,401,5],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4a10073f63d8fb559374f9e7c6585ae5":[7,0,0,374,47],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4a10073f63d8fb559374f9e7c6585ae5":[6,0,0,401,47],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4a698f48957f6d466fbddcbf2e80becd":[7,0,0,374,46],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4a698f48957f6d466fbddcbf2e80becd":[6,0,0,401,46],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4b8b1fafde32b5190ac4660a9ffa2adc":[7,0,0,374,26],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4a698f48957f6d466fbddcbf2e80becd":[7,0,0,374,46],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4b8b1fafde32b5190ac4660a9ffa2adc":[6,0,0,401,26],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4b8b1fafde32b5190ac4660a9ffa2adc":[7,0,0,374,26],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4c0edfcf7c6354c686d2ff580e7a5011":[6,0,0,401,82],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4c0edfcf7c6354c686d2ff580e7a5011":[7,0,0,374,82],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4c626ccabbd6c853ee1490358b9ca490":[7,0,0,374,14],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4c626ccabbd6c853ee1490358b9ca490":[6,0,0,401,14],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4c626ccabbd6c853ee1490358b9ca490":[7,0,0,374,14],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4d4ea058e8a05f5d1949fe952ad00063":[6,0,0,401,42],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4d4ea058e8a05f5d1949fe952ad00063":[7,0,0,374,42],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4d6bc1fdda7b86b12d3b3656ec53ce77":[7,0,0,374,1],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4d6bc1fdda7b86b12d3b3656ec53ce77":[6,0,0,401,1],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4de8595b73e911c15ce9e8066926380d":[7,0,0,374,70],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4d6bc1fdda7b86b12d3b3656ec53ce77":[7,0,0,374,1],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4de8595b73e911c15ce9e8066926380d":[6,0,0,401,70],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a4de8595b73e911c15ce9e8066926380d":[7,0,0,374,70],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4ebc3bec47d599f4d0f7a9cde67bd4d3":[7,0,0,374,77],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a4ebc3bec47d599f4d0f7a9cde67bd4d3":[6,0,0,401,77],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a50b8aace07a416886cc0f871b32f078c":[6,0,0,401,24],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a50b8aace07a416886cc0f871b32f078c":[7,0,0,374,24],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a529bc39128cc173557a2742b7278c400":[7,0,0,374,84],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a50b8aace07a416886cc0f871b32f078c":[6,0,0,401,24],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a529bc39128cc173557a2742b7278c400":[6,0,0,401,84],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a52acdc930dff7ae7f455256822d9520d":[7,0,0,374,87],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a529bc39128cc173557a2742b7278c400":[7,0,0,374,84],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a52acdc930dff7ae7f455256822d9520d":[6,0,0,401,87],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a52acdc930dff7ae7f455256822d9520d":[7,0,0,374,87],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a54dfe2523d8e5647e79caaf28c296d4e":[7,0,0,374,106],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a54dfe2523d8e5647e79caaf28c296d4e":[6,0,0,401,106],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a56ccef279ef9251c5a4b40bfaf7b9e05":[7,0,0,374,16],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a56ccef279ef9251c5a4b40bfaf7b9e05":[6,0,0,401,16],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a57c6e78baed76ebbde12a2061b35ab16":[7,0,0,374,56],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a57c6e78baed76ebbde12a2061b35ab16":[6,0,0,401,56],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a57c6e78baed76ebbde12a2061b35ab16":[7,0,0,374,56],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a594b69325b5d85480e0ca521eca9c027":[7,0,0,374,3],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a594b69325b5d85480e0ca521eca9c027":[6,0,0,401,3],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,401,93],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,374,93],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a59c0a87d81a1166e3239c247c1f66677":[6,0,0,401,37],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a59c0a87d81a1166e3239c247c1f66677":[7,0,0,374,37],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a59c0a87d81a1166e3239c247c1f66677":[6,0,0,401,37],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a5aee1b547e1be5bfafae466ca0b374ba":[7,0,0,374,45],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a5aee1b547e1be5bfafae466ca0b374ba":[6,0,0,401,45],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a5dbda8603b2d42d666a9aea7113e290d":[6,0,0,401,49],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a5dbda8603b2d42d666a9aea7113e290d":[7,0,0,374,49],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a6061da5422410802a10d2e97e9ab46f0":[7,0,0,374,7],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a6061da5422410802a10d2e97e9ab46f0":[6,0,0,401,7],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,401,96],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a6061da5422410802a10d2e97e9ab46f0":[7,0,0,374,7],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,374,96],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a65a6949bdace3ca3e22d9cdb8cc77411":[6,0,0,401,53],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,401,96],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a65a6949bdace3ca3e22d9cdb8cc77411":[7,0,0,374,53],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a65a6949bdace3ca3e22d9cdb8cc77411":[6,0,0,401,53],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a6740006ae83f39c4aeb83f300b67f6b2":[7,0,0,374,115],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a6740006ae83f39c4aeb83f300b67f6b2":[6,0,0,401,115],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a6ae40391d39c8feae00acaf25839c6f9":[6,0,0,401,104],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a6ae40391d39c8feae00acaf25839c6f9":[7,0,0,374,104],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a714b2b71f5443736c7c0ac2a97753c02":[6,0,0,401,35],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a714b2b71f5443736c7c0ac2a97753c02":[7,0,0,374,35],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a72fc34cf0b95593aa41df1370f5da312":[6,0,0,401,30],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a714b2b71f5443736c7c0ac2a97753c02":[6,0,0,401,35],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a72fc34cf0b95593aa41df1370f5da312":[7,0,0,374,30],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a7345e4a1d69f94657945067273376684":[6,0,0,401,15],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a72fc34cf0b95593aa41df1370f5da312":[6,0,0,401,30],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a7345e4a1d69f94657945067273376684":[7,0,0,374,15],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a7556d2e92eb39b9f465d25bd811c5c22":[7,0,0,374,39],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a7345e4a1d69f94657945067273376684":[6,0,0,401,15],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a7556d2e92eb39b9f465d25bd811c5c22":[6,0,0,401,39],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a78663647804665d50f8e0ec251845ff3":[6,0,0,401,66],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a7556d2e92eb39b9f465d25bd811c5c22":[7,0,0,374,39],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a78663647804665d50f8e0ec251845ff3":[7,0,0,374,66],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a78bd23c2116dc08afcaa8dc1b8d2384e":[7,0,0,374,109],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a78663647804665d50f8e0ec251845ff3":[6,0,0,401,66],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a78bd23c2116dc08afcaa8dc1b8d2384e":[6,0,0,401,109],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a78dd6a8c7c23f1dc98a9ec150bdf16e1":[7,0,0,374,50],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a78bd23c2116dc08afcaa8dc1b8d2384e":[7,0,0,374,109],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a78dd6a8c7c23f1dc98a9ec150bdf16e1":[6,0,0,401,50],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a78dd6a8c7c23f1dc98a9ec150bdf16e1":[7,0,0,374,50],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a7bb35caa0639bfa59b095295a73ab6c0":[7,0,0,374,43],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a7bb35caa0639bfa59b095295a73ab6c0":[6,0,0,401,43],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,374,89],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,401,89],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,374,89],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a85f9670da9031ec138caf8b3e910b37e":[7,0,0,374,21],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a85f9670da9031ec138caf8b3e910b37e":[6,0,0,401,21],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a88170d5ed9c9d2dc6e886217aaf1f6a5":[6,0,0,401,62],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a88170d5ed9c9d2dc6e886217aaf1f6a5":[7,0,0,374,62],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a8ec57ce0ef0c682416c3a6b6d13a095a":[7,0,0,374,117],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a88170d5ed9c9d2dc6e886217aaf1f6a5":[6,0,0,401,62],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a8ec57ce0ef0c682416c3a6b6d13a095a":[6,0,0,401,117],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a9034d26bf967a6a9ab6a03f3f2a75a88":[6,0,0,401,103],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a8ec57ce0ef0c682416c3a6b6d13a095a":[7,0,0,374,117],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a9034d26bf967a6a9ab6a03f3f2a75a88":[7,0,0,374,103],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a9034d26bf967a6a9ab6a03f3f2a75a88":[6,0,0,401,103],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a9078e54f74753c91de4a74462bdff406":[7,0,0,374,85],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a9078e54f74753c91de4a74462bdff406":[6,0,0,401,85],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a929c97b9b08168ccff81b0c20081eca8":[7,0,0,374,0],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a929c97b9b08168ccff81b0c20081eca8":[6,0,0,401,0],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a929c97b9b08168ccff81b0c20081eca8":[7,0,0,374,0],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a93baf8152625edecb31e20bac225ed96":[7,0,0,374,34],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a93baf8152625edecb31e20bac225ed96":[6,0,0,401,34],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,401,92],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,374,92],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,401,92],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a96c0f33134c2401b0e711506c8055623":[7,0,0,374,61],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a96c0f33134c2401b0e711506c8055623":[6,0,0,401,61],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a9be2b0daaad98d2140ca22efc6685684":[7,0,0,374,58],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a9be2b0daaad98d2140ca22efc6685684":[6,0,0,401,58],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a9cf89e55f18c75154a841da462e9606c":[7,0,0,374,28],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a9be2b0daaad98d2140ca22efc6685684":[7,0,0,374,58],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a9cf89e55f18c75154a841da462e9606c":[6,0,0,401,28],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#a9e98f7545f8b2fd4d92dd412fa5ac270":[7,0,0,374,33],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a9cf89e55f18c75154a841da462e9606c":[7,0,0,374,28],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#a9e98f7545f8b2fd4d92dd412fa5ac270":[6,0,0,401,33],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#a9e98f7545f8b2fd4d92dd412fa5ac270":[7,0,0,374,33],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa0c236009b4074f43621c21db5ff6ef4":[6,0,0,401,83],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa0c236009b4074f43621c21db5ff6ef4":[7,0,0,374,83],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa2ee4d088c32b3e9efeb4d2fec5cad3e":[6,0,0,401,108],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa2ee4d088c32b3e9efeb4d2fec5cad3e":[7,0,0,374,108],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa307d3e0905e7de18587dcb30c0b65e2":[6,0,0,401,110],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa307d3e0905e7de18587dcb30c0b65e2":[7,0,0,374,110],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#aa3c2ce1e86de183dd2e2eff87da180a5":[7,0,0,374,72],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa3c2ce1e86de183dd2e2eff87da180a5":[6,0,0,401,72],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#aa3efd161b3ec98e3a405cf3167b7d022":[6,0,0,401,113],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#aa3c2ce1e86de183dd2e2eff87da180a5":[7,0,0,374,72],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa3efd161b3ec98e3a405cf3167b7d022":[7,0,0,374,113],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#aa5cba290939fe64d8d12c514d79e9fc4":[6,0,0,401,65],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#aa3efd161b3ec98e3a405cf3167b7d022":[6,0,0,401,113],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa5cba290939fe64d8d12c514d79e9fc4":[7,0,0,374,65],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#aa81e2a8d0caf9096dbab0723bab2b894":[6,0,0,401,20],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#aa5cba290939fe64d8d12c514d79e9fc4":[6,0,0,401,65],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa81e2a8d0caf9096dbab0723bab2b894":[7,0,0,374,20],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#aa81e2a8d0caf9096dbab0723bab2b894":[6,0,0,401,20],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa844386b35f2cb71fee2f61304cb0d8d":[7,0,0,374,73],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aa844386b35f2cb71fee2f61304cb0d8d":[6,0,0,401,73],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aad718ff4ec85f52e36ef2772d9b150c2":[7,0,0,374,60],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aad718ff4ec85f52e36ef2772d9b150c2":[6,0,0,401,60],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#ab038b4f32feeaa739a8cff7397e8809d":[7,0,0,374,69],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ab038b4f32feeaa739a8cff7397e8809d":[6,0,0,401,69],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,374,95],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#ab038b4f32feeaa739a8cff7397e8809d":[7,0,0,374,69],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,401,95],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,374,95],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ab6906f8bdd2c820cc47b60b7d494d147":[7,0,0,374,67],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ab6906f8bdd2c820cc47b60b7d494d147":[6,0,0,401,67],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ac2d30ea54e791fd18489ad3cd28fe9b6":[7,0,0,374,63],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ac2d30ea54e791fd18489ad3cd28fe9b6":[6,0,0,401,63],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#ac707e8be721a47fb23a628003b1ade1f":[6,0,0,401,112],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ac707e8be721a47fb23a628003b1ade1f":[7,0,0,374,112],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#ac7261ed5e880bbe376162a666d0ebea3":[6,0,0,401,41],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#ac707e8be721a47fb23a628003b1ade1f":[6,0,0,401,112],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ac7261ed5e880bbe376162a666d0ebea3":[7,0,0,374,41],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,401,90],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#ac7261ed5e880bbe376162a666d0ebea3":[6,0,0,401,41],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,374,90],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#acc59aec11b770b8fc317dea50313d052":[7,0,0,374,27],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,401,90],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#acc59aec11b770b8fc317dea50313d052":[6,0,0,401,27],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#acc59aec11b770b8fc317dea50313d052":[7,0,0,374,27],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#acdde6ea96205d73550d17a18bf4653a4":[6,0,0,401,86],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#acdde6ea96205d73550d17a18bf4653a4":[7,0,0,374,86],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ace88832ef330c2b560127ca2386c87de":[7,0,0,374,74],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ace88832ef330c2b560127ca2386c87de":[6,0,0,401,74],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ad1858af3588de15e9da271d22fe9d5c1":[7,0,0,374,68],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ad1858af3588de15e9da271d22fe9d5c1":[6,0,0,401,68],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,374,94],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,401,94],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,374,94],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ad3b879c519f45ccb57f91bc45a221f3e":[6,0,0,401,9],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ad3b879c519f45ccb57f91bc45a221f3e":[7,0,0,374,9],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#ad623ee0c97e95e276074d3cfd64c374c":[6,0,0,401,2],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ad623ee0c97e95e276074d3cfd64c374c":[7,0,0,374,2],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#ad623ee0c97e95e276074d3cfd64c374c":[6,0,0,401,2],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ad9e5b1428a5fc4fdfaca35292509c716":[6,0,0,401,31],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ad9e5b1428a5fc4fdfaca35292509c716":[7,0,0,374,31],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#adaef49d04083efa37638502be9ece306":[6,0,0,401,54],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#adaef49d04083efa37638502be9ece306":[7,0,0,374,54],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#adc608f61167b7b737a4129cd2b85f5f4":[6,0,0,401,114],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#adc608f61167b7b737a4129cd2b85f5f4":[7,0,0,374,114],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#adce32528577d71b228692df906ecd17c":[7,0,0,374,97],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#adce32528577d71b228692df906ecd17c":[6,0,0,401,97],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#ae3e0ad601752b91f2851c88f9ed49869":[6,0,0,401,100],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#adce32528577d71b228692df906ecd17c":[7,0,0,374,97],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ae3e0ad601752b91f2851c88f9ed49869":[7,0,0,374,100],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#ae3e0ad601752b91f2851c88f9ed49869":[6,0,0,401,100],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ae641939cec4a57193dab3fc88921b7ae":[7,0,0,374,18],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ae641939cec4a57193dab3fc88921b7ae":[6,0,0,401,18],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#ae6576323b0cf05a3efbf46f9ab5d6e1e":[7,0,0,374,80],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ae6576323b0cf05a3efbf46f9ab5d6e1e":[6,0,0,401,80],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#ae6576323b0cf05a3efbf46f9ab5d6e1e":[7,0,0,374,80],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ae7872e21340e360c58fa62f35b306a64":[7,0,0,374,11],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ae7872e21340e360c58fa62f35b306a64":[6,0,0,401,11],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#ae9039d0b1ef9d873aea7440407b37cb2":[6,0,0,401,51],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#ae9039d0b1ef9d873aea7440407b37cb2":[7,0,0,374,51],
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#ae9039d0b1ef9d873aea7440407b37cb2":[6,0,0,401,51],
 "class_ogre_1_1_g_l3_plus_texture_gpu.html#aeab133cc1245bb5648652e4369d9497b":[6,0,0,401,57],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#aeab133cc1245bb5648652e4369d9497b":[7,0,0,374,57],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#aeb11dd2fac1160eaa5ae7ea0d8165581":[6,0,0,401,4],
-"class_ogre_1_1_g_l3_plus_texture_gpu.html#aeb11dd2fac1160eaa5ae7ea0d8165581":[7,0,0,374,4]
+"class_ogre_1_1_g_l3_plus_texture_gpu.html#aeab133cc1245bb5648652e4369d9497b":[7,0,0,374,57]
 };
