@@ -1,5 +1,7 @@
 var NAVTREEINDEX136 =
 {
+"class_ogre_1_1_invalid_call_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba359c10b8abe9abf39f84550a903e4698":[5,2,2,57,0,2],
+"class_ogre_1_1_invalid_call_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba55da7c9771a98e7c96c3900028f02703":[5,2,2,57,0,3],
 "class_ogre_1_1_invalid_call_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba65ef64423bae408d90e0af0166bac152":[5,2,2,57,0,6],
 "class_ogre_1_1_invalid_call_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba69f87eaf2ef88aabef0d5d11666b6705":[5,2,2,57,0,10],
 "class_ogre_1_1_invalid_call_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba932168f4c4ae1a90391233de8a21ab1a":[5,2,2,57,0,4],
@@ -61,22 +63,22 @@ var NAVTREEINDEX136 =
 "class_ogre_1_1_invalid_state_exception.html#af4d342026b7af34ba64ed365c7300659":[5,2,2,59,6],
 "class_ogre_1_1_irradiance_field.html":[6,0,0,557],
 "class_ogre_1_1_irradiance_field.html":[7,0,0,530],
-"class_ogre_1_1_irradiance_field.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[6,0,0,557,14],
 "class_ogre_1_1_irradiance_field.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[7,0,0,530,14],
+"class_ogre_1_1_irradiance_field.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[6,0,0,557,14],
 "class_ogre_1_1_irradiance_field.html#a0ca2cb9026aef0203ff4037efe4d88ad":[6,0,0,557,6],
 "class_ogre_1_1_irradiance_field.html#a0ca2cb9026aef0203ff4037efe4d88ad":[7,0,0,530,6],
-"class_ogre_1_1_irradiance_field.html#a17abea0cd515ae956c92d6e4f6e489d9":[6,0,0,557,1],
 "class_ogre_1_1_irradiance_field.html#a17abea0cd515ae956c92d6e4f6e489d9":[7,0,0,530,1],
+"class_ogre_1_1_irradiance_field.html#a17abea0cd515ae956c92d6e4f6e489d9":[6,0,0,557,1],
 "class_ogre_1_1_irradiance_field.html#a41156332f76f4565fea6bdf70b204a0e":[7,0,0,530,0],
 "class_ogre_1_1_irradiance_field.html#a41156332f76f4565fea6bdf70b204a0e":[6,0,0,557,0],
-"class_ogre_1_1_irradiance_field.html#a41156332f76f4565fea6bdf70b204a0ea3bc8ba934b61fa0034f1ec85fa128886":[6,0,0,557,0,2],
 "class_ogre_1_1_irradiance_field.html#a41156332f76f4565fea6bdf70b204a0ea3bc8ba934b61fa0034f1ec85fa128886":[7,0,0,530,0,2],
+"class_ogre_1_1_irradiance_field.html#a41156332f76f4565fea6bdf70b204a0ea3bc8ba934b61fa0034f1ec85fa128886":[6,0,0,557,0,2],
 "class_ogre_1_1_irradiance_field.html#a41156332f76f4565fea6bdf70b204a0ea730f4af2fcc76c3b3cf00b2527450b6d":[7,0,0,530,0,0],
 "class_ogre_1_1_irradiance_field.html#a41156332f76f4565fea6bdf70b204a0ea730f4af2fcc76c3b3cf00b2527450b6d":[6,0,0,557,0,0],
-"class_ogre_1_1_irradiance_field.html#a41156332f76f4565fea6bdf70b204a0eab01cc912fa8f5de4569c2985918d60db":[6,0,0,557,0,1],
 "class_ogre_1_1_irradiance_field.html#a41156332f76f4565fea6bdf70b204a0eab01cc912fa8f5de4569c2985918d60db":[7,0,0,530,0,1],
-"class_ogre_1_1_irradiance_field.html#a4d334192ab430000b164291ccad91408":[7,0,0,530,9],
+"class_ogre_1_1_irradiance_field.html#a41156332f76f4565fea6bdf70b204a0eab01cc912fa8f5de4569c2985918d60db":[6,0,0,557,0,1],
 "class_ogre_1_1_irradiance_field.html#a4d334192ab430000b164291ccad91408":[6,0,0,557,9],
+"class_ogre_1_1_irradiance_field.html#a4d334192ab430000b164291ccad91408":[7,0,0,530,9],
 "class_ogre_1_1_irradiance_field.html#a553e76d4af6c8d8a38b91913f209a030":[6,0,0,557,11],
 "class_ogre_1_1_irradiance_field.html#a553e76d4af6c8d8a38b91913f209a030":[7,0,0,530,11],
 "class_ogre_1_1_irradiance_field.html#a57e0523432c6e5133ff4fc251111a60e":[6,0,0,557,13],
@@ -87,54 +89,54 @@ var NAVTREEINDEX136 =
 "class_ogre_1_1_irradiance_field.html#a6ed7bdc966f72180111b87a7c3162df8":[7,0,0,530,8],
 "class_ogre_1_1_irradiance_field.html#a8bd7c938df6c80dd07dacb592a41313d":[6,0,0,557,18],
 "class_ogre_1_1_irradiance_field.html#a8bd7c938df6c80dd07dacb592a41313d":[7,0,0,530,18],
-"class_ogre_1_1_irradiance_field.html#a8f0e6e27854fea48c83bb374962b1efd":[7,0,0,530,16],
 "class_ogre_1_1_irradiance_field.html#a8f0e6e27854fea48c83bb374962b1efd":[6,0,0,557,16],
-"class_ogre_1_1_irradiance_field.html#a90b0c636f04aec3859dd3c5219234623":[7,0,0,530,12],
+"class_ogre_1_1_irradiance_field.html#a8f0e6e27854fea48c83bb374962b1efd":[7,0,0,530,16],
 "class_ogre_1_1_irradiance_field.html#a90b0c636f04aec3859dd3c5219234623":[6,0,0,557,12],
+"class_ogre_1_1_irradiance_field.html#a90b0c636f04aec3859dd3c5219234623":[7,0,0,530,12],
 "class_ogre_1_1_irradiance_field.html#a9f189cebd1f6a7153c8a9ab7755871f0":[6,0,0,557,15],
 "class_ogre_1_1_irradiance_field.html#a9f189cebd1f6a7153c8a9ab7755871f0":[7,0,0,530,15],
 "class_ogre_1_1_irradiance_field.html#ab152c8f646a835c2f88585ad4fe0413a":[7,0,0,530,10],
 "class_ogre_1_1_irradiance_field.html#ab152c8f646a835c2f88585ad4fe0413a":[6,0,0,557,10],
 "class_ogre_1_1_irradiance_field.html#ac6b23619abaf8b2d57c5bab948cfd6bf":[7,0,0,530,7],
 "class_ogre_1_1_irradiance_field.html#ac6b23619abaf8b2d57c5bab948cfd6bf":[6,0,0,557,7],
-"class_ogre_1_1_irradiance_field.html#add8ca4aba0a670ed60eeb8d6964fa8fc":[6,0,0,557,2],
 "class_ogre_1_1_irradiance_field.html#add8ca4aba0a670ed60eeb8d6964fa8fc":[7,0,0,530,2],
-"class_ogre_1_1_irradiance_field.html#aeca5a734c18fe28d98ea5a9fbb60d6f7":[6,0,0,557,4],
+"class_ogre_1_1_irradiance_field.html#add8ca4aba0a670ed60eeb8d6964fa8fc":[6,0,0,557,2],
 "class_ogre_1_1_irradiance_field.html#aeca5a734c18fe28d98ea5a9fbb60d6f7":[7,0,0,530,4],
-"class_ogre_1_1_irradiance_field.html#afa88e2552b98e01a2f1b8a21ddbfd064":[6,0,0,557,3],
+"class_ogre_1_1_irradiance_field.html#aeca5a734c18fe28d98ea5a9fbb60d6f7":[6,0,0,557,4],
 "class_ogre_1_1_irradiance_field.html#afa88e2552b98e01a2f1b8a21ddbfd064":[7,0,0,530,3],
-"class_ogre_1_1_irradiance_field.html#afc5daa0b4930f3d2dce32ad8edd58c30":[6,0,0,557,5],
+"class_ogre_1_1_irradiance_field.html#afa88e2552b98e01a2f1b8a21ddbfd064":[6,0,0,557,3],
 "class_ogre_1_1_irradiance_field.html#afc5daa0b4930f3d2dce32ad8edd58c30":[7,0,0,530,5],
-"class_ogre_1_1_irradiance_field_raster.html":[7,0,0,531],
+"class_ogre_1_1_irradiance_field.html#afc5daa0b4930f3d2dce32ad8edd58c30":[6,0,0,557,5],
 "class_ogre_1_1_irradiance_field_raster.html":[6,0,0,558],
-"class_ogre_1_1_irradiance_field_raster.html#a0bf7e92c3f503e982acfb91e61ed404a":[7,0,0,531,2],
+"class_ogre_1_1_irradiance_field_raster.html":[7,0,0,531],
 "class_ogre_1_1_irradiance_field_raster.html#a0bf7e92c3f503e982acfb91e61ed404a":[6,0,0,558,2],
+"class_ogre_1_1_irradiance_field_raster.html#a0bf7e92c3f503e982acfb91e61ed404a":[7,0,0,531,2],
 "class_ogre_1_1_irradiance_field_raster.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,531,6],
 "class_ogre_1_1_irradiance_field_raster.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,558,6],
-"class_ogre_1_1_irradiance_field_raster.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,558,8],
 "class_ogre_1_1_irradiance_field_raster.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,531,8],
-"class_ogre_1_1_irradiance_field_raster.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,558,11],
+"class_ogre_1_1_irradiance_field_raster.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,558,8],
 "class_ogre_1_1_irradiance_field_raster.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,531,11],
+"class_ogre_1_1_irradiance_field_raster.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,558,11],
 "class_ogre_1_1_irradiance_field_raster.html#a69085ac8c0566e39f1babe4a937311d1":[7,0,0,531,1],
 "class_ogre_1_1_irradiance_field_raster.html#a69085ac8c0566e39f1babe4a937311d1":[6,0,0,558,1],
-"class_ogre_1_1_irradiance_field_raster.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,531,4],
 "class_ogre_1_1_irradiance_field_raster.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,558,4],
+"class_ogre_1_1_irradiance_field_raster.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,531,4],
 "class_ogre_1_1_irradiance_field_raster.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,558,7],
 "class_ogre_1_1_irradiance_field_raster.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,531,7],
-"class_ogre_1_1_irradiance_field_raster.html#a9ae4e301cf5b99010ac03b0a9c347534":[6,0,0,558,14],
 "class_ogre_1_1_irradiance_field_raster.html#a9ae4e301cf5b99010ac03b0a9c347534":[7,0,0,531,14],
+"class_ogre_1_1_irradiance_field_raster.html#a9ae4e301cf5b99010ac03b0a9c347534":[6,0,0,558,14],
 "class_ogre_1_1_irradiance_field_raster.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,531,10],
 "class_ogre_1_1_irradiance_field_raster.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,558,10],
 "class_ogre_1_1_irradiance_field_raster.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,558,5],
 "class_ogre_1_1_irradiance_field_raster.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,531,5],
-"class_ogre_1_1_irradiance_field_raster.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,558,9],
 "class_ogre_1_1_irradiance_field_raster.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,531,9],
-"class_ogre_1_1_irradiance_field_raster.html#adce32528577d71b228692df906ecd17c":[7,0,0,531,12],
+"class_ogre_1_1_irradiance_field_raster.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,558,9],
 "class_ogre_1_1_irradiance_field_raster.html#adce32528577d71b228692df906ecd17c":[6,0,0,558,12],
+"class_ogre_1_1_irradiance_field_raster.html#adce32528577d71b228692df906ecd17c":[7,0,0,531,12],
 "class_ogre_1_1_irradiance_field_raster.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,558,13],
 "class_ogre_1_1_irradiance_field_raster.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,531,13],
-"class_ogre_1_1_irradiance_field_raster.html#af71648239fe1481ea84339d6f6fc825e":[7,0,0,531,0],
 "class_ogre_1_1_irradiance_field_raster.html#af71648239fe1481ea84339d6f6fc825e":[6,0,0,558,0],
+"class_ogre_1_1_irradiance_field_raster.html#af71648239fe1481ea84339d6f6fc825e":[7,0,0,531,0],
 "class_ogre_1_1_irradiance_field_raster.html#afee5f8deb09844cfbab069cfd3a3d7f4":[7,0,0,531,3],
 "class_ogre_1_1_irradiance_field_raster.html#afee5f8deb09844cfbab069cfd3a3d7f4":[6,0,0,558,3],
 "class_ogre_1_1_irradiance_volume.html":[5,0,0,16],
@@ -165,20 +167,20 @@ var NAVTREEINDEX136 =
 "class_ogre_1_1_irradiance_volume.html#adf403ef637fbcca96b6862ff35229c8e":[5,0,0,16,0],
 "class_ogre_1_1_irradiance_volume.html#afc8619d85d69113b588d210d90a0aa0e":[5,0,0,16,16],
 "class_ogre_1_1_irradiance_volume.html#afdd4cfcb5064f1c56661a3b77d74a283":[5,0,0,16,1],
-"class_ogre_1_1_item.html":[5,2,12,24],
 "class_ogre_1_1_item.html":[5,0,1,24],
-"class_ogre_1_1_item.html#a005e208ddd35eba230f42ab58171290a":[5,2,12,24,41],
+"class_ogre_1_1_item.html":[5,2,12,24],
 "class_ogre_1_1_item.html#a005e208ddd35eba230f42ab58171290a":[5,0,1,24,41],
-"class_ogre_1_1_item.html#a015c3801632c98bca5dbb5aa3da1aa24":[5,0,1,24,28],
+"class_ogre_1_1_item.html#a005e208ddd35eba230f42ab58171290a":[5,2,12,24,41],
 "class_ogre_1_1_item.html#a015c3801632c98bca5dbb5aa3da1aa24":[5,2,12,24,28],
+"class_ogre_1_1_item.html#a015c3801632c98bca5dbb5aa3da1aa24":[5,0,1,24,28],
 "class_ogre_1_1_item.html#a01f48775e48b672d7796311f3ffe2930":[5,2,12,24,31],
 "class_ogre_1_1_item.html#a01f48775e48b672d7796311f3ffe2930":[5,0,1,24,31],
-"class_ogre_1_1_item.html#a05d2bd6634b2da72bfe71fcf22878718":[5,2,12,24,38],
 "class_ogre_1_1_item.html#a05d2bd6634b2da72bfe71fcf22878718":[5,0,1,24,38],
-"class_ogre_1_1_item.html#a0872a0ef9b2891ec3a8c223aa8de5198":[5,0,1,24,94],
+"class_ogre_1_1_item.html#a05d2bd6634b2da72bfe71fcf22878718":[5,2,12,24,38],
 "class_ogre_1_1_item.html#a0872a0ef9b2891ec3a8c223aa8de5198":[5,2,12,24,94],
-"class_ogre_1_1_item.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[5,2,12,24,78],
+"class_ogre_1_1_item.html#a0872a0ef9b2891ec3a8c223aa8de5198":[5,0,1,24,94],
 "class_ogre_1_1_item.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[5,0,1,24,78],
+"class_ogre_1_1_item.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[5,2,12,24,78],
 "class_ogre_1_1_item.html#a13629b96b4a6b0b34f652234f037d8d9":[5,2,12,24,58],
 "class_ogre_1_1_item.html#a13629b96b4a6b0b34f652234f037d8d9":[5,0,1,24,58],
 "class_ogre_1_1_item.html#a164483d42186628f7e14833b2df7a7a7":[5,0,1,24,46],
@@ -187,67 +189,65 @@ var NAVTREEINDEX136 =
 "class_ogre_1_1_item.html#a19bf2951b97744064509c13068143f3d":[5,2,12,24,54],
 "class_ogre_1_1_item.html#a1a048b8ace0a21cd2ed2c3008941ce3d":[5,0,1,24,30],
 "class_ogre_1_1_item.html#a1a048b8ace0a21cd2ed2c3008941ce3d":[5,2,12,24,30],
-"class_ogre_1_1_item.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,24,69],
 "class_ogre_1_1_item.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,24,69],
+"class_ogre_1_1_item.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,24,69],
 "class_ogre_1_1_item.html#a27eb8980ee187b42ea619c582eaebf73":[5,0,1,24,53],
 "class_ogre_1_1_item.html#a27eb8980ee187b42ea619c582eaebf73":[5,2,12,24,53],
-"class_ogre_1_1_item.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[5,2,12,24,102],
 "class_ogre_1_1_item.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[5,0,1,24,102],
-"class_ogre_1_1_item.html#a2d62d2c3d09910210c948fc660468c46":[5,0,1,24,61],
+"class_ogre_1_1_item.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[5,2,12,24,102],
 "class_ogre_1_1_item.html#a2d62d2c3d09910210c948fc660468c46":[5,2,12,24,61],
+"class_ogre_1_1_item.html#a2d62d2c3d09910210c948fc660468c46":[5,0,1,24,61],
 "class_ogre_1_1_item.html#a2e3e690195e9d7e14c6ad4e1fe7ba9e5":[5,0,1,24,64],
 "class_ogre_1_1_item.html#a2e3e690195e9d7e14c6ad4e1fe7ba9e5":[5,2,12,24,64],
-"class_ogre_1_1_item.html#a2eb94fea5944cf0d33702a75cfa14a74":[5,2,12,24,32],
 "class_ogre_1_1_item.html#a2eb94fea5944cf0d33702a75cfa14a74":[5,0,1,24,32],
-"class_ogre_1_1_item.html#a30acf249cd312d9eed03a0f3ad618067":[5,0,1,24,36],
+"class_ogre_1_1_item.html#a2eb94fea5944cf0d33702a75cfa14a74":[5,2,12,24,32],
 "class_ogre_1_1_item.html#a30acf249cd312d9eed03a0f3ad618067":[5,2,12,24,36],
-"class_ogre_1_1_item.html#a35b519fd7cbbee4b8dc8ef7c1e526ba3":[5,0,1,24,37],
+"class_ogre_1_1_item.html#a30acf249cd312d9eed03a0f3ad618067":[5,0,1,24,36],
 "class_ogre_1_1_item.html#a35b519fd7cbbee4b8dc8ef7c1e526ba3":[5,2,12,24,37],
+"class_ogre_1_1_item.html#a35b519fd7cbbee4b8dc8ef7c1e526ba3":[5,0,1,24,37],
 "class_ogre_1_1_item.html#a38f8241458458e4f1235eae7d8f850c3":[5,2,12,24,101],
 "class_ogre_1_1_item.html#a38f8241458458e4f1235eae7d8f850c3":[5,0,1,24,101],
-"class_ogre_1_1_item.html#a4569b91ce5341ab892f74ab4555cac7d":[5,0,1,24,47],
 "class_ogre_1_1_item.html#a4569b91ce5341ab892f74ab4555cac7d":[5,2,12,24,47],
-"class_ogre_1_1_item.html#a467587f43ff2aa8774347050cc4fc5cc":[5,0,1,24,1],
+"class_ogre_1_1_item.html#a4569b91ce5341ab892f74ab4555cac7d":[5,0,1,24,47],
 "class_ogre_1_1_item.html#a467587f43ff2aa8774347050cc4fc5cc":[5,2,12,24,1],
+"class_ogre_1_1_item.html#a467587f43ff2aa8774347050cc4fc5cc":[5,0,1,24,1],
 "class_ogre_1_1_item.html#a4a40a12d7cd0f7fa4c4c0fc31bbf9a40":[5,0,1,24,80],
 "class_ogre_1_1_item.html#a4a40a12d7cd0f7fa4c4c0fc31bbf9a40":[5,2,12,24,80],
 "class_ogre_1_1_item.html#a4adc0275cc4fb1e0650b3214b0436d94":[5,2,12,24,7],
 "class_ogre_1_1_item.html#a4adc0275cc4fb1e0650b3214b0436d94":[5,0,1,24,7],
-"class_ogre_1_1_item.html#a4c29a048d9254c17c43a9fa313df0a6b":[5,0,1,24,8],
 "class_ogre_1_1_item.html#a4c29a048d9254c17c43a9fa313df0a6b":[5,2,12,24,8],
+"class_ogre_1_1_item.html#a4c29a048d9254c17c43a9fa313df0a6b":[5,0,1,24,8],
 "class_ogre_1_1_item.html#a4d43f57e9abcc21d4bc50e6e6d1b5cc7":[5,0,1,24,98],
 "class_ogre_1_1_item.html#a4d43f57e9abcc21d4bc50e6e6d1b5cc7":[5,2,12,24,98],
-"class_ogre_1_1_item.html#a504e2192036f75007c51e157315e1548":[5,2,12,24,82],
 "class_ogre_1_1_item.html#a504e2192036f75007c51e157315e1548":[5,0,1,24,82],
+"class_ogre_1_1_item.html#a504e2192036f75007c51e157315e1548":[5,2,12,24,82],
 "class_ogre_1_1_item.html#a5456ecd630d55c91b2fd1b19969d29f5":[5,2,12,24,90],
 "class_ogre_1_1_item.html#a5456ecd630d55c91b2fd1b19969d29f5":[5,0,1,24,90],
-"class_ogre_1_1_item.html#a54fc365f16014359d23cecf859da5510":[5,0,1,24,34],
 "class_ogre_1_1_item.html#a54fc365f16014359d23cecf859da5510":[5,2,12,24,34],
-"class_ogre_1_1_item.html#a55237a2e03c449e5c3c62858e61d5494":[5,2,12,24,4],
+"class_ogre_1_1_item.html#a54fc365f16014359d23cecf859da5510":[5,0,1,24,34],
 "class_ogre_1_1_item.html#a55237a2e03c449e5c3c62858e61d5494":[5,0,1,24,4],
-"class_ogre_1_1_item.html#a57123ae4fec1b472f25270c1dd6abe59":[5,2,12,24,12],
+"class_ogre_1_1_item.html#a55237a2e03c449e5c3c62858e61d5494":[5,2,12,24,4],
 "class_ogre_1_1_item.html#a57123ae4fec1b472f25270c1dd6abe59":[5,0,1,24,12],
-"class_ogre_1_1_item.html#a5735d8e15f75f73003543a0fb600f1d3":[5,0,1,24,86],
+"class_ogre_1_1_item.html#a57123ae4fec1b472f25270c1dd6abe59":[5,2,12,24,12],
 "class_ogre_1_1_item.html#a5735d8e15f75f73003543a0fb600f1d3":[5,2,12,24,86],
-"class_ogre_1_1_item.html#a57e0523432c6e5133ff4fc251111a60e":[5,0,1,24,77],
+"class_ogre_1_1_item.html#a5735d8e15f75f73003543a0fb600f1d3":[5,0,1,24,86],
 "class_ogre_1_1_item.html#a57e0523432c6e5133ff4fc251111a60e":[5,2,12,24,77],
-"class_ogre_1_1_item.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,24,71],
+"class_ogre_1_1_item.html#a57e0523432c6e5133ff4fc251111a60e":[5,0,1,24,77],
 "class_ogre_1_1_item.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,24,71],
+"class_ogre_1_1_item.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,24,71],
 "class_ogre_1_1_item.html#a59fad8564d612b23eaef3489bca32f51":[5,0,1,24,110],
 "class_ogre_1_1_item.html#a59fad8564d612b23eaef3489bca32f51":[5,2,12,24,110],
 "class_ogre_1_1_item.html#a5f7b365da61eba227c468681e0fb1cde":[5,0,1,24,25],
 "class_ogre_1_1_item.html#a5f7b365da61eba227c468681e0fb1cde":[5,2,12,24,25],
 "class_ogre_1_1_item.html#a61b39d44e60020d43033a6957895aa5f":[5,0,1,24,24],
 "class_ogre_1_1_item.html#a61b39d44e60020d43033a6957895aa5f":[5,2,12,24,24],
-"class_ogre_1_1_item.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,24,74],
 "class_ogre_1_1_item.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,24,74],
-"class_ogre_1_1_item.html#a64bd61f33ae8a2d4e824ce7e23308d98":[5,2,12,24,18],
+"class_ogre_1_1_item.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,24,74],
 "class_ogre_1_1_item.html#a64bd61f33ae8a2d4e824ce7e23308d98":[5,0,1,24,18],
-"class_ogre_1_1_item.html#a6542bed916c367c49675fe193708b805":[5,2,12,24,85],
+"class_ogre_1_1_item.html#a64bd61f33ae8a2d4e824ce7e23308d98":[5,2,12,24,18],
 "class_ogre_1_1_item.html#a6542bed916c367c49675fe193708b805":[5,0,1,24,85],
-"class_ogre_1_1_item.html#a67415cb80794ff8ba8debfdae5c5fbdf":[5,2,12,24,109],
+"class_ogre_1_1_item.html#a6542bed916c367c49675fe193708b805":[5,2,12,24,85],
 "class_ogre_1_1_item.html#a67415cb80794ff8ba8debfdae5c5fbdf":[5,0,1,24,109],
-"class_ogre_1_1_item.html#a6944af26e8944b13756ade50cd1092d8":[5,2,12,24,35],
-"class_ogre_1_1_item.html#a6944af26e8944b13756ade50cd1092d8":[5,0,1,24,35],
-"class_ogre_1_1_item.html#a6b823b52684730302908ecfd1a8e6d54":[5,2,12,24,16]
+"class_ogre_1_1_item.html#a67415cb80794ff8ba8debfdae5c5fbdf":[5,2,12,24,109],
+"class_ogre_1_1_item.html#a6944af26e8944b13756ade50cd1092d8":[5,2,12,24,35]
 };
