@@ -1,8 +1,10 @@
 var NAVTREEINDEX138 =
 {
+"class_ogre_1_1_kf_transform_array_memory_manager.html#a81ef5397bd517180f3f0e88f9a78633f":[6,0,0,582,5],
 "class_ogre_1_1_kf_transform_array_memory_manager.html#a8c128b8ba585ecb04205e81d2aa2c341":[6,0,0,582,7],
-"class_ogre_1_1_kf_transform_array_memory_manager.html#aa59979265f37644b7b411c1c186412a0":[7,0,0,555,6],
+"class_ogre_1_1_kf_transform_array_memory_manager.html#a8c128b8ba585ecb04205e81d2aa2c341":[7,0,0,555,7],
 "class_ogre_1_1_kf_transform_array_memory_manager.html#aa59979265f37644b7b411c1c186412a0":[6,0,0,582,6],
+"class_ogre_1_1_kf_transform_array_memory_manager.html#aa59979265f37644b7b411c1c186412a0":[7,0,0,555,6],
 "class_ogre_1_1_kf_transform_array_memory_manager.html#aac88868dab1629f0becfe78f25f27426":[7,0,0,555,0],
 "class_ogre_1_1_kf_transform_array_memory_manager.html#aac88868dab1629f0becfe78f25f27426":[6,0,0,582,0],
 "class_ogre_1_1_kf_transform_array_memory_manager.html#ac639db8f3c078fa02ceb2691d4b86065":[6,0,0,582,8],
@@ -27,28 +29,28 @@ var NAVTREEINDEX138 =
 "class_ogre_1_1_layer_blend_mode_ex.html#afc151f1c17683cd99df776459df2c778":[5,2,5,13,8],
 "class_ogre_1_1_light.html":[5,2,12,26],
 "class_ogre_1_1_light.html":[5,0,1,26],
-"class_ogre_1_1_light.html#a015c3801632c98bca5dbb5aa3da1aa24":[5,0,1,26,40],
 "class_ogre_1_1_light.html#a015c3801632c98bca5dbb5aa3da1aa24":[5,2,12,26,40],
-"class_ogre_1_1_light.html#a01f48775e48b672d7796311f3ffe2930":[5,0,1,26,45],
+"class_ogre_1_1_light.html#a015c3801632c98bca5dbb5aa3da1aa24":[5,0,1,26,40],
 "class_ogre_1_1_light.html#a01f48775e48b672d7796311f3ffe2930":[5,2,12,26,45],
-"class_ogre_1_1_light.html#a04c17999a4050f4c9aebc1df19a4ff66":[5,0,1,26,158],
+"class_ogre_1_1_light.html#a01f48775e48b672d7796311f3ffe2930":[5,0,1,26,45],
 "class_ogre_1_1_light.html#a04c17999a4050f4c9aebc1df19a4ff66":[5,2,12,26,158],
+"class_ogre_1_1_light.html#a04c17999a4050f4c9aebc1df19a4ff66":[5,0,1,26,158],
 "class_ogre_1_1_light.html#a0555108e060be64b83dc9cf75e8cf85d":[5,2,12,26,31],
 "class_ogre_1_1_light.html#a0555108e060be64b83dc9cf75e8cf85d":[5,0,1,26,31],
 "class_ogre_1_1_light.html#a074b1b671ccfcd0883155be8ab439b17":[5,0,1,26,95],
 "class_ogre_1_1_light.html#a074b1b671ccfcd0883155be8ab439b17":[5,2,12,26,95],
 "class_ogre_1_1_light.html#a07c50eb182b14e404d34c3a1bcae9664":[5,2,12,26,139],
 "class_ogre_1_1_light.html#a07c50eb182b14e404d34c3a1bcae9664":[5,0,1,26,139],
-"class_ogre_1_1_light.html#a0a7c23a753bf2c7b1ded3b6b874a82a5":[5,2,12,26,7],
 "class_ogre_1_1_light.html#a0a7c23a753bf2c7b1ded3b6b874a82a5":[5,0,1,26,7],
+"class_ogre_1_1_light.html#a0a7c23a753bf2c7b1ded3b6b874a82a5":[5,2,12,26,7],
 "class_ogre_1_1_light.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[5,0,1,26,107],
 "class_ogre_1_1_light.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[5,2,12,26,107],
 "class_ogre_1_1_light.html#a0b335a53572a929e720e563b2f45b72c":[5,2,12,26,111],
 "class_ogre_1_1_light.html#a0b335a53572a929e720e563b2f45b72c":[5,0,1,26,111],
-"class_ogre_1_1_light.html#a11d3640138e32ff2d4644dadf5e24c74":[5,2,12,26,51],
 "class_ogre_1_1_light.html#a11d3640138e32ff2d4644dadf5e24c74":[5,0,1,26,51],
-"class_ogre_1_1_light.html#a13629b96b4a6b0b34f652234f037d8d9":[5,0,1,26,89],
+"class_ogre_1_1_light.html#a11d3640138e32ff2d4644dadf5e24c74":[5,2,12,26,51],
 "class_ogre_1_1_light.html#a13629b96b4a6b0b34f652234f037d8d9":[5,2,12,26,89],
+"class_ogre_1_1_light.html#a13629b96b4a6b0b34f652234f037d8d9":[5,0,1,26,89],
 "class_ogre_1_1_light.html#a1427f0b635a4186cd6083a9bab879fa2":[5,2,12,26,151],
 "class_ogre_1_1_light.html#a1427f0b635a4186cd6083a9bab879fa2":[5,0,1,26,151],
 "class_ogre_1_1_light.html#a164483d42186628f7e14833b2df7a7a7":[5,0,1,26,67],
@@ -59,92 +61,92 @@ var NAVTREEINDEX138 =
 "class_ogre_1_1_light.html#a19bf2951b97744064509c13068143f3d":[5,0,1,26,85],
 "class_ogre_1_1_light.html#a1a048b8ace0a21cd2ed2c3008941ce3d":[5,2,12,26,44],
 "class_ogre_1_1_light.html#a1a048b8ace0a21cd2ed2c3008941ce3d":[5,0,1,26,44],
-"class_ogre_1_1_light.html#a1a93c6cee2acca8aaf140e0430a1edce":[5,0,1,26,33],
 "class_ogre_1_1_light.html#a1a93c6cee2acca8aaf140e0430a1edce":[5,2,12,26,33],
-"class_ogre_1_1_light.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,26,98],
+"class_ogre_1_1_light.html#a1a93c6cee2acca8aaf140e0430a1edce":[5,0,1,26,33],
 "class_ogre_1_1_light.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,26,98],
-"class_ogre_1_1_light.html#a1cab92f6d67cb87f2ca99d04e897093c":[5,2,12,26,120],
+"class_ogre_1_1_light.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,26,98],
 "class_ogre_1_1_light.html#a1cab92f6d67cb87f2ca99d04e897093c":[5,0,1,26,120],
-"class_ogre_1_1_light.html#a20900182d64a3aebaddbb34e9717badc":[5,2,12,26,80],
+"class_ogre_1_1_light.html#a1cab92f6d67cb87f2ca99d04e897093c":[5,2,12,26,120],
 "class_ogre_1_1_light.html#a20900182d64a3aebaddbb34e9717badc":[5,0,1,26,80],
-"class_ogre_1_1_light.html#a20ef8a0dc69223d29971f00a90bf5b35":[5,2,12,26,79],
+"class_ogre_1_1_light.html#a20900182d64a3aebaddbb34e9717badc":[5,2,12,26,80],
 "class_ogre_1_1_light.html#a20ef8a0dc69223d29971f00a90bf5b35":[5,0,1,26,79],
-"class_ogre_1_1_light.html#a2356327c5a908a82f8656996ed43f67a":[5,2,12,26,47],
+"class_ogre_1_1_light.html#a20ef8a0dc69223d29971f00a90bf5b35":[5,2,12,26,79],
 "class_ogre_1_1_light.html#a2356327c5a908a82f8656996ed43f67a":[5,0,1,26,47],
+"class_ogre_1_1_light.html#a2356327c5a908a82f8656996ed43f67a":[5,2,12,26,47],
 "class_ogre_1_1_light.html#a27eb8980ee187b42ea619c582eaebf73":[5,2,12,26,84],
 "class_ogre_1_1_light.html#a27eb8980ee187b42ea619c582eaebf73":[5,0,1,26,84],
 "class_ogre_1_1_light.html#a2880f26669477a55cf01919f906bb65d":[5,0,1,26,113],
 "class_ogre_1_1_light.html#a2880f26669477a55cf01919f906bb65d":[5,2,12,26,113],
-"class_ogre_1_1_light.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[5,2,12,26,149],
 "class_ogre_1_1_light.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[5,0,1,26,149],
+"class_ogre_1_1_light.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[5,2,12,26,149],
 "class_ogre_1_1_light.html#a2c43bfbf959d7b0c0680c79ad3469bfb":[5,2,12,26,19],
 "class_ogre_1_1_light.html#a2c43bfbf959d7b0c0680c79ad3469bfb":[5,0,1,26,19],
-"class_ogre_1_1_light.html#a2d62d2c3d09910210c948fc660468c46":[5,2,12,26,91],
 "class_ogre_1_1_light.html#a2d62d2c3d09910210c948fc660468c46":[5,0,1,26,91],
-"class_ogre_1_1_light.html#a2e3e690195e9d7e14c6ad4e1fe7ba9e5":[5,2,12,26,93],
+"class_ogre_1_1_light.html#a2d62d2c3d09910210c948fc660468c46":[5,2,12,26,91],
 "class_ogre_1_1_light.html#a2e3e690195e9d7e14c6ad4e1fe7ba9e5":[5,0,1,26,93],
+"class_ogre_1_1_light.html#a2e3e690195e9d7e14c6ad4e1fe7ba9e5":[5,2,12,26,93],
 "class_ogre_1_1_light.html#a2e562e3231d1ebdbebb009b5d4bc9af4":[5,0,1,26,3],
 "class_ogre_1_1_light.html#a2e562e3231d1ebdbebb009b5d4bc9af4":[5,2,12,26,3],
 "class_ogre_1_1_light.html#a2eb94fea5944cf0d33702a75cfa14a74":[5,0,1,26,46],
 "class_ogre_1_1_light.html#a2eb94fea5944cf0d33702a75cfa14a74":[5,2,12,26,46],
-"class_ogre_1_1_light.html#a30acf249cd312d9eed03a0f3ad618067":[5,2,12,26,57],
 "class_ogre_1_1_light.html#a30acf249cd312d9eed03a0f3ad618067":[5,0,1,26,57],
+"class_ogre_1_1_light.html#a30acf249cd312d9eed03a0f3ad618067":[5,2,12,26,57],
 "class_ogre_1_1_light.html#a3243b2bb1fed56341351bf97b9a9a492":[5,0,1,26,48],
 "class_ogre_1_1_light.html#a3243b2bb1fed56341351bf97b9a9a492":[5,2,12,26,48],
-"class_ogre_1_1_light.html#a332b43da87b897dee7c36d6f4fdd3a7b":[5,0,1,26,55],
 "class_ogre_1_1_light.html#a332b43da87b897dee7c36d6f4fdd3a7b":[5,2,12,26,55],
-"class_ogre_1_1_light.html#a35b519fd7cbbee4b8dc8ef7c1e526ba3":[5,0,1,26,58],
+"class_ogre_1_1_light.html#a332b43da87b897dee7c36d6f4fdd3a7b":[5,0,1,26,55],
 "class_ogre_1_1_light.html#a35b519fd7cbbee4b8dc8ef7c1e526ba3":[5,2,12,26,58],
+"class_ogre_1_1_light.html#a35b519fd7cbbee4b8dc8ef7c1e526ba3":[5,0,1,26,58],
 "class_ogre_1_1_light.html#a37f518126915aa920a8b6a70d632d5ee":[5,0,1,26,130],
 "class_ogre_1_1_light.html#a37f518126915aa920a8b6a70d632d5ee":[5,2,12,26,130],
-"class_ogre_1_1_light.html#a38f8241458458e4f1235eae7d8f850c3":[5,2,12,26,145],
 "class_ogre_1_1_light.html#a38f8241458458e4f1235eae7d8f850c3":[5,0,1,26,145],
-"class_ogre_1_1_light.html#a42fedb6f221a6712b1c21849fb650819":[5,2,12,26,59],
+"class_ogre_1_1_light.html#a38f8241458458e4f1235eae7d8f850c3":[5,2,12,26,145],
 "class_ogre_1_1_light.html#a42fedb6f221a6712b1c21849fb650819":[5,0,1,26,59],
+"class_ogre_1_1_light.html#a42fedb6f221a6712b1c21849fb650819":[5,2,12,26,59],
 "class_ogre_1_1_light.html#a4569b91ce5341ab892f74ab4555cac7d":[5,2,12,26,68],
 "class_ogre_1_1_light.html#a4569b91ce5341ab892f74ab4555cac7d":[5,0,1,26,68],
 "class_ogre_1_1_light.html#a4a40a12d7cd0f7fa4c4c0fc31bbf9a40":[5,0,1,26,108],
 "class_ogre_1_1_light.html#a4a40a12d7cd0f7fa4c4c0fc31bbf9a40":[5,2,12,26,108],
-"class_ogre_1_1_light.html#a4c29a048d9254c17c43a9fa313df0a6b":[5,2,12,26,13],
 "class_ogre_1_1_light.html#a4c29a048d9254c17c43a9fa313df0a6b":[5,0,1,26,13],
+"class_ogre_1_1_light.html#a4c29a048d9254c17c43a9fa313df0a6b":[5,2,12,26,13],
 "class_ogre_1_1_light.html#a4d43f57e9abcc21d4bc50e6e6d1b5cc7":[5,0,1,26,132],
 "class_ogre_1_1_light.html#a4d43f57e9abcc21d4bc50e6e6d1b5cc7":[5,2,12,26,132],
 "class_ogre_1_1_light.html#a4e4899f7a0b1ecc5e37fe135bb37bec7":[5,0,1,26,34],
 "class_ogre_1_1_light.html#a4e4899f7a0b1ecc5e37fe135bb37bec7":[5,2,12,26,34],
 "class_ogre_1_1_light.html#a4e8ebf22380f3c76cd7e901dac362abb":[5,2,12,26,116],
 "class_ogre_1_1_light.html#a4e8ebf22380f3c76cd7e901dac362abb":[5,0,1,26,116],
-"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbc":[5,2,12,26,1],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbc":[5,0,1,26,1],
+"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbc":[5,2,12,26,1],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca0d59bfdcfeb338dbfe06e2e2999e752f":[5,2,12,26,1,1],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca0d59bfdcfeb338dbfe06e2e2999e752f":[5,0,1,26,1,1],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca28725f65eb27dedd10c97848ca3188e2":[5,2,12,26,1,6],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca28725f65eb27dedd10c97848ca3188e2":[5,0,1,26,1,6],
-"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca4c5582d28848ce40c2b652488494b4a3":[5,2,12,26,1,0],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca4c5582d28848ce40c2b652488494b4a3":[5,0,1,26,1,0],
-"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca6b85e19aa8243a75424e990d0c22e596":[5,2,12,26,1,3],
+"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca4c5582d28848ce40c2b652488494b4a3":[5,2,12,26,1,0],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca6b85e19aa8243a75424e990d0c22e596":[5,0,1,26,1,3],
-"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca82096faf2c3e88def5977c8520a09794":[5,0,1,26,1,4],
+"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca6b85e19aa8243a75424e990d0c22e596":[5,2,12,26,1,3],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca82096faf2c3e88def5977c8520a09794":[5,2,12,26,1,4],
+"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca82096faf2c3e88def5977c8520a09794":[5,0,1,26,1,4],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca8fc40a1ccfb026944417ef92b7ddaefe":[5,2,12,26,1,2],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca8fc40a1ccfb026944417ef92b7ddaefe":[5,0,1,26,1,2],
-"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca90fd73505abfc3ebfa47c8571ca55b18":[5,2,12,26,1,7],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca90fd73505abfc3ebfa47c8571ca55b18":[5,0,1,26,1,7],
-"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbcaf7bed0743d1dfef2117f8c21dd51e91e":[5,0,1,26,1,5],
+"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbca90fd73505abfc3ebfa47c8571ca55b18":[5,2,12,26,1,7],
 "class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbcaf7bed0743d1dfef2117f8c21dd51e91e":[5,2,12,26,1,5],
-"class_ogre_1_1_light.html#a504e2192036f75007c51e157315e1548":[5,0,1,26,110],
+"class_ogre_1_1_light.html#a4f1dea084d1497c6f49e802ade940dbcaf7bed0743d1dfef2117f8c21dd51e91e":[5,0,1,26,1,5],
 "class_ogre_1_1_light.html#a504e2192036f75007c51e157315e1548":[5,2,12,26,110],
+"class_ogre_1_1_light.html#a504e2192036f75007c51e157315e1548":[5,0,1,26,110],
 "class_ogre_1_1_light.html#a5456ecd630d55c91b2fd1b19969d29f5":[5,0,1,26,124],
 "class_ogre_1_1_light.html#a5456ecd630d55c91b2fd1b19969d29f5":[5,2,12,26,124],
 "class_ogre_1_1_light.html#a54fc365f16014359d23cecf859da5510":[5,2,12,26,54],
 "class_ogre_1_1_light.html#a54fc365f16014359d23cecf859da5510":[5,0,1,26,54],
-"class_ogre_1_1_light.html#a55237a2e03c449e5c3c62858e61d5494":[5,0,1,26,9],
 "class_ogre_1_1_light.html#a55237a2e03c449e5c3c62858e61d5494":[5,2,12,26,9],
+"class_ogre_1_1_light.html#a55237a2e03c449e5c3c62858e61d5494":[5,0,1,26,9],
 "class_ogre_1_1_light.html#a55cda420f991dcb9cfc8ccb56fc227b0":[5,2,12,26,77],
 "class_ogre_1_1_light.html#a55cda420f991dcb9cfc8ccb56fc227b0":[5,0,1,26,77],
-"class_ogre_1_1_light.html#a57123ae4fec1b472f25270c1dd6abe59":[5,0,1,26,17],
 "class_ogre_1_1_light.html#a57123ae4fec1b472f25270c1dd6abe59":[5,2,12,26,17],
-"class_ogre_1_1_light.html#a57d11f3d9ff77b0318d72d639342047f":[5,0,1,26,65],
+"class_ogre_1_1_light.html#a57123ae4fec1b472f25270c1dd6abe59":[5,0,1,26,17],
 "class_ogre_1_1_light.html#a57d11f3d9ff77b0318d72d639342047f":[5,2,12,26,65],
+"class_ogre_1_1_light.html#a57d11f3d9ff77b0318d72d639342047f":[5,0,1,26,65],
 "class_ogre_1_1_light.html#a57e0523432c6e5133ff4fc251111a60e":[5,0,1,26,106],
 "class_ogre_1_1_light.html#a57e0523432c6e5133ff4fc251111a60e":[5,2,12,26,106],
 "class_ogre_1_1_light.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,26,100],
@@ -153,14 +155,14 @@ var NAVTREEINDEX138 =
 "class_ogre_1_1_light.html#a5a38124467ef557f7f93487407caf069":[5,2,12,26,21],
 "class_ogre_1_1_light.html#a5f7b365da61eba227c468681e0fb1cde":[5,2,12,26,32],
 "class_ogre_1_1_light.html#a5f7b365da61eba227c468681e0fb1cde":[5,0,1,26,32],
-"class_ogre_1_1_light.html#a6019f7fa89624e35316ba444e519d8f8":[5,2,12,26,148],
 "class_ogre_1_1_light.html#a6019f7fa89624e35316ba444e519d8f8":[5,0,1,26,148],
+"class_ogre_1_1_light.html#a6019f7fa89624e35316ba444e519d8f8":[5,2,12,26,148],
 "class_ogre_1_1_light.html#a614988755dcedf910f7df90fafe6158e":[5,0,1,26,138],
 "class_ogre_1_1_light.html#a614988755dcedf910f7df90fafe6158e":[5,2,12,26,138],
 "class_ogre_1_1_light.html#a61b39d44e60020d43033a6957895aa5f":[5,2,12,26,30],
 "class_ogre_1_1_light.html#a61b39d44e60020d43033a6957895aa5f":[5,0,1,26,30],
-"class_ogre_1_1_light.html#a61ce8158c2eda6a08b884c56bc811783":[5,0,1,26,114],
 "class_ogre_1_1_light.html#a61ce8158c2eda6a08b884c56bc811783":[5,2,12,26,114],
+"class_ogre_1_1_light.html#a61ce8158c2eda6a08b884c56bc811783":[5,0,1,26,114],
 "class_ogre_1_1_light.html#a6372e140e51cab8406adcffefe46a9f5":[5,2,12,26,76],
 "class_ogre_1_1_light.html#a6372e140e51cab8406adcffefe46a9f5":[5,0,1,26,76],
 "class_ogre_1_1_light.html#a63ea738c19ed36e7c0a160585095e9ef":[5,2,12,26,70],
@@ -169,74 +171,74 @@ var NAVTREEINDEX138 =
 "class_ogre_1_1_light.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,26,103],
 "class_ogre_1_1_light.html#a64bd61f33ae8a2d4e824ce7e23308d98":[5,0,1,26,25],
 "class_ogre_1_1_light.html#a64bd61f33ae8a2d4e824ce7e23308d98":[5,2,12,26,25],
-"class_ogre_1_1_light.html#a68adbcfd66dbe03705a046f383ce587f":[5,0,1,26,81],
 "class_ogre_1_1_light.html#a68adbcfd66dbe03705a046f383ce587f":[5,2,12,26,81],
-"class_ogre_1_1_light.html#a6944af26e8944b13756ade50cd1092d8":[5,2,12,26,56],
+"class_ogre_1_1_light.html#a68adbcfd66dbe03705a046f383ce587f":[5,0,1,26,81],
 "class_ogre_1_1_light.html#a6944af26e8944b13756ade50cd1092d8":[5,0,1,26,56],
-"class_ogre_1_1_light.html#a6b0962ead2b2a699af0d2b564450e5ae":[5,0,1,26,5],
+"class_ogre_1_1_light.html#a6944af26e8944b13756ade50cd1092d8":[5,2,12,26,56],
 "class_ogre_1_1_light.html#a6b0962ead2b2a699af0d2b564450e5ae":[5,2,12,26,5],
-"class_ogre_1_1_light.html#a6b823b52684730302908ecfd1a8e6d54":[5,0,1,26,23],
+"class_ogre_1_1_light.html#a6b0962ead2b2a699af0d2b564450e5ae":[5,0,1,26,5],
 "class_ogre_1_1_light.html#a6b823b52684730302908ecfd1a8e6d54":[5,2,12,26,23],
+"class_ogre_1_1_light.html#a6b823b52684730302908ecfd1a8e6d54":[5,0,1,26,23],
 "class_ogre_1_1_light.html#a6c4003f6b67540727844dc33c20714f7":[5,2,12,26,94],
 "class_ogre_1_1_light.html#a6c4003f6b67540727844dc33c20714f7":[5,0,1,26,94],
 "class_ogre_1_1_light.html#a6d84ea02ea0ad4f27fb1c2aeebcbc6e8":[5,0,1,26,75],
 "class_ogre_1_1_light.html#a6d84ea02ea0ad4f27fb1c2aeebcbc6e8":[5,2,12,26,75],
-"class_ogre_1_1_light.html#a6e0be3df5d41752c0bedfcf9c89e492b":[5,0,1,26,27],
 "class_ogre_1_1_light.html#a6e0be3df5d41752c0bedfcf9c89e492b":[5,2,12,26,27],
-"class_ogre_1_1_light.html#a6fb94e1627676c7d7517e13944bd0580":[5,2,12,26,109],
+"class_ogre_1_1_light.html#a6e0be3df5d41752c0bedfcf9c89e492b":[5,0,1,26,27],
 "class_ogre_1_1_light.html#a6fb94e1627676c7d7517e13944bd0580":[5,0,1,26,109],
+"class_ogre_1_1_light.html#a6fb94e1627676c7d7517e13944bd0580":[5,2,12,26,109],
 "class_ogre_1_1_light.html#a6ffba71e5b797689b61ff0e285449491":[5,2,12,26,72],
 "class_ogre_1_1_light.html#a6ffba71e5b797689b61ff0e285449491":[5,0,1,26,72],
 "class_ogre_1_1_light.html#a7241fd29a548973d1d2fa56bcc9f13a4":[5,2,12,26,12],
 "class_ogre_1_1_light.html#a7241fd29a548973d1d2fa56bcc9f13a4":[5,0,1,26,12],
-"class_ogre_1_1_light.html#a77198e02dd65dd368ea4e6af88a93fda":[5,2,12,26,129],
 "class_ogre_1_1_light.html#a77198e02dd65dd368ea4e6af88a93fda":[5,0,1,26,129],
-"class_ogre_1_1_light.html#a7c3bff2a6922bbc098c789e9386140e3":[5,2,12,26,153],
+"class_ogre_1_1_light.html#a77198e02dd65dd368ea4e6af88a93fda":[5,2,12,26,129],
 "class_ogre_1_1_light.html#a7c3bff2a6922bbc098c789e9386140e3":[5,0,1,26,153],
+"class_ogre_1_1_light.html#a7c3bff2a6922bbc098c789e9386140e3":[5,2,12,26,153],
 "class_ogre_1_1_light.html#a7c633da32362e05bd24871c7a612fdac":[5,0,1,26,39],
 "class_ogre_1_1_light.html#a7c633da32362e05bd24871c7a612fdac":[5,2,12,26,39],
 "class_ogre_1_1_light.html#a7cd15e3a5caae8ae786bd752c6b27f26":[5,2,12,26,137],
 "class_ogre_1_1_light.html#a7cd15e3a5caae8ae786bd752c6b27f26":[5,0,1,26,137],
-"class_ogre_1_1_light.html#a7d491859c987cf03cd2b62121e9bfea0":[5,0,1,26,28],
 "class_ogre_1_1_light.html#a7d491859c987cf03cd2b62121e9bfea0":[5,2,12,26,28],
+"class_ogre_1_1_light.html#a7d491859c987cf03cd2b62121e9bfea0":[5,0,1,26,28],
 "class_ogre_1_1_light.html#a83464478d3db0b92d4d81071ba015e01":[5,0,1,26,11],
 "class_ogre_1_1_light.html#a83464478d3db0b92d4d81071ba015e01":[5,2,12,26,11],
-"class_ogre_1_1_light.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,26,96],
 "class_ogre_1_1_light.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,26,96],
-"class_ogre_1_1_light.html#a8588796e58389701c22fb8e5c62a080e":[5,0,1,26,128],
+"class_ogre_1_1_light.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,26,96],
 "class_ogre_1_1_light.html#a8588796e58389701c22fb8e5c62a080e":[5,2,12,26,128],
+"class_ogre_1_1_light.html#a8588796e58389701c22fb8e5c62a080e":[5,0,1,26,128],
 "class_ogre_1_1_light.html#a862e7d3af40ee31de2f95a626207f96d":[5,2,12,26,8],
 "class_ogre_1_1_light.html#a862e7d3af40ee31de2f95a626207f96d":[5,0,1,26,8],
 "class_ogre_1_1_light.html#a863bac56e5c968767e811816376d3ce5":[5,2,12,26,38],
 "class_ogre_1_1_light.html#a863bac56e5c968767e811816376d3ce5":[5,0,1,26,38],
 "class_ogre_1_1_light.html#a865cb46cc09cbb8bd560abeca1d0d31e":[5,2,12,26,14],
 "class_ogre_1_1_light.html#a865cb46cc09cbb8bd560abeca1d0d31e":[5,0,1,26,14],
-"class_ogre_1_1_light.html#a8b09bac9505986355e0e18ca31d67c6d":[5,2,12,26,157],
 "class_ogre_1_1_light.html#a8b09bac9505986355e0e18ca31d67c6d":[5,0,1,26,157],
-"class_ogre_1_1_light.html#a8d2bda146778c180dc55224bfffe5bed":[5,2,12,26,52],
+"class_ogre_1_1_light.html#a8b09bac9505986355e0e18ca31d67c6d":[5,2,12,26,157],
 "class_ogre_1_1_light.html#a8d2bda146778c180dc55224bfffe5bed":[5,0,1,26,52],
+"class_ogre_1_1_light.html#a8d2bda146778c180dc55224bfffe5bed":[5,2,12,26,52],
 "class_ogre_1_1_light.html#a8ef06bd9c2e7113461c50c83c5f09fe9":[5,0,1,26,144],
 "class_ogre_1_1_light.html#a8ef06bd9c2e7113461c50c83c5f09fe9":[5,2,12,26,144],
 "class_ogre_1_1_light.html#a8ef572fd5d20b366328cbdb0eb71b4a0":[5,2,12,26,82],
 "class_ogre_1_1_light.html#a8ef572fd5d20b366328cbdb0eb71b4a0":[5,0,1,26,82],
-"class_ogre_1_1_light.html#a91a8c7867631ecda45eb934bfaf0aff1":[5,0,1,26,136],
 "class_ogre_1_1_light.html#a91a8c7867631ecda45eb934bfaf0aff1":[5,2,12,26,136],
-"class_ogre_1_1_light.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,26,99],
+"class_ogre_1_1_light.html#a91a8c7867631ecda45eb934bfaf0aff1":[5,0,1,26,136],
 "class_ogre_1_1_light.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,26,99],
-"class_ogre_1_1_light.html#a97143cbcc65f87597c491e566d793c32":[5,2,12,26,6],
+"class_ogre_1_1_light.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,26,99],
 "class_ogre_1_1_light.html#a97143cbcc65f87597c491e566d793c32":[5,0,1,26,6],
-"class_ogre_1_1_light.html#a98fe88f82f86eafa19308074495db809":[5,0,1,26,22],
+"class_ogre_1_1_light.html#a97143cbcc65f87597c491e566d793c32":[5,2,12,26,6],
 "class_ogre_1_1_light.html#a98fe88f82f86eafa19308074495db809":[5,2,12,26,22],
-"class_ogre_1_1_light.html#a9a62a4a12787812f012691af0c3493f1":[5,0,1,26,117],
+"class_ogre_1_1_light.html#a98fe88f82f86eafa19308074495db809":[5,0,1,26,22],
 "class_ogre_1_1_light.html#a9a62a4a12787812f012691af0c3493f1":[5,2,12,26,117],
+"class_ogre_1_1_light.html#a9a62a4a12787812f012691af0c3493f1":[5,0,1,26,117],
 "class_ogre_1_1_light.html#a9a72ade896561e23c32cf8659f1640e4":[5,0,1,26,87],
 "class_ogre_1_1_light.html#a9a72ade896561e23c32cf8659f1640e4":[5,2,12,26,87],
-"class_ogre_1_1_light.html#a9b4832d473cacad1614494419ffe807f":[5,0,1,26,61],
 "class_ogre_1_1_light.html#a9b4832d473cacad1614494419ffe807f":[5,2,12,26,61],
+"class_ogre_1_1_light.html#a9b4832d473cacad1614494419ffe807f":[5,0,1,26,61],
 "class_ogre_1_1_light.html#a9b67c869ff417a54178b4406a8082144":[5,0,1,26,37],
 "class_ogre_1_1_light.html#a9b67c869ff417a54178b4406a8082144":[5,2,12,26,37],
-"class_ogre_1_1_light.html#aa47b4c48c6f868811bd64cee42097ca3":[5,0,1,26,123],
 "class_ogre_1_1_light.html#aa47b4c48c6f868811bd64cee42097ca3":[5,2,12,26,123],
+"class_ogre_1_1_light.html#aa47b4c48c6f868811bd64cee42097ca3":[5,0,1,26,123],
 "class_ogre_1_1_light.html#aa6978865a8a995606fe9f82eb66002af":[5,2,12,26,35],
 "class_ogre_1_1_light.html#aa6978865a8a995606fe9f82eb66002af":[5,0,1,26,35],
 "class_ogre_1_1_light.html#aa6ae8d976be50b007ba1e87732a6397d":[5,2,12,26,83],
@@ -247,7 +249,5 @@ var NAVTREEINDEX138 =
 "class_ogre_1_1_light.html#aaa6e49d21586b363c4d40a87407be38b":[5,0,1,26,63],
 "class_ogre_1_1_light.html#aad9369e62c971d55ca75b7b294c50944":[5,2,12,26,155],
 "class_ogre_1_1_light.html#aad9369e62c971d55ca75b7b294c50944":[5,0,1,26,155],
-"class_ogre_1_1_light.html#aaf2c5dfccfad0c80316c9d55ecc07e99":[5,2,12,26,71],
-"class_ogre_1_1_light.html#aaf2c5dfccfad0c80316c9d55ecc07e99":[5,0,1,26,71],
-"class_ogre_1_1_light.html#ab1014fe5901c78f1b51f00227a6d9f84":[5,2,12,26,42]
+"class_ogre_1_1_light.html#aaf2c5dfccfad0c80316c9d55ecc07e99":[5,2,12,26,71]
 };
