@@ -1,80 +1,82 @@
 var NAVTREEINDEX139 =
 {
+"class_ogre_1_1_light.html#aaf2c5dfccfad0c80316c9d55ecc07e99":[5,0,1,26,71],
+"class_ogre_1_1_light.html#ab1014fe5901c78f1b51f00227a6d9f84":[5,2,12,26,42],
 "class_ogre_1_1_light.html#ab1014fe5901c78f1b51f00227a6d9f84":[5,0,1,26,42],
 "class_ogre_1_1_light.html#ab152c8f646a835c2f88585ad4fe0413a":[5,2,12,26,53],
 "class_ogre_1_1_light.html#ab152c8f646a835c2f88585ad4fe0413a":[5,0,1,26,53],
 "class_ogre_1_1_light.html#ab2d58aba9bb1591a393a4a23f4a89142":[5,0,1,26,73],
 "class_ogre_1_1_light.html#ab2d58aba9bb1591a393a4a23f4a89142":[5,2,12,26,73],
-"class_ogre_1_1_light.html#ab3fe0289fbcabb17897c53445fa29339":[5,0,1,26,16],
 "class_ogre_1_1_light.html#ab3fe0289fbcabb17897c53445fa29339":[5,2,12,26,16],
-"class_ogre_1_1_light.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,26,102],
+"class_ogre_1_1_light.html#ab3fe0289fbcabb17897c53445fa29339":[5,0,1,26,16],
 "class_ogre_1_1_light.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,26,102],
-"class_ogre_1_1_light.html#ab55eab7ca8e96a3bbb3f69a4095bf067":[5,0,1,26,125],
+"class_ogre_1_1_light.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,26,102],
 "class_ogre_1_1_light.html#ab55eab7ca8e96a3bbb3f69a4095bf067":[5,2,12,26,125],
-"class_ogre_1_1_light.html#ab703ec1f1cf82763b0ac9c4b1e51a17b":[5,0,1,26,156],
+"class_ogre_1_1_light.html#ab55eab7ca8e96a3bbb3f69a4095bf067":[5,0,1,26,125],
 "class_ogre_1_1_light.html#ab703ec1f1cf82763b0ac9c4b1e51a17b":[5,2,12,26,156],
-"class_ogre_1_1_light.html#ab86b755f38ec01b52ed6a512d9d31ef9":[5,2,12,26,26],
+"class_ogre_1_1_light.html#ab703ec1f1cf82763b0ac9c4b1e51a17b":[5,0,1,26,156],
 "class_ogre_1_1_light.html#ab86b755f38ec01b52ed6a512d9d31ef9":[5,0,1,26,26],
+"class_ogre_1_1_light.html#ab86b755f38ec01b52ed6a512d9d31ef9":[5,2,12,26,26],
 "class_ogre_1_1_light.html#ab90b269de93324996df439355dd69dd2":[5,2,12,26,10],
 "class_ogre_1_1_light.html#ab90b269de93324996df439355dd69dd2":[5,0,1,26,10],
-"class_ogre_1_1_light.html#abcb1342c56f66f1959ca03441ba826ff":[5,0,1,26,60],
 "class_ogre_1_1_light.html#abcb1342c56f66f1959ca03441ba826ff":[5,2,12,26,60],
-"class_ogre_1_1_light.html#abd5561a07f78291e327351fe83e64a9b":[5,0,1,26,18],
+"class_ogre_1_1_light.html#abcb1342c56f66f1959ca03441ba826ff":[5,0,1,26,60],
 "class_ogre_1_1_light.html#abd5561a07f78291e327351fe83e64a9b":[5,2,12,26,18],
-"class_ogre_1_1_light.html#ac2904cb122ab8c8d5066abefb29dfa96":[5,0,1,26,119],
+"class_ogre_1_1_light.html#abd5561a07f78291e327351fe83e64a9b":[5,0,1,26,18],
 "class_ogre_1_1_light.html#ac2904cb122ab8c8d5066abefb29dfa96":[5,2,12,26,119],
+"class_ogre_1_1_light.html#ac2904cb122ab8c8d5066abefb29dfa96":[5,0,1,26,119],
 "class_ogre_1_1_light.html#ac4305df204604a027ca27ef77efff295":[5,2,12,26,24],
 "class_ogre_1_1_light.html#ac4305df204604a027ca27ef77efff295":[5,0,1,26,24],
-"class_ogre_1_1_light.html#ac4b8f3f72f7bf7a6bc20dd0677e125c1":[5,0,1,26,29],
 "class_ogre_1_1_light.html#ac4b8f3f72f7bf7a6bc20dd0677e125c1":[5,2,12,26,29],
+"class_ogre_1_1_light.html#ac4b8f3f72f7bf7a6bc20dd0677e125c1":[5,0,1,26,29],
 "class_ogre_1_1_light.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,26,97],
 "class_ogre_1_1_light.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,26,97],
 "class_ogre_1_1_light.html#acbfc4840224e8b6ed6e27849d3341675":[5,0,1,26,115],
 "class_ogre_1_1_light.html#acbfc4840224e8b6ed6e27849d3341675":[5,2,12,26,115],
-"class_ogre_1_1_light.html#ace79ed42960f5f2860b02bc408fbd767":[5,2,12,26,78],
 "class_ogre_1_1_light.html#ace79ed42960f5f2860b02bc408fbd767":[5,0,1,26,78],
+"class_ogre_1_1_light.html#ace79ed42960f5f2860b02bc408fbd767":[5,2,12,26,78],
 "class_ogre_1_1_light.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,26,101],
 "class_ogre_1_1_light.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,26,101],
 "class_ogre_1_1_light.html#ad23fd215ed54a72f90c2b1765dfa8cdb":[5,0,1,26,126],
 "class_ogre_1_1_light.html#ad23fd215ed54a72f90c2b1765dfa8cdb":[5,2,12,26,126],
 "class_ogre_1_1_light.html#ad2db241677e9fd1d48a3c97abeadfe07":[5,2,12,26,135],
 "class_ogre_1_1_light.html#ad2db241677e9fd1d48a3c97abeadfe07":[5,0,1,26,135],
-"class_ogre_1_1_light.html#ad42ba158cac70430c34f8a9eac94b237":[5,2,12,26,90],
 "class_ogre_1_1_light.html#ad42ba158cac70430c34f8a9eac94b237":[5,0,1,26,90],
+"class_ogre_1_1_light.html#ad42ba158cac70430c34f8a9eac94b237":[5,2,12,26,90],
 "class_ogre_1_1_light.html#ad4d52d64dca4df8a930a2401028f73ff":[5,2,12,26,143],
 "class_ogre_1_1_light.html#ad4d52d64dca4df8a930a2401028f73ff":[5,0,1,26,143],
-"class_ogre_1_1_light.html#ad563191e86e4d119c62ea9acfc2a90d5":[5,0,1,26,150],
 "class_ogre_1_1_light.html#ad563191e86e4d119c62ea9acfc2a90d5":[5,2,12,26,150],
+"class_ogre_1_1_light.html#ad563191e86e4d119c62ea9acfc2a90d5":[5,0,1,26,150],
 "class_ogre_1_1_light.html#ad66149b7a6f5ba1cd5c58fbd69f0446a":[5,2,12,26,64],
 "class_ogre_1_1_light.html#ad66149b7a6f5ba1cd5c58fbd69f0446a":[5,0,1,26,64],
-"class_ogre_1_1_light.html#ad8db1f22329b2a96f2aed7260d565944":[5,2,12,26,118],
 "class_ogre_1_1_light.html#ad8db1f22329b2a96f2aed7260d565944":[5,0,1,26,118],
-"class_ogre_1_1_light.html#ad9adeeb164ff515099236e2e8fb0c850":[5,0,1,26,141],
+"class_ogre_1_1_light.html#ad8db1f22329b2a96f2aed7260d565944":[5,2,12,26,118],
 "class_ogre_1_1_light.html#ad9adeeb164ff515099236e2e8fb0c850":[5,2,12,26,141],
-"class_ogre_1_1_light.html#adadf14592da40dfe79b40106317a2710":[5,0,1,26,133],
+"class_ogre_1_1_light.html#ad9adeeb164ff515099236e2e8fb0c850":[5,0,1,26,141],
 "class_ogre_1_1_light.html#adadf14592da40dfe79b40106317a2710":[5,2,12,26,133],
-"class_ogre_1_1_light.html#adbe9a3d02c0984a5a331a160b8a91b10":[5,2,12,26,49],
+"class_ogre_1_1_light.html#adadf14592da40dfe79b40106317a2710":[5,0,1,26,133],
 "class_ogre_1_1_light.html#adbe9a3d02c0984a5a331a160b8a91b10":[5,0,1,26,49],
-"class_ogre_1_1_light.html#adce32528577d71b228692df906ecd17c":[5,2,12,26,104],
+"class_ogre_1_1_light.html#adbe9a3d02c0984a5a331a160b8a91b10":[5,2,12,26,49],
 "class_ogre_1_1_light.html#adce32528577d71b228692df906ecd17c":[5,0,1,26,104],
+"class_ogre_1_1_light.html#adce32528577d71b228692df906ecd17c":[5,2,12,26,104],
 "class_ogre_1_1_light.html#add737d6564593333aeac457a1a2c0269":[5,2,12,26,152],
 "class_ogre_1_1_light.html#add737d6564593333aeac457a1a2c0269":[5,0,1,26,152],
-"class_ogre_1_1_light.html#adead68de3305bd67d1617352c14da3c3":[5,2,12,26,121],
 "class_ogre_1_1_light.html#adead68de3305bd67d1617352c14da3c3":[5,0,1,26,121],
+"class_ogre_1_1_light.html#adead68de3305bd67d1617352c14da3c3":[5,2,12,26,121],
 "class_ogre_1_1_light.html#adf841793f9978a635dd0345a6eb7a3e6":[5,0,1,26,112],
 "class_ogre_1_1_light.html#adf841793f9978a635dd0345a6eb7a3e6":[5,2,12,26,112],
 "class_ogre_1_1_light.html#ae1752d6520ad9eca130db3cca222e6db":[5,0,1,26,43],
 "class_ogre_1_1_light.html#ae1752d6520ad9eca130db3cca222e6db":[5,2,12,26,43],
-"class_ogre_1_1_light.html#ae1ec083410e3b53c589239a20fa5dbf0":[5,0,1,26,74],
 "class_ogre_1_1_light.html#ae1ec083410e3b53c589239a20fa5dbf0":[5,2,12,26,74],
-"class_ogre_1_1_light.html#ae3e2e4e50055bf99fd923ffa4f539f7d":[5,0,1,26,159],
+"class_ogre_1_1_light.html#ae1ec083410e3b53c589239a20fa5dbf0":[5,0,1,26,74],
 "class_ogre_1_1_light.html#ae3e2e4e50055bf99fd923ffa4f539f7d":[5,2,12,26,159],
+"class_ogre_1_1_light.html#ae3e2e4e50055bf99fd923ffa4f539f7d":[5,0,1,26,159],
 "class_ogre_1_1_light.html#ae47c1fe914431bbbd47d5d2a3ba258d0":[5,2,12,26,15],
 "class_ogre_1_1_light.html#ae47c1fe914431bbbd47d5d2a3ba258d0":[5,0,1,26,15],
-"class_ogre_1_1_light.html#aead9fea5c5d5869387d88869d0132cad":[5,2,12,26,142],
 "class_ogre_1_1_light.html#aead9fea5c5d5869387d88869d0132cad":[5,0,1,26,142],
-"class_ogre_1_1_light.html#aeb90ddb3515b7e3ac936367e40d49d20":[5,2,12,26,134],
+"class_ogre_1_1_light.html#aead9fea5c5d5869387d88869d0132cad":[5,2,12,26,142],
 "class_ogre_1_1_light.html#aeb90ddb3515b7e3ac936367e40d49d20":[5,0,1,26,134],
+"class_ogre_1_1_light.html#aeb90ddb3515b7e3ac936367e40d49d20":[5,2,12,26,134],
 "class_ogre_1_1_light.html#aec895d9f784ea062ce69c823737229c5":[5,0,1,26,140],
 "class_ogre_1_1_light.html#aec895d9f784ea062ce69c823737229c5":[5,2,12,26,140],
 "class_ogre_1_1_light.html#aec9af1bee1f7349370c7f7367860046e":[5,0,1,26,146],
@@ -85,26 +87,26 @@ var NAVTREEINDEX139 =
 "class_ogre_1_1_light.html#aed64949cd01302bef1001588a50c1b4a":[5,0,1,26,147],
 "class_ogre_1_1_light.html#aed8ab393d6f46e865a6753be69f96d8b":[5,0,1,26,88],
 "class_ogre_1_1_light.html#aed8ab393d6f46e865a6753be69f96d8b":[5,2,12,26,88],
-"class_ogre_1_1_light.html#aee4828c2dee7731058f0b9cd047cf78d":[5,2,12,26,154],
 "class_ogre_1_1_light.html#aee4828c2dee7731058f0b9cd047cf78d":[5,0,1,26,154],
+"class_ogre_1_1_light.html#aee4828c2dee7731058f0b9cd047cf78d":[5,2,12,26,154],
 "class_ogre_1_1_light.html#aef2a2634077942a2939514a6c1114d32":[5,0,1,26,92],
 "class_ogre_1_1_light.html#aef2a2634077942a2939514a6c1114d32":[5,2,12,26,92],
 "class_ogre_1_1_light.html#af19ca18abcd6ca7bceb2f55a814e1c1b":[5,2,12,26,86],
 "class_ogre_1_1_light.html#af19ca18abcd6ca7bceb2f55a814e1c1b":[5,0,1,26,86],
-"class_ogre_1_1_light.html#af333112ff9478bf29693eb59a9caf172":[5,0,1,26,20],
 "class_ogre_1_1_light.html#af333112ff9478bf29693eb59a9caf172":[5,2,12,26,20],
+"class_ogre_1_1_light.html#af333112ff9478bf29693eb59a9caf172":[5,0,1,26,20],
 "class_ogre_1_1_light.html#af3cd6abc354021078ce103eda3aa2b1a":[5,0,1,26,69],
 "class_ogre_1_1_light.html#af3cd6abc354021078ce103eda3aa2b1a":[5,2,12,26,69],
 "class_ogre_1_1_light.html#af6788ed3697ab34c561c0afcf39ac8c3":[5,0,1,26,66],
 "class_ogre_1_1_light.html#af6788ed3697ab34c561c0afcf39ac8c3":[5,2,12,26,66],
 "class_ogre_1_1_light.html#afb58624fb567bb790c55d8a716b472da":[5,0,1,26,0],
 "class_ogre_1_1_light.html#afb58624fb567bb790c55d8a716b472da":[5,2,12,26,0],
-"class_ogre_1_1_light.html#afbfeabb7d5503e571528fc0d365dc80a":[5,0,1,26,4],
 "class_ogre_1_1_light.html#afbfeabb7d5503e571528fc0d365dc80a":[5,2,12,26,4],
+"class_ogre_1_1_light.html#afbfeabb7d5503e571528fc0d365dc80a":[5,0,1,26,4],
 "class_ogre_1_1_light.html#afdf18128b8f4f8be71566ce2d5d5a30a":[5,2,12,26,127],
 "class_ogre_1_1_light.html#afdf18128b8f4f8be71566ce2d5d5a30a":[5,0,1,26,127],
-"class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7d":[5,0,1,26,2],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7d":[5,2,12,26,2],
+"class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7d":[5,0,1,26,2],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da058c0eecb9f3f188fccc4d0018bf337b":[5,0,1,26,2,2],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da058c0eecb9f3f188fccc4d0018bf337b":[5,2,12,26,2,2],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da218a4243be85ec9c989b777119d5ff47":[5,2,12,26,2,6],
@@ -113,48 +115,48 @@ var NAVTREEINDEX139 =
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da2b732a317de0915527e291485ca42e82":[5,0,1,26,2,0],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da4f559ca1853a24a28b40caae1acda604":[5,0,1,26,2,7],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da4f559ca1853a24a28b40caae1acda604":[5,2,12,26,2,7],
-"class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da55066351a26967068b944c2170e51af1":[5,2,12,26,2,3],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da55066351a26967068b944c2170e51af1":[5,0,1,26,2,3],
+"class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da55066351a26967068b944c2170e51af1":[5,2,12,26,2,3],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da58fd07194714679ed3ba9857d7656f27":[5,2,12,26,2,1],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da58fd07194714679ed3ba9857d7656f27":[5,0,1,26,2,1],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da61729c4ae25807d6132d5bc46580ff3d":[5,2,12,26,2,4],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da61729c4ae25807d6132d5bc46580ff3d":[5,0,1,26,2,4],
-"class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da704ea118c7e9f0b1598b528bdcbe1b26":[5,0,1,26,2,8],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da704ea118c7e9f0b1598b528bdcbe1b26":[5,2,12,26,2,8],
-"class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dabb2a61a0002ccca6afbde7588787e58e":[5,2,12,26,2,11],
+"class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7da704ea118c7e9f0b1598b528bdcbe1b26":[5,0,1,26,2,8],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dabb2a61a0002ccca6afbde7588787e58e":[5,0,1,26,2,11],
+"class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dabb2a61a0002ccca6afbde7588787e58e":[5,2,12,26,2,11],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dad4d9c6e3b7755f38d8d5f003be100257":[5,0,1,26,2,10],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dad4d9c6e3b7755f38d8d5f003be100257":[5,2,12,26,2,10],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dae3eb70053cbf5401f22893cdb47f81a7":[5,0,1,26,2,9],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dae3eb70053cbf5401f22893cdb47f81a7":[5,2,12,26,2,9],
-"class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dafbdd85981846de4423d48d1a0ff665e0":[5,2,12,26,2,5],
 "class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dafbdd85981846de4423d48d1a0ff665e0":[5,0,1,26,2,5],
+"class_ogre_1_1_light.html#afe11bd546cf7315f4526488e7078cc7dafbdd85981846de4423d48d1a0ff665e0":[5,2,12,26,2,5],
 "class_ogre_1_1_light.html#afe1f2a1009e3f14f36e1bcc9b1b9557e":[5,0,1,26,131],
 "class_ogre_1_1_light.html#afe1f2a1009e3f14f36e1bcc9b1b9557e":[5,2,12,26,131],
 "class_ogre_1_1_light.html#aff35a0dcf855331bdd0fe72fe0f66824":[5,0,1,26,41],
 "class_ogre_1_1_light.html#aff35a0dcf855331bdd0fe72fe0f66824":[5,2,12,26,41],
-"class_ogre_1_1_light.html#aff8dd8756aba9a9ecb276270e6614c96":[5,0,1,26,62],
 "class_ogre_1_1_light.html#aff8dd8756aba9a9ecb276270e6614c96":[5,2,12,26,62],
+"class_ogre_1_1_light.html#aff8dd8756aba9a9ecb276270e6614c96":[5,0,1,26,62],
 "class_ogre_1_1_light.html#aff98b9ed31a64b4801740ff400ac8e85":[5,0,1,26,50],
 "class_ogre_1_1_light.html#aff98b9ed31a64b4801740ff400ac8e85":[5,2,12,26,50],
-"class_ogre_1_1_light_factory.html":[5,0,1,27],
 "class_ogre_1_1_light_factory.html":[5,2,12,27],
+"class_ogre_1_1_light_factory.html":[5,0,1,27],
 "class_ogre_1_1_light_factory.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,27,7],
 "class_ogre_1_1_light_factory.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,27,7],
-"class_ogre_1_1_light_factory.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,27,9],
 "class_ogre_1_1_light_factory.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,27,9],
-"class_ogre_1_1_light_factory.html#a5b926946c7150a3eb68c92f31bfde97c":[5,2,12,27,15],
+"class_ogre_1_1_light_factory.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,27,9],
 "class_ogre_1_1_light_factory.html#a5b926946c7150a3eb68c92f31bfde97c":[5,0,1,27,15],
+"class_ogre_1_1_light_factory.html#a5b926946c7150a3eb68c92f31bfde97c":[5,2,12,27,15],
 "class_ogre_1_1_light_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,27,12],
 "class_ogre_1_1_light_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,27,12],
-"class_ogre_1_1_light_factory.html#a7cce44bd71877c5bc68bce055171380f":[5,0,1,27,0],
 "class_ogre_1_1_light_factory.html#a7cce44bd71877c5bc68bce055171380f":[5,2,12,27,0],
-"class_ogre_1_1_light_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,27,5],
+"class_ogre_1_1_light_factory.html#a7cce44bd71877c5bc68bce055171380f":[5,0,1,27,0],
 "class_ogre_1_1_light_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,27,5],
+"class_ogre_1_1_light_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,27,5],
 "class_ogre_1_1_light_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,27,8],
 "class_ogre_1_1_light_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,27,8],
-"class_ogre_1_1_light_factory.html#ab128c82ed2e160d4c870baca1c041add":[5,2,12,27,3],
 "class_ogre_1_1_light_factory.html#ab128c82ed2e160d4c870baca1c041add":[5,0,1,27,3],
+"class_ogre_1_1_light_factory.html#ab128c82ed2e160d4c870baca1c041add":[5,2,12,27,3],
 "class_ogre_1_1_light_factory.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,27,11],
 "class_ogre_1_1_light_factory.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,27,11],
 "class_ogre_1_1_light_factory.html#ab9ac351abe4182001f985058e22cd31f":[5,2,12,27,4],
@@ -165,60 +167,60 @@ var NAVTREEINDEX139 =
 "class_ogre_1_1_light_factory.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,27,6],
 "class_ogre_1_1_light_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,27,10],
 "class_ogre_1_1_light_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,27,10],
-"class_ogre_1_1_light_factory.html#ad4e5a3107760c39b3742113c336bff8d":[5,2,12,27,1],
 "class_ogre_1_1_light_factory.html#ad4e5a3107760c39b3742113c336bff8d":[5,0,1,27,1],
-"class_ogre_1_1_light_factory.html#adce32528577d71b228692df906ecd17c":[5,2,12,27,13],
+"class_ogre_1_1_light_factory.html#ad4e5a3107760c39b3742113c336bff8d":[5,2,12,27,1],
 "class_ogre_1_1_light_factory.html#adce32528577d71b228692df906ecd17c":[5,0,1,27,13],
+"class_ogre_1_1_light_factory.html#adce32528577d71b228692df906ecd17c":[5,2,12,27,13],
 "class_ogre_1_1_light_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,27,14],
 "class_ogre_1_1_light_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,27,14],
-"class_ogre_1_1_light_profiles.html":[6,0,0,588],
 "class_ogre_1_1_light_profiles.html":[7,0,0,561],
-"class_ogre_1_1_light_profiles.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,561,10],
+"class_ogre_1_1_light_profiles.html":[6,0,0,588],
 "class_ogre_1_1_light_profiles.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,588,10],
-"class_ogre_1_1_light_profiles.html#a5696c2d3c28a78c1333a6c6c7fe9dd27":[7,0,0,561,3],
+"class_ogre_1_1_light_profiles.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,561,10],
 "class_ogre_1_1_light_profiles.html#a5696c2d3c28a78c1333a6c6c7fe9dd27":[6,0,0,588,3],
-"class_ogre_1_1_light_profiles.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,561,12],
+"class_ogre_1_1_light_profiles.html#a5696c2d3c28a78c1333a6c6c7fe9dd27":[7,0,0,561,3],
 "class_ogre_1_1_light_profiles.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,588,12],
-"class_ogre_1_1_light_profiles.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,588,15],
+"class_ogre_1_1_light_profiles.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,561,12],
 "class_ogre_1_1_light_profiles.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,561,15],
-"class_ogre_1_1_light_profiles.html#a6ab8b91ad49d3156ffddc85dc1d7d7df":[6,0,0,588,4],
+"class_ogre_1_1_light_profiles.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,588,15],
 "class_ogre_1_1_light_profiles.html#a6ab8b91ad49d3156ffddc85dc1d7d7df":[7,0,0,561,4],
-"class_ogre_1_1_light_profiles.html#a6c91200e020185a48cce83cc049680f7":[6,0,0,588,5],
+"class_ogre_1_1_light_profiles.html#a6ab8b91ad49d3156ffddc85dc1d7d7df":[6,0,0,588,4],
 "class_ogre_1_1_light_profiles.html#a6c91200e020185a48cce83cc049680f7":[7,0,0,561,5],
+"class_ogre_1_1_light_profiles.html#a6c91200e020185a48cce83cc049680f7":[6,0,0,588,5],
 "class_ogre_1_1_light_profiles.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,588,8],
 "class_ogre_1_1_light_profiles.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,561,8],
-"class_ogre_1_1_light_profiles.html#a8ea58e6b12fa5981a8625af06d71aec2":[7,0,0,561,6],
 "class_ogre_1_1_light_profiles.html#a8ea58e6b12fa5981a8625af06d71aec2":[6,0,0,588,6],
+"class_ogre_1_1_light_profiles.html#a8ea58e6b12fa5981a8625af06d71aec2":[7,0,0,561,6],
 "class_ogre_1_1_light_profiles.html#a923784e8c4fb05d7aace3f8e1aadece4":[7,0,0,561,0],
 "class_ogre_1_1_light_profiles.html#a923784e8c4fb05d7aace3f8e1aadece4":[6,0,0,588,0],
 "class_ogre_1_1_light_profiles.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,588,11],
 "class_ogre_1_1_light_profiles.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,561,11],
 "class_ogre_1_1_light_profiles.html#aa2f7befb98ebd7a4996916672c3583df":[7,0,0,561,1],
 "class_ogre_1_1_light_profiles.html#aa2f7befb98ebd7a4996916672c3583df":[6,0,0,588,1],
-"class_ogre_1_1_light_profiles.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,588,14],
 "class_ogre_1_1_light_profiles.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,561,14],
+"class_ogre_1_1_light_profiles.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,588,14],
 "class_ogre_1_1_light_profiles.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,588,9],
 "class_ogre_1_1_light_profiles.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,561,9],
 "class_ogre_1_1_light_profiles.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,588,13],
 "class_ogre_1_1_light_profiles.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,561,13],
-"class_ogre_1_1_light_profiles.html#adce32528577d71b228692df906ecd17c":[6,0,0,588,16],
 "class_ogre_1_1_light_profiles.html#adce32528577d71b228692df906ecd17c":[7,0,0,561,16],
+"class_ogre_1_1_light_profiles.html#adce32528577d71b228692df906ecd17c":[6,0,0,588,16],
 "class_ogre_1_1_light_profiles.html#adee2e0deb6a1517c25c86579ca9b7d0f":[6,0,0,588,7],
 "class_ogre_1_1_light_profiles.html#adee2e0deb6a1517c25c86579ca9b7d0f":[7,0,0,561,7],
-"class_ogre_1_1_light_profiles.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,588,17],
 "class_ogre_1_1_light_profiles.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,561,17],
-"class_ogre_1_1_light_profiles.html#af40fa349790aa937007e8cdb80e19c8f":[6,0,0,588,2],
+"class_ogre_1_1_light_profiles.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,588,17],
 "class_ogre_1_1_light_profiles.html#af40fa349790aa937007e8cdb80e19c8f":[7,0,0,561,2],
-"class_ogre_1_1_lightweight_mutex.html":[7,0,0,562],
+"class_ogre_1_1_light_profiles.html#af40fa349790aa937007e8cdb80e19c8f":[6,0,0,588,2],
 "class_ogre_1_1_lightweight_mutex.html":[6,0,0,589],
+"class_ogre_1_1_lightweight_mutex.html":[7,0,0,562],
 "class_ogre_1_1_lightweight_mutex.html#a00e3efe19ccce8efc676ee1a91f3507a":[7,0,0,562,0],
 "class_ogre_1_1_lightweight_mutex.html#a00e3efe19ccce8efc676ee1a91f3507a":[6,0,0,589,0],
 "class_ogre_1_1_lightweight_mutex.html#a1876f974fd17bb2885d73747e1e7364c":[7,0,0,562,2],
 "class_ogre_1_1_lightweight_mutex.html#a1876f974fd17bb2885d73747e1e7364c":[6,0,0,589,2],
-"class_ogre_1_1_lightweight_mutex.html#a794873780d7b9b823afc33fe631207e2":[6,0,0,589,4],
 "class_ogre_1_1_lightweight_mutex.html#a794873780d7b9b823afc33fe631207e2":[7,0,0,562,4],
-"class_ogre_1_1_lightweight_mutex.html#a9ae870716c169e4f7cd89757a99c635f":[6,0,0,589,1],
+"class_ogre_1_1_lightweight_mutex.html#a794873780d7b9b823afc33fe631207e2":[6,0,0,589,4],
 "class_ogre_1_1_lightweight_mutex.html#a9ae870716c169e4f7cd89757a99c635f":[7,0,0,562,1],
+"class_ogre_1_1_lightweight_mutex.html#a9ae870716c169e4f7cd89757a99c635f":[6,0,0,589,1],
 "class_ogre_1_1_lightweight_mutex.html#acf6cc18c5986611ddc1a1f1b9afa9186":[7,0,0,562,3],
 "class_ogre_1_1_lightweight_mutex.html#acf6cc18c5986611ddc1a1f1b9afa9186":[6,0,0,589,3],
 "class_ogre_1_1_linear_controller_function.html":[5,2,2,64],
@@ -236,18 +238,16 @@ var NAVTREEINDEX139 =
 "class_ogre_1_1_linear_controller_function.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,2,64,11],
 "class_ogre_1_1_lod0_stripifier.html":[6,0,0,594],
 "class_ogre_1_1_lod0_stripifier.html":[7,0,0,567],
-"class_ogre_1_1_lod0_stripifier.html#a94f191280507c1253370ddca21113c87":[6,0,0,594,0],
 "class_ogre_1_1_lod0_stripifier.html#a94f191280507c1253370ddca21113c87":[7,0,0,567,0],
+"class_ogre_1_1_lod0_stripifier.html#a94f191280507c1253370ddca21113c87":[6,0,0,594,0],
 "class_ogre_1_1_lod0_stripifier.html#aa593f9fb11eedbbe253a4d8f210176b5":[6,0,0,594,2],
 "class_ogre_1_1_lod0_stripifier.html#aa593f9fb11eedbbe253a4d8f210176b5":[7,0,0,567,2],
 "class_ogre_1_1_lod0_stripifier.html#aaf8b57b5395eed707f960a10a1856d1d":[6,0,0,594,1],
 "class_ogre_1_1_lod0_stripifier.html#aaf8b57b5395eed707f960a10a1856d1d":[7,0,0,567,1],
-"class_ogre_1_1_lod_collapse_cost.html":[6,0,0,595],
 "class_ogre_1_1_lod_collapse_cost.html":[7,0,0,568],
+"class_ogre_1_1_lod_collapse_cost.html":[6,0,0,595],
 "class_ogre_1_1_lod_collapse_cost.html#a0544405a072903833e93500006036743":[7,0,0,568,0],
 "class_ogre_1_1_lod_collapse_cost.html#a0544405a072903833e93500006036743":[6,0,0,595,0],
-"class_ogre_1_1_lod_collapse_cost.html#a1134ac436cd2bc6d46eb316a4f74ef5a":[7,0,0,568,4],
 "class_ogre_1_1_lod_collapse_cost.html#a1134ac436cd2bc6d46eb316a4f74ef5a":[6,0,0,595,4],
-"class_ogre_1_1_lod_collapse_cost.html#a26facaf2f6d360fe5ccf9853fea41f98":[7,0,0,568,1],
-"class_ogre_1_1_lod_collapse_cost.html#a26facaf2f6d360fe5ccf9853fea41f98":[6,0,0,595,1]
+"class_ogre_1_1_lod_collapse_cost.html#a1134ac436cd2bc6d46eb316a4f74ef5a":[7,0,0,568,4]
 };
