@@ -1,11 +1,13 @@
 var NAVTREEINDEX140 =
 {
-"class_ogre_1_1_lod_collapse_cost.html#a354e7502246237f033d48fec0adfad4f":[7,0,0,568,3],
+"class_ogre_1_1_lod_collapse_cost.html#a26facaf2f6d360fe5ccf9853fea41f98":[6,0,0,595,1],
+"class_ogre_1_1_lod_collapse_cost.html#a26facaf2f6d360fe5ccf9853fea41f98":[7,0,0,568,1],
 "class_ogre_1_1_lod_collapse_cost.html#a354e7502246237f033d48fec0adfad4f":[6,0,0,595,3],
-"class_ogre_1_1_lod_collapse_cost.html#a96e2e1469204e79798e48924a11dee4c":[7,0,0,568,2],
+"class_ogre_1_1_lod_collapse_cost.html#a354e7502246237f033d48fec0adfad4f":[7,0,0,568,3],
 "class_ogre_1_1_lod_collapse_cost.html#a96e2e1469204e79798e48924a11dee4c":[6,0,0,595,2],
-"class_ogre_1_1_lod_collapse_cost.html#ab474f9fb95e3ad566d0b550a7018deb9":[6,0,0,595,5],
+"class_ogre_1_1_lod_collapse_cost.html#a96e2e1469204e79798e48924a11dee4c":[7,0,0,568,2],
 "class_ogre_1_1_lod_collapse_cost.html#ab474f9fb95e3ad566d0b550a7018deb9":[7,0,0,568,5],
+"class_ogre_1_1_lod_collapse_cost.html#ab474f9fb95e3ad566d0b550a7018deb9":[6,0,0,595,5],
 "class_ogre_1_1_lod_collapse_cost_curvature.html":[7,0,0,569],
 "class_ogre_1_1_lod_collapse_cost_curvature.html":[6,0,0,596],
 "class_ogre_1_1_lod_collapse_cost_curvature.html#a1134ac436cd2bc6d46eb316a4f74ef5a":[7,0,0,569,3],
@@ -16,20 +18,20 @@ var NAVTREEINDEX140 =
 "class_ogre_1_1_lod_collapse_cost_curvature.html#a96e2e1469204e79798e48924a11dee4c":[7,0,0,569,1],
 "class_ogre_1_1_lod_collapse_cost_curvature.html#ab474f9fb95e3ad566d0b550a7018deb9":[7,0,0,569,4],
 "class_ogre_1_1_lod_collapse_cost_curvature.html#ab474f9fb95e3ad566d0b550a7018deb9":[6,0,0,596,4],
-"class_ogre_1_1_lod_collapse_cost_curvature.html#ab8b43dbb0610cb663c03ea3c4a2c5e81":[7,0,0,569,0],
 "class_ogre_1_1_lod_collapse_cost_curvature.html#ab8b43dbb0610cb663c03ea3c4a2c5e81":[6,0,0,596,0],
-"class_ogre_1_1_lod_collapse_cost_outside.html":[7,0,0,570],
+"class_ogre_1_1_lod_collapse_cost_curvature.html#ab8b43dbb0610cb663c03ea3c4a2c5e81":[7,0,0,569,0],
 "class_ogre_1_1_lod_collapse_cost_outside.html":[6,0,0,597],
+"class_ogre_1_1_lod_collapse_cost_outside.html":[7,0,0,570],
 "class_ogre_1_1_lod_collapse_cost_outside.html#a1134ac436cd2bc6d46eb316a4f74ef5a":[6,0,0,597,5],
 "class_ogre_1_1_lod_collapse_cost_outside.html#a1134ac436cd2bc6d46eb316a4f74ef5a":[7,0,0,570,5],
-"class_ogre_1_1_lod_collapse_cost_outside.html#a96e2e1469204e79798e48924a11dee4c":[6,0,0,597,3],
 "class_ogre_1_1_lod_collapse_cost_outside.html#a96e2e1469204e79798e48924a11dee4c":[7,0,0,570,3],
+"class_ogre_1_1_lod_collapse_cost_outside.html#a96e2e1469204e79798e48924a11dee4c":[6,0,0,597,3],
 "class_ogre_1_1_lod_collapse_cost_outside.html#aa5cef7538a33a82740003f63b3e9337c":[6,0,0,597,0],
 "class_ogre_1_1_lod_collapse_cost_outside.html#aa5cef7538a33a82740003f63b3e9337c":[7,0,0,570,0],
-"class_ogre_1_1_lod_collapse_cost_outside.html#ab474f9fb95e3ad566d0b550a7018deb9":[6,0,0,597,6],
 "class_ogre_1_1_lod_collapse_cost_outside.html#ab474f9fb95e3ad566d0b550a7018deb9":[7,0,0,570,6],
-"class_ogre_1_1_lod_collapse_cost_outside.html#acbd8331275592e9398b749610f6a8c9f":[6,0,0,597,4],
+"class_ogre_1_1_lod_collapse_cost_outside.html#ab474f9fb95e3ad566d0b550a7018deb9":[6,0,0,597,6],
 "class_ogre_1_1_lod_collapse_cost_outside.html#acbd8331275592e9398b749610f6a8c9f":[7,0,0,570,4],
+"class_ogre_1_1_lod_collapse_cost_outside.html#acbd8331275592e9398b749610f6a8c9f":[6,0,0,597,4],
 "class_ogre_1_1_lod_collapse_cost_outside.html#adaecb877dc2cb42af7723807f703aad7":[6,0,0,597,2],
 "class_ogre_1_1_lod_collapse_cost_outside.html#adaecb877dc2cb42af7723807f703aad7":[7,0,0,570,2],
 "class_ogre_1_1_lod_collapse_cost_outside.html#af49fbc592c47e4b9521c03148bbbbbbf":[6,0,0,597,1],
@@ -42,82 +44,82 @@ var NAVTREEINDEX140 =
 "class_ogre_1_1_lod_collapse_cost_profiler.html#a1fd0aae8b9143d3627f479447bc5f7c7":[7,0,0,571,3],
 "class_ogre_1_1_lod_collapse_cost_profiler.html#a233b15a24b2f61c61c45e2116a13adf0":[6,0,0,598,2],
 "class_ogre_1_1_lod_collapse_cost_profiler.html#a233b15a24b2f61c61c45e2116a13adf0":[7,0,0,571,2],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#a54c2815544dadcfeacd1e79f2ce8ba6f":[7,0,0,571,0],
 "class_ogre_1_1_lod_collapse_cost_profiler.html#a54c2815544dadcfeacd1e79f2ce8ba6f":[6,0,0,598,0],
-"class_ogre_1_1_lod_collapse_cost_profiler.html#a66305605b4154ec3c25e8a592f12c078":[7,0,0,571,1],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#a54c2815544dadcfeacd1e79f2ce8ba6f":[7,0,0,571,0],
 "class_ogre_1_1_lod_collapse_cost_profiler.html#a66305605b4154ec3c25e8a592f12c078":[6,0,0,598,1],
+"class_ogre_1_1_lod_collapse_cost_profiler.html#a66305605b4154ec3c25e8a592f12c078":[7,0,0,571,1],
 "class_ogre_1_1_lod_collapse_cost_profiler.html#ab474f9fb95e3ad566d0b550a7018deb9":[6,0,0,598,5],
 "class_ogre_1_1_lod_collapse_cost_profiler.html#ab474f9fb95e3ad566d0b550a7018deb9":[7,0,0,571,5],
-"class_ogre_1_1_lod_collapse_cost_quadric.html":[7,0,0,572],
 "class_ogre_1_1_lod_collapse_cost_quadric.html":[6,0,0,599],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a1134ac436cd2bc6d46eb316a4f74ef5a":[7,0,0,572,3],
+"class_ogre_1_1_lod_collapse_cost_quadric.html":[7,0,0,572],
 "class_ogre_1_1_lod_collapse_cost_quadric.html#a1134ac436cd2bc6d46eb316a4f74ef5a":[6,0,0,599,3],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#a64171ea81eb1c4c65b9a6e1a15aae1fe":[7,0,0,572,4],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a1134ac436cd2bc6d46eb316a4f74ef5a":[7,0,0,572,3],
 "class_ogre_1_1_lod_collapse_cost_quadric.html#a64171ea81eb1c4c65b9a6e1a15aae1fe":[6,0,0,599,4],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#a64171ea81eb1c4c65b9a6e1a15aae1fe":[7,0,0,572,4],
 "class_ogre_1_1_lod_collapse_cost_quadric.html#a96e2e1469204e79798e48924a11dee4c":[7,0,0,572,1],
 "class_ogre_1_1_lod_collapse_cost_quadric.html#a96e2e1469204e79798e48924a11dee4c":[6,0,0,599,1],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#ac0ccfe8fff61ddd8ce87bd47bc64dd17":[6,0,0,599,2],
 "class_ogre_1_1_lod_collapse_cost_quadric.html#ac0ccfe8fff61ddd8ce87bd47bc64dd17":[7,0,0,572,2],
-"class_ogre_1_1_lod_collapse_cost_quadric.html#ae658a931cca54a885b56ede1eff3798e":[6,0,0,599,0],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#ac0ccfe8fff61ddd8ce87bd47bc64dd17":[6,0,0,599,2],
 "class_ogre_1_1_lod_collapse_cost_quadric.html#ae658a931cca54a885b56ede1eff3798e":[7,0,0,572,0],
+"class_ogre_1_1_lod_collapse_cost_quadric.html#ae658a931cca54a885b56ede1eff3798e":[6,0,0,599,0],
 "class_ogre_1_1_lod_collapser.html":[6,0,0,600],
 "class_ogre_1_1_lod_collapser.html":[7,0,0,573],
 "class_ogre_1_1_lod_collapser.html#a51d851d50ebcee4f77cff26f500ccce7":[6,0,0,600,0],
 "class_ogre_1_1_lod_collapser.html#a51d851d50ebcee4f77cff26f500ccce7":[7,0,0,573,0],
-"class_ogre_1_1_lod_collapser.html#a8a3dc7a3ba0d2777dd8656429540e8cd":[7,0,0,573,1],
 "class_ogre_1_1_lod_collapser.html#a8a3dc7a3ba0d2777dd8656429540e8cd":[6,0,0,600,1],
-"class_ogre_1_1_lod_collapser.html#ab2c58971bcc0ecac574ac377b56f3c30":[7,0,0,573,2],
+"class_ogre_1_1_lod_collapser.html#a8a3dc7a3ba0d2777dd8656429540e8cd":[7,0,0,573,1],
 "class_ogre_1_1_lod_collapser.html#ab2c58971bcc0ecac574ac377b56f3c30":[6,0,0,600,2],
+"class_ogre_1_1_lod_collapser.html#ab2c58971bcc0ecac574ac377b56f3c30":[7,0,0,573,2],
 "class_ogre_1_1_lod_collapser.html#ad292c42636402fafb2eb193264ca67a4":[6,0,0,600,3],
 "class_ogre_1_1_lod_collapser.html#ad292c42636402fafb2eb193264ca67a4":[7,0,0,573,3],
 "class_ogre_1_1_lod_config_serializer.html":[6,0,0,602],
 "class_ogre_1_1_lod_config_serializer.html":[7,0,0,575],
-"class_ogre_1_1_lod_config_serializer.html#a0f12f84184b32b0d2716667d533e3d1c":[7,0,0,575,3],
 "class_ogre_1_1_lod_config_serializer.html#a0f12f84184b32b0d2716667d533e3d1c":[6,0,0,602,3],
-"class_ogre_1_1_lod_config_serializer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,602,8],
+"class_ogre_1_1_lod_config_serializer.html#a0f12f84184b32b0d2716667d533e3d1c":[7,0,0,575,3],
 "class_ogre_1_1_lod_config_serializer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,575,8],
+"class_ogre_1_1_lod_config_serializer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,602,8],
 "class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39":[7,0,0,575,0],
 "class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39":[6,0,0,602,0],
-"class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39a10ce3b8f55cba526f6bc8237d8b25cc3":[6,0,0,602,0,2],
 "class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39a10ce3b8f55cba526f6bc8237d8b25cc3":[7,0,0,575,0,2],
+"class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39a10ce3b8f55cba526f6bc8237d8b25cc3":[6,0,0,602,0,2],
 "class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39a7f044c7683a7374276db6e7060f51240":[6,0,0,602,0,1],
 "class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39a7f044c7683a7374276db6e7060f51240":[7,0,0,575,0,1],
-"class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39aed60ca999861d8939cf57f19090c70ef":[7,0,0,575,0,0],
 "class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39aed60ca999861d8939cf57f19090c70ef":[6,0,0,602,0,0],
+"class_ogre_1_1_lod_config_serializer.html#a5122d5a3161fb5fd819d9a0521fe9d39aed60ca999861d8939cf57f19090c70ef":[7,0,0,575,0,0],
 "class_ogre_1_1_lod_config_serializer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,602,10],
 "class_ogre_1_1_lod_config_serializer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,575,10],
-"class_ogre_1_1_lod_config_serializer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,602,13],
 "class_ogre_1_1_lod_config_serializer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,575,13],
+"class_ogre_1_1_lod_config_serializer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,602,13],
 "class_ogre_1_1_lod_config_serializer.html#a72f631aab3f43aa1ccb441cbbd8cd63c":[7,0,0,575,5],
 "class_ogre_1_1_lod_config_serializer.html#a72f631aab3f43aa1ccb441cbbd8cd63c":[6,0,0,602,5],
-"class_ogre_1_1_lod_config_serializer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,575,6],
 "class_ogre_1_1_lod_config_serializer.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,602,6],
+"class_ogre_1_1_lod_config_serializer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,575,6],
 "class_ogre_1_1_lod_config_serializer.html#a90888570c5ea11c98e7ea8cfdab52fae":[7,0,0,575,1],
 "class_ogre_1_1_lod_config_serializer.html#a90888570c5ea11c98e7ea8cfdab52fae":[6,0,0,602,1],
-"class_ogre_1_1_lod_config_serializer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,602,9],
 "class_ogre_1_1_lod_config_serializer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,575,9],
-"class_ogre_1_1_lod_config_serializer.html#ab0d2cd1a61870f28aabbf0bd9d61b350":[7,0,0,575,2],
+"class_ogre_1_1_lod_config_serializer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,602,9],
 "class_ogre_1_1_lod_config_serializer.html#ab0d2cd1a61870f28aabbf0bd9d61b350":[6,0,0,602,2],
-"class_ogre_1_1_lod_config_serializer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,602,12],
+"class_ogre_1_1_lod_config_serializer.html#ab0d2cd1a61870f28aabbf0bd9d61b350":[7,0,0,575,2],
 "class_ogre_1_1_lod_config_serializer.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,575,12],
-"class_ogre_1_1_lod_config_serializer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,575,7],
+"class_ogre_1_1_lod_config_serializer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,602,12],
 "class_ogre_1_1_lod_config_serializer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,602,7],
+"class_ogre_1_1_lod_config_serializer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,575,7],
 "class_ogre_1_1_lod_config_serializer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,602,11],
 "class_ogre_1_1_lod_config_serializer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,575,11],
 "class_ogre_1_1_lod_config_serializer.html#adce32528577d71b228692df906ecd17c":[6,0,0,602,14],
 "class_ogre_1_1_lod_config_serializer.html#adce32528577d71b228692df906ecd17c":[7,0,0,575,14],
 "class_ogre_1_1_lod_config_serializer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,602,15],
 "class_ogre_1_1_lod_config_serializer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,575,15],
-"class_ogre_1_1_lod_config_serializer.html#af4e0f6e5ceae25f6fdb735cec0b51069":[6,0,0,602,4],
 "class_ogre_1_1_lod_config_serializer.html#af4e0f6e5ceae25f6fdb735cec0b51069":[7,0,0,575,4],
-"class_ogre_1_1_lod_input_provider.html":[7,0,0,579],
+"class_ogre_1_1_lod_config_serializer.html#af4e0f6e5ceae25f6fdb735cec0b51069":[6,0,0,602,4],
 "class_ogre_1_1_lod_input_provider.html":[6,0,0,606],
+"class_ogre_1_1_lod_input_provider.html":[7,0,0,579],
 "class_ogre_1_1_lod_input_provider.html#a551a6f7b7d3e27fccea16452485f5167":[7,0,0,579,0],
 "class_ogre_1_1_lod_input_provider.html#a551a6f7b7d3e27fccea16452485f5167":[6,0,0,606,0],
 "class_ogre_1_1_lod_input_provider.html#ae09684e1afda55cac84ad037c3f85fc0":[7,0,0,579,1],
 "class_ogre_1_1_lod_input_provider.html#ae09684e1afda55cac84ad037c3f85fc0":[6,0,0,606,1],
-"class_ogre_1_1_lod_input_provider_buffer.html":[6,0,0,607],
 "class_ogre_1_1_lod_input_provider_buffer.html":[7,0,0,580],
+"class_ogre_1_1_lod_input_provider_buffer.html":[6,0,0,607],
 "class_ogre_1_1_lod_input_provider_buffer.html#a7174a85c6ada830c23a3c4002310881f":[7,0,0,580,0],
 "class_ogre_1_1_lod_input_provider_buffer.html#a7174a85c6ada830c23a3c4002310881f":[6,0,0,607,0],
 "class_ogre_1_1_lod_input_provider_buffer.html#ad111c0b02f304bbef104e936e891e7b2":[7,0,0,580,1],
@@ -126,8 +128,8 @@ var NAVTREEINDEX140 =
 "class_ogre_1_1_lod_input_provider_mesh.html":[6,0,0,608],
 "class_ogre_1_1_lod_input_provider_mesh.html#a46fae4fac33c9e5f99de77d729454bdc":[6,0,0,608,0],
 "class_ogre_1_1_lod_input_provider_mesh.html#a46fae4fac33c9e5f99de77d729454bdc":[7,0,0,581,0],
-"class_ogre_1_1_lod_input_provider_mesh.html#a9600d8a33417aa16bbf390cfa55e53bd":[6,0,0,608,1],
 "class_ogre_1_1_lod_input_provider_mesh.html#a9600d8a33417aa16bbf390cfa55e53bd":[7,0,0,581,1],
+"class_ogre_1_1_lod_input_provider_mesh.html#a9600d8a33417aa16bbf390cfa55e53bd":[6,0,0,608,1],
 "class_ogre_1_1_lod_listener.html":[5,2,4,5],
 "class_ogre_1_1_lod_listener.html#a2690efbb582ca532ad79f4e682730ecd":[5,2,4,5,4],
 "class_ogre_1_1_lod_listener.html#a437b5f300e0f3c38fa581d87e8643784":[5,2,4,5,0],
@@ -138,56 +140,56 @@ var NAVTREEINDEX140 =
 "class_ogre_1_1_lod_listener.html#afeed906381e75aa6449c95085a207a53":[5,2,4,5,6],
 "class_ogre_1_1_lod_output_provider.html":[7,0,0,585],
 "class_ogre_1_1_lod_output_provider.html":[6,0,0,612],
-"class_ogre_1_1_lod_output_provider.html#a1390b1ae86435e6dd6d7434fba229ac8":[6,0,0,612,4],
 "class_ogre_1_1_lod_output_provider.html#a1390b1ae86435e6dd6d7434fba229ac8":[7,0,0,585,4],
+"class_ogre_1_1_lod_output_provider.html#a1390b1ae86435e6dd6d7434fba229ac8":[6,0,0,612,4],
 "class_ogre_1_1_lod_output_provider.html#a27748353c3278f8b45a6d262a3a2d31b":[7,0,0,585,1],
 "class_ogre_1_1_lod_output_provider.html#a27748353c3278f8b45a6d262a3a2d31b":[6,0,0,612,1],
-"class_ogre_1_1_lod_output_provider.html#a46c70b8500cfdf6563662db9fc60ffa4":[7,0,0,585,6],
 "class_ogre_1_1_lod_output_provider.html#a46c70b8500cfdf6563662db9fc60ffa4":[6,0,0,612,6],
+"class_ogre_1_1_lod_output_provider.html#a46c70b8500cfdf6563662db9fc60ffa4":[7,0,0,585,6],
 "class_ogre_1_1_lod_output_provider.html#a55fabf495b1a4b4cede411a2b0609ba4":[6,0,0,612,5],
 "class_ogre_1_1_lod_output_provider.html#a55fabf495b1a4b4cede411a2b0609ba4":[7,0,0,585,5],
-"class_ogre_1_1_lod_output_provider.html#a61092e44961ca1554be9c71e34160b08":[6,0,0,612,3],
 "class_ogre_1_1_lod_output_provider.html#a61092e44961ca1554be9c71e34160b08":[7,0,0,585,3],
-"class_ogre_1_1_lod_output_provider.html#a9d6fab6afb7888f7241b92fd539f2c79":[6,0,0,612,2],
+"class_ogre_1_1_lod_output_provider.html#a61092e44961ca1554be9c71e34160b08":[6,0,0,612,3],
 "class_ogre_1_1_lod_output_provider.html#a9d6fab6afb7888f7241b92fd539f2c79":[7,0,0,585,2],
-"class_ogre_1_1_lod_output_provider.html#ac2c30b1e51095cac424ad6ec88a9080b":[7,0,0,585,0],
+"class_ogre_1_1_lod_output_provider.html#a9d6fab6afb7888f7241b92fd539f2c79":[6,0,0,612,2],
 "class_ogre_1_1_lod_output_provider.html#ac2c30b1e51095cac424ad6ec88a9080b":[6,0,0,612,0],
+"class_ogre_1_1_lod_output_provider.html#ac2c30b1e51095cac424ad6ec88a9080b":[7,0,0,585,0],
 "class_ogre_1_1_lod_output_provider.html#afd7fbf85dab8b295e1ec15b30b4837e9":[7,0,0,585,7],
 "class_ogre_1_1_lod_output_provider.html#afd7fbf85dab8b295e1ec15b30b4837e9":[6,0,0,612,7],
-"class_ogre_1_1_lod_output_provider_buffer.html":[7,0,0,586],
 "class_ogre_1_1_lod_output_provider_buffer.html":[6,0,0,613],
-"class_ogre_1_1_lod_output_provider_buffer.html#a08d524c0a2e1dc09e229b740e1e593c3":[7,0,0,586,1],
+"class_ogre_1_1_lod_output_provider_buffer.html":[7,0,0,586],
 "class_ogre_1_1_lod_output_provider_buffer.html#a08d524c0a2e1dc09e229b740e1e593c3":[6,0,0,613,1],
+"class_ogre_1_1_lod_output_provider_buffer.html#a08d524c0a2e1dc09e229b740e1e593c3":[7,0,0,586,1],
 "class_ogre_1_1_lod_output_provider_buffer.html#a0aa8163b5a17d35af711668d1a0124a7":[6,0,0,613,3],
 "class_ogre_1_1_lod_output_provider_buffer.html#a0aa8163b5a17d35af711668d1a0124a7":[7,0,0,586,3],
 "class_ogre_1_1_lod_output_provider_buffer.html#a46c70b8500cfdf6563662db9fc60ffa4":[7,0,0,586,7],
 "class_ogre_1_1_lod_output_provider_buffer.html#a46c70b8500cfdf6563662db9fc60ffa4":[6,0,0,613,7],
-"class_ogre_1_1_lod_output_provider_buffer.html#a4de90dd96a42ac8ed0f3a8c170073835":[6,0,0,613,5],
 "class_ogre_1_1_lod_output_provider_buffer.html#a4de90dd96a42ac8ed0f3a8c170073835":[7,0,0,586,5],
+"class_ogre_1_1_lod_output_provider_buffer.html#a4de90dd96a42ac8ed0f3a8c170073835":[6,0,0,613,5],
 "class_ogre_1_1_lod_output_provider_buffer.html#a5176d58819796bf128e38c0e6ed32e4c":[6,0,0,613,6],
 "class_ogre_1_1_lod_output_provider_buffer.html#a5176d58819796bf128e38c0e6ed32e4c":[7,0,0,586,6],
-"class_ogre_1_1_lod_output_provider_buffer.html#a634ef81c70087e4e0832e477e852395f":[7,0,0,586,0],
 "class_ogre_1_1_lod_output_provider_buffer.html#a634ef81c70087e4e0832e477e852395f":[6,0,0,613,0],
-"class_ogre_1_1_lod_output_provider_buffer.html#a7bf0b1948eff56ea577696eedfd2fe99":[6,0,0,613,2],
+"class_ogre_1_1_lod_output_provider_buffer.html#a634ef81c70087e4e0832e477e852395f":[7,0,0,586,0],
 "class_ogre_1_1_lod_output_provider_buffer.html#a7bf0b1948eff56ea577696eedfd2fe99":[7,0,0,586,2],
+"class_ogre_1_1_lod_output_provider_buffer.html#a7bf0b1948eff56ea577696eedfd2fe99":[6,0,0,613,2],
 "class_ogre_1_1_lod_output_provider_buffer.html#ae4175d51843982919547f850999dd0f9":[6,0,0,613,4],
 "class_ogre_1_1_lod_output_provider_buffer.html#ae4175d51843982919547f850999dd0f9":[7,0,0,586,4],
-"class_ogre_1_1_lod_output_provider_buffer.html#afd7fbf85dab8b295e1ec15b30b4837e9":[7,0,0,586,8],
 "class_ogre_1_1_lod_output_provider_buffer.html#afd7fbf85dab8b295e1ec15b30b4837e9":[6,0,0,613,8],
-"class_ogre_1_1_lod_output_provider_compressed_buffer.html":[7,0,0,587],
+"class_ogre_1_1_lod_output_provider_buffer.html#afd7fbf85dab8b295e1ec15b30b4837e9":[7,0,0,586,8],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html":[6,0,0,614],
+"class_ogre_1_1_lod_output_provider_compressed_buffer.html":[7,0,0,587],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#a0ea43a899427ec5404348d1fd653815b":[7,0,0,587,3],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#a0ea43a899427ec5404348d1fd653815b":[6,0,0,614,3],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#a2dbc6c42ba62eac31810f55f7c69ed6d":[7,0,0,587,4],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#a2dbc6c42ba62eac31810f55f7c69ed6d":[6,0,0,614,4],
-"class_ogre_1_1_lod_output_provider_compressed_buffer.html#a3769c4fae04e2eb03dba0083f95de6b2":[7,0,0,587,0],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#a3769c4fae04e2eb03dba0083f95de6b2":[6,0,0,614,0],
-"class_ogre_1_1_lod_output_provider_compressed_buffer.html#a673c60f562bc877ee867395b2e550a4a":[6,0,0,614,7],
+"class_ogre_1_1_lod_output_provider_compressed_buffer.html#a3769c4fae04e2eb03dba0083f95de6b2":[7,0,0,587,0],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#a673c60f562bc877ee867395b2e550a4a":[7,0,0,587,7],
+"class_ogre_1_1_lod_output_provider_compressed_buffer.html#a673c60f562bc877ee867395b2e550a4a":[6,0,0,614,7],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#abad048cc7b8fe39696d9bd4356dca765":[6,0,0,614,1],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#abad048cc7b8fe39696d9bd4356dca765":[7,0,0,587,1],
-"class_ogre_1_1_lod_output_provider_compressed_buffer.html#aedaa383e20889e7c4c3c63766d1103af":[6,0,0,614,6],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#aedaa383e20889e7c4c3c63766d1103af":[7,0,0,587,6],
+"class_ogre_1_1_lod_output_provider_compressed_buffer.html#aedaa383e20889e7c4c3c63766d1103af":[6,0,0,614,6],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#af8f5b48d14f6064b8e9abc3128fc1ba7":[6,0,0,614,5],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#af8f5b48d14f6064b8e9abc3128fc1ba7":[7,0,0,587,5],
 "class_ogre_1_1_lod_output_provider_compressed_buffer.html#afd5c89f38214630421fcf242c041320f":[6,0,0,614,2],
@@ -198,38 +200,38 @@ var NAVTREEINDEX140 =
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#a0ea43a899427ec5404348d1fd653815b":[6,0,0,615,4],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#a2dbc6c42ba62eac31810f55f7c69ed6d":[7,0,0,588,5],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#a2dbc6c42ba62eac31810f55f7c69ed6d":[6,0,0,615,5],
-"class_ogre_1_1_lod_output_provider_compressed_mesh.html#a2e84961b8af47ee2d6d80366ecaccb03":[6,0,0,615,1],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#a2e84961b8af47ee2d6d80366ecaccb03":[7,0,0,588,1],
+"class_ogre_1_1_lod_output_provider_compressed_mesh.html#a2e84961b8af47ee2d6d80366ecaccb03":[6,0,0,615,1],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#a605b2dbcb291ce0208062447f7dbd26a":[6,0,0,615,0],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#a605b2dbcb291ce0208062447f7dbd26a":[7,0,0,588,0],
-"class_ogre_1_1_lod_output_provider_compressed_mesh.html#a673c60f562bc877ee867395b2e550a4a":[7,0,0,588,8],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#a673c60f562bc877ee867395b2e550a4a":[6,0,0,615,8],
-"class_ogre_1_1_lod_output_provider_compressed_mesh.html#abad048cc7b8fe39696d9bd4356dca765":[6,0,0,615,2],
+"class_ogre_1_1_lod_output_provider_compressed_mesh.html#a673c60f562bc877ee867395b2e550a4a":[7,0,0,588,8],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#abad048cc7b8fe39696d9bd4356dca765":[7,0,0,588,2],
+"class_ogre_1_1_lod_output_provider_compressed_mesh.html#abad048cc7b8fe39696d9bd4356dca765":[6,0,0,615,2],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#aedaa383e20889e7c4c3c63766d1103af":[7,0,0,588,7],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#aedaa383e20889e7c4c3c63766d1103af":[6,0,0,615,7],
-"class_ogre_1_1_lod_output_provider_compressed_mesh.html#af8f5b48d14f6064b8e9abc3128fc1ba7":[7,0,0,588,6],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#af8f5b48d14f6064b8e9abc3128fc1ba7":[6,0,0,615,6],
+"class_ogre_1_1_lod_output_provider_compressed_mesh.html#af8f5b48d14f6064b8e9abc3128fc1ba7":[7,0,0,588,6],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#afd5c89f38214630421fcf242c041320f":[7,0,0,588,3],
 "class_ogre_1_1_lod_output_provider_compressed_mesh.html#afd5c89f38214630421fcf242c041320f":[6,0,0,615,3],
 "class_ogre_1_1_lod_output_provider_mesh.html":[7,0,0,589],
 "class_ogre_1_1_lod_output_provider_mesh.html":[6,0,0,616],
 "class_ogre_1_1_lod_output_provider_mesh.html#a1390b1ae86435e6dd6d7434fba229ac8":[6,0,0,616,4],
 "class_ogre_1_1_lod_output_provider_mesh.html#a1390b1ae86435e6dd6d7434fba229ac8":[7,0,0,589,4],
-"class_ogre_1_1_lod_output_provider_mesh.html#a2717811709e73b9376755fecf68d2725":[7,0,0,589,0],
 "class_ogre_1_1_lod_output_provider_mesh.html#a2717811709e73b9376755fecf68d2725":[6,0,0,616,0],
+"class_ogre_1_1_lod_output_provider_mesh.html#a2717811709e73b9376755fecf68d2725":[7,0,0,589,0],
 "class_ogre_1_1_lod_output_provider_mesh.html#a46c70b8500cfdf6563662db9fc60ffa4":[7,0,0,589,6],
 "class_ogre_1_1_lod_output_provider_mesh.html#a46c70b8500cfdf6563662db9fc60ffa4":[6,0,0,616,6],
 "class_ogre_1_1_lod_output_provider_mesh.html#a570655d1d1b34e2853b044e8cb0d95f7":[7,0,0,589,1],
 "class_ogre_1_1_lod_output_provider_mesh.html#a570655d1d1b34e2853b044e8cb0d95f7":[6,0,0,616,1],
 "class_ogre_1_1_lod_output_provider_mesh.html#a98cc6a955107a208c8205ccb76985ec0":[7,0,0,589,3],
 "class_ogre_1_1_lod_output_provider_mesh.html#a98cc6a955107a208c8205ccb76985ec0":[6,0,0,616,3],
-"class_ogre_1_1_lod_output_provider_mesh.html#ac5e22ad812a12f01946a67618091e99f":[7,0,0,589,2],
 "class_ogre_1_1_lod_output_provider_mesh.html#ac5e22ad812a12f01946a67618091e99f":[6,0,0,616,2],
-"class_ogre_1_1_lod_output_provider_mesh.html#af6e27b063be84d204a55dc2d8a643419":[6,0,0,616,5],
+"class_ogre_1_1_lod_output_provider_mesh.html#ac5e22ad812a12f01946a67618091e99f":[7,0,0,589,2],
 "class_ogre_1_1_lod_output_provider_mesh.html#af6e27b063be84d204a55dc2d8a643419":[7,0,0,589,5],
-"class_ogre_1_1_lod_output_provider_mesh.html#afd7fbf85dab8b295e1ec15b30b4837e9":[6,0,0,616,7],
+"class_ogre_1_1_lod_output_provider_mesh.html#af6e27b063be84d204a55dc2d8a643419":[6,0,0,616,5],
 "class_ogre_1_1_lod_output_provider_mesh.html#afd7fbf85dab8b295e1ec15b30b4837e9":[7,0,0,589,7],
+"class_ogre_1_1_lod_output_provider_mesh.html#afd7fbf85dab8b295e1ec15b30b4837e9":[6,0,0,616,7],
 "class_ogre_1_1_lod_outside_marker.html":[6,0,0,617],
 "class_ogre_1_1_lod_outside_marker.html":[7,0,0,590],
 "class_ogre_1_1_lod_outside_marker.html#a05e6374a8d4df03160d5fbbf46338b24":[6,0,0,617,2],
@@ -238,8 +240,8 @@ var NAVTREEINDEX140 =
 "class_ogre_1_1_lod_outside_marker.html#a29dd4b0f1d314671a8eb66a6ae260f93":[7,0,0,590,3],
 "class_ogre_1_1_lod_outside_marker.html#a9ed12c63e911c6a05d376f5ddf9abc29":[7,0,0,590,0],
 "class_ogre_1_1_lod_outside_marker.html#a9ed12c63e911c6a05d376f5ddf9abc29":[6,0,0,617,0],
-"class_ogre_1_1_lod_outside_marker.html#aca910316d85300475e4d5a4658f27513":[7,0,0,590,1],
 "class_ogre_1_1_lod_outside_marker.html#aca910316d85300475e4d5a4658f27513":[6,0,0,617,1],
+"class_ogre_1_1_lod_outside_marker.html#aca910316d85300475e4d5a4658f27513":[7,0,0,590,1],
 "class_ogre_1_1_lod_strategy.html":[5,2,4,6],
 "class_ogre_1_1_lod_strategy.html#a11c15567a651d4e46856030f6d34b789":[5,2,4,6,2],
 "class_ogre_1_1_lod_strategy.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,4,6,9],
@@ -247,7 +249,5 @@ var NAVTREEINDEX140 =
 "class_ogre_1_1_lod_strategy.html#a44ca92b0906532d0f7f99984bca6c193":[5,2,4,6,6],
 "class_ogre_1_1_lod_strategy.html#a49536ec8eff8497fda98ea8ecab569df":[5,2,4,6,0],
 "class_ogre_1_1_lod_strategy.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,4,6,11],
-"class_ogre_1_1_lod_strategy.html#a60e9908806b839380729aae13b9a959a":[5,2,4,6,18],
-"class_ogre_1_1_lod_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,4,6,14],
-"class_ogre_1_1_lod_strategy.html#a667bd94e7c15e2b5d5692146d22cd1f8":[5,2,4,6,1]
+"class_ogre_1_1_lod_strategy.html#a60e9908806b839380729aae13b9a959a":[5,2,4,6,18]
 };
