@@ -1,88 +1,90 @@
 var NAVTREEINDEX15 =
 {
+"class_ogre_1_1_array_ray.html#a1e8cbbda73ce427f9c5418b2552f819e":[7,0,0,34,2],
+"class_ogre_1_1_array_ray.html#a1e8cbbda73ce427f9c5418b2552f819e":[6,0,0,61,2],
 "class_ogre_1_1_array_ray.html#a446c150f80233b39a7c4d6f93cd6a9d3":[7,0,0,34,3],
 "class_ogre_1_1_array_ray.html#a446c150f80233b39a7c4d6f93cd6a9d3":[6,0,0,61,3],
-"class_ogre_1_1_array_ray.html#a9388d8ae147479be1923e9047e0cdebb":[6,0,0,61,0],
 "class_ogre_1_1_array_ray.html#a9388d8ae147479be1923e9047e0cdebb":[7,0,0,34,0],
+"class_ogre_1_1_array_ray.html#a9388d8ae147479be1923e9047e0cdebb":[6,0,0,61,0],
 "class_ogre_1_1_array_ray.html#ad3cbf5a9e2fb760ff10e53b5121c9440":[6,0,0,61,1],
 "class_ogre_1_1_array_ray.html#ad3cbf5a9e2fb760ff10e53b5121c9440":[7,0,0,34,1],
 "class_ogre_1_1_array_sphere.html":[5,2,6,6],
 "class_ogre_1_1_array_sphere.html#a038c2a2adb7ceb38cf53502989c9a5f7":[5,2,6,6,14],
 "class_ogre_1_1_array_sphere.html#a2e3cf4710ceeebd71e01eb77bdd882d4":[5,2,6,6,22],
-"class_ogre_1_1_array_sphere.html#a2e3cf4710ceeebd71e01eb77bdd882d4":[5,2,6,6,21],
 "class_ogre_1_1_array_sphere.html#a2e3cf4710ceeebd71e01eb77bdd882d4":[5,2,6,6,23],
+"class_ogre_1_1_array_sphere.html#a2e3cf4710ceeebd71e01eb77bdd882d4":[5,2,6,6,21],
 "class_ogre_1_1_array_sphere.html#a3879f5cb5cad88a5a7e5d9e7a6761480":[5,2,6,6,26],
 "class_ogre_1_1_array_sphere.html#a3879f5cb5cad88a5a7e5d9e7a6761480":[5,2,6,6,25],
 "class_ogre_1_1_array_sphere.html#a3879f5cb5cad88a5a7e5d9e7a6761480":[5,2,6,6,24],
-"class_ogre_1_1_array_sphere.html#a4607012096ce57af36999191fa50ad7a":[5,2,6,6,7],
 "class_ogre_1_1_array_sphere.html#a4607012096ce57af36999191fa50ad7a":[5,2,6,6,6],
+"class_ogre_1_1_array_sphere.html#a4607012096ce57af36999191fa50ad7a":[5,2,6,6,7],
 "class_ogre_1_1_array_sphere.html#a4607012096ce57af36999191fa50ad7a":[5,2,6,6,8],
 "class_ogre_1_1_array_sphere.html#a51324c09af387e26fae268abcd366c3c":[5,2,6,6,17],
 "class_ogre_1_1_array_sphere.html#a7670729740e21cdd1d5ae3e554ba3cf5":[5,2,6,6,20],
 "class_ogre_1_1_array_sphere.html#a97e019c2f327544c84a66d5f39223041":[5,2,6,6,15],
 "class_ogre_1_1_array_sphere.html#a97e019c2f327544c84a66d5f39223041":[5,2,6,6,16],
-"class_ogre_1_1_array_sphere.html#abe82b6267513cfc304726c6c95f063db":[5,2,6,6,3],
 "class_ogre_1_1_array_sphere.html#abe82b6267513cfc304726c6c95f063db":[5,2,6,6,1],
+"class_ogre_1_1_array_sphere.html#abe82b6267513cfc304726c6c95f063db":[5,2,6,6,3],
 "class_ogre_1_1_array_sphere.html#abe82b6267513cfc304726c6c95f063db":[5,2,6,6,5],
 "class_ogre_1_1_array_sphere.html#ac3feba6d323cd711fca881f94a314e2a":[5,2,6,6,12],
 "class_ogre_1_1_array_sphere.html#ac3feba6d323cd711fca881f94a314e2a":[5,2,6,6,13],
 "class_ogre_1_1_array_sphere.html#adc93e8e377d533e50b64c8a6bbe0b9d9":[5,2,6,6,27],
-"class_ogre_1_1_array_sphere.html#ade0be53d896930c25b138721b9c3dfaf":[5,2,6,6,9],
 "class_ogre_1_1_array_sphere.html#ade0be53d896930c25b138721b9c3dfaf":[5,2,6,6,11],
 "class_ogre_1_1_array_sphere.html#ade0be53d896930c25b138721b9c3dfaf":[5,2,6,6,10],
+"class_ogre_1_1_array_sphere.html#ade0be53d896930c25b138721b9c3dfaf":[5,2,6,6,9],
 "class_ogre_1_1_array_sphere.html#ae143885ae832213c23b460dfd35d3c1a":[5,2,6,6,0],
-"class_ogre_1_1_array_sphere.html#ae143885ae832213c23b460dfd35d3c1a":[5,2,6,6,2],
 "class_ogre_1_1_array_sphere.html#ae143885ae832213c23b460dfd35d3c1a":[5,2,6,6,4],
+"class_ogre_1_1_array_sphere.html#ae143885ae832213c23b460dfd35d3c1a":[5,2,6,6,2],
 "class_ogre_1_1_array_sphere.html#ae702c2ce3d4d764e2408c59d9afa76d9":[5,2,6,6,18],
 "class_ogre_1_1_array_sphere.html#ae702c2ce3d4d764e2408c59d9afa76d9":[5,2,6,6,19],
 "class_ogre_1_1_array_sphere.html#aefe1f6a28c0eae3c3f41e72c3ac2e0f6":[5,2,6,6,28],
 "class_ogre_1_1_array_vector3.html":[5,2,6,7],
-"class_ogre_1_1_array_vector3.html#a003f296f292d0bea684a41a38fdbfdd3":[5,2,6,7,72],
-"class_ogre_1_1_array_vector3.html#a003f296f292d0bea684a41a38fdbfdd3":[5,2,6,7,73],
 "class_ogre_1_1_array_vector3.html#a003f296f292d0bea684a41a38fdbfdd3":[5,2,6,7,74],
+"class_ogre_1_1_array_vector3.html#a003f296f292d0bea684a41a38fdbfdd3":[5,2,6,7,73],
+"class_ogre_1_1_array_vector3.html#a003f296f292d0bea684a41a38fdbfdd3":[5,2,6,7,72],
 "class_ogre_1_1_array_vector3.html#a03c9bb82113607b3f57b5c35a72a9c7d":[5,2,6,7,205],
 "class_ogre_1_1_array_vector3.html#a08483bf68f3a83c2256bbacb4c13505f":[5,2,6,7,78],
 "class_ogre_1_1_array_vector3.html#a08483bf68f3a83c2256bbacb4c13505f":[5,2,6,7,79],
 "class_ogre_1_1_array_vector3.html#a0b764f1b04faeeba5aebfb8238eabf07":[5,2,6,7,154],
-"class_ogre_1_1_array_vector3.html#a0b764f1b04faeeba5aebfb8238eabf07":[5,2,6,7,152],
 "class_ogre_1_1_array_vector3.html#a0b764f1b04faeeba5aebfb8238eabf07":[5,2,6,7,153],
+"class_ogre_1_1_array_vector3.html#a0b764f1b04faeeba5aebfb8238eabf07":[5,2,6,7,152],
 "class_ogre_1_1_array_vector3.html#a0d240293db14723529e48511e740457e":[5,2,6,7,77],
 "class_ogre_1_1_array_vector3.html#a0d240293db14723529e48511e740457e":[5,2,6,7,76],
 "class_ogre_1_1_array_vector3.html#a0d240293db14723529e48511e740457e":[5,2,6,7,75],
-"class_ogre_1_1_array_vector3.html#a101ace91b0add48e5fcc959f6a037fd4":[5,2,6,7,133],
-"class_ogre_1_1_array_vector3.html#a101ace91b0add48e5fcc959f6a037fd4":[5,2,6,7,132],
 "class_ogre_1_1_array_vector3.html#a101ace91b0add48e5fcc959f6a037fd4":[5,2,6,7,131],
+"class_ogre_1_1_array_vector3.html#a101ace91b0add48e5fcc959f6a037fd4":[5,2,6,7,132],
+"class_ogre_1_1_array_vector3.html#a101ace91b0add48e5fcc959f6a037fd4":[5,2,6,7,133],
 "class_ogre_1_1_array_vector3.html#a1850e46810eb005235fc6dcb7ebf6c9e":[5,2,6,7,198],
 "class_ogre_1_1_array_vector3.html#a1d76edf0716fe7260a288e0c879c6547":[5,2,6,7,99],
 "class_ogre_1_1_array_vector3.html#a1d76edf0716fe7260a288e0c879c6547":[5,2,6,7,98],
 "class_ogre_1_1_array_vector3.html#a1d76edf0716fe7260a288e0c879c6547":[5,2,6,7,97],
 "class_ogre_1_1_array_vector3.html#a1fcb417792cf81b60dcfaa0ec77b150f":[5,2,6,7,204],
 "class_ogre_1_1_array_vector3.html#a26d13d0e2cd250d894339d3f83b4e7a8":[5,2,6,7,1],
-"class_ogre_1_1_array_vector3.html#a26d13d0e2cd250d894339d3f83b4e7a8":[5,2,6,7,5],
 "class_ogre_1_1_array_vector3.html#a26d13d0e2cd250d894339d3f83b4e7a8":[5,2,6,7,3],
+"class_ogre_1_1_array_vector3.html#a26d13d0e2cd250d894339d3f83b4e7a8":[5,2,6,7,5],
 "class_ogre_1_1_array_vector3.html#a2b2c7df5a26223cf4997f177e2af2fb8":[5,2,6,7,160],
-"class_ogre_1_1_array_vector3.html#a2b2c7df5a26223cf4997f177e2af2fb8":[5,2,6,7,159],
 "class_ogre_1_1_array_vector3.html#a2b2c7df5a26223cf4997f177e2af2fb8":[5,2,6,7,158],
+"class_ogre_1_1_array_vector3.html#a2b2c7df5a26223cf4997f177e2af2fb8":[5,2,6,7,159],
 "class_ogre_1_1_array_vector3.html#a2e5f785b5a83995300ce5364cd8374ee":[5,2,6,7,180],
-"class_ogre_1_1_array_vector3.html#a2e5f785b5a83995300ce5364cd8374ee":[5,2,6,7,179],
 "class_ogre_1_1_array_vector3.html#a2e5f785b5a83995300ce5364cd8374ee":[5,2,6,7,181],
-"class_ogre_1_1_array_vector3.html#a2f04199290a76d2e1df59007b739f670":[5,2,6,7,129],
-"class_ogre_1_1_array_vector3.html#a2f04199290a76d2e1df59007b739f670":[5,2,6,7,128],
+"class_ogre_1_1_array_vector3.html#a2e5f785b5a83995300ce5364cd8374ee":[5,2,6,7,179],
 "class_ogre_1_1_array_vector3.html#a2f04199290a76d2e1df59007b739f670":[5,2,6,7,130],
+"class_ogre_1_1_array_vector3.html#a2f04199290a76d2e1df59007b739f670":[5,2,6,7,128],
+"class_ogre_1_1_array_vector3.html#a2f04199290a76d2e1df59007b739f670":[5,2,6,7,129],
 "class_ogre_1_1_array_vector3.html#a2f1339f5b3cf2661fb2ff3cf0b70c515":[5,2,6,7,157],
 "class_ogre_1_1_array_vector3.html#a2f1339f5b3cf2661fb2ff3cf0b70c515":[5,2,6,7,156],
 "class_ogre_1_1_array_vector3.html#a2f1339f5b3cf2661fb2ff3cf0b70c515":[5,2,6,7,155],
-"class_ogre_1_1_array_vector3.html#a34f2c866ac1fd2332b80d5049409f5f8":[5,2,6,7,26],
 "class_ogre_1_1_array_vector3.html#a34f2c866ac1fd2332b80d5049409f5f8":[5,2,6,7,24],
 "class_ogre_1_1_array_vector3.html#a34f2c866ac1fd2332b80d5049409f5f8":[5,2,6,7,25],
-"class_ogre_1_1_array_vector3.html#a35154dc79323513ec99b7dca4c43d1dc":[5,2,6,7,145],
+"class_ogre_1_1_array_vector3.html#a34f2c866ac1fd2332b80d5049409f5f8":[5,2,6,7,26],
 "class_ogre_1_1_array_vector3.html#a35154dc79323513ec99b7dca4c43d1dc":[5,2,6,7,144],
+"class_ogre_1_1_array_vector3.html#a35154dc79323513ec99b7dca4c43d1dc":[5,2,6,7,145],
 "class_ogre_1_1_array_vector3.html#a35154dc79323513ec99b7dca4c43d1dc":[5,2,6,7,143],
-"class_ogre_1_1_array_vector3.html#a3ee72f680790a341db04fac3be6c5691":[5,2,6,7,65],
 "class_ogre_1_1_array_vector3.html#a3ee72f680790a341db04fac3be6c5691":[5,2,6,7,64],
+"class_ogre_1_1_array_vector3.html#a3ee72f680790a341db04fac3be6c5691":[5,2,6,7,65],
 "class_ogre_1_1_array_vector3.html#a3ee72f680790a341db04fac3be6c5691":[5,2,6,7,63],
-"class_ogre_1_1_array_vector3.html#a40431a5fffe7c96ecf4fce6dd455e5ff":[5,2,6,7,16],
 "class_ogre_1_1_array_vector3.html#a40431a5fffe7c96ecf4fce6dd455e5ff":[5,2,6,7,15],
+"class_ogre_1_1_array_vector3.html#a40431a5fffe7c96ecf4fce6dd455e5ff":[5,2,6,7,16],
 "class_ogre_1_1_array_vector3.html#a40431a5fffe7c96ecf4fce6dd455e5ff":[5,2,6,7,17],
 "class_ogre_1_1_array_vector3.html#a4043d5a0b54859eea5b1173feab2a653":[5,2,6,7,125],
 "class_ogre_1_1_array_vector3.html#a4043d5a0b54859eea5b1173feab2a653":[5,2,6,7,126],
@@ -90,49 +92,49 @@ var NAVTREEINDEX15 =
 "class_ogre_1_1_array_vector3.html#a430a0a90f2cdab4764844a276636a2d9":[5,2,6,7,201],
 "class_ogre_1_1_array_vector3.html#a4377bd6a0f3c34d7fe96abac787a9720":[5,2,6,7,100],
 "class_ogre_1_1_array_vector3.html#a4377bd6a0f3c34d7fe96abac787a9720":[5,2,6,7,101],
-"class_ogre_1_1_array_vector3.html#a448dcf1a6d8eb4298a3dbb687afb7970":[5,2,6,7,107],
 "class_ogre_1_1_array_vector3.html#a448dcf1a6d8eb4298a3dbb687afb7970":[5,2,6,7,106],
+"class_ogre_1_1_array_vector3.html#a448dcf1a6d8eb4298a3dbb687afb7970":[5,2,6,7,107],
 "class_ogre_1_1_array_vector3.html#a448dcf1a6d8eb4298a3dbb687afb7970":[5,2,6,7,105],
+"class_ogre_1_1_array_vector3.html#a456e979750ed64f62fe083f04447264d":[5,2,6,7,57],
 "class_ogre_1_1_array_vector3.html#a456e979750ed64f62fe083f04447264d":[5,2,6,7,59],
 "class_ogre_1_1_array_vector3.html#a456e979750ed64f62fe083f04447264d":[5,2,6,7,58],
-"class_ogre_1_1_array_vector3.html#a456e979750ed64f62fe083f04447264d":[5,2,6,7,57],
-"class_ogre_1_1_array_vector3.html#a4950c21ce53c92acca289072479877f7":[5,2,6,7,6],
 "class_ogre_1_1_array_vector3.html#a4950c21ce53c92acca289072479877f7":[5,2,6,7,8],
 "class_ogre_1_1_array_vector3.html#a4950c21ce53c92acca289072479877f7":[5,2,6,7,7],
-"class_ogre_1_1_array_vector3.html#a4bc0bf26201ccf0eaca2292a27420526":[5,2,6,7,96],
-"class_ogre_1_1_array_vector3.html#a4bc0bf26201ccf0eaca2292a27420526":[5,2,6,7,95],
+"class_ogre_1_1_array_vector3.html#a4950c21ce53c92acca289072479877f7":[5,2,6,7,6],
 "class_ogre_1_1_array_vector3.html#a4bc0bf26201ccf0eaca2292a27420526":[5,2,6,7,94],
+"class_ogre_1_1_array_vector3.html#a4bc0bf26201ccf0eaca2292a27420526":[5,2,6,7,95],
+"class_ogre_1_1_array_vector3.html#a4bc0bf26201ccf0eaca2292a27420526":[5,2,6,7,96],
 "class_ogre_1_1_array_vector3.html#a4d62ed0f1cc257fc715822ad330958b2":[5,2,6,7,42],
-"class_ogre_1_1_array_vector3.html#a4d62ed0f1cc257fc715822ad330958b2":[5,2,6,7,44],
 "class_ogre_1_1_array_vector3.html#a4d62ed0f1cc257fc715822ad330958b2":[5,2,6,7,43],
-"class_ogre_1_1_array_vector3.html#a4e028c8ddea0849816bd5838276b2d84":[5,2,6,7,86],
-"class_ogre_1_1_array_vector3.html#a4e028c8ddea0849816bd5838276b2d84":[5,2,6,7,87],
+"class_ogre_1_1_array_vector3.html#a4d62ed0f1cc257fc715822ad330958b2":[5,2,6,7,44],
 "class_ogre_1_1_array_vector3.html#a4e028c8ddea0849816bd5838276b2d84":[5,2,6,7,88],
+"class_ogre_1_1_array_vector3.html#a4e028c8ddea0849816bd5838276b2d84":[5,2,6,7,87],
+"class_ogre_1_1_array_vector3.html#a4e028c8ddea0849816bd5838276b2d84":[5,2,6,7,86],
 "class_ogre_1_1_array_vector3.html#a562cba710f599b904af3e5ba81978dfd":[5,2,6,7,193],
-"class_ogre_1_1_array_vector3.html#a562cba710f599b904af3e5ba81978dfd":[5,2,6,7,191],
 "class_ogre_1_1_array_vector3.html#a562cba710f599b904af3e5ba81978dfd":[5,2,6,7,192],
+"class_ogre_1_1_array_vector3.html#a562cba710f599b904af3e5ba81978dfd":[5,2,6,7,191],
 "class_ogre_1_1_array_vector3.html#a593d3dc8c197b35438397cd18c4be868":[5,2,6,7,173],
 "class_ogre_1_1_array_vector3.html#a593d3dc8c197b35438397cd18c4be868":[5,2,6,7,174],
 "class_ogre_1_1_array_vector3.html#a593d3dc8c197b35438397cd18c4be868":[5,2,6,7,175],
 "class_ogre_1_1_array_vector3.html#a5a17d1040d1c54120f64b657301b47f1":[5,2,6,7,161],
-"class_ogre_1_1_array_vector3.html#a5a17d1040d1c54120f64b657301b47f1":[5,2,6,7,163],
 "class_ogre_1_1_array_vector3.html#a5a17d1040d1c54120f64b657301b47f1":[5,2,6,7,162],
+"class_ogre_1_1_array_vector3.html#a5a17d1040d1c54120f64b657301b47f1":[5,2,6,7,163],
 "class_ogre_1_1_array_vector3.html#a628d9a2a7f22c66fd901e5432f095a98":[5,2,6,7,110],
-"class_ogre_1_1_array_vector3.html#a628d9a2a7f22c66fd901e5432f095a98":[5,2,6,7,112],
 "class_ogre_1_1_array_vector3.html#a628d9a2a7f22c66fd901e5432f095a98":[5,2,6,7,111],
+"class_ogre_1_1_array_vector3.html#a628d9a2a7f22c66fd901e5432f095a98":[5,2,6,7,112],
 "class_ogre_1_1_array_vector3.html#a62cb4ba8c5f808cc1dff2244cf47b38f":[5,2,6,7,93],
 "class_ogre_1_1_array_vector3.html#a62cb4ba8c5f808cc1dff2244cf47b38f":[5,2,6,7,92],
 "class_ogre_1_1_array_vector3.html#a62cb4ba8c5f808cc1dff2244cf47b38f":[5,2,6,7,91],
 "class_ogre_1_1_array_vector3.html#a63ce091c241e52986e45298af2cc53c8":[5,2,6,7,103],
-"class_ogre_1_1_array_vector3.html#a63ce091c241e52986e45298af2cc53c8":[5,2,6,7,102],
 "class_ogre_1_1_array_vector3.html#a63ce091c241e52986e45298af2cc53c8":[5,2,6,7,104],
+"class_ogre_1_1_array_vector3.html#a63ce091c241e52986e45298af2cc53c8":[5,2,6,7,102],
 "class_ogre_1_1_array_vector3.html#a648c9686db201b1e04e38d0dbaff416e":[5,2,6,7,4],
-"class_ogre_1_1_array_vector3.html#a648c9686db201b1e04e38d0dbaff416e":[5,2,6,7,0],
 "class_ogre_1_1_array_vector3.html#a648c9686db201b1e04e38d0dbaff416e":[5,2,6,7,2],
+"class_ogre_1_1_array_vector3.html#a648c9686db201b1e04e38d0dbaff416e":[5,2,6,7,0],
 "class_ogre_1_1_array_vector3.html#a6a152308d886080433232254917bb4bb":[5,2,6,7,203],
-"class_ogre_1_1_array_vector3.html#a6df36f6acd1a5a62ac5f00571b2a8a3a":[5,2,6,7,50],
-"class_ogre_1_1_array_vector3.html#a6df36f6acd1a5a62ac5f00571b2a8a3a":[5,2,6,7,49],
 "class_ogre_1_1_array_vector3.html#a6df36f6acd1a5a62ac5f00571b2a8a3a":[5,2,6,7,48],
+"class_ogre_1_1_array_vector3.html#a6df36f6acd1a5a62ac5f00571b2a8a3a":[5,2,6,7,49],
+"class_ogre_1_1_array_vector3.html#a6df36f6acd1a5a62ac5f00571b2a8a3a":[5,2,6,7,50],
 "class_ogre_1_1_array_vector3.html#a6e8e9b0e7599217aeebb8ad30b9a62bb":[5,2,6,7,27],
 "class_ogre_1_1_array_vector3.html#a6e8e9b0e7599217aeebb8ad30b9a62bb":[5,2,6,7,28],
 "class_ogre_1_1_array_vector3.html#a6e8e9b0e7599217aeebb8ad30b9a62bb":[5,2,6,7,29],
@@ -141,113 +143,111 @@ var NAVTREEINDEX15 =
 "class_ogre_1_1_array_vector3.html#a78faa789317226334e7940b998e61c28":[5,2,6,7,66],
 "class_ogre_1_1_array_vector3.html#a78faa789317226334e7940b998e61c28":[5,2,6,7,67],
 "class_ogre_1_1_array_vector3.html#a78faa789317226334e7940b998e61c28":[5,2,6,7,68],
-"class_ogre_1_1_array_vector3.html#a805a9b00aaa5a7814c5223c889ec5444":[5,2,6,7,10],
 "class_ogre_1_1_array_vector3.html#a805a9b00aaa5a7814c5223c889ec5444":[5,2,6,7,11],
 "class_ogre_1_1_array_vector3.html#a805a9b00aaa5a7814c5223c889ec5444":[5,2,6,7,9],
+"class_ogre_1_1_array_vector3.html#a805a9b00aaa5a7814c5223c889ec5444":[5,2,6,7,10],
 "class_ogre_1_1_array_vector3.html#a811d19510f8352453fa8f86d8c226a49":[5,2,6,7,202],
-"class_ogre_1_1_array_vector3.html#a8234218506651f28d009fe48459a58ac":[5,2,6,7,190],
-"class_ogre_1_1_array_vector3.html#a8234218506651f28d009fe48459a58ac":[5,2,6,7,189],
 "class_ogre_1_1_array_vector3.html#a8234218506651f28d009fe48459a58ac":[5,2,6,7,188],
-"class_ogre_1_1_array_vector3.html#a8c34e42bf951a4dfd877241c2ac9e3f8":[5,2,6,7,122],
+"class_ogre_1_1_array_vector3.html#a8234218506651f28d009fe48459a58ac":[5,2,6,7,189],
+"class_ogre_1_1_array_vector3.html#a8234218506651f28d009fe48459a58ac":[5,2,6,7,190],
 "class_ogre_1_1_array_vector3.html#a8c34e42bf951a4dfd877241c2ac9e3f8":[5,2,6,7,123],
+"class_ogre_1_1_array_vector3.html#a8c34e42bf951a4dfd877241c2ac9e3f8":[5,2,6,7,122],
 "class_ogre_1_1_array_vector3.html#a8c34e42bf951a4dfd877241c2ac9e3f8":[5,2,6,7,124],
 "class_ogre_1_1_array_vector3.html#a8fa921a8d16b20e4360b75b6132a6fcd":[5,2,6,7,45],
 "class_ogre_1_1_array_vector3.html#a8fa921a8d16b20e4360b75b6132a6fcd":[5,2,6,7,46],
 "class_ogre_1_1_array_vector3.html#a8fa921a8d16b20e4360b75b6132a6fcd":[5,2,6,7,47],
 "class_ogre_1_1_array_vector3.html#a8fb49217a4bfb137555db4b2ad017b91":[5,2,6,7,21],
-"class_ogre_1_1_array_vector3.html#a8fb49217a4bfb137555db4b2ad017b91":[5,2,6,7,22],
 "class_ogre_1_1_array_vector3.html#a8fb49217a4bfb137555db4b2ad017b91":[5,2,6,7,23],
+"class_ogre_1_1_array_vector3.html#a8fb49217a4bfb137555db4b2ad017b91":[5,2,6,7,22],
 "class_ogre_1_1_array_vector3.html#a9282cdd8d88616927501af0769b114ab":[5,2,6,7,195],
-"class_ogre_1_1_array_vector3.html#a9282cdd8d88616927501af0769b114ab":[5,2,6,7,196],
 "class_ogre_1_1_array_vector3.html#a9282cdd8d88616927501af0769b114ab":[5,2,6,7,194],
-"class_ogre_1_1_array_vector3.html#a96be5dec2fce6a3afd7ce9d369776a87":[5,2,6,7,182],
+"class_ogre_1_1_array_vector3.html#a9282cdd8d88616927501af0769b114ab":[5,2,6,7,196],
 "class_ogre_1_1_array_vector3.html#a96be5dec2fce6a3afd7ce9d369776a87":[5,2,6,7,183],
+"class_ogre_1_1_array_vector3.html#a96be5dec2fce6a3afd7ce9d369776a87":[5,2,6,7,182],
 "class_ogre_1_1_array_vector3.html#a96be5dec2fce6a3afd7ce9d369776a87":[5,2,6,7,184],
 "class_ogre_1_1_array_vector3.html#a9b512047e8401f1ad418413535df5b10":[5,2,6,7,108],
 "class_ogre_1_1_array_vector3.html#a9b512047e8401f1ad418413535df5b10":[5,2,6,7,109],
 "class_ogre_1_1_array_vector3.html#a9bcda6cac93c0156f8ac2ad181c91d79":[5,2,6,7,151],
-"class_ogre_1_1_array_vector3.html#a9bcda6cac93c0156f8ac2ad181c91d79":[5,2,6,7,150],
 "class_ogre_1_1_array_vector3.html#a9bcda6cac93c0156f8ac2ad181c91d79":[5,2,6,7,149],
-"class_ogre_1_1_array_vector3.html#aa1da9a8f7332070b10426a64bc80f36d":[5,2,6,7,137],
-"class_ogre_1_1_array_vector3.html#aa1da9a8f7332070b10426a64bc80f36d":[5,2,6,7,138],
+"class_ogre_1_1_array_vector3.html#a9bcda6cac93c0156f8ac2ad181c91d79":[5,2,6,7,150],
 "class_ogre_1_1_array_vector3.html#aa1da9a8f7332070b10426a64bc80f36d":[5,2,6,7,139],
+"class_ogre_1_1_array_vector3.html#aa1da9a8f7332070b10426a64bc80f36d":[5,2,6,7,138],
+"class_ogre_1_1_array_vector3.html#aa1da9a8f7332070b10426a64bc80f36d":[5,2,6,7,137],
+"class_ogre_1_1_array_vector3.html#aa234d85338fdb34ec62d8abd510efedf":[5,2,6,7,141],
 "class_ogre_1_1_array_vector3.html#aa234d85338fdb34ec62d8abd510efedf":[5,2,6,7,140],
 "class_ogre_1_1_array_vector3.html#aa234d85338fdb34ec62d8abd510efedf":[5,2,6,7,142],
-"class_ogre_1_1_array_vector3.html#aa234d85338fdb34ec62d8abd510efedf":[5,2,6,7,141],
-"class_ogre_1_1_array_vector3.html#aa6e27c2ec4412788016f4c389536fdea":[5,2,6,7,84],
-"class_ogre_1_1_array_vector3.html#aa6e27c2ec4412788016f4c389536fdea":[5,2,6,7,85],
 "class_ogre_1_1_array_vector3.html#aa6e27c2ec4412788016f4c389536fdea":[5,2,6,7,83],
-"class_ogre_1_1_array_vector3.html#aa8e0b920f898d2a32c9d7f0cecd4b6ec":[5,2,6,7,115],
+"class_ogre_1_1_array_vector3.html#aa6e27c2ec4412788016f4c389536fdea":[5,2,6,7,85],
+"class_ogre_1_1_array_vector3.html#aa6e27c2ec4412788016f4c389536fdea":[5,2,6,7,84],
 "class_ogre_1_1_array_vector3.html#aa8e0b920f898d2a32c9d7f0cecd4b6ec":[5,2,6,7,114],
+"class_ogre_1_1_array_vector3.html#aa8e0b920f898d2a32c9d7f0cecd4b6ec":[5,2,6,7,115],
 "class_ogre_1_1_array_vector3.html#aa8e0b920f898d2a32c9d7f0cecd4b6ec":[5,2,6,7,113],
+"class_ogre_1_1_array_vector3.html#aac65bfcb4e385ac60b021ebc14f386ed":[5,2,6,7,80],
 "class_ogre_1_1_array_vector3.html#aac65bfcb4e385ac60b021ebc14f386ed":[5,2,6,7,82],
 "class_ogre_1_1_array_vector3.html#aac65bfcb4e385ac60b021ebc14f386ed":[5,2,6,7,81],
-"class_ogre_1_1_array_vector3.html#aac65bfcb4e385ac60b021ebc14f386ed":[5,2,6,7,80],
-"class_ogre_1_1_array_vector3.html#aaec06d68161d4123b3fad14fb72fd9c5":[5,2,6,7,34],
 "class_ogre_1_1_array_vector3.html#aaec06d68161d4123b3fad14fb72fd9c5":[5,2,6,7,33],
+"class_ogre_1_1_array_vector3.html#aaec06d68161d4123b3fad14fb72fd9c5":[5,2,6,7,34],
 "class_ogre_1_1_array_vector3.html#aaec06d68161d4123b3fad14fb72fd9c5":[5,2,6,7,35],
+"class_ogre_1_1_array_vector3.html#ab573b7c18f1f76071a3f40b0e1bfd9ea":[5,2,6,7,61],
 "class_ogre_1_1_array_vector3.html#ab573b7c18f1f76071a3f40b0e1bfd9ea":[5,2,6,7,60],
 "class_ogre_1_1_array_vector3.html#ab573b7c18f1f76071a3f40b0e1bfd9ea":[5,2,6,7,62],
-"class_ogre_1_1_array_vector3.html#ab573b7c18f1f76071a3f40b0e1bfd9ea":[5,2,6,7,61],
-"class_ogre_1_1_array_vector3.html#ab5b7a214726ba5ac0e7c39493e8baed0":[5,2,6,7,41],
 "class_ogre_1_1_array_vector3.html#ab5b7a214726ba5ac0e7c39493e8baed0":[5,2,6,7,39],
 "class_ogre_1_1_array_vector3.html#ab5b7a214726ba5ac0e7c39493e8baed0":[5,2,6,7,40],
-"class_ogre_1_1_array_vector3.html#ab6ab388de60346a25db6a88ef83ab658":[5,2,6,7,119],
-"class_ogre_1_1_array_vector3.html#ab6ab388de60346a25db6a88ef83ab658":[5,2,6,7,120],
+"class_ogre_1_1_array_vector3.html#ab5b7a214726ba5ac0e7c39493e8baed0":[5,2,6,7,41],
 "class_ogre_1_1_array_vector3.html#ab6ab388de60346a25db6a88ef83ab658":[5,2,6,7,121],
-"class_ogre_1_1_array_vector3.html#ab74355e17ae530d4938a47405c954b44":[5,2,6,7,165],
+"class_ogre_1_1_array_vector3.html#ab6ab388de60346a25db6a88ef83ab658":[5,2,6,7,120],
+"class_ogre_1_1_array_vector3.html#ab6ab388de60346a25db6a88ef83ab658":[5,2,6,7,119],
 "class_ogre_1_1_array_vector3.html#ab74355e17ae530d4938a47405c954b44":[5,2,6,7,164],
+"class_ogre_1_1_array_vector3.html#ab74355e17ae530d4938a47405c954b44":[5,2,6,7,165],
 "class_ogre_1_1_array_vector3.html#ab74355e17ae530d4938a47405c954b44":[5,2,6,7,166],
-"class_ogre_1_1_array_vector3.html#ac2fbed28450e4e09a015a7de33d493cc":[5,2,6,7,167],
-"class_ogre_1_1_array_vector3.html#ac2fbed28450e4e09a015a7de33d493cc":[5,2,6,7,169],
 "class_ogre_1_1_array_vector3.html#ac2fbed28450e4e09a015a7de33d493cc":[5,2,6,7,168],
-"class_ogre_1_1_array_vector3.html#ad261d645fdf7f488ad9cca7a9a0e986f":[5,2,6,7,38],
+"class_ogre_1_1_array_vector3.html#ac2fbed28450e4e09a015a7de33d493cc":[5,2,6,7,169],
+"class_ogre_1_1_array_vector3.html#ac2fbed28450e4e09a015a7de33d493cc":[5,2,6,7,167],
 "class_ogre_1_1_array_vector3.html#ad261d645fdf7f488ad9cca7a9a0e986f":[5,2,6,7,36],
 "class_ogre_1_1_array_vector3.html#ad261d645fdf7f488ad9cca7a9a0e986f":[5,2,6,7,37],
+"class_ogre_1_1_array_vector3.html#ad261d645fdf7f488ad9cca7a9a0e986f":[5,2,6,7,38],
 "class_ogre_1_1_array_vector3.html#ad37aed4b430c6d8b50b47d5eac29cb7d":[5,2,6,7,197],
-"class_ogre_1_1_array_vector3.html#ad8261e192367367f56def116c8a9deed":[5,2,6,7,187],
 "class_ogre_1_1_array_vector3.html#ad8261e192367367f56def116c8a9deed":[5,2,6,7,185],
 "class_ogre_1_1_array_vector3.html#ad8261e192367367f56def116c8a9deed":[5,2,6,7,186],
+"class_ogre_1_1_array_vector3.html#ad8261e192367367f56def116c8a9deed":[5,2,6,7,187],
+"class_ogre_1_1_array_vector3.html#ad990bd193089901d14ad24bcfbfc9242":[5,2,6,7,118],
 "class_ogre_1_1_array_vector3.html#ad990bd193089901d14ad24bcfbfc9242":[5,2,6,7,117],
 "class_ogre_1_1_array_vector3.html#ad990bd193089901d14ad24bcfbfc9242":[5,2,6,7,116],
-"class_ogre_1_1_array_vector3.html#ad990bd193089901d14ad24bcfbfc9242":[5,2,6,7,118],
 "class_ogre_1_1_array_vector3.html#adf3ddabbf07ee074fb9f92faa2a19da1":[5,2,6,7,53],
-"class_ogre_1_1_array_vector3.html#adf3ddabbf07ee074fb9f92faa2a19da1":[5,2,6,7,51],
 "class_ogre_1_1_array_vector3.html#adf3ddabbf07ee074fb9f92faa2a19da1":[5,2,6,7,52],
+"class_ogre_1_1_array_vector3.html#adf3ddabbf07ee074fb9f92faa2a19da1":[5,2,6,7,51],
 "class_ogre_1_1_array_vector3.html#ae01d1a2ad3c795ed608ed191c84de476":[5,2,6,7,56],
-"class_ogre_1_1_array_vector3.html#ae01d1a2ad3c795ed608ed191c84de476":[5,2,6,7,55],
 "class_ogre_1_1_array_vector3.html#ae01d1a2ad3c795ed608ed191c84de476":[5,2,6,7,54],
+"class_ogre_1_1_array_vector3.html#ae01d1a2ad3c795ed608ed191c84de476":[5,2,6,7,55],
+"class_ogre_1_1_array_vector3.html#ae4afec2be1d360d7d077e41f023f3b5a":[5,2,6,7,18],
 "class_ogre_1_1_array_vector3.html#ae4afec2be1d360d7d077e41f023f3b5a":[5,2,6,7,20],
 "class_ogre_1_1_array_vector3.html#ae4afec2be1d360d7d077e41f023f3b5a":[5,2,6,7,19],
-"class_ogre_1_1_array_vector3.html#ae4afec2be1d360d7d077e41f023f3b5a":[5,2,6,7,18],
+"class_ogre_1_1_array_vector3.html#ae6ba2bd0750dc691b18d6f49a7082009":[5,2,6,7,172],
 "class_ogre_1_1_array_vector3.html#ae6ba2bd0750dc691b18d6f49a7082009":[5,2,6,7,171],
 "class_ogre_1_1_array_vector3.html#ae6ba2bd0750dc691b18d6f49a7082009":[5,2,6,7,170],
-"class_ogre_1_1_array_vector3.html#ae6ba2bd0750dc691b18d6f49a7082009":[5,2,6,7,172],
 "class_ogre_1_1_array_vector3.html#aeb4a9c7b168037f0d46b1476cfad8035":[5,2,6,7,176],
 "class_ogre_1_1_array_vector3.html#aeb4a9c7b168037f0d46b1476cfad8035":[5,2,6,7,177],
 "class_ogre_1_1_array_vector3.html#aeb4a9c7b168037f0d46b1476cfad8035":[5,2,6,7,178],
-"class_ogre_1_1_array_vector3.html#af126fffa83c6d1bf3d6d3a2d67979430":[5,2,6,7,30],
-"class_ogre_1_1_array_vector3.html#af126fffa83c6d1bf3d6d3a2d67979430":[5,2,6,7,31],
 "class_ogre_1_1_array_vector3.html#af126fffa83c6d1bf3d6d3a2d67979430":[5,2,6,7,32],
-"class_ogre_1_1_array_vector3.html#af1780194efb10594484f2d3f9306b2c2":[5,2,6,7,71],
-"class_ogre_1_1_array_vector3.html#af1780194efb10594484f2d3f9306b2c2":[5,2,6,7,70],
+"class_ogre_1_1_array_vector3.html#af126fffa83c6d1bf3d6d3a2d67979430":[5,2,6,7,31],
+"class_ogre_1_1_array_vector3.html#af126fffa83c6d1bf3d6d3a2d67979430":[5,2,6,7,30],
 "class_ogre_1_1_array_vector3.html#af1780194efb10594484f2d3f9306b2c2":[5,2,6,7,69],
-"class_ogre_1_1_array_vector3.html#af6afb89604e05e1240f4cfc2e9695591":[5,2,6,7,136],
-"class_ogre_1_1_array_vector3.html#af6afb89604e05e1240f4cfc2e9695591":[5,2,6,7,135],
+"class_ogre_1_1_array_vector3.html#af1780194efb10594484f2d3f9306b2c2":[5,2,6,7,70],
+"class_ogre_1_1_array_vector3.html#af1780194efb10594484f2d3f9306b2c2":[5,2,6,7,71],
 "class_ogre_1_1_array_vector3.html#af6afb89604e05e1240f4cfc2e9695591":[5,2,6,7,134],
-"class_ogre_1_1_array_vector3.html#af899eb2447629726f0021c24174e2d8d":[5,2,6,7,89],
+"class_ogre_1_1_array_vector3.html#af6afb89604e05e1240f4cfc2e9695591":[5,2,6,7,135],
+"class_ogre_1_1_array_vector3.html#af6afb89604e05e1240f4cfc2e9695591":[5,2,6,7,136],
 "class_ogre_1_1_array_vector3.html#af899eb2447629726f0021c24174e2d8d":[5,2,6,7,90],
-"class_ogre_1_1_array_vector3.html#afb4e1c7d15b5819e3cdb720bc133fb96":[5,2,6,7,12],
+"class_ogre_1_1_array_vector3.html#af899eb2447629726f0021c24174e2d8d":[5,2,6,7,89],
 "class_ogre_1_1_array_vector3.html#afb4e1c7d15b5819e3cdb720bc133fb96":[5,2,6,7,13],
 "class_ogre_1_1_array_vector3.html#afb4e1c7d15b5819e3cdb720bc133fb96":[5,2,6,7,14],
-"class_ogre_1_1_array_vector3.html#afea1bbb9c9ca492fb1936e455f649fa8":[5,2,6,7,148],
-"class_ogre_1_1_array_vector3.html#afea1bbb9c9ca492fb1936e455f649fa8":[5,2,6,7,147],
+"class_ogre_1_1_array_vector3.html#afb4e1c7d15b5819e3cdb720bc133fb96":[5,2,6,7,12],
 "class_ogre_1_1_array_vector3.html#afea1bbb9c9ca492fb1936e455f649fa8":[5,2,6,7,146],
-"class_ogre_1_1_async_texture_ticket.html":[6,0,0,65],
+"class_ogre_1_1_array_vector3.html#afea1bbb9c9ca492fb1936e455f649fa8":[5,2,6,7,147],
+"class_ogre_1_1_array_vector3.html#afea1bbb9c9ca492fb1936e455f649fa8":[5,2,6,7,148],
 "class_ogre_1_1_async_texture_ticket.html":[7,0,0,38],
-"class_ogre_1_1_async_texture_ticket.html#a1427f0b635a4186cd6083a9bab879fa2":[6,0,0,65,28],
+"class_ogre_1_1_async_texture_ticket.html":[6,0,0,65],
 "class_ogre_1_1_async_texture_ticket.html#a1427f0b635a4186cd6083a9bab879fa2":[7,0,0,38,28],
-"class_ogre_1_1_async_texture_ticket.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,38,19],
-"class_ogre_1_1_async_texture_ticket.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,65,19],
-"class_ogre_1_1_async_texture_ticket.html#a25041a6b2f21149ddfd4a85d82006b00":[7,0,0,38,11]
+"class_ogre_1_1_async_texture_ticket.html#a1427f0b635a4186cd6083a9bab879fa2":[6,0,0,65,28],
+"class_ogre_1_1_async_texture_ticket.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,38,19]
 };
