@@ -1,13 +1,15 @@
 var NAVTREEINDEX151 =
 {
-"class_ogre_1_1_metal_device_list.html#a010554b0f42a6b41974a528a5b2ea053":[7,0,0,638,1],
+"class_ogre_1_1_metal_device_list.html":[6,0,0,665],
+"class_ogre_1_1_metal_device_list.html":[7,0,0,638],
 "class_ogre_1_1_metal_device_list.html#a010554b0f42a6b41974a528a5b2ea053":[6,0,0,665,1],
+"class_ogre_1_1_metal_device_list.html#a010554b0f42a6b41974a528a5b2ea053":[7,0,0,638,1],
 "class_ogre_1_1_metal_device_list.html#a229ecf8b0e375a1badd81dfc8eca0230":[6,0,0,665,3],
 "class_ogre_1_1_metal_device_list.html#a229ecf8b0e375a1badd81dfc8eca0230":[7,0,0,638,3],
 "class_ogre_1_1_metal_device_list.html#a2c7cac74ab1330e754ed53bf8e46a190":[6,0,0,665,0],
 "class_ogre_1_1_metal_device_list.html#a2c7cac74ab1330e754ed53bf8e46a190":[7,0,0,638,0],
-"class_ogre_1_1_metal_device_list.html#ae849211f10db226e5ee6441d0ba61e46":[6,0,0,665,4],
 "class_ogre_1_1_metal_device_list.html#ae849211f10db226e5ee6441d0ba61e46":[7,0,0,638,4],
+"class_ogre_1_1_metal_device_list.html#ae849211f10db226e5ee6441d0ba61e46":[6,0,0,665,4],
 "class_ogre_1_1_metal_device_list.html#aeb7fd49d5b5bd46fb0d662e7ad33bd35":[6,0,0,665,2],
 "class_ogre_1_1_metal_device_list.html#aeb7fd49d5b5bd46fb0d662e7ad33bd35":[7,0,0,638,2],
 "class_ogre_1_1_metal_discard_buffer.html":[6,0,0,666],
@@ -18,60 +20,60 @@ var NAVTREEINDEX151 =
 "class_ogre_1_1_metal_discard_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,666,11],
 "class_ogre_1_1_metal_discard_buffer.html#a2f3e5d36acc1db27317078522260b666":[7,0,0,639,19],
 "class_ogre_1_1_metal_discard_buffer.html#a2f3e5d36acc1db27317078522260b666":[6,0,0,666,19],
-"class_ogre_1_1_metal_discard_buffer.html#a353865cac81742d6be7a070a8bb4ec19":[7,0,0,639,0],
 "class_ogre_1_1_metal_discard_buffer.html#a353865cac81742d6be7a070a8bb4ec19":[6,0,0,666,0],
-"class_ogre_1_1_metal_discard_buffer.html#a49cbe9b6f6f7fb418c6161ba66ba144c":[6,0,0,666,7],
+"class_ogre_1_1_metal_discard_buffer.html#a353865cac81742d6be7a070a8bb4ec19":[7,0,0,639,0],
 "class_ogre_1_1_metal_discard_buffer.html#a49cbe9b6f6f7fb418c6161ba66ba144c":[7,0,0,639,7],
-"class_ogre_1_1_metal_discard_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,639,13],
+"class_ogre_1_1_metal_discard_buffer.html#a49cbe9b6f6f7fb418c6161ba66ba144c":[6,0,0,666,7],
 "class_ogre_1_1_metal_discard_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,666,13],
-"class_ogre_1_1_metal_discard_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,666,16],
+"class_ogre_1_1_metal_discard_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,639,13],
 "class_ogre_1_1_metal_discard_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,639,16],
-"class_ogre_1_1_metal_discard_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,639,9],
+"class_ogre_1_1_metal_discard_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,666,16],
 "class_ogre_1_1_metal_discard_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,666,9],
+"class_ogre_1_1_metal_discard_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,639,9],
 "class_ogre_1_1_metal_discard_buffer.html#a910ba95a57b2a48bce4924f1e256e628":[6,0,0,666,1],
 "class_ogre_1_1_metal_discard_buffer.html#a910ba95a57b2a48bce4924f1e256e628":[7,0,0,639,1],
 "class_ogre_1_1_metal_discard_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,639,12],
 "class_ogre_1_1_metal_discard_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,666,12],
-"class_ogre_1_1_metal_discard_buffer.html#aa4051916151e6583bbe11cecb25659b4":[7,0,0,639,3],
 "class_ogre_1_1_metal_discard_buffer.html#aa4051916151e6583bbe11cecb25659b4":[6,0,0,666,3],
-"class_ogre_1_1_metal_discard_buffer.html#aa6d608e8584f94f5f9096d4954556cbb":[7,0,0,639,20],
+"class_ogre_1_1_metal_discard_buffer.html#aa4051916151e6583bbe11cecb25659b4":[7,0,0,639,3],
 "class_ogre_1_1_metal_discard_buffer.html#aa6d608e8584f94f5f9096d4954556cbb":[6,0,0,666,20],
-"class_ogre_1_1_metal_discard_buffer.html#aab7b0b1fc6e3245aedc436353e906305":[6,0,0,666,2],
+"class_ogre_1_1_metal_discard_buffer.html#aa6d608e8584f94f5f9096d4954556cbb":[7,0,0,639,20],
 "class_ogre_1_1_metal_discard_buffer.html#aab7b0b1fc6e3245aedc436353e906305":[7,0,0,639,2],
-"class_ogre_1_1_metal_discard_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,666,15],
+"class_ogre_1_1_metal_discard_buffer.html#aab7b0b1fc6e3245aedc436353e906305":[6,0,0,666,2],
 "class_ogre_1_1_metal_discard_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,639,15],
-"class_ogre_1_1_metal_discard_buffer.html#abe8ec11c0e7602228c88fd900ecb0a40":[6,0,0,666,6],
+"class_ogre_1_1_metal_discard_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,666,15],
 "class_ogre_1_1_metal_discard_buffer.html#abe8ec11c0e7602228c88fd900ecb0a40":[7,0,0,639,6],
-"class_ogre_1_1_metal_discard_buffer.html#ac6fc7368d2dc0d93200a5b901c1a0434":[6,0,0,666,5],
+"class_ogre_1_1_metal_discard_buffer.html#abe8ec11c0e7602228c88fd900ecb0a40":[6,0,0,666,6],
 "class_ogre_1_1_metal_discard_buffer.html#ac6fc7368d2dc0d93200a5b901c1a0434":[7,0,0,639,5],
-"class_ogre_1_1_metal_discard_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,666,10],
+"class_ogre_1_1_metal_discard_buffer.html#ac6fc7368d2dc0d93200a5b901c1a0434":[6,0,0,666,5],
 "class_ogre_1_1_metal_discard_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,639,10],
+"class_ogre_1_1_metal_discard_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,666,10],
 "class_ogre_1_1_metal_discard_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,639,14],
 "class_ogre_1_1_metal_discard_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,666,14],
-"class_ogre_1_1_metal_discard_buffer.html#adce32528577d71b228692df906ecd17c":[7,0,0,639,17],
 "class_ogre_1_1_metal_discard_buffer.html#adce32528577d71b228692df906ecd17c":[6,0,0,666,17],
+"class_ogre_1_1_metal_discard_buffer.html#adce32528577d71b228692df906ecd17c":[7,0,0,639,17],
 "class_ogre_1_1_metal_discard_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,666,18],
 "class_ogre_1_1_metal_discard_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,639,18],
 "class_ogre_1_1_metal_discard_buffer.html#af33741f1af49c8cd9564204f46fd0da3":[7,0,0,639,4],
 "class_ogre_1_1_metal_discard_buffer.html#af33741f1af49c8cd9564204f46fd0da3":[6,0,0,666,4],
-"class_ogre_1_1_metal_discard_buffer_manager.html":[7,0,0,640],
 "class_ogre_1_1_metal_discard_buffer_manager.html":[6,0,0,667],
-"class_ogre_1_1_metal_discard_buffer_manager.html#a0237db555814ab90aac4d9e89fc674cf":[6,0,0,667,3],
+"class_ogre_1_1_metal_discard_buffer_manager.html":[7,0,0,640],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a0237db555814ab90aac4d9e89fc674cf":[7,0,0,640,3],
-"class_ogre_1_1_metal_discard_buffer_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,640,12],
+"class_ogre_1_1_metal_discard_buffer_manager.html#a0237db555814ab90aac4d9e89fc674cf":[6,0,0,667,3],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,667,12],
-"class_ogre_1_1_metal_discard_buffer_manager.html#a338c91f9060e9fc08da3b300c2852f18":[6,0,0,667,8],
+"class_ogre_1_1_metal_discard_buffer_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,640,12],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a338c91f9060e9fc08da3b300c2852f18":[7,0,0,640,8],
+"class_ogre_1_1_metal_discard_buffer_manager.html#a338c91f9060e9fc08da3b300c2852f18":[6,0,0,667,8],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a3651ee834a507f877021ffcdebc01734":[7,0,0,640,1],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a3651ee834a507f877021ffcdebc01734":[6,0,0,667,1],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a46a7e7735b6d7bcded420c091d3fca40":[7,0,0,640,6],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a46a7e7735b6d7bcded420c091d3fca40":[6,0,0,667,6],
-"class_ogre_1_1_metal_discard_buffer_manager.html#a50fb9fed588421fb9ac6732fd98efbf2":[6,0,0,667,7],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a50fb9fed588421fb9ac6732fd98efbf2":[7,0,0,640,7],
+"class_ogre_1_1_metal_discard_buffer_manager.html#a50fb9fed588421fb9ac6732fd98efbf2":[6,0,0,667,7],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,667,14],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,640,14],
-"class_ogre_1_1_metal_discard_buffer_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,640,17],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,667,17],
+"class_ogre_1_1_metal_discard_buffer_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,640,17],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a69932d68f4f31138060c210a06780315":[7,0,0,640,5],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a69932d68f4f31138060c210a06780315":[6,0,0,667,5],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a6ce02978ae006aed921fef70c80e73e5":[7,0,0,640,9],
@@ -80,20 +82,20 @@ var NAVTREEINDEX151 =
 "class_ogre_1_1_metal_discard_buffer_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,667,10],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,640,13],
 "class_ogre_1_1_metal_discard_buffer_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,667,13],
-"class_ogre_1_1_metal_discard_buffer_manager.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,667,16],
 "class_ogre_1_1_metal_discard_buffer_manager.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,640,16],
+"class_ogre_1_1_metal_discard_buffer_manager.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,667,16],
 "class_ogre_1_1_metal_discard_buffer_manager.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,667,11],
 "class_ogre_1_1_metal_discard_buffer_manager.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,640,11],
 "class_ogre_1_1_metal_discard_buffer_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,640,15],
 "class_ogre_1_1_metal_discard_buffer_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,667,15],
-"class_ogre_1_1_metal_discard_buffer_manager.html#adce32528577d71b228692df906ecd17c":[6,0,0,667,18],
 "class_ogre_1_1_metal_discard_buffer_manager.html#adce32528577d71b228692df906ecd17c":[7,0,0,640,18],
-"class_ogre_1_1_metal_discard_buffer_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,667,19],
+"class_ogre_1_1_metal_discard_buffer_manager.html#adce32528577d71b228692df906ecd17c":[6,0,0,667,18],
 "class_ogre_1_1_metal_discard_buffer_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,640,19],
-"class_ogre_1_1_metal_discard_buffer_manager.html#aef0f4ad118c914c73a49d3af71fa3593":[6,0,0,667,4],
+"class_ogre_1_1_metal_discard_buffer_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,667,19],
 "class_ogre_1_1_metal_discard_buffer_manager.html#aef0f4ad118c914c73a49d3af71fa3593":[7,0,0,640,4],
-"class_ogre_1_1_metal_discard_buffer_manager.html#af2d5bd7439c1a8608907ceb5ed1d64f6":[7,0,0,640,2],
+"class_ogre_1_1_metal_discard_buffer_manager.html#aef0f4ad118c914c73a49d3af71fa3593":[6,0,0,667,4],
 "class_ogre_1_1_metal_discard_buffer_manager.html#af2d5bd7439c1a8608907ceb5ed1d64f6":[6,0,0,667,2],
+"class_ogre_1_1_metal_discard_buffer_manager.html#af2d5bd7439c1a8608907ceb5ed1d64f6":[7,0,0,640,2],
 "class_ogre_1_1_metal_dynamic_buffer.html":[6,0,0,668],
 "class_ogre_1_1_metal_dynamic_buffer.html":[7,0,0,641],
 "class_ogre_1_1_metal_dynamic_buffer.html#a29b1ab18c09cacad2dda19ac3a7fee4a":[6,0,0,668,5],
@@ -104,14 +106,14 @@ var NAVTREEINDEX151 =
 "class_ogre_1_1_metal_dynamic_buffer.html#a35443de6172f20c68517a8fe1c95da09":[7,0,0,641,3],
 "class_ogre_1_1_metal_dynamic_buffer.html#a65ae6693060651b48e226013e2a27d62":[6,0,0,668,1],
 "class_ogre_1_1_metal_dynamic_buffer.html#a65ae6693060651b48e226013e2a27d62":[7,0,0,641,1],
-"class_ogre_1_1_metal_dynamic_buffer.html#a8c493ecd51d5cbf05a7dc3c74eb7dedc":[6,0,0,668,4],
 "class_ogre_1_1_metal_dynamic_buffer.html#a8c493ecd51d5cbf05a7dc3c74eb7dedc":[7,0,0,641,4],
-"class_ogre_1_1_metal_dynamic_buffer.html#adcd92b2d77e54c6bdb43f0d175297a8e":[6,0,0,668,2],
+"class_ogre_1_1_metal_dynamic_buffer.html#a8c493ecd51d5cbf05a7dc3c74eb7dedc":[6,0,0,668,4],
 "class_ogre_1_1_metal_dynamic_buffer.html#adcd92b2d77e54c6bdb43f0d175297a8e":[7,0,0,641,2],
+"class_ogre_1_1_metal_dynamic_buffer.html#adcd92b2d77e54c6bdb43f0d175297a8e":[6,0,0,668,2],
 "class_ogre_1_1_metal_gpu_program_manager.html":[6,0,0,670],
 "class_ogre_1_1_metal_gpu_program_manager.html":[7,0,0,643],
-"class_ogre_1_1_metal_gpu_program_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[6,0,0,670,27],
 "class_ogre_1_1_metal_gpu_program_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[7,0,0,643,27],
+"class_ogre_1_1_metal_gpu_program_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[6,0,0,670,27],
 "class_ogre_1_1_metal_gpu_program_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[7,0,0,643,42],
 "class_ogre_1_1_metal_gpu_program_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[6,0,0,670,42],
 "class_ogre_1_1_metal_gpu_program_manager.html#a02228d2937847ffae1a620633cf0c3a3":[6,0,0,670,45],
@@ -120,108 +122,108 @@ var NAVTREEINDEX151 =
 "class_ogre_1_1_metal_gpu_program_manager.html#a0b3d897dacdf542d029ea2d2a5a988c7":[6,0,0,670,74],
 "class_ogre_1_1_metal_gpu_program_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[6,0,0,670,39],
 "class_ogre_1_1_metal_gpu_program_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[7,0,0,643,39],
-"class_ogre_1_1_metal_gpu_program_manager.html#a117a3887bbf9e83e0585777beb0501dc":[6,0,0,670,7],
 "class_ogre_1_1_metal_gpu_program_manager.html#a117a3887bbf9e83e0585777beb0501dc":[7,0,0,643,7],
+"class_ogre_1_1_metal_gpu_program_manager.html#a117a3887bbf9e83e0585777beb0501dc":[6,0,0,670,7],
 "class_ogre_1_1_metal_gpu_program_manager.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,670,56],
 "class_ogre_1_1_metal_gpu_program_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,643,56],
 "class_ogre_1_1_metal_gpu_program_manager.html#a1eadda53bbed16d5a3804cdba2ad687e":[6,0,0,670,23],
 "class_ogre_1_1_metal_gpu_program_manager.html#a1eadda53bbed16d5a3804cdba2ad687e":[7,0,0,643,23],
 "class_ogre_1_1_metal_gpu_program_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[6,0,0,670,84],
 "class_ogre_1_1_metal_gpu_program_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[7,0,0,643,84],
-"class_ogre_1_1_metal_gpu_program_manager.html#a2208200adc00affea9fee67fec2f393e":[6,0,0,670,19],
 "class_ogre_1_1_metal_gpu_program_manager.html#a2208200adc00affea9fee67fec2f393e":[7,0,0,643,19],
+"class_ogre_1_1_metal_gpu_program_manager.html#a2208200adc00affea9fee67fec2f393e":[6,0,0,670,19],
 "class_ogre_1_1_metal_gpu_program_manager.html#a26d2aa93c5e041457b4ce49d6222f67d":[6,0,0,670,66],
 "class_ogre_1_1_metal_gpu_program_manager.html#a26d2aa93c5e041457b4ce49d6222f67d":[7,0,0,643,66],
-"class_ogre_1_1_metal_gpu_program_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[6,0,0,670,5],
 "class_ogre_1_1_metal_gpu_program_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[7,0,0,643,5],
-"class_ogre_1_1_metal_gpu_program_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[6,0,0,670,4],
+"class_ogre_1_1_metal_gpu_program_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[6,0,0,670,5],
 "class_ogre_1_1_metal_gpu_program_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[7,0,0,643,4],
-"class_ogre_1_1_metal_gpu_program_manager.html#a2aebd515c488f378e859db9bded95412":[6,0,0,670,43],
+"class_ogre_1_1_metal_gpu_program_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[6,0,0,670,4],
 "class_ogre_1_1_metal_gpu_program_manager.html#a2aebd515c488f378e859db9bded95412":[7,0,0,643,43],
-"class_ogre_1_1_metal_gpu_program_manager.html#a2cf457c70ea86892b1bec52028c96237":[6,0,0,670,82],
+"class_ogre_1_1_metal_gpu_program_manager.html#a2aebd515c488f378e859db9bded95412":[6,0,0,670,43],
 "class_ogre_1_1_metal_gpu_program_manager.html#a2cf457c70ea86892b1bec52028c96237":[7,0,0,643,82],
+"class_ogre_1_1_metal_gpu_program_manager.html#a2cf457c70ea86892b1bec52028c96237":[6,0,0,670,82],
 "class_ogre_1_1_metal_gpu_program_manager.html#a39cb435674c75c8e6b5f9e8aeebe6ec9":[6,0,0,670,9],
 "class_ogre_1_1_metal_gpu_program_manager.html#a39cb435674c75c8e6b5f9e8aeebe6ec9":[7,0,0,643,9],
 "class_ogre_1_1_metal_gpu_program_manager.html#a3e5398bdfcac88d573ea1dc0ba68e5aa":[7,0,0,643,48],
 "class_ogre_1_1_metal_gpu_program_manager.html#a3e5398bdfcac88d573ea1dc0ba68e5aa":[6,0,0,670,48],
 "class_ogre_1_1_metal_gpu_program_manager.html#a3f92489910e40e3756606a35618d7b06":[7,0,0,643,70],
 "class_ogre_1_1_metal_gpu_program_manager.html#a3f92489910e40e3756606a35618d7b06":[6,0,0,670,70],
-"class_ogre_1_1_metal_gpu_program_manager.html#a3fa0473ad1390af99f69325c2eced427":[7,0,0,643,22],
 "class_ogre_1_1_metal_gpu_program_manager.html#a3fa0473ad1390af99f69325c2eced427":[6,0,0,670,22],
-"class_ogre_1_1_metal_gpu_program_manager.html#a40769092850d5b296e1d1a9190631700":[7,0,0,643,13],
+"class_ogre_1_1_metal_gpu_program_manager.html#a3fa0473ad1390af99f69325c2eced427":[7,0,0,643,22],
 "class_ogre_1_1_metal_gpu_program_manager.html#a40769092850d5b296e1d1a9190631700":[6,0,0,670,13],
-"class_ogre_1_1_metal_gpu_program_manager.html#a42f172a8ed1625011d510b081eee66dd":[7,0,0,643,32],
+"class_ogre_1_1_metal_gpu_program_manager.html#a40769092850d5b296e1d1a9190631700":[7,0,0,643,13],
 "class_ogre_1_1_metal_gpu_program_manager.html#a42f172a8ed1625011d510b081eee66dd":[6,0,0,670,32],
+"class_ogre_1_1_metal_gpu_program_manager.html#a42f172a8ed1625011d510b081eee66dd":[7,0,0,643,32],
 "class_ogre_1_1_metal_gpu_program_manager.html#a48c565d0e63b286c6388439ae73417df":[6,0,0,670,20],
 "class_ogre_1_1_metal_gpu_program_manager.html#a48c565d0e63b286c6388439ae73417df":[7,0,0,643,20],
-"class_ogre_1_1_metal_gpu_program_manager.html#a4d3289d4636168230da11c1c9794db59":[7,0,0,643,38],
 "class_ogre_1_1_metal_gpu_program_manager.html#a4d3289d4636168230da11c1c9794db59":[6,0,0,670,38],
-"class_ogre_1_1_metal_gpu_program_manager.html#a4d6b9934b69d6c0731d717b22fae5715":[6,0,0,670,25],
+"class_ogre_1_1_metal_gpu_program_manager.html#a4d3289d4636168230da11c1c9794db59":[7,0,0,643,38],
 "class_ogre_1_1_metal_gpu_program_manager.html#a4d6b9934b69d6c0731d717b22fae5715":[7,0,0,643,25],
+"class_ogre_1_1_metal_gpu_program_manager.html#a4d6b9934b69d6c0731d717b22fae5715":[6,0,0,670,25],
 "class_ogre_1_1_metal_gpu_program_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[7,0,0,643,69],
 "class_ogre_1_1_metal_gpu_program_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[6,0,0,670,69],
-"class_ogre_1_1_metal_gpu_program_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[6,0,0,670,6],
 "class_ogre_1_1_metal_gpu_program_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[7,0,0,643,6],
+"class_ogre_1_1_metal_gpu_program_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[6,0,0,670,6],
 "class_ogre_1_1_metal_gpu_program_manager.html#a54d1843a43aebb13542312cd17134e6a":[6,0,0,670,14],
 "class_ogre_1_1_metal_gpu_program_manager.html#a54d1843a43aebb13542312cd17134e6a":[7,0,0,643,14],
 "class_ogre_1_1_metal_gpu_program_manager.html#a57e22b305d763f9ede5bda93f31051ca":[7,0,0,643,40],
 "class_ogre_1_1_metal_gpu_program_manager.html#a57e22b305d763f9ede5bda93f31051ca":[6,0,0,670,40],
-"class_ogre_1_1_metal_gpu_program_manager.html#a57f4e910b4f119e33a750b7fbb85ff66":[7,0,0,643,0],
 "class_ogre_1_1_metal_gpu_program_manager.html#a57f4e910b4f119e33a750b7fbb85ff66":[6,0,0,670,0],
-"class_ogre_1_1_metal_gpu_program_manager.html#a58e89a2444fd9134b9a87ec6d8f18544":[6,0,0,670,50],
+"class_ogre_1_1_metal_gpu_program_manager.html#a57f4e910b4f119e33a750b7fbb85ff66":[7,0,0,643,0],
 "class_ogre_1_1_metal_gpu_program_manager.html#a58e89a2444fd9134b9a87ec6d8f18544":[7,0,0,643,50],
+"class_ogre_1_1_metal_gpu_program_manager.html#a58e89a2444fd9134b9a87ec6d8f18544":[6,0,0,670,50],
 "class_ogre_1_1_metal_gpu_program_manager.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,670,58],
 "class_ogre_1_1_metal_gpu_program_manager.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,643,58],
 "class_ogre_1_1_metal_gpu_program_manager.html#a5feb934731d48691738aa13c63c4518b":[6,0,0,670,41],
 "class_ogre_1_1_metal_gpu_program_manager.html#a5feb934731d48691738aa13c63c4518b":[7,0,0,643,41],
 "class_ogre_1_1_metal_gpu_program_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,670,61],
 "class_ogre_1_1_metal_gpu_program_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,643,61],
-"class_ogre_1_1_metal_gpu_program_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[7,0,0,643,37],
 "class_ogre_1_1_metal_gpu_program_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[6,0,0,670,37],
+"class_ogre_1_1_metal_gpu_program_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[7,0,0,643,37],
 "class_ogre_1_1_metal_gpu_program_manager.html#a68acfcef19450e7fac3b31ab01c90438":[6,0,0,670,10],
 "class_ogre_1_1_metal_gpu_program_manager.html#a68acfcef19450e7fac3b31ab01c90438":[7,0,0,643,10],
 "class_ogre_1_1_metal_gpu_program_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[6,0,0,670,75],
 "class_ogre_1_1_metal_gpu_program_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[7,0,0,643,75],
-"class_ogre_1_1_metal_gpu_program_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[6,0,0,670,73],
 "class_ogre_1_1_metal_gpu_program_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[7,0,0,643,73],
-"class_ogre_1_1_metal_gpu_program_manager.html#a730630d8b38183b274235966721582ed":[6,0,0,670,29],
+"class_ogre_1_1_metal_gpu_program_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[6,0,0,670,73],
 "class_ogre_1_1_metal_gpu_program_manager.html#a730630d8b38183b274235966721582ed":[7,0,0,643,29],
-"class_ogre_1_1_metal_gpu_program_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[7,0,0,643,26],
+"class_ogre_1_1_metal_gpu_program_manager.html#a730630d8b38183b274235966721582ed":[6,0,0,670,29],
 "class_ogre_1_1_metal_gpu_program_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[6,0,0,670,26],
+"class_ogre_1_1_metal_gpu_program_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[7,0,0,643,26],
 "class_ogre_1_1_metal_gpu_program_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[6,0,0,670,64],
 "class_ogre_1_1_metal_gpu_program_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[7,0,0,643,64],
-"class_ogre_1_1_metal_gpu_program_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,643,54],
 "class_ogre_1_1_metal_gpu_program_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,670,54],
-"class_ogre_1_1_metal_gpu_program_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[6,0,0,670,68],
+"class_ogre_1_1_metal_gpu_program_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,643,54],
 "class_ogre_1_1_metal_gpu_program_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[7,0,0,643,68],
-"class_ogre_1_1_metal_gpu_program_manager.html#a88b278890e6c8c0cc137d8053700aabe":[7,0,0,643,21],
+"class_ogre_1_1_metal_gpu_program_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[6,0,0,670,68],
 "class_ogre_1_1_metal_gpu_program_manager.html#a88b278890e6c8c0cc137d8053700aabe":[6,0,0,670,21],
+"class_ogre_1_1_metal_gpu_program_manager.html#a88b278890e6c8c0cc137d8053700aabe":[7,0,0,643,21],
 "class_ogre_1_1_metal_gpu_program_manager.html#a8b08a9cf68859ad0f7c6b723487fd118":[6,0,0,670,2],
 "class_ogre_1_1_metal_gpu_program_manager.html#a8b08a9cf68859ad0f7c6b723487fd118":[7,0,0,643,2],
-"class_ogre_1_1_metal_gpu_program_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[6,0,0,670,85],
 "class_ogre_1_1_metal_gpu_program_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[7,0,0,643,85],
-"class_ogre_1_1_metal_gpu_program_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,670,57],
+"class_ogre_1_1_metal_gpu_program_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[6,0,0,670,85],
 "class_ogre_1_1_metal_gpu_program_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,643,57],
+"class_ogre_1_1_metal_gpu_program_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,670,57],
 "class_ogre_1_1_metal_gpu_program_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[6,0,0,670,83],
 "class_ogre_1_1_metal_gpu_program_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[7,0,0,643,83],
-"class_ogre_1_1_metal_gpu_program_manager.html#a95ad629bcb4005c9427dbea8e24699d4":[6,0,0,670,36],
 "class_ogre_1_1_metal_gpu_program_manager.html#a95ad629bcb4005c9427dbea8e24699d4":[7,0,0,643,36],
+"class_ogre_1_1_metal_gpu_program_manager.html#a95ad629bcb4005c9427dbea8e24699d4":[6,0,0,670,36],
 "class_ogre_1_1_metal_gpu_program_manager.html#a964ed591329cc8046c9fbab0713a35ce":[7,0,0,643,18],
 "class_ogre_1_1_metal_gpu_program_manager.html#a964ed591329cc8046c9fbab0713a35ce":[6,0,0,670,18],
 "class_ogre_1_1_metal_gpu_program_manager.html#a9ba5ed16850087dad793713281264527":[7,0,0,643,78],
 "class_ogre_1_1_metal_gpu_program_manager.html#a9ba5ed16850087dad793713281264527":[6,0,0,670,78],
-"class_ogre_1_1_metal_gpu_program_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[7,0,0,643,76],
 "class_ogre_1_1_metal_gpu_program_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[6,0,0,670,76],
-"class_ogre_1_1_metal_gpu_program_manager.html#aa18e33240cbe5003e3ab87ad247dd1b3":[6,0,0,670,44],
+"class_ogre_1_1_metal_gpu_program_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[7,0,0,643,76],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa18e33240cbe5003e3ab87ad247dd1b3":[7,0,0,643,44],
+"class_ogre_1_1_metal_gpu_program_manager.html#aa18e33240cbe5003e3ab87ad247dd1b3":[6,0,0,670,44],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa21d703ad5720d87243b2cbb8b7dc02a":[7,0,0,643,80],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa21d703ad5720d87243b2cbb8b7dc02a":[6,0,0,670,80],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[6,0,0,670,34],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[7,0,0,643,34],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[7,0,0,643,81],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[6,0,0,670,81],
-"class_ogre_1_1_metal_gpu_program_manager.html#aa4723c868424304f5bec942e9534ab4f":[7,0,0,643,16],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa4723c868424304f5bec942e9534ab4f":[6,0,0,670,16],
+"class_ogre_1_1_metal_gpu_program_manager.html#aa4723c868424304f5bec942e9534ab4f":[7,0,0,643,16],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[6,0,0,670,79],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[7,0,0,643,79],
 "class_ogre_1_1_metal_gpu_program_manager.html#aa8b761abb06d74347e9636550307ccd9":[7,0,0,643,28],
@@ -232,8 +234,8 @@ var NAVTREEINDEX151 =
 "class_ogre_1_1_metal_gpu_program_manager.html#aa97ecb7825ee46c6be15313b6592ee16":[6,0,0,670,52],
 "class_ogre_1_1_metal_gpu_program_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[6,0,0,670,30],
 "class_ogre_1_1_metal_gpu_program_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[7,0,0,643,30],
-"class_ogre_1_1_metal_gpu_program_manager.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,670,60],
 "class_ogre_1_1_metal_gpu_program_manager.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,643,60],
+"class_ogre_1_1_metal_gpu_program_manager.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,670,60],
 "class_ogre_1_1_metal_gpu_program_manager.html#ab60406fd10fc46a8e5c44f10d4b7acb8":[6,0,0,670,11],
 "class_ogre_1_1_metal_gpu_program_manager.html#ab60406fd10fc46a8e5c44f10d4b7acb8":[7,0,0,643,11],
 "class_ogre_1_1_metal_gpu_program_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[7,0,0,643,88],
@@ -246,8 +248,6 @@ var NAVTREEINDEX151 =
 "class_ogre_1_1_metal_gpu_program_manager.html#ac7311b1e2dea2bdbf6d1f497edc2c4a0":[6,0,0,670,49],
 "class_ogre_1_1_metal_gpu_program_manager.html#ac8f7ee61606730572a8590060d8896a0":[7,0,0,643,33],
 "class_ogre_1_1_metal_gpu_program_manager.html#ac8f7ee61606730572a8590060d8896a0":[6,0,0,670,33],
-"class_ogre_1_1_metal_gpu_program_manager.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,670,55],
 "class_ogre_1_1_metal_gpu_program_manager.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,643,55],
-"class_ogre_1_1_metal_gpu_program_manager.html#acc4fc3a525b714c0ec554b11af197946":[7,0,0,643,46],
-"class_ogre_1_1_metal_gpu_program_manager.html#acc4fc3a525b714c0ec554b11af197946":[6,0,0,670,46]
+"class_ogre_1_1_metal_gpu_program_manager.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,670,55]
 };
