@@ -1,92 +1,94 @@
 var NAVTREEINDEX159 =
 {
+"class_ogre_1_1_metal_render_texture.html#ab0a25b2489c9ea19e93b1c28dc4d3824":[6,0,0,684,3],
+"class_ogre_1_1_metal_render_texture.html#ab16d079db49b93e915e9386b4e27880b":[7,0,0,657,8],
 "class_ogre_1_1_metal_render_texture.html#ab16d079db49b93e915e9386b4e27880b":[6,0,0,684,8],
 "class_ogre_1_1_metal_render_texture.html#ab2133478c53c874dcad98a877393260b":[7,0,0,657,73],
 "class_ogre_1_1_metal_render_texture.html#ab2133478c53c874dcad98a877393260b":[6,0,0,684,73],
-"class_ogre_1_1_metal_render_texture.html#ab251ab4046e34b249be7d85ed7a358db":[7,0,0,657,14],
 "class_ogre_1_1_metal_render_texture.html#ab251ab4046e34b249be7d85ed7a358db":[6,0,0,684,14],
+"class_ogre_1_1_metal_render_texture.html#ab251ab4046e34b249be7d85ed7a358db":[7,0,0,657,14],
 "class_ogre_1_1_metal_render_texture.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,657,54],
 "class_ogre_1_1_metal_render_texture.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,684,54],
 "class_ogre_1_1_metal_render_texture.html#ab82d2cf13a93ae6406cee9d2d044aa06":[6,0,0,684,31],
 "class_ogre_1_1_metal_render_texture.html#ab82d2cf13a93ae6406cee9d2d044aa06":[7,0,0,657,31],
-"class_ogre_1_1_metal_render_texture.html#abb4fa5e6970515a4d6cb9a16501557b5":[7,0,0,657,37],
 "class_ogre_1_1_metal_render_texture.html#abb4fa5e6970515a4d6cb9a16501557b5":[6,0,0,684,37],
-"class_ogre_1_1_metal_render_texture.html#aca21c0cb66c690e35847a1cf30aef357":[7,0,0,657,35],
+"class_ogre_1_1_metal_render_texture.html#abb4fa5e6970515a4d6cb9a16501557b5":[7,0,0,657,37],
 "class_ogre_1_1_metal_render_texture.html#aca21c0cb66c690e35847a1cf30aef357":[6,0,0,684,35],
+"class_ogre_1_1_metal_render_texture.html#aca21c0cb66c690e35847a1cf30aef357":[7,0,0,657,35],
 "class_ogre_1_1_metal_render_texture.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,657,49],
 "class_ogre_1_1_metal_render_texture.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,684,49],
 "class_ogre_1_1_metal_render_texture.html#accf6680935c6c39cfa55cd4445e479e8":[7,0,0,657,47],
 "class_ogre_1_1_metal_render_texture.html#accf6680935c6c39cfa55cd4445e479e8":[6,0,0,684,47],
-"class_ogre_1_1_metal_render_texture.html#acdd2df1d7b419b61d1abd82b72e0d0a5":[7,0,0,657,40],
 "class_ogre_1_1_metal_render_texture.html#acdd2df1d7b419b61d1abd82b72e0d0a5":[6,0,0,684,40],
-"class_ogre_1_1_metal_render_texture.html#acfb338c927b445144253ce6893bbbb55":[7,0,0,657,10],
+"class_ogre_1_1_metal_render_texture.html#acdd2df1d7b419b61d1abd82b72e0d0a5":[7,0,0,657,40],
 "class_ogre_1_1_metal_render_texture.html#acfb338c927b445144253ce6893bbbb55":[6,0,0,684,10],
-"class_ogre_1_1_metal_render_texture.html#ad0b724596d2b9e278293aee6e55a5273":[7,0,0,657,4],
+"class_ogre_1_1_metal_render_texture.html#acfb338c927b445144253ce6893bbbb55":[7,0,0,657,10],
 "class_ogre_1_1_metal_render_texture.html#ad0b724596d2b9e278293aee6e55a5273":[6,0,0,684,4],
+"class_ogre_1_1_metal_render_texture.html#ad0b724596d2b9e278293aee6e55a5273":[7,0,0,657,4],
 "class_ogre_1_1_metal_render_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,684,53],
 "class_ogre_1_1_metal_render_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,657,53],
 "class_ogre_1_1_metal_render_texture.html#ad4e95b76827cb41d936ccb4a8c308c6e":[7,0,0,657,29],
 "class_ogre_1_1_metal_render_texture.html#ad4e95b76827cb41d936ccb4a8c308c6e":[6,0,0,684,29],
 "class_ogre_1_1_metal_render_texture.html#ad6a737624f18ad142c9a710aa1cd59a3":[6,0,0,684,30],
 "class_ogre_1_1_metal_render_texture.html#ad6a737624f18ad142c9a710aa1cd59a3":[7,0,0,657,30],
-"class_ogre_1_1_metal_render_texture.html#adc5ae8e1b69ca1a62df88d52471910db":[7,0,0,657,67],
 "class_ogre_1_1_metal_render_texture.html#adc5ae8e1b69ca1a62df88d52471910db":[6,0,0,684,67],
-"class_ogre_1_1_metal_render_texture.html#adce32528577d71b228692df906ecd17c":[7,0,0,657,56],
+"class_ogre_1_1_metal_render_texture.html#adc5ae8e1b69ca1a62df88d52471910db":[7,0,0,657,67],
 "class_ogre_1_1_metal_render_texture.html#adce32528577d71b228692df906ecd17c":[6,0,0,684,56],
-"class_ogre_1_1_metal_render_texture.html#ade23b0e64aea68657b81833b99868802":[7,0,0,657,24],
+"class_ogre_1_1_metal_render_texture.html#adce32528577d71b228692df906ecd17c":[7,0,0,657,56],
 "class_ogre_1_1_metal_render_texture.html#ade23b0e64aea68657b81833b99868802":[6,0,0,684,24],
+"class_ogre_1_1_metal_render_texture.html#ade23b0e64aea68657b81833b99868802":[7,0,0,657,24],
 "class_ogre_1_1_metal_render_texture.html#adecbcc8034f602f138ced97b5783dafa":[6,0,0,684,32],
 "class_ogre_1_1_metal_render_texture.html#adecbcc8034f602f138ced97b5783dafa":[7,0,0,657,32],
-"class_ogre_1_1_metal_render_texture.html#ae2bd3003533d24447f883d9035b7aed0":[6,0,0,684,64],
 "class_ogre_1_1_metal_render_texture.html#ae2bd3003533d24447f883d9035b7aed0":[7,0,0,657,64],
-"class_ogre_1_1_metal_render_texture.html#ae68eb2ce228a55811c058de85e369a29":[6,0,0,684,5],
+"class_ogre_1_1_metal_render_texture.html#ae2bd3003533d24447f883d9035b7aed0":[6,0,0,684,64],
 "class_ogre_1_1_metal_render_texture.html#ae68eb2ce228a55811c058de85e369a29":[7,0,0,657,5],
+"class_ogre_1_1_metal_render_texture.html#ae68eb2ce228a55811c058de85e369a29":[6,0,0,684,5],
 "class_ogre_1_1_metal_render_texture.html#ae78e25805a045b8834c831d452ab6e07":[6,0,0,684,75],
 "class_ogre_1_1_metal_render_texture.html#ae78e25805a045b8834c831d452ab6e07":[7,0,0,657,75],
-"class_ogre_1_1_metal_render_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,684,57],
 "class_ogre_1_1_metal_render_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,657,57],
-"class_ogre_1_1_metal_render_texture.html#af31a02e64d08c411b8873f9f7b006b55":[7,0,0,657,13],
+"class_ogre_1_1_metal_render_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,684,57],
 "class_ogre_1_1_metal_render_texture.html#af31a02e64d08c411b8873f9f7b006b55":[6,0,0,684,13],
+"class_ogre_1_1_metal_render_texture.html#af31a02e64d08c411b8873f9f7b006b55":[7,0,0,657,13],
 "class_ogre_1_1_metal_render_texture.html#af5c3edbea78c8e6e9c60cd7dfeb79f3c":[6,0,0,684,2],
 "class_ogre_1_1_metal_render_texture.html#af5c3edbea78c8e6e9c60cd7dfeb79f3c":[7,0,0,657,2],
-"class_ogre_1_1_metal_render_texture.html#af77a2b45550db00c0ca364d762a5ca36":[7,0,0,657,21],
 "class_ogre_1_1_metal_render_texture.html#af77a2b45550db00c0ca364d762a5ca36":[6,0,0,684,21],
-"class_ogre_1_1_metal_render_texture.html#af8c3f070c7c1f59e4be242531b1ec9b4":[6,0,0,684,16],
+"class_ogre_1_1_metal_render_texture.html#af77a2b45550db00c0ca364d762a5ca36":[7,0,0,657,21],
 "class_ogre_1_1_metal_render_texture.html#af8c3f070c7c1f59e4be242531b1ec9b4":[7,0,0,657,16],
+"class_ogre_1_1_metal_render_texture.html#af8c3f070c7c1f59e4be242531b1ec9b4":[6,0,0,684,16],
 "class_ogre_1_1_metal_render_texture.html#af8ca9d240bd48662c37dbdf8fa881bad":[6,0,0,684,66],
 "class_ogre_1_1_metal_render_texture.html#af8ca9d240bd48662c37dbdf8fa881bad":[7,0,0,657,66],
-"class_ogre_1_1_metal_staging_buffer.html":[6,0,0,685],
 "class_ogre_1_1_metal_staging_buffer.html":[7,0,0,658],
+"class_ogre_1_1_metal_staging_buffer.html":[6,0,0,685],
 "class_ogre_1_1_metal_staging_buffer.html#a0512e57da9c9f75e7666133a10883126":[6,0,0,685,15],
 "class_ogre_1_1_metal_staging_buffer.html#a0512e57da9c9f75e7666133a10883126":[7,0,0,658,15],
-"class_ogre_1_1_metal_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[6,0,0,685,19],
 "class_ogre_1_1_metal_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[7,0,0,658,19],
+"class_ogre_1_1_metal_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[6,0,0,685,19],
 "class_ogre_1_1_metal_staging_buffer.html#a06dfed7c83a6aa991b0bceef76743550":[7,0,0,658,14],
 "class_ogre_1_1_metal_staging_buffer.html#a06dfed7c83a6aa991b0bceef76743550":[6,0,0,685,14],
 "class_ogre_1_1_metal_staging_buffer.html#a10b28de5293c036bf7f23e87bef00de6":[6,0,0,685,9],
 "class_ogre_1_1_metal_staging_buffer.html#a10b28de5293c036bf7f23e87bef00de6":[7,0,0,658,9],
-"class_ogre_1_1_metal_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[6,0,0,685,13],
 "class_ogre_1_1_metal_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[7,0,0,658,13],
+"class_ogre_1_1_metal_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[6,0,0,685,13],
 "class_ogre_1_1_metal_staging_buffer.html#a1c30d062d8acf7485f7b5c273f839dc3":[6,0,0,685,8],
 "class_ogre_1_1_metal_staging_buffer.html#a1c30d062d8acf7485f7b5c273f839dc3":[7,0,0,658,8],
-"class_ogre_1_1_metal_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,658,23],
 "class_ogre_1_1_metal_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,685,23],
-"class_ogre_1_1_metal_staging_buffer.html#a29313389dacd812a8d238df458f9e979":[6,0,0,685,31],
+"class_ogre_1_1_metal_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,658,23],
 "class_ogre_1_1_metal_staging_buffer.html#a29313389dacd812a8d238df458f9e979":[7,0,0,658,31],
-"class_ogre_1_1_metal_staging_buffer.html#a2ff58a77b03cb4f65028ebdd1cfb565d":[6,0,0,685,7],
+"class_ogre_1_1_metal_staging_buffer.html#a29313389dacd812a8d238df458f9e979":[6,0,0,685,31],
 "class_ogre_1_1_metal_staging_buffer.html#a2ff58a77b03cb4f65028ebdd1cfb565d":[7,0,0,658,7],
-"class_ogre_1_1_metal_staging_buffer.html#a438d82f09b5f657be30c30d7d1c0801d":[7,0,0,658,32],
+"class_ogre_1_1_metal_staging_buffer.html#a2ff58a77b03cb4f65028ebdd1cfb565d":[6,0,0,685,7],
 "class_ogre_1_1_metal_staging_buffer.html#a438d82f09b5f657be30c30d7d1c0801d":[6,0,0,685,32],
+"class_ogre_1_1_metal_staging_buffer.html#a438d82f09b5f657be30c30d7d1c0801d":[7,0,0,658,32],
 "class_ogre_1_1_metal_staging_buffer.html#a4c28caa8b6d7010e5e9bf5b258df3964":[6,0,0,685,4],
 "class_ogre_1_1_metal_staging_buffer.html#a4c28caa8b6d7010e5e9bf5b258df3964":[7,0,0,658,4],
-"class_ogre_1_1_metal_staging_buffer.html#a5239fe8fda6e2de02e5c053edb69661a":[6,0,0,685,20],
 "class_ogre_1_1_metal_staging_buffer.html#a5239fe8fda6e2de02e5c053edb69661a":[7,0,0,658,20],
-"class_ogre_1_1_metal_staging_buffer.html#a53adbd5b91819a0e58c9d2c010eba469":[6,0,0,685,18],
+"class_ogre_1_1_metal_staging_buffer.html#a5239fe8fda6e2de02e5c053edb69661a":[6,0,0,685,20],
 "class_ogre_1_1_metal_staging_buffer.html#a53adbd5b91819a0e58c9d2c010eba469":[7,0,0,658,18],
-"class_ogre_1_1_metal_staging_buffer.html#a5841760c78a96721dd5728e96de0b604":[6,0,0,685,1],
+"class_ogre_1_1_metal_staging_buffer.html#a53adbd5b91819a0e58c9d2c010eba469":[6,0,0,685,18],
 "class_ogre_1_1_metal_staging_buffer.html#a5841760c78a96721dd5728e96de0b604":[7,0,0,658,1],
-"class_ogre_1_1_metal_staging_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,685,25],
+"class_ogre_1_1_metal_staging_buffer.html#a5841760c78a96721dd5728e96de0b604":[6,0,0,685,1],
 "class_ogre_1_1_metal_staging_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,658,25],
+"class_ogre_1_1_metal_staging_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,685,25],
 "class_ogre_1_1_metal_staging_buffer.html#a5968d9f98ad2f0746b62ef58d74d0169":[7,0,0,658,12],
 "class_ogre_1_1_metal_staging_buffer.html#a5968d9f98ad2f0746b62ef58d74d0169":[6,0,0,685,12],
 "class_ogre_1_1_metal_staging_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,685,28],
@@ -95,26 +97,26 @@ var NAVTREEINDEX159 =
 "class_ogre_1_1_metal_staging_buffer.html#a6ee0032ef0fe4c1200eb07f7fb052a1b":[7,0,0,658,35],
 "class_ogre_1_1_metal_staging_buffer.html#a7651b7ed0115951d4b38bcef9b3a8ea5":[7,0,0,658,2],
 "class_ogre_1_1_metal_staging_buffer.html#a7651b7ed0115951d4b38bcef9b3a8ea5":[6,0,0,685,2],
-"class_ogre_1_1_metal_staging_buffer.html#a765f26f80115c9341308fc86330ec9c2":[6,0,0,685,16],
 "class_ogre_1_1_metal_staging_buffer.html#a765f26f80115c9341308fc86330ec9c2":[7,0,0,658,16],
+"class_ogre_1_1_metal_staging_buffer.html#a765f26f80115c9341308fc86330ec9c2":[6,0,0,685,16],
 "class_ogre_1_1_metal_staging_buffer.html#a8047cc93c004c2f6c5700aca44e35b2a":[7,0,0,658,6],
 "class_ogre_1_1_metal_staging_buffer.html#a8047cc93c004c2f6c5700aca44e35b2a":[6,0,0,685,6],
 "class_ogre_1_1_metal_staging_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,658,21],
 "class_ogre_1_1_metal_staging_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,685,21],
 "class_ogre_1_1_metal_staging_buffer.html#a897e0ef920699d059b273eed1fe71d4d":[6,0,0,685,17],
 "class_ogre_1_1_metal_staging_buffer.html#a897e0ef920699d059b273eed1fe71d4d":[7,0,0,658,17],
-"class_ogre_1_1_metal_staging_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,658,24],
 "class_ogre_1_1_metal_staging_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,685,24],
+"class_ogre_1_1_metal_staging_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,658,24],
 "class_ogre_1_1_metal_staging_buffer.html#a9c8e2853c21a7418218605a0b9cdf461":[7,0,0,658,33],
 "class_ogre_1_1_metal_staging_buffer.html#a9c8e2853c21a7418218605a0b9cdf461":[6,0,0,685,33],
-"class_ogre_1_1_metal_staging_buffer.html#aa2b8517a2fb41ba09bb276ccf84c84b7":[7,0,0,658,11],
 "class_ogre_1_1_metal_staging_buffer.html#aa2b8517a2fb41ba09bb276ccf84c84b7":[6,0,0,685,11],
+"class_ogre_1_1_metal_staging_buffer.html#aa2b8517a2fb41ba09bb276ccf84c84b7":[7,0,0,658,11],
 "class_ogre_1_1_metal_staging_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,658,27],
 "class_ogre_1_1_metal_staging_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,685,27],
-"class_ogre_1_1_metal_staging_buffer.html#ab4ad5fe671c29396b3e44f500e4e1a6a":[6,0,0,685,5],
 "class_ogre_1_1_metal_staging_buffer.html#ab4ad5fe671c29396b3e44f500e4e1a6a":[7,0,0,658,5],
-"class_ogre_1_1_metal_staging_buffer.html#ac2d7dbe292ec9d93f9c41da437a7429b":[6,0,0,685,10],
+"class_ogre_1_1_metal_staging_buffer.html#ab4ad5fe671c29396b3e44f500e4e1a6a":[6,0,0,685,5],
 "class_ogre_1_1_metal_staging_buffer.html#ac2d7dbe292ec9d93f9c41da437a7429b":[7,0,0,658,10],
+"class_ogre_1_1_metal_staging_buffer.html#ac2d7dbe292ec9d93f9c41da437a7429b":[6,0,0,685,10],
 "class_ogre_1_1_metal_staging_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,685,22],
 "class_ogre_1_1_metal_staging_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,658,22],
 "class_ogre_1_1_metal_staging_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,658,26],
@@ -123,131 +125,129 @@ var NAVTREEINDEX159 =
 "class_ogre_1_1_metal_staging_buffer.html#adce32528577d71b228692df906ecd17c":[6,0,0,685,29],
 "class_ogre_1_1_metal_staging_buffer.html#ae41bfebb124f220f7f5a170ac101ce59":[6,0,0,685,3],
 "class_ogre_1_1_metal_staging_buffer.html#ae41bfebb124f220f7f5a170ac101ce59":[7,0,0,658,3],
-"class_ogre_1_1_metal_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[7,0,0,658,0],
 "class_ogre_1_1_metal_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[6,0,0,685,0],
+"class_ogre_1_1_metal_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[7,0,0,658,0],
 "class_ogre_1_1_metal_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,685,30],
 "class_ogre_1_1_metal_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,658,30],
 "class_ogre_1_1_metal_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[7,0,0,658,34],
 "class_ogre_1_1_metal_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[6,0,0,685,34],
-"class_ogre_1_1_metal_staging_texture.html":[7,0,0,659],
 "class_ogre_1_1_metal_staging_texture.html":[6,0,0,686],
-"class_ogre_1_1_metal_staging_texture.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,686,12],
+"class_ogre_1_1_metal_staging_texture.html":[7,0,0,659],
 "class_ogre_1_1_metal_staging_texture.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,659,12],
-"class_ogre_1_1_metal_staging_texture.html#a20b8f55c40f5a54344feb86af13bc7f6":[6,0,0,686,3],
+"class_ogre_1_1_metal_staging_texture.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,686,12],
 "class_ogre_1_1_metal_staging_texture.html#a20b8f55c40f5a54344feb86af13bc7f6":[7,0,0,659,3],
-"class_ogre_1_1_metal_staging_texture.html#a2615e8cadf5c914000df3222aef2f949":[6,0,0,686,21],
+"class_ogre_1_1_metal_staging_texture.html#a20b8f55c40f5a54344feb86af13bc7f6":[6,0,0,686,3],
 "class_ogre_1_1_metal_staging_texture.html#a2615e8cadf5c914000df3222aef2f949":[7,0,0,659,21],
-"class_ogre_1_1_metal_staging_texture.html#a2c77f84776623ba4ed6d5e0cf29d2c57":[6,0,0,686,8],
+"class_ogre_1_1_metal_staging_texture.html#a2615e8cadf5c914000df3222aef2f949":[6,0,0,686,21],
 "class_ogre_1_1_metal_staging_texture.html#a2c77f84776623ba4ed6d5e0cf29d2c57":[7,0,0,659,8],
-"class_ogre_1_1_metal_staging_texture.html#a35820d573649ed982148d6bcfaed895a":[7,0,0,659,0],
+"class_ogre_1_1_metal_staging_texture.html#a2c77f84776623ba4ed6d5e0cf29d2c57":[6,0,0,686,8],
 "class_ogre_1_1_metal_staging_texture.html#a35820d573649ed982148d6bcfaed895a":[6,0,0,686,0],
-"class_ogre_1_1_metal_staging_texture.html#a3b415effaa2eb00ce82916ee24b2e131":[7,0,0,659,7],
+"class_ogre_1_1_metal_staging_texture.html#a35820d573649ed982148d6bcfaed895a":[7,0,0,659,0],
 "class_ogre_1_1_metal_staging_texture.html#a3b415effaa2eb00ce82916ee24b2e131":[6,0,0,686,7],
+"class_ogre_1_1_metal_staging_texture.html#a3b415effaa2eb00ce82916ee24b2e131":[7,0,0,659,7],
 "class_ogre_1_1_metal_staging_texture.html#a572f1d702e3abcbaf415bbaa8c0ccaed":[6,0,0,686,23],
 "class_ogre_1_1_metal_staging_texture.html#a572f1d702e3abcbaf415bbaa8c0ccaed":[7,0,0,659,23],
-"class_ogre_1_1_metal_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,686,14],
 "class_ogre_1_1_metal_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,659,14],
+"class_ogre_1_1_metal_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,686,14],
 "class_ogre_1_1_metal_staging_texture.html#a63e494e2f4ba1c65ff3ea79e25bfbfc6":[6,0,0,686,5],
 "class_ogre_1_1_metal_staging_texture.html#a63e494e2f4ba1c65ff3ea79e25bfbfc6":[7,0,0,659,5],
-"class_ogre_1_1_metal_staging_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,659,17],
 "class_ogre_1_1_metal_staging_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,686,17],
+"class_ogre_1_1_metal_staging_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,659,17],
 "class_ogre_1_1_metal_staging_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,659,10],
 "class_ogre_1_1_metal_staging_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,686,10],
-"class_ogre_1_1_metal_staging_texture.html#a8996efde036324ee9c422d11d91a6215":[6,0,0,686,24],
 "class_ogre_1_1_metal_staging_texture.html#a8996efde036324ee9c422d11d91a6215":[7,0,0,659,24],
-"class_ogre_1_1_metal_staging_texture.html#a8d13f4da13e756feb265e2755d15fffb":[6,0,0,686,22],
+"class_ogre_1_1_metal_staging_texture.html#a8996efde036324ee9c422d11d91a6215":[6,0,0,686,24],
 "class_ogre_1_1_metal_staging_texture.html#a8d13f4da13e756feb265e2755d15fffb":[7,0,0,659,22],
-"class_ogre_1_1_metal_staging_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,686,13],
+"class_ogre_1_1_metal_staging_texture.html#a8d13f4da13e756feb265e2755d15fffb":[6,0,0,686,22],
 "class_ogre_1_1_metal_staging_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,659,13],
-"class_ogre_1_1_metal_staging_texture.html#a9c55be7d477bda7d0e8616a45ac8611d":[7,0,0,659,4],
+"class_ogre_1_1_metal_staging_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,686,13],
 "class_ogre_1_1_metal_staging_texture.html#a9c55be7d477bda7d0e8616a45ac8611d":[6,0,0,686,4],
-"class_ogre_1_1_metal_staging_texture.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,686,16],
+"class_ogre_1_1_metal_staging_texture.html#a9c55be7d477bda7d0e8616a45ac8611d":[7,0,0,659,4],
 "class_ogre_1_1_metal_staging_texture.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,659,16],
-"class_ogre_1_1_metal_staging_texture.html#ab51b2b48ec9ebed5db7d34842c49fcdc":[7,0,0,659,20],
+"class_ogre_1_1_metal_staging_texture.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,686,16],
 "class_ogre_1_1_metal_staging_texture.html#ab51b2b48ec9ebed5db7d34842c49fcdc":[6,0,0,686,20],
-"class_ogre_1_1_metal_staging_texture.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,659,11],
+"class_ogre_1_1_metal_staging_texture.html#ab51b2b48ec9ebed5db7d34842c49fcdc":[7,0,0,659,20],
 "class_ogre_1_1_metal_staging_texture.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,686,11],
+"class_ogre_1_1_metal_staging_texture.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,659,11],
 "class_ogre_1_1_metal_staging_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,659,15],
 "class_ogre_1_1_metal_staging_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,686,15],
-"class_ogre_1_1_metal_staging_texture.html#ad34f6bc75407060643f55f4537a5ca6c":[6,0,0,686,2],
 "class_ogre_1_1_metal_staging_texture.html#ad34f6bc75407060643f55f4537a5ca6c":[7,0,0,659,2],
+"class_ogre_1_1_metal_staging_texture.html#ad34f6bc75407060643f55f4537a5ca6c":[6,0,0,686,2],
 "class_ogre_1_1_metal_staging_texture.html#adce32528577d71b228692df906ecd17c":[7,0,0,659,18],
 "class_ogre_1_1_metal_staging_texture.html#adce32528577d71b228692df906ecd17c":[6,0,0,686,18],
-"class_ogre_1_1_metal_staging_texture.html#adf5cc3adc54a4ab2ea4e83cde01b3398":[7,0,0,659,9],
 "class_ogre_1_1_metal_staging_texture.html#adf5cc3adc54a4ab2ea4e83cde01b3398":[6,0,0,686,9],
+"class_ogre_1_1_metal_staging_texture.html#adf5cc3adc54a4ab2ea4e83cde01b3398":[7,0,0,659,9],
 "class_ogre_1_1_metal_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,659,19],
 "class_ogre_1_1_metal_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,686,19],
 "class_ogre_1_1_metal_staging_texture.html#af7bfea35cccd06f683087cac318ae828":[6,0,0,686,1],
 "class_ogre_1_1_metal_staging_texture.html#af7bfea35cccd06f683087cac318ae828":[7,0,0,659,1],
-"class_ogre_1_1_metal_staging_texture.html#af880dfa4d3f849a20ffb03a4c248d997":[6,0,0,686,6],
 "class_ogre_1_1_metal_staging_texture.html#af880dfa4d3f849a20ffb03a4c248d997":[7,0,0,659,6],
-"class_ogre_1_1_metal_tex_buffer_packed.html":[7,0,0,660],
+"class_ogre_1_1_metal_staging_texture.html#af880dfa4d3f849a20ffb03a4c248d997":[6,0,0,686,6],
 "class_ogre_1_1_metal_tex_buffer_packed.html":[6,0,0,687],
+"class_ogre_1_1_metal_tex_buffer_packed.html":[7,0,0,660],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a0a4c654c7a32c2b2b0c66f7103b1c626":[7,0,0,660,10],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a0a4c654c7a32c2b2b0c66f7103b1c626":[6,0,0,687,10],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[7,0,0,660,44],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[6,0,0,687,44],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[6,0,0,687,27],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[7,0,0,660,44],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[7,0,0,660,27],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[7,0,0,660,17],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[6,0,0,687,27],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[6,0,0,687,17],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[7,0,0,660,17],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,660,33],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,687,33],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a1db179a83ff63833b4fbfc853e69d3e8":[6,0,0,687,16],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a1db179a83ff63833b4fbfc853e69d3e8":[7,0,0,660,16],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[6,0,0,687,9],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[7,0,0,660,9],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[6,0,0,687,9],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[6,0,0,687,30],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[7,0,0,660,30],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[7,0,0,660,18],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[6,0,0,687,18],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[7,0,0,660,26],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[7,0,0,660,18],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[6,0,0,687,26],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a35b7997d716ab78bdc6c05cd0c9a3d0c":[6,0,0,687,0],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[7,0,0,660,26],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a35b7997d716ab78bdc6c05cd0c9a3d0c":[7,0,0,660,0],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a3d389b0aae18bb6dcb82af84c93b77de":[6,0,0,687,29],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a35b7997d716ab78bdc6c05cd0c9a3d0c":[6,0,0,687,0],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a3d389b0aae18bb6dcb82af84c93b77de":[7,0,0,660,29],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a481ad7b97cb88501c5777f4703ff2320":[7,0,0,660,4],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a3d389b0aae18bb6dcb82af84c93b77de":[6,0,0,687,29],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a481ad7b97cb88501c5777f4703ff2320":[6,0,0,687,4],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a481ad7b97cb88501c5777f4703ff2320":[7,0,0,660,4],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a4cc0148191016adfb10557f85af7c1ab":[7,0,0,660,14],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a4cc0148191016adfb10557f85af7c1ab":[6,0,0,687,14],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a4f31390a156614abd7ffe33b48af84b4":[6,0,0,687,25],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a4f31390a156614abd7ffe33b48af84b4":[7,0,0,660,25],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a4f31390a156614abd7ffe33b48af84b4":[6,0,0,687,25],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a50080eb729acd0c995606d512d5633c9":[7,0,0,660,20],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a50080eb729acd0c995606d512d5633c9":[6,0,0,687,20],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a542b46fc7a7cf5fe524cfc7b4b389ba9":[7,0,0,660,22],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a542b46fc7a7cf5fe524cfc7b4b389ba9":[6,0,0,687,22],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a564935579f2252627f46dff29142e7ff":[6,0,0,687,8],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a564935579f2252627f46dff29142e7ff":[7,0,0,660,8],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a564935579f2252627f46dff29142e7ff":[6,0,0,687,8],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a566014653e1b98b5ed24166f9e11bacd":[6,0,0,687,24],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a566014653e1b98b5ed24166f9e11bacd":[7,0,0,660,24],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,687,35],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,660,35],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,687,35],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a6154032bc42078afb2739ec32d33e0ac":[7,0,0,660,11],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a6154032bc42078afb2739ec32d33e0ac":[6,0,0,687,11],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,660,38],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,687,38],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a69984ccd67bf7c801cc33dd20780b581":[6,0,0,687,23],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a69984ccd67bf7c801cc33dd20780b581":[7,0,0,660,23],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a69984ccd67bf7c801cc33dd20780b581":[6,0,0,687,23],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a73e02f6b2fa2c16340c1a9359926b481":[6,0,0,687,43],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a73e02f6b2fa2c16340c1a9359926b481":[7,0,0,660,43],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a7cfd9629389ccf2aedec4b37f5a1b403":[7,0,0,660,7],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a7cfd9629389ccf2aedec4b37f5a1b403":[6,0,0,687,7],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a80c6682bd4adc315782091679d230cee":[7,0,0,660,41],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a7cfd9629389ccf2aedec4b37f5a1b403":[7,0,0,660,7],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a80c6682bd4adc315782091679d230cee":[6,0,0,687,41],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a80c6682bd4adc315782091679d230cee":[7,0,0,660,41],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,660,31],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,687,31],
-"class_ogre_1_1_metal_tex_buffer_packed.html#a8e2a1c3d6fdd8c8f9123ff5a38cd4e8f":[6,0,0,687,2],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a8e2a1c3d6fdd8c8f9123ff5a38cd4e8f":[7,0,0,660,2],
+"class_ogre_1_1_metal_tex_buffer_packed.html#a8e2a1c3d6fdd8c8f9123ff5a38cd4e8f":[6,0,0,687,2],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a8fe6a1ecb4b3ab2b2a5208e9daeb4168":[7,0,0,660,6],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a8fe6a1ecb4b3ab2b2a5208e9daeb4168":[6,0,0,687,6],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,687,34],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,660,34],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a9fddac86ed17dfa5ebad15625c1f3a8c":[7,0,0,660,12],
 "class_ogre_1_1_metal_tex_buffer_packed.html#a9fddac86ed17dfa5ebad15625c1f3a8c":[6,0,0,687,12],
-"class_ogre_1_1_metal_tex_buffer_packed.html#aa72314a540d9ec2568d31275bf28ab65":[6,0,0,687,13],
 "class_ogre_1_1_metal_tex_buffer_packed.html#aa72314a540d9ec2568d31275bf28ab65":[7,0,0,660,13],
-"class_ogre_1_1_metal_tex_buffer_packed.html#aac73dd5b3bfea12dca1c5a64e6e95c7a":[7,0,0,660,3],
-"class_ogre_1_1_metal_tex_buffer_packed.html#aac73dd5b3bfea12dca1c5a64e6e95c7a":[6,0,0,687,3],
-"class_ogre_1_1_metal_tex_buffer_packed.html#aac7d5a7fc76d5e3086620800003e55b5":[7,0,0,660,28]
+"class_ogre_1_1_metal_tex_buffer_packed.html#aa72314a540d9ec2568d31275bf28ab65":[6,0,0,687,13],
+"class_ogre_1_1_metal_tex_buffer_packed.html#aac73dd5b3bfea12dca1c5a64e6e95c7a":[7,0,0,660,3]
 };
