@@ -1,47 +1,49 @@
 var NAVTREEINDEX164 =
 {
-"class_ogre_1_1_metal_texture_gpu_window.html#a9be2b0daaad98d2140ca22efc6685684":[7,0,0,666,59],
+"class_ogre_1_1_metal_texture_gpu_window.html#a96c0f33134c2401b0e711506c8055623":[6,0,0,693,62],
+"class_ogre_1_1_metal_texture_gpu_window.html#a96c0f33134c2401b0e711506c8055623":[7,0,0,666,62],
 "class_ogre_1_1_metal_texture_gpu_window.html#a9be2b0daaad98d2140ca22efc6685684":[6,0,0,693,59],
-"class_ogre_1_1_metal_texture_gpu_window.html#aa0c236009b4074f43621c21db5ff6ef4":[6,0,0,693,87],
+"class_ogre_1_1_metal_texture_gpu_window.html#a9be2b0daaad98d2140ca22efc6685684":[7,0,0,666,59],
 "class_ogre_1_1_metal_texture_gpu_window.html#aa0c236009b4074f43621c21db5ff6ef4":[7,0,0,666,87],
+"class_ogre_1_1_metal_texture_gpu_window.html#aa0c236009b4074f43621c21db5ff6ef4":[6,0,0,693,87],
 "class_ogre_1_1_metal_texture_gpu_window.html#aa2ee4d088c32b3e9efeb4d2fec5cad3e":[7,0,0,666,113],
 "class_ogre_1_1_metal_texture_gpu_window.html#aa2ee4d088c32b3e9efeb4d2fec5cad3e":[6,0,0,693,113],
-"class_ogre_1_1_metal_texture_gpu_window.html#aa3c2ce1e86de183dd2e2eff87da180a5":[6,0,0,693,76],
 "class_ogre_1_1_metal_texture_gpu_window.html#aa3c2ce1e86de183dd2e2eff87da180a5":[7,0,0,666,76],
-"class_ogre_1_1_metal_texture_gpu_window.html#aa3efd161b3ec98e3a405cf3167b7d022":[7,0,0,666,118],
+"class_ogre_1_1_metal_texture_gpu_window.html#aa3c2ce1e86de183dd2e2eff87da180a5":[6,0,0,693,76],
 "class_ogre_1_1_metal_texture_gpu_window.html#aa3efd161b3ec98e3a405cf3167b7d022":[6,0,0,693,118],
+"class_ogre_1_1_metal_texture_gpu_window.html#aa3efd161b3ec98e3a405cf3167b7d022":[7,0,0,666,118],
 "class_ogre_1_1_metal_texture_gpu_window.html#aa5cba290939fe64d8d12c514d79e9fc4":[7,0,0,666,66],
 "class_ogre_1_1_metal_texture_gpu_window.html#aa5cba290939fe64d8d12c514d79e9fc4":[6,0,0,693,66],
 "class_ogre_1_1_metal_texture_gpu_window.html#aa81e2a8d0caf9096dbab0723bab2b894":[6,0,0,693,22],
 "class_ogre_1_1_metal_texture_gpu_window.html#aa81e2a8d0caf9096dbab0723bab2b894":[7,0,0,666,22],
-"class_ogre_1_1_metal_texture_gpu_window.html#aa844386b35f2cb71fee2f61304cb0d8d":[7,0,0,666,77],
 "class_ogre_1_1_metal_texture_gpu_window.html#aa844386b35f2cb71fee2f61304cb0d8d":[6,0,0,693,77],
-"class_ogre_1_1_metal_texture_gpu_window.html#aad718ff4ec85f52e36ef2772d9b150c2":[6,0,0,693,61],
+"class_ogre_1_1_metal_texture_gpu_window.html#aa844386b35f2cb71fee2f61304cb0d8d":[7,0,0,666,77],
 "class_ogre_1_1_metal_texture_gpu_window.html#aad718ff4ec85f52e36ef2772d9b150c2":[7,0,0,666,61],
-"class_ogre_1_1_metal_texture_gpu_window.html#ab038b4f32feeaa739a8cff7397e8809d":[7,0,0,666,73],
+"class_ogre_1_1_metal_texture_gpu_window.html#aad718ff4ec85f52e36ef2772d9b150c2":[6,0,0,693,61],
 "class_ogre_1_1_metal_texture_gpu_window.html#ab038b4f32feeaa739a8cff7397e8809d":[6,0,0,693,73],
+"class_ogre_1_1_metal_texture_gpu_window.html#ab038b4f32feeaa739a8cff7397e8809d":[7,0,0,666,73],
 "class_ogre_1_1_metal_texture_gpu_window.html#ab04b234a5e98c431ad6e8b3c46e9080b":[7,0,0,666,3],
 "class_ogre_1_1_metal_texture_gpu_window.html#ab04b234a5e98c431ad6e8b3c46e9080b":[6,0,0,693,3],
-"class_ogre_1_1_metal_texture_gpu_window.html#ab2695e8f4f208b95547ccf1dcd93837f":[6,0,0,693,30],
 "class_ogre_1_1_metal_texture_gpu_window.html#ab2695e8f4f208b95547ccf1dcd93837f":[7,0,0,666,30],
+"class_ogre_1_1_metal_texture_gpu_window.html#ab2695e8f4f208b95547ccf1dcd93837f":[6,0,0,693,30],
 "class_ogre_1_1_metal_texture_gpu_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,693,100],
 "class_ogre_1_1_metal_texture_gpu_window.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,666,100],
 "class_ogre_1_1_metal_texture_gpu_window.html#ab6906f8bdd2c820cc47b60b7d494d147":[6,0,0,693,68],
 "class_ogre_1_1_metal_texture_gpu_window.html#ab6906f8bdd2c820cc47b60b7d494d147":[7,0,0,666,68],
-"class_ogre_1_1_metal_texture_gpu_window.html#abcf5995181ba29cd8ed6940d1e52ebcd":[6,0,0,693,35],
 "class_ogre_1_1_metal_texture_gpu_window.html#abcf5995181ba29cd8ed6940d1e52ebcd":[7,0,0,666,35],
-"class_ogre_1_1_metal_texture_gpu_window.html#abe4809a1316cb8a86907767c1a071cf9":[6,0,0,693,52],
+"class_ogre_1_1_metal_texture_gpu_window.html#abcf5995181ba29cd8ed6940d1e52ebcd":[6,0,0,693,35],
 "class_ogre_1_1_metal_texture_gpu_window.html#abe4809a1316cb8a86907767c1a071cf9":[7,0,0,666,52],
+"class_ogre_1_1_metal_texture_gpu_window.html#abe4809a1316cb8a86907767c1a071cf9":[6,0,0,693,52],
 "class_ogre_1_1_metal_texture_gpu_window.html#ac66494237857ec1982d7eb15d3e1b67d":[6,0,0,693,33],
 "class_ogre_1_1_metal_texture_gpu_window.html#ac66494237857ec1982d7eb15d3e1b67d":[7,0,0,666,33],
-"class_ogre_1_1_metal_texture_gpu_window.html#ac7261ed5e880bbe376162a666d0ebea3":[6,0,0,693,42],
 "class_ogre_1_1_metal_texture_gpu_window.html#ac7261ed5e880bbe376162a666d0ebea3":[7,0,0,666,42],
-"class_ogre_1_1_metal_texture_gpu_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,693,95],
+"class_ogre_1_1_metal_texture_gpu_window.html#ac7261ed5e880bbe376162a666d0ebea3":[6,0,0,693,42],
 "class_ogre_1_1_metal_texture_gpu_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,666,95],
+"class_ogre_1_1_metal_texture_gpu_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,693,95],
 "class_ogre_1_1_metal_texture_gpu_window.html#acc59aec11b770b8fc317dea50313d052":[7,0,0,666,29],
 "class_ogre_1_1_metal_texture_gpu_window.html#acc59aec11b770b8fc317dea50313d052":[6,0,0,693,29],
-"class_ogre_1_1_metal_texture_gpu_window.html#acdde6ea96205d73550d17a18bf4653a4":[6,0,0,693,90],
 "class_ogre_1_1_metal_texture_gpu_window.html#acdde6ea96205d73550d17a18bf4653a4":[7,0,0,666,90],
+"class_ogre_1_1_metal_texture_gpu_window.html#acdde6ea96205d73550d17a18bf4653a4":[6,0,0,693,90],
 "class_ogre_1_1_metal_texture_gpu_window.html#ace88832ef330c2b560127ca2386c87de":[7,0,0,666,78],
 "class_ogre_1_1_metal_texture_gpu_window.html#ace88832ef330c2b560127ca2386c87de":[6,0,0,693,78],
 "class_ogre_1_1_metal_texture_gpu_window.html#acfce629e8215f50fb4ffc2207b950510":[7,0,0,666,28],
@@ -50,8 +52,8 @@ var NAVTREEINDEX164 =
 "class_ogre_1_1_metal_texture_gpu_window.html#ad1858af3588de15e9da271d22fe9d5c1":[6,0,0,693,72],
 "class_ogre_1_1_metal_texture_gpu_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,693,99],
 "class_ogre_1_1_metal_texture_gpu_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,666,99],
-"class_ogre_1_1_metal_texture_gpu_window.html#ad3b879c519f45ccb57f91bc45a221f3e":[7,0,0,666,9],
 "class_ogre_1_1_metal_texture_gpu_window.html#ad3b879c519f45ccb57f91bc45a221f3e":[6,0,0,693,9],
+"class_ogre_1_1_metal_texture_gpu_window.html#ad3b879c519f45ccb57f91bc45a221f3e":[7,0,0,666,9],
 "class_ogre_1_1_metal_texture_gpu_window.html#ad623ee0c97e95e276074d3cfd64c374c":[6,0,0,693,2],
 "class_ogre_1_1_metal_texture_gpu_window.html#ad623ee0c97e95e276074d3cfd64c374c":[7,0,0,666,2],
 "class_ogre_1_1_metal_texture_gpu_window.html#ad6793827145cb49c0118f61dcbfdbc99":[6,0,0,693,11],
@@ -60,16 +62,16 @@ var NAVTREEINDEX164 =
 "class_ogre_1_1_metal_texture_gpu_window.html#ada88818a92391098af106c48291e8457":[7,0,0,666,16],
 "class_ogre_1_1_metal_texture_gpu_window.html#adc608f61167b7b737a4129cd2b85f5f4":[7,0,0,666,119],
 "class_ogre_1_1_metal_texture_gpu_window.html#adc608f61167b7b737a4129cd2b85f5f4":[6,0,0,693,119],
-"class_ogre_1_1_metal_texture_gpu_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,666,102],
 "class_ogre_1_1_metal_texture_gpu_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,693,102],
-"class_ogre_1_1_metal_texture_gpu_window.html#adf2b1c44eeed67e875e3acaef60b7a31":[7,0,0,666,91],
+"class_ogre_1_1_metal_texture_gpu_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,666,102],
 "class_ogre_1_1_metal_texture_gpu_window.html#adf2b1c44eeed67e875e3acaef60b7a31":[6,0,0,693,91],
+"class_ogre_1_1_metal_texture_gpu_window.html#adf2b1c44eeed67e875e3acaef60b7a31":[7,0,0,666,91],
 "class_ogre_1_1_metal_texture_gpu_window.html#ae397cdfc17678036779b216214120077":[7,0,0,666,64],
 "class_ogre_1_1_metal_texture_gpu_window.html#ae397cdfc17678036779b216214120077":[6,0,0,693,64],
-"class_ogre_1_1_metal_texture_gpu_window.html#ae3e0ad601752b91f2851c88f9ed49869":[7,0,0,666,105],
 "class_ogre_1_1_metal_texture_gpu_window.html#ae3e0ad601752b91f2851c88f9ed49869":[6,0,0,693,105],
-"class_ogre_1_1_metal_texture_gpu_window.html#ae4cc1dcd531021ff3a604aa3c324133f":[7,0,0,666,93],
+"class_ogre_1_1_metal_texture_gpu_window.html#ae3e0ad601752b91f2851c88f9ed49869":[7,0,0,666,105],
 "class_ogre_1_1_metal_texture_gpu_window.html#ae4cc1dcd531021ff3a604aa3c324133f":[6,0,0,693,93],
+"class_ogre_1_1_metal_texture_gpu_window.html#ae4cc1dcd531021ff3a604aa3c324133f":[7,0,0,666,93],
 "class_ogre_1_1_metal_texture_gpu_window.html#ae641939cec4a57193dab3fc88921b7ae":[7,0,0,666,20],
 "class_ogre_1_1_metal_texture_gpu_window.html#ae641939cec4a57193dab3fc88921b7ae":[6,0,0,693,20],
 "class_ogre_1_1_metal_texture_gpu_window.html#ae6576323b0cf05a3efbf46f9ab5d6e1e":[6,0,0,693,84],
@@ -84,106 +86,106 @@ var NAVTREEINDEX164 =
 "class_ogre_1_1_metal_texture_gpu_window.html#aed4c74e16ccbdaf8bf82c04a0f7ea2d6":[6,0,0,693,12],
 "class_ogre_1_1_metal_texture_gpu_window.html#aeebb419ba824d0128f437bbe20cc81f9":[6,0,0,693,13],
 "class_ogre_1_1_metal_texture_gpu_window.html#aeebb419ba824d0128f437bbe20cc81f9":[7,0,0,666,13],
-"class_ogre_1_1_metal_texture_gpu_window.html#af042e9ab52c07776f154ee077330f592":[6,0,0,693,121],
 "class_ogre_1_1_metal_texture_gpu_window.html#af042e9ab52c07776f154ee077330f592":[7,0,0,666,121],
-"class_ogre_1_1_metal_texture_gpu_window.html#af3e85ec353d2f79da71c96ad69b4048a":[6,0,0,693,41],
+"class_ogre_1_1_metal_texture_gpu_window.html#af042e9ab52c07776f154ee077330f592":[6,0,0,693,121],
 "class_ogre_1_1_metal_texture_gpu_window.html#af3e85ec353d2f79da71c96ad69b4048a":[7,0,0,666,41],
+"class_ogre_1_1_metal_texture_gpu_window.html#af3e85ec353d2f79da71c96ad69b4048a":[6,0,0,693,41],
 "class_ogre_1_1_metal_texture_gpu_window.html#af7046d90f92e6a950d6d803892ee4b09":[7,0,0,666,6],
 "class_ogre_1_1_metal_texture_gpu_window.html#af7046d90f92e6a950d6d803892ee4b09":[6,0,0,693,6],
-"class_ogre_1_1_metal_texture_gpu_window.html#af79e22c90559d13385d75dc19970806d":[7,0,0,666,112],
 "class_ogre_1_1_metal_texture_gpu_window.html#af79e22c90559d13385d75dc19970806d":[6,0,0,693,112],
-"class_ogre_1_1_metal_texture_gpu_window.html#af943f8d1fd87f457fb4633058d696470":[7,0,0,666,75],
+"class_ogre_1_1_metal_texture_gpu_window.html#af79e22c90559d13385d75dc19970806d":[7,0,0,666,112],
 "class_ogre_1_1_metal_texture_gpu_window.html#af943f8d1fd87f457fb4633058d696470":[6,0,0,693,75],
+"class_ogre_1_1_metal_texture_gpu_window.html#af943f8d1fd87f457fb4633058d696470":[7,0,0,666,75],
 "class_ogre_1_1_metal_texture_gpu_window.html#aff8a7082cb7abd2e76f8a62a4db36361":[6,0,0,693,0],
 "class_ogre_1_1_metal_texture_gpu_window.html#aff8a7082cb7abd2e76f8a62a4db36361":[7,0,0,666,0],
 "class_ogre_1_1_metal_texture_manager.html":[7,0,0,667],
 "class_ogre_1_1_metal_texture_manager.html":[6,0,0,694],
-"class_ogre_1_1_metal_texture_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[6,0,0,694,17],
 "class_ogre_1_1_metal_texture_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[7,0,0,667,17],
-"class_ogre_1_1_metal_texture_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[6,0,0,694,32],
+"class_ogre_1_1_metal_texture_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[6,0,0,694,17],
 "class_ogre_1_1_metal_texture_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[7,0,0,667,32],
-"class_ogre_1_1_metal_texture_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[7,0,0,667,30],
+"class_ogre_1_1_metal_texture_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[6,0,0,694,32],
 "class_ogre_1_1_metal_texture_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[6,0,0,694,30],
-"class_ogre_1_1_metal_texture_manager.html#a117a3887bbf9e83e0585777beb0501dc":[6,0,0,694,4],
+"class_ogre_1_1_metal_texture_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[7,0,0,667,30],
 "class_ogre_1_1_metal_texture_manager.html#a117a3887bbf9e83e0585777beb0501dc":[7,0,0,667,4],
+"class_ogre_1_1_metal_texture_manager.html#a117a3887bbf9e83e0585777beb0501dc":[6,0,0,694,4],
 "class_ogre_1_1_metal_texture_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,667,45],
 "class_ogre_1_1_metal_texture_manager.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,694,45],
-"class_ogre_1_1_metal_texture_manager.html#a1db642a9eef36b32dbdea28d19e8ea0d":[7,0,0,667,40],
 "class_ogre_1_1_metal_texture_manager.html#a1db642a9eef36b32dbdea28d19e8ea0d":[6,0,0,694,40],
+"class_ogre_1_1_metal_texture_manager.html#a1db642a9eef36b32dbdea28d19e8ea0d":[7,0,0,667,40],
 "class_ogre_1_1_metal_texture_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[7,0,0,667,74],
 "class_ogre_1_1_metal_texture_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[6,0,0,694,74],
 "class_ogre_1_1_metal_texture_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[7,0,0,667,2],
 "class_ogre_1_1_metal_texture_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[6,0,0,694,2],
-"class_ogre_1_1_metal_texture_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[7,0,0,667,1],
 "class_ogre_1_1_metal_texture_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[6,0,0,694,1],
-"class_ogre_1_1_metal_texture_manager.html#a2a5f6c92d4f91eb1eaa0ccf9b73f8c83":[6,0,0,694,26],
+"class_ogre_1_1_metal_texture_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[7,0,0,667,1],
 "class_ogre_1_1_metal_texture_manager.html#a2a5f6c92d4f91eb1eaa0ccf9b73f8c83":[7,0,0,667,26],
+"class_ogre_1_1_metal_texture_manager.html#a2a5f6c92d4f91eb1eaa0ccf9b73f8c83":[6,0,0,694,26],
 "class_ogre_1_1_metal_texture_manager.html#a2cf457c70ea86892b1bec52028c96237":[7,0,0,667,72],
 "class_ogre_1_1_metal_texture_manager.html#a2cf457c70ea86892b1bec52028c96237":[6,0,0,694,72],
 "class_ogre_1_1_metal_texture_manager.html#a3083fb17ce51843aecdc0382d2d717f6":[6,0,0,694,42],
 "class_ogre_1_1_metal_texture_manager.html#a3083fb17ce51843aecdc0382d2d717f6":[7,0,0,667,42],
-"class_ogre_1_1_metal_texture_manager.html#a3b27a21f192919d78c14bccea5184736":[6,0,0,694,14],
 "class_ogre_1_1_metal_texture_manager.html#a3b27a21f192919d78c14bccea5184736":[7,0,0,667,14],
-"class_ogre_1_1_metal_texture_manager.html#a3cc7b930d37bc9fc156f7a2cadb572a3":[6,0,0,694,21],
+"class_ogre_1_1_metal_texture_manager.html#a3b27a21f192919d78c14bccea5184736":[6,0,0,694,14],
 "class_ogre_1_1_metal_texture_manager.html#a3cc7b930d37bc9fc156f7a2cadb572a3":[7,0,0,667,21],
-"class_ogre_1_1_metal_texture_manager.html#a3f92489910e40e3756606a35618d7b06":[7,0,0,667,59],
+"class_ogre_1_1_metal_texture_manager.html#a3cc7b930d37bc9fc156f7a2cadb572a3":[6,0,0,694,21],
 "class_ogre_1_1_metal_texture_manager.html#a3f92489910e40e3756606a35618d7b06":[6,0,0,694,59],
-"class_ogre_1_1_metal_texture_manager.html#a40769092850d5b296e1d1a9190631700":[7,0,0,667,8],
+"class_ogre_1_1_metal_texture_manager.html#a3f92489910e40e3756606a35618d7b06":[7,0,0,667,59],
 "class_ogre_1_1_metal_texture_manager.html#a40769092850d5b296e1d1a9190631700":[6,0,0,694,8],
-"class_ogre_1_1_metal_texture_manager.html#a42ae3de59dd5ccfd449645ec4af1143c":[7,0,0,667,34],
+"class_ogre_1_1_metal_texture_manager.html#a40769092850d5b296e1d1a9190631700":[7,0,0,667,8],
 "class_ogre_1_1_metal_texture_manager.html#a42ae3de59dd5ccfd449645ec4af1143c":[6,0,0,694,34],
-"class_ogre_1_1_metal_texture_manager.html#a42f172a8ed1625011d510b081eee66dd":[7,0,0,667,22],
+"class_ogre_1_1_metal_texture_manager.html#a42ae3de59dd5ccfd449645ec4af1143c":[7,0,0,667,34],
 "class_ogre_1_1_metal_texture_manager.html#a42f172a8ed1625011d510b081eee66dd":[6,0,0,694,22],
+"class_ogre_1_1_metal_texture_manager.html#a42f172a8ed1625011d510b081eee66dd":[7,0,0,667,22],
 "class_ogre_1_1_metal_texture_manager.html#a45d8b138d17f258816383140ca765aa3":[6,0,0,694,55],
 "class_ogre_1_1_metal_texture_manager.html#a45d8b138d17f258816383140ca765aa3":[7,0,0,667,55],
-"class_ogre_1_1_metal_texture_manager.html#a48c565d0e63b286c6388439ae73417df":[6,0,0,694,13],
 "class_ogre_1_1_metal_texture_manager.html#a48c565d0e63b286c6388439ae73417df":[7,0,0,667,13],
-"class_ogre_1_1_metal_texture_manager.html#a49a47b8919269342243265df3bd1e1fc":[7,0,0,667,27],
+"class_ogre_1_1_metal_texture_manager.html#a48c565d0e63b286c6388439ae73417df":[6,0,0,694,13],
 "class_ogre_1_1_metal_texture_manager.html#a49a47b8919269342243265df3bd1e1fc":[6,0,0,694,27],
+"class_ogre_1_1_metal_texture_manager.html#a49a47b8919269342243265df3bd1e1fc":[7,0,0,667,27],
 "class_ogre_1_1_metal_texture_manager.html#a4d3289d4636168230da11c1c9794db59":[7,0,0,667,29],
 "class_ogre_1_1_metal_texture_manager.html#a4d3289d4636168230da11c1c9794db59":[6,0,0,694,29],
 "class_ogre_1_1_metal_texture_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[7,0,0,667,58],
 "class_ogre_1_1_metal_texture_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[6,0,0,694,58],
-"class_ogre_1_1_metal_texture_manager.html#a4f00d9cf3ea35b9804e5ce10d45d2fff":[7,0,0,667,12],
 "class_ogre_1_1_metal_texture_manager.html#a4f00d9cf3ea35b9804e5ce10d45d2fff":[6,0,0,694,12],
+"class_ogre_1_1_metal_texture_manager.html#a4f00d9cf3ea35b9804e5ce10d45d2fff":[7,0,0,667,12],
 "class_ogre_1_1_metal_texture_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[7,0,0,667,3],
 "class_ogre_1_1_metal_texture_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[6,0,0,694,3],
-"class_ogre_1_1_metal_texture_manager.html#a54d1843a43aebb13542312cd17134e6a":[6,0,0,694,9],
 "class_ogre_1_1_metal_texture_manager.html#a54d1843a43aebb13542312cd17134e6a":[7,0,0,667,9],
+"class_ogre_1_1_metal_texture_manager.html#a54d1843a43aebb13542312cd17134e6a":[6,0,0,694,9],
 "class_ogre_1_1_metal_texture_manager.html#a57e22b305d763f9ede5bda93f31051ca":[7,0,0,667,31],
 "class_ogre_1_1_metal_texture_manager.html#a57e22b305d763f9ede5bda93f31051ca":[6,0,0,694,31],
-"class_ogre_1_1_metal_texture_manager.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,694,47],
 "class_ogre_1_1_metal_texture_manager.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,667,47],
+"class_ogre_1_1_metal_texture_manager.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,694,47],
 "class_ogre_1_1_metal_texture_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,667,50],
 "class_ogre_1_1_metal_texture_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,694,50],
-"class_ogre_1_1_metal_texture_manager.html#a65730ea50a81401518b4cbf6bb6a0a73":[6,0,0,694,37],
 "class_ogre_1_1_metal_texture_manager.html#a65730ea50a81401518b4cbf6bb6a0a73":[7,0,0,667,37],
+"class_ogre_1_1_metal_texture_manager.html#a65730ea50a81401518b4cbf6bb6a0a73":[6,0,0,694,37],
 "class_ogre_1_1_metal_texture_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[6,0,0,694,28],
 "class_ogre_1_1_metal_texture_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[7,0,0,667,28],
-"class_ogre_1_1_metal_texture_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[7,0,0,667,63],
 "class_ogre_1_1_metal_texture_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[6,0,0,694,63],
-"class_ogre_1_1_metal_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[6,0,0,694,62],
+"class_ogre_1_1_metal_texture_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[7,0,0,667,63],
 "class_ogre_1_1_metal_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[7,0,0,667,62],
+"class_ogre_1_1_metal_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[6,0,0,694,62],
 "class_ogre_1_1_metal_texture_manager.html#a77d097944def071bd10e1c2a03fc5b2c":[7,0,0,667,69],
 "class_ogre_1_1_metal_texture_manager.html#a77d097944def071bd10e1c2a03fc5b2c":[6,0,0,694,69],
 "class_ogre_1_1_metal_texture_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[6,0,0,694,16],
 "class_ogre_1_1_metal_texture_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[7,0,0,667,16],
 "class_ogre_1_1_metal_texture_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[7,0,0,667,53],
 "class_ogre_1_1_metal_texture_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[6,0,0,694,53],
-"class_ogre_1_1_metal_texture_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,694,43],
 "class_ogre_1_1_metal_texture_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,667,43],
+"class_ogre_1_1_metal_texture_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,694,43],
 "class_ogre_1_1_metal_texture_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[6,0,0,694,57],
 "class_ogre_1_1_metal_texture_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[7,0,0,667,57],
 "class_ogre_1_1_metal_texture_manager.html#a851d95c070542c83823f99664395af8d":[7,0,0,667,5],
 "class_ogre_1_1_metal_texture_manager.html#a851d95c070542c83823f99664395af8d":[6,0,0,694,5],
-"class_ogre_1_1_metal_texture_manager.html#a8faa10c9150687d1bf229ccff16a8960":[6,0,0,694,33],
 "class_ogre_1_1_metal_texture_manager.html#a8faa10c9150687d1bf229ccff16a8960":[7,0,0,667,33],
-"class_ogre_1_1_metal_texture_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[6,0,0,694,75],
+"class_ogre_1_1_metal_texture_manager.html#a8faa10c9150687d1bf229ccff16a8960":[6,0,0,694,33],
 "class_ogre_1_1_metal_texture_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[7,0,0,667,75],
+"class_ogre_1_1_metal_texture_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[6,0,0,694,75],
 "class_ogre_1_1_metal_texture_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,667,46],
 "class_ogre_1_1_metal_texture_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,694,46],
-"class_ogre_1_1_metal_texture_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[6,0,0,694,73],
 "class_ogre_1_1_metal_texture_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[7,0,0,667,73],
+"class_ogre_1_1_metal_texture_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[6,0,0,694,73],
 "class_ogre_1_1_metal_texture_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[6,0,0,694,64],
 "class_ogre_1_1_metal_texture_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[7,0,0,667,64],
 "class_ogre_1_1_metal_texture_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[7,0,0,667,24],
@@ -192,38 +194,38 @@ var NAVTREEINDEX164 =
 "class_ogre_1_1_metal_texture_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[6,0,0,694,71],
 "class_ogre_1_1_metal_texture_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[6,0,0,694,67],
 "class_ogre_1_1_metal_texture_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[7,0,0,667,67],
-"class_ogre_1_1_metal_texture_manager.html#aa8b761abb06d74347e9636550307ccd9":[6,0,0,694,18],
 "class_ogre_1_1_metal_texture_manager.html#aa8b761abb06d74347e9636550307ccd9":[7,0,0,667,18],
-"class_ogre_1_1_metal_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[7,0,0,667,56],
+"class_ogre_1_1_metal_texture_manager.html#aa8b761abb06d74347e9636550307ccd9":[6,0,0,694,18],
 "class_ogre_1_1_metal_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[6,0,0,694,56],
+"class_ogre_1_1_metal_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[7,0,0,667,56],
 "class_ogre_1_1_metal_texture_manager.html#aaaa53651124f3773fbcf6ae2b4a6fbe5":[7,0,0,667,70],
 "class_ogre_1_1_metal_texture_manager.html#aaaa53651124f3773fbcf6ae2b4a6fbe5":[6,0,0,694,70],
-"class_ogre_1_1_metal_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[6,0,0,694,41],
 "class_ogre_1_1_metal_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[7,0,0,667,41],
+"class_ogre_1_1_metal_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[6,0,0,694,41],
 "class_ogre_1_1_metal_texture_manager.html#ab100fde4ba39c0465e6d18f6a225d7bf":[7,0,0,667,25],
 "class_ogre_1_1_metal_texture_manager.html#ab100fde4ba39c0465e6d18f6a225d7bf":[6,0,0,694,25],
-"class_ogre_1_1_metal_texture_manager.html#ab194cb5e332fc3eb35591e468f5dbcd3":[7,0,0,667,66],
 "class_ogre_1_1_metal_texture_manager.html#ab194cb5e332fc3eb35591e468f5dbcd3":[6,0,0,694,66],
-"class_ogre_1_1_metal_texture_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[7,0,0,667,19],
+"class_ogre_1_1_metal_texture_manager.html#ab194cb5e332fc3eb35591e468f5dbcd3":[7,0,0,667,66],
 "class_ogre_1_1_metal_texture_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[6,0,0,694,19],
-"class_ogre_1_1_metal_texture_manager.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,667,49],
+"class_ogre_1_1_metal_texture_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[7,0,0,667,19],
 "class_ogre_1_1_metal_texture_manager.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,694,49],
-"class_ogre_1_1_metal_texture_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[7,0,0,667,77],
+"class_ogre_1_1_metal_texture_manager.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,667,49],
 "class_ogre_1_1_metal_texture_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[6,0,0,694,77],
-"class_ogre_1_1_metal_texture_manager.html#abbbab1db9a334e39c2114ee3a21b013f":[6,0,0,694,36],
+"class_ogre_1_1_metal_texture_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[7,0,0,667,77],
 "class_ogre_1_1_metal_texture_manager.html#abbbab1db9a334e39c2114ee3a21b013f":[7,0,0,667,36],
+"class_ogre_1_1_metal_texture_manager.html#abbbab1db9a334e39c2114ee3a21b013f":[6,0,0,694,36],
 "class_ogre_1_1_metal_texture_manager.html#abfb0022b18d022a7605f0d19a966f00f":[6,0,0,694,60],
 "class_ogre_1_1_metal_texture_manager.html#abfb0022b18d022a7605f0d19a966f00f":[7,0,0,667,60],
-"class_ogre_1_1_metal_texture_manager.html#ac14ba89b6f362479e461836cecc198c9":[6,0,0,694,6],
 "class_ogre_1_1_metal_texture_manager.html#ac14ba89b6f362479e461836cecc198c9":[7,0,0,667,6],
+"class_ogre_1_1_metal_texture_manager.html#ac14ba89b6f362479e461836cecc198c9":[6,0,0,694,6],
 "class_ogre_1_1_metal_texture_manager.html#ac22655af03ecea85d863a1d1d561778c":[6,0,0,694,61],
 "class_ogre_1_1_metal_texture_manager.html#ac22655af03ecea85d863a1d1d561778c":[7,0,0,667,61],
-"class_ogre_1_1_metal_texture_manager.html#ac8f7ee61606730572a8590060d8896a0":[7,0,0,667,23],
 "class_ogre_1_1_metal_texture_manager.html#ac8f7ee61606730572a8590060d8896a0":[6,0,0,694,23],
+"class_ogre_1_1_metal_texture_manager.html#ac8f7ee61606730572a8590060d8896a0":[7,0,0,667,23],
 "class_ogre_1_1_metal_texture_manager.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,667,44],
 "class_ogre_1_1_metal_texture_manager.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,694,44],
-"class_ogre_1_1_metal_texture_manager.html#acd4223279e97a7687e2f9994f05e2491":[6,0,0,694,15],
 "class_ogre_1_1_metal_texture_manager.html#acd4223279e97a7687e2f9994f05e2491":[7,0,0,667,15],
+"class_ogre_1_1_metal_texture_manager.html#acd4223279e97a7687e2f9994f05e2491":[6,0,0,694,15],
 "class_ogre_1_1_metal_texture_manager.html#ad123cb83e4daa046824401f8cc24f649":[7,0,0,667,38],
 "class_ogre_1_1_metal_texture_manager.html#ad123cb83e4daa046824401f8cc24f649":[6,0,0,694,38],
 "class_ogre_1_1_metal_texture_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,694,48],
@@ -234,20 +236,18 @@ var NAVTREEINDEX164 =
 "class_ogre_1_1_metal_texture_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[6,0,0,694,65],
 "class_ogre_1_1_metal_texture_manager.html#adce32528577d71b228692df906ecd17c":[6,0,0,694,51],
 "class_ogre_1_1_metal_texture_manager.html#adce32528577d71b228692df906ecd17c":[7,0,0,667,51],
-"class_ogre_1_1_metal_texture_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[6,0,0,694,54],
 "class_ogre_1_1_metal_texture_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[7,0,0,667,54],
-"class_ogre_1_1_metal_texture_manager.html#ae63b06c1fd6d1266b4c5dacc35e521b4":[6,0,0,694,10],
+"class_ogre_1_1_metal_texture_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[6,0,0,694,54],
 "class_ogre_1_1_metal_texture_manager.html#ae63b06c1fd6d1266b4c5dacc35e521b4":[7,0,0,667,10],
+"class_ogre_1_1_metal_texture_manager.html#ae63b06c1fd6d1266b4c5dacc35e521b4":[6,0,0,694,10],
 "class_ogre_1_1_metal_texture_manager.html#aeaa1410333b7bcea14b00c360112a528":[7,0,0,667,76],
 "class_ogre_1_1_metal_texture_manager.html#aeaa1410333b7bcea14b00c360112a528":[6,0,0,694,76],
 "class_ogre_1_1_metal_texture_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,667,52],
 "class_ogre_1_1_metal_texture_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,694,52],
-"class_ogre_1_1_metal_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[6,0,0,694,7],
 "class_ogre_1_1_metal_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[7,0,0,667,7],
+"class_ogre_1_1_metal_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[6,0,0,694,7],
 "class_ogre_1_1_metal_texture_manager.html#af2cae9ecc99635a541df72ae7cdd337a":[6,0,0,694,68],
 "class_ogre_1_1_metal_texture_manager.html#af2cae9ecc99635a541df72ae7cdd337a":[7,0,0,667,68],
-"class_ogre_1_1_metal_texture_manager.html#af33a91a3a918df919de56635b13a532e":[7,0,0,667,11],
 "class_ogre_1_1_metal_texture_manager.html#af33a91a3a918df919de56635b13a532e":[6,0,0,694,11],
-"class_ogre_1_1_metal_texture_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[6,0,0,694,0],
-"class_ogre_1_1_metal_texture_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[7,0,0,667,0]
+"class_ogre_1_1_metal_texture_manager.html#af33a91a3a918df919de56635b13a532e":[7,0,0,667,11]
 };
