@@ -1,5 +1,7 @@
 var NAVTREEINDEX186 =
 {
+"class_ogre_1_1_particle_affector.html#a3e314036bfd3198e89bd1d250f5eb6a1":[5,2,1,37,7],
+"class_ogre_1_1_particle_affector.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,1,37,15],
 "class_ogre_1_1_particle_affector.html#a5f401d9023e7bb484ff3ff49e70c9510":[5,2,1,37,3],
 "class_ogre_1_1_particle_affector.html#a61826c830fc3ef4f37410a656aae7a81":[5,2,1,37,2],
 "class_ogre_1_1_particle_affector.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,1,37,18],
@@ -247,7 +249,5 @@ var NAVTREEINDEX186 =
 "class_ogre_1_1_particle_system.html#a5f7b365da61eba227c468681e0fb1cde":[5,2,1,42,49],
 "class_ogre_1_1_particle_system.html#a61b39d44e60020d43033a6957895aa5f":[5,2,1,42,46],
 "class_ogre_1_1_particle_system.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,1,42,118],
-"class_ogre_1_1_particle_system.html#a64bd61f33ae8a2d4e824ce7e23308d98":[5,2,1,42,36],
-"class_ogre_1_1_particle_system.html#a64ce63202976ae66e5ee70c36cdf26e3":[5,2,1,42,90],
-"class_ogre_1_1_particle_system.html#a6784cc5dfe836936e8f7cda0079fce74":[5,2,1,42,14]
+"class_ogre_1_1_particle_system.html#a64bd61f33ae8a2d4e824ce7e23308d98":[5,2,1,42,36]
 };
