@@ -1,5 +1,7 @@
 var NAVTREEINDEX190 =
 {
+"class_ogre_1_1_plane.html#a1530cc182a2a783e072eabe44f536149":[5,2,6,19,1],
+"class_ogre_1_1_plane.html#a1f4b68ae4354cd7b0cc63374497461cb":[5,2,6,19,8],
 "class_ogre_1_1_plane.html#a1f5ace6a3a4bedc91a283895fb77a6a8":[5,2,6,19,13],
 "class_ogre_1_1_plane.html#a296599d7461accceada20df86f7bd334":[5,2,6,19,2],
 "class_ogre_1_1_plane.html#a3f97462d3822f6add8c070048f6c2d92":[5,2,6,19,19],
@@ -33,8 +35,8 @@ var NAVTREEINDEX190 =
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html":[5,0,1,33],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,2,12,33,0],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,0,1,33,0],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,33,0,2],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,0,1,33,0,2],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,33,0,2],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,0,1,33,0,1],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,2,12,33,0,1],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,2,12,33,0,0],
@@ -43,42 +45,42 @@ var NAVTREEINDEX190 =
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,0,1,33,0,4],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,0,1,33,0,3],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,2,12,33,0,3],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,33,13],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,33,13],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,2,12,33,3],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,33,13],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,0,1,33,3],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,2,12,33,3],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a20e200f7a33292e6644a44bf882ae8f6":[5,2,12,33,4],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a20e200f7a33292e6644a44bf882ae8f6":[5,0,1,33,4],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a37f0a7cdf7bdb53bfa98c9e3c8541c41":[5,0,1,33,2],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a37f0a7cdf7bdb53bfa98c9e3c8541c41":[5,2,12,33,2],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a37f0a7cdf7bdb53bfa98c9e3c8541c41":[5,0,1,33,2],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,2,12,33,27],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,0,1,33,27],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,0,1,33,21],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,2,12,33,21],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,33,15],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,0,1,33,21],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,33,15],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,33,18],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,33,15],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,33,18],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,33,18],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,0,1,33,8],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,2,12,33,8],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,33,11],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,33,11],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,2,12,33,6],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,0,1,33,6],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,33,14],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,2,12,33,6],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,33,14],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,0,1,33,5],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,33,14],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,2,12,33,5],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,0,1,33,5],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,33,17],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,33,17],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ac7f81d455b20245603c5d51f4b00ea90":[5,0,1,33,1],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ac7f81d455b20245603c5d51f4b00ea90":[5,2,12,33,1],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ac7f81d455b20245603c5d51f4b00ea90":[5,0,1,33,1],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,33,12],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,33,12],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,2,12,33,10],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,0,1,33,10],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,33,16],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,33,16],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,33,16],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,12,33,23],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,0,1,33,23],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#adce32528577d71b228692df906ecd17c":[5,2,12,33,19],
@@ -91,22 +93,22 @@ var NAVTREEINDEX190 =
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,1,33,25],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,33,20],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,33,20],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,12,33,7],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,0,1,33,7],
-"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#af82e119f79b5e4e91e599c27623977df":[5,0,1,33,24],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,12,33,7],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#af82e119f79b5e4e91e599c27623977df":[5,2,12,33,24],
+"class_ogre_1_1_plane_bounded_volume_list_scene_query.html#af82e119f79b5e4e91e599c27623977df":[5,0,1,33,24],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#af9f6f42dc4cd2b5368e380ff4297fdbf":[5,2,12,33,9],
 "class_ogre_1_1_plane_bounded_volume_list_scene_query.html#af9f6f42dc4cd2b5368e380ff4297fdbf":[5,0,1,33,9],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html":[5,0,1,34],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html":[5,2,12,34],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html":[5,0,1,34],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a0fdd507e53ed2fecb42080c9c9fe85ec":[5,0,1,34,1],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a0fdd507e53ed2fecb42080c9c9fe85ec":[5,2,12,34,1],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,34,7],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,34,7],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a4711539f8fe2386bfdeb18bda84862ee":[5,0,1,34,4],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,34,7],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a4711539f8fe2386bfdeb18bda84862ee":[5,2,12,34,4],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,34,9],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a4711539f8fe2386bfdeb18bda84862ee":[5,0,1,34,4],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,34,9],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,34,9],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,2,12,34,2],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,0,1,34,2],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,34,12],
@@ -115,22 +117,22 @@ var NAVTREEINDEX190 =
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,0,1,34,15],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,34,5],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,34,5],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a84aeb5d693cf9235080fc84031ec881f":[5,0,1,34,0],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a84aeb5d693cf9235080fc84031ec881f":[5,2,12,34,0],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,34,8],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a84aeb5d693cf9235080fc84031ec881f":[5,0,1,34,0],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,34,8],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,34,11],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,34,8],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,34,11],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,34,6],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,34,11],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,34,6],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,34,10],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,34,6],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,34,10],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,0,1,34,3],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,34,10],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,2,12,34,3],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,0,1,34,13],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,0,1,34,3],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,2,12,34,13],
-"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,34,14],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,0,1,34,13],
 "class_ogre_1_1_plane_optimal_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,34,14],
+"class_ogre_1_1_plane_optimal_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,34,14],
 "class_ogre_1_1_platform_information.html":[5,2,2,80],
 "class_ogre_1_1_platform_information.html#a1b64c69682054e5e3d1563067fa19f68":[5,2,2,80,2],
 "class_ogre_1_1_platform_information.html#a9c975bf5f74c9c085a7ff073cacf6834":[5,2,2,80,3],
@@ -190,18 +192,18 @@ var NAVTREEINDEX190 =
 "class_ogre_1_1_polygon.html#a9d80e759f5c77ba5a308d298c8b498c2":[5,2,6,21,9],
 "class_ogre_1_1_polygon.html#a9db9518c3381e7a840610bf181d65b73":[5,2,6,21,16],
 "class_ogre_1_1_polygon.html#ac32b2d0a6e7c0cee21471fdaf6da13c4":[5,2,6,21,10],
-"class_ogre_1_1_pool.html":[7,0,0,777],
 "class_ogre_1_1_pool.html":[6,0,0,804],
+"class_ogre_1_1_pool.html":[7,0,0,777],
 "class_ogre_1_1_pool.html#a31c74c47be2a3c8e5abe93a8ac061bc7":[6,0,0,804,4],
 "class_ogre_1_1_pool.html#a31c74c47be2a3c8e5abe93a8ac061bc7":[7,0,0,777,4],
-"class_ogre_1_1_pool.html#a4fb09f4b25feb32de79b6f578359aab1":[7,0,0,777,1],
 "class_ogre_1_1_pool.html#a4fb09f4b25feb32de79b6f578359aab1":[6,0,0,804,1],
+"class_ogre_1_1_pool.html#a4fb09f4b25feb32de79b6f578359aab1":[7,0,0,777,1],
 "class_ogre_1_1_pool.html#a7bd667e735a8fdaf2e7017d436ba75a6":[6,0,0,804,0],
 "class_ogre_1_1_pool.html#a7bd667e735a8fdaf2e7017d436ba75a6":[7,0,0,777,0],
-"class_ogre_1_1_pool.html#abafd7c72963d86ef829c0373fe50aa7f":[7,0,0,777,2],
 "class_ogre_1_1_pool.html#abafd7c72963d86ef829c0373fe50aa7f":[6,0,0,804,2],
-"class_ogre_1_1_pool.html#af399adb462aa706c25e1e961cdfb5a1e":[7,0,0,777,3],
+"class_ogre_1_1_pool.html#abafd7c72963d86ef829c0373fe50aa7f":[7,0,0,777,2],
 "class_ogre_1_1_pool.html#af399adb462aa706c25e1e961cdfb5a1e":[6,0,0,804,3],
+"class_ogre_1_1_pool.html#af399adb462aa706c25e1e961cdfb5a1e":[7,0,0,777,3],
 "class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html":[5,2,2,82],
 "class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a298f1b128634bef5d5964726097278e8":[5,2,2,82,2],
 "class_ogre_1_1_pre_apply_texture_aliases_script_compiler_event.html#a403617d0cc5f8e8bffccca4012dd6fb1":[5,2,2,82,1],
@@ -247,7 +249,5 @@ var NAVTREEINDEX190 =
 "class_ogre_1_1_profile_instance.html#a1fd3ce0a1a19f9721d712c9a1426b515":[5,2,2,88,19],
 "class_ogre_1_1_profile_instance.html#a27bde362d885b8aab267d0635b0c30ae":[5,2,2,88,22],
 "class_ogre_1_1_profile_instance.html#a40b76f9c74bd13e1b07db0559af27dc5":[5,2,2,88,29],
-"class_ogre_1_1_profile_instance.html#a41f4675a0f1e9bebe386851423f2e682":[5,2,2,88,4],
-"class_ogre_1_1_profile_instance.html#a4921211276e29e72155077235687cf54":[5,2,2,88,2],
-"class_ogre_1_1_profile_instance.html#a57bcfc956ed84e6e4a85bf485a98d7c3":[5,2,2,88,0]
+"class_ogre_1_1_profile_instance.html#a41f4675a0f1e9bebe386851423f2e682":[5,2,2,88,4]
 };
