@@ -1,5 +1,7 @@
 var NAVTREEINDEX207 =
 {
+"class_ogre_1_1_rendering_a_p_i_exception.html#a46395691f8826d1d5f3e70a183f321c8":[5,2,2,93,9],
+"class_ogre_1_1_rendering_a_p_i_exception.html#a569c60c64b13e2bd73d579a1584367f0":[5,2,2,93,2],
 "class_ogre_1_1_rendering_a_p_i_exception.html#a9bdf9b8a0a83b95818d676848beaa29b":[5,2,2,93,0],
 "class_ogre_1_1_rendering_a_p_i_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba359c10b8abe9abf39f84550a903e4698":[5,2,2,93,0,2],
 "class_ogre_1_1_rendering_a_p_i_exception.html#a9bdf9b8a0a83b95818d676848beaa29ba55da7c9771a98e7c96c3900028f02703":[5,2,2,93,0,3],
@@ -247,7 +249,5 @@ var NAVTREEINDEX207 =
 "class_ogre_1_1_resource_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[5,2,11,119,22],
 "class_ogre_1_1_resource_manager.html#a117a3887bbf9e83e0585777beb0501dc":[5,2,11,119,5],
 "class_ogre_1_1_resource_manager.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,11,119,29],
-"class_ogre_1_1_resource_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[5,2,11,119,53],
-"class_ogre_1_1_resource_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[5,2,11,119,3],
-"class_ogre_1_1_resource_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[5,2,11,119,2]
+"class_ogre_1_1_resource_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[5,2,11,119,53]
 };
