@@ -1,186 +1,188 @@
 var NAVTREEINDEX214 =
 {
+"class_ogre_1_1_scene_node.html#a6dced923268b7b145eb397d2bbf55520":[5,2,12,50,34],
 "class_ogre_1_1_scene_node.html#a6e4f546194a1dcf79703ef2ffd6cead4":[5,0,1,50,127],
+"class_ogre_1_1_scene_node.html#a6e4f546194a1dcf79703ef2ffd6cead4":[5,2,12,50,127],
 "class_ogre_1_1_scene_node.html#a6f5fc23a04991fc7a524763b0bdf829c":[5,0,1,50,80],
 "class_ogre_1_1_scene_node.html#a6f5fc23a04991fc7a524763b0bdf829c":[5,2,12,50,80],
 "class_ogre_1_1_scene_node.html#a70ff235b93b63af33f3b7f7164e3c643":[5,0,1,50,67],
 "class_ogre_1_1_scene_node.html#a70ff235b93b63af33f3b7f7164e3c643":[5,2,12,50,67],
-"class_ogre_1_1_scene_node.html#a732f69dff26b677c6ab11da2a9474059":[5,2,12,50,35],
 "class_ogre_1_1_scene_node.html#a732f69dff26b677c6ab11da2a9474059":[5,0,1,50,35],
+"class_ogre_1_1_scene_node.html#a732f69dff26b677c6ab11da2a9474059":[5,2,12,50,35],
 "class_ogre_1_1_scene_node.html#a73a39cee77eb770833f90a2085b16afd":[5,2,12,50,40],
 "class_ogre_1_1_scene_node.html#a73a39cee77eb770833f90a2085b16afd":[5,0,1,50,40],
 "class_ogre_1_1_scene_node.html#a79b3e979879906d5500b961a98d04bc0":[5,0,1,50,96],
 "class_ogre_1_1_scene_node.html#a79b3e979879906d5500b961a98d04bc0":[5,2,12,50,96],
 "class_ogre_1_1_scene_node.html#a7ca6fb6ba2217c21dac4cb49bcc31521":[5,2,12,50,106],
 "class_ogre_1_1_scene_node.html#a7ca6fb6ba2217c21dac4cb49bcc31521":[5,0,1,50,106],
-"class_ogre_1_1_scene_node.html#a7d2016f05ed7253d617374ec137d47fb":[5,0,1,50,61],
 "class_ogre_1_1_scene_node.html#a7d2016f05ed7253d617374ec137d47fb":[5,2,12,50,61],
-"class_ogre_1_1_scene_node.html#a7ed3d23f3069df5e3356369fc5174e9d":[5,0,1,50,17],
+"class_ogre_1_1_scene_node.html#a7d2016f05ed7253d617374ec137d47fb":[5,0,1,50,61],
 "class_ogre_1_1_scene_node.html#a7ed3d23f3069df5e3356369fc5174e9d":[5,2,12,50,17],
+"class_ogre_1_1_scene_node.html#a7ed3d23f3069df5e3356369fc5174e9d":[5,0,1,50,17],
 "class_ogre_1_1_scene_node.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,50,83],
 "class_ogre_1_1_scene_node.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,50,83],
-"class_ogre_1_1_scene_node.html#a84efd2062a90048361e94e4db7bc79bc":[5,2,12,50,0],
 "class_ogre_1_1_scene_node.html#a84efd2062a90048361e94e4db7bc79bc":[5,0,1,50,0],
-"class_ogre_1_1_scene_node.html#a8527d3766bb672f8bccc8535666511cb":[5,2,12,50,99],
+"class_ogre_1_1_scene_node.html#a84efd2062a90048361e94e4db7bc79bc":[5,2,12,50,0],
 "class_ogre_1_1_scene_node.html#a8527d3766bb672f8bccc8535666511cb":[5,0,1,50,99],
+"class_ogre_1_1_scene_node.html#a8527d3766bb672f8bccc8535666511cb":[5,2,12,50,99],
 "class_ogre_1_1_scene_node.html#a860bc1957a00d3fb8b8b301b25edc895":[5,2,12,50,53],
 "class_ogre_1_1_scene_node.html#a860bc1957a00d3fb8b8b301b25edc895":[5,0,1,50,53],
-"class_ogre_1_1_scene_node.html#a8878eac5eb981866436badd7274195f2":[5,0,1,50,58],
 "class_ogre_1_1_scene_node.html#a8878eac5eb981866436badd7274195f2":[5,2,12,50,58],
-"class_ogre_1_1_scene_node.html#a92880d01d440c1a3b2b8ec4c0a20c037":[5,0,1,50,15],
+"class_ogre_1_1_scene_node.html#a8878eac5eb981866436badd7274195f2":[5,0,1,50,58],
 "class_ogre_1_1_scene_node.html#a92880d01d440c1a3b2b8ec4c0a20c037":[5,2,12,50,15],
+"class_ogre_1_1_scene_node.html#a92880d01d440c1a3b2b8ec4c0a20c037":[5,0,1,50,15],
 "class_ogre_1_1_scene_node.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,50,86],
 "class_ogre_1_1_scene_node.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,50,86],
-"class_ogre_1_1_scene_node.html#a95cfc691608c8dedd4b9b3b88b3923c3":[5,0,1,50,129],
 "class_ogre_1_1_scene_node.html#a95cfc691608c8dedd4b9b3b88b3923c3":[5,2,12,50,129],
+"class_ogre_1_1_scene_node.html#a95cfc691608c8dedd4b9b3b88b3923c3":[5,0,1,50,129],
 "class_ogre_1_1_scene_node.html#a9917951055045991a3c260dc7a28793e":[5,0,1,50,7],
 "class_ogre_1_1_scene_node.html#a9917951055045991a3c260dc7a28793e":[5,2,12,50,7],
-"class_ogre_1_1_scene_node.html#a9ea731e0b03a84dec688dd05739ca108":[5,2,12,50,117],
 "class_ogre_1_1_scene_node.html#a9ea731e0b03a84dec688dd05739ca108":[5,0,1,50,117],
+"class_ogre_1_1_scene_node.html#a9ea731e0b03a84dec688dd05739ca108":[5,2,12,50,117],
 "class_ogre_1_1_scene_node.html#aa15ab49332eefe8613e09898be31c5ff":[5,2,12,50,44],
 "class_ogre_1_1_scene_node.html#aa15ab49332eefe8613e09898be31c5ff":[5,0,1,50,44],
-"class_ogre_1_1_scene_node.html#aa26ad04301cff9834e9cbec7e4f8cada":[5,0,1,50,75],
 "class_ogre_1_1_scene_node.html#aa26ad04301cff9834e9cbec7e4f8cada":[5,2,12,50,75],
+"class_ogre_1_1_scene_node.html#aa26ad04301cff9834e9cbec7e4f8cada":[5,0,1,50,75],
 "class_ogre_1_1_scene_node.html#aa528fdf12bc4f9ade3f81aa3ada75e78":[5,2,12,50,100],
 "class_ogre_1_1_scene_node.html#aa528fdf12bc4f9ade3f81aa3ada75e78":[5,0,1,50,100],
 "class_ogre_1_1_scene_node.html#aa61f161b03f1a80bc5974b2804171062":[5,2,12,50,26],
 "class_ogre_1_1_scene_node.html#aa61f161b03f1a80bc5974b2804171062":[5,0,1,50,26],
-"class_ogre_1_1_scene_node.html#aa9c0b966080de019c3b68c7f8db9eb4d":[5,2,12,50,36],
 "class_ogre_1_1_scene_node.html#aa9c0b966080de019c3b68c7f8db9eb4d":[5,0,1,50,36],
-"class_ogre_1_1_scene_node.html#ab085e833deecddee7b293fc5e91439f4":[5,0,1,50,56],
+"class_ogre_1_1_scene_node.html#aa9c0b966080de019c3b68c7f8db9eb4d":[5,2,12,50,36],
 "class_ogre_1_1_scene_node.html#ab085e833deecddee7b293fc5e91439f4":[5,2,12,50,56],
+"class_ogre_1_1_scene_node.html#ab085e833deecddee7b293fc5e91439f4":[5,0,1,50,56],
 "class_ogre_1_1_scene_node.html#ab152c8f646a835c2f88585ad4fe0413a":[5,0,1,50,60],
 "class_ogre_1_1_scene_node.html#ab152c8f646a835c2f88585ad4fe0413a":[5,2,12,50,60],
 "class_ogre_1_1_scene_node.html#ab16b6213fc5f3ad8684332147ad1f30f":[5,2,12,50,121],
 "class_ogre_1_1_scene_node.html#ab16b6213fc5f3ad8684332147ad1f30f":[5,0,1,50,121],
-"class_ogre_1_1_scene_node.html#ab2678a117ecc1a85d960c3ee921f5d37":[5,0,1,50,8],
 "class_ogre_1_1_scene_node.html#ab2678a117ecc1a85d960c3ee921f5d37":[5,2,12,50,8],
+"class_ogre_1_1_scene_node.html#ab2678a117ecc1a85d960c3ee921f5d37":[5,0,1,50,8],
 "class_ogre_1_1_scene_node.html#ab2f5e0c7aba434f6636329e25593eb33":[5,2,12,50,48],
 "class_ogre_1_1_scene_node.html#ab2f5e0c7aba434f6636329e25593eb33":[5,0,1,50,48],
 "class_ogre_1_1_scene_node.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,50,89],
 "class_ogre_1_1_scene_node.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,50,89],
-"class_ogre_1_1_scene_node.html#ab57c31b84135b19d0ef12f4a9024e711":[5,2,12,50,19],
 "class_ogre_1_1_scene_node.html#ab57c31b84135b19d0ef12f4a9024e711":[5,0,1,50,19],
+"class_ogre_1_1_scene_node.html#ab57c31b84135b19d0ef12f4a9024e711":[5,2,12,50,19],
 "class_ogre_1_1_scene_node.html#ab907c8d7fd2e5b2934dc57fe845cdbd8":[5,0,1,50,13],
 "class_ogre_1_1_scene_node.html#ab907c8d7fd2e5b2934dc57fe845cdbd8":[5,2,12,50,13],
-"class_ogre_1_1_scene_node.html#abb509726b3e96301eb5fcb3b5977a236":[5,2,12,50,1],
 "class_ogre_1_1_scene_node.html#abb509726b3e96301eb5fcb3b5977a236":[5,0,1,50,1],
-"class_ogre_1_1_scene_node.html#abfe1f0d7aace82d233c326ad31dd097c":[5,0,1,50,105],
+"class_ogre_1_1_scene_node.html#abb509726b3e96301eb5fcb3b5977a236":[5,2,12,50,1],
 "class_ogre_1_1_scene_node.html#abfe1f0d7aace82d233c326ad31dd097c":[5,2,12,50,105],
+"class_ogre_1_1_scene_node.html#abfe1f0d7aace82d233c326ad31dd097c":[5,0,1,50,105],
 "class_ogre_1_1_scene_node.html#ac42e2063379286eb673eaffff6ca5e99":[5,2,12,50,6],
 "class_ogre_1_1_scene_node.html#ac42e2063379286eb673eaffff6ca5e99":[5,0,1,50,6],
 "class_ogre_1_1_scene_node.html#ac42e2063379286eb673eaffff6ca5e99a34e6c3ebabc2e9fa00de4f62be0ce7ce":[5,2,12,50,6,1],
 "class_ogre_1_1_scene_node.html#ac42e2063379286eb673eaffff6ca5e99a34e6c3ebabc2e9fa00de4f62be0ce7ce":[5,0,1,50,6,1],
-"class_ogre_1_1_scene_node.html#ac42e2063379286eb673eaffff6ca5e99ae28ff4f09161c3f5d19c08c5ef210e04":[5,2,12,50,6,2],
 "class_ogre_1_1_scene_node.html#ac42e2063379286eb673eaffff6ca5e99ae28ff4f09161c3f5d19c08c5ef210e04":[5,0,1,50,6,2],
+"class_ogre_1_1_scene_node.html#ac42e2063379286eb673eaffff6ca5e99ae28ff4f09161c3f5d19c08c5ef210e04":[5,2,12,50,6,2],
 "class_ogre_1_1_scene_node.html#ac42e2063379286eb673eaffff6ca5e99afcc5f69a4f8962eec29c8b57c1a675a2":[5,2,12,50,6,0],
 "class_ogre_1_1_scene_node.html#ac42e2063379286eb673eaffff6ca5e99afcc5f69a4f8962eec29c8b57c1a675a2":[5,0,1,50,6,0],
-"class_ogre_1_1_scene_node.html#ac70989f6375d53ee7e91e06ae8341023":[5,0,1,50,41],
 "class_ogre_1_1_scene_node.html#ac70989f6375d53ee7e91e06ae8341023":[5,2,12,50,41],
-"class_ogre_1_1_scene_node.html#ac781fd1e67dee5a278fa08a43e40c402":[5,0,1,50,2],
+"class_ogre_1_1_scene_node.html#ac70989f6375d53ee7e91e06ae8341023":[5,0,1,50,41],
 "class_ogre_1_1_scene_node.html#ac781fd1e67dee5a278fa08a43e40c402":[5,2,12,50,2],
-"class_ogre_1_1_scene_node.html#ac892e2e5a007c0f91112823d73ce5b38":[5,2,12,50,32],
+"class_ogre_1_1_scene_node.html#ac781fd1e67dee5a278fa08a43e40c402":[5,0,1,50,2],
 "class_ogre_1_1_scene_node.html#ac892e2e5a007c0f91112823d73ce5b38":[5,0,1,50,32],
+"class_ogre_1_1_scene_node.html#ac892e2e5a007c0f91112823d73ce5b38":[5,2,12,50,32],
 "class_ogre_1_1_scene_node.html#ac911c22e8ebf889a33a87e67af4e934c":[5,2,12,50,24],
 "class_ogre_1_1_scene_node.html#ac911c22e8ebf889a33a87e67af4e934c":[5,0,1,50,24],
-"class_ogre_1_1_scene_node.html#ac9359ac4b3b032726d28445e77e7588d":[5,2,12,50,68],
 "class_ogre_1_1_scene_node.html#ac9359ac4b3b032726d28445e77e7588d":[5,0,1,50,68],
-"class_ogre_1_1_scene_node.html#ac97975ed6d907bc0674dc9f26b154a8f":[5,0,1,50,126],
+"class_ogre_1_1_scene_node.html#ac9359ac4b3b032726d28445e77e7588d":[5,2,12,50,68],
 "class_ogre_1_1_scene_node.html#ac97975ed6d907bc0674dc9f26b154a8f":[5,2,12,50,126],
-"class_ogre_1_1_scene_node.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,50,84],
+"class_ogre_1_1_scene_node.html#ac97975ed6d907bc0674dc9f26b154a8f":[5,0,1,50,126],
 "class_ogre_1_1_scene_node.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,50,84],
-"class_ogre_1_1_scene_node.html#acc33f0b8cc5bbfed3c12611d89f1dd46":[5,2,12,50,54],
+"class_ogre_1_1_scene_node.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,50,84],
 "class_ogre_1_1_scene_node.html#acc33f0b8cc5bbfed3c12611d89f1dd46":[5,0,1,50,54],
+"class_ogre_1_1_scene_node.html#acc33f0b8cc5bbfed3c12611d89f1dd46":[5,2,12,50,54],
 "class_ogre_1_1_scene_node.html#acdab50f1d9eff37d64d9c25b40ca55f1":[5,0,1,50,14],
 "class_ogre_1_1_scene_node.html#acdab50f1d9eff37d64d9c25b40ca55f1":[5,2,12,50,14],
-"class_ogre_1_1_scene_node.html#acde91d0c99db29ca7fbbf6bec5ed508b":[5,2,12,50,11],
 "class_ogre_1_1_scene_node.html#acde91d0c99db29ca7fbbf6bec5ed508b":[5,0,1,50,11],
-"class_ogre_1_1_scene_node.html#ace65afce742d7a51edd85631470e21b8":[5,2,12,50,65],
+"class_ogre_1_1_scene_node.html#acde91d0c99db29ca7fbbf6bec5ed508b":[5,2,12,50,11],
 "class_ogre_1_1_scene_node.html#ace65afce742d7a51edd85631470e21b8":[5,0,1,50,65],
-"class_ogre_1_1_scene_node.html#acf639f3cc469fec01702cd647c4ba3a6":[5,2,12,50,116],
+"class_ogre_1_1_scene_node.html#ace65afce742d7a51edd85631470e21b8":[5,2,12,50,65],
 "class_ogre_1_1_scene_node.html#acf639f3cc469fec01702cd647c4ba3a6":[5,0,1,50,116],
-"class_ogre_1_1_scene_node.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,50,88],
+"class_ogre_1_1_scene_node.html#acf639f3cc469fec01702cd647c4ba3a6":[5,2,12,50,116],
 "class_ogre_1_1_scene_node.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,50,88],
-"class_ogre_1_1_scene_node.html#ad2933401db8b45ddc8e22ed93fad06fb":[5,0,1,50,62],
+"class_ogre_1_1_scene_node.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,50,88],
 "class_ogre_1_1_scene_node.html#ad2933401db8b45ddc8e22ed93fad06fb":[5,2,12,50,62],
+"class_ogre_1_1_scene_node.html#ad2933401db8b45ddc8e22ed93fad06fb":[5,0,1,50,62],
 "class_ogre_1_1_scene_node.html#ada5432efc903b990958e5befc260591c":[5,2,12,50,115],
 "class_ogre_1_1_scene_node.html#ada5432efc903b990958e5befc260591c":[5,0,1,50,115],
-"class_ogre_1_1_scene_node.html#ada725e7b64b51803eaedbe28d7c8195e":[5,2,12,50,123],
 "class_ogre_1_1_scene_node.html#ada725e7b64b51803eaedbe28d7c8195e":[5,0,1,50,123],
+"class_ogre_1_1_scene_node.html#ada725e7b64b51803eaedbe28d7c8195e":[5,2,12,50,123],
 "class_ogre_1_1_scene_node.html#adc228e347a86ee09e4a57e8809d73ff5":[5,2,12,50,66],
 "class_ogre_1_1_scene_node.html#adc228e347a86ee09e4a57e8809d73ff5":[5,0,1,50,66],
-"class_ogre_1_1_scene_node.html#adcde26f4821e24a7eebef127251a4bea":[5,0,1,50,107],
 "class_ogre_1_1_scene_node.html#adcde26f4821e24a7eebef127251a4bea":[5,2,12,50,107],
-"class_ogre_1_1_scene_node.html#adce32528577d71b228692df906ecd17c":[5,2,12,50,91],
+"class_ogre_1_1_scene_node.html#adcde26f4821e24a7eebef127251a4bea":[5,0,1,50,107],
 "class_ogre_1_1_scene_node.html#adce32528577d71b228692df906ecd17c":[5,0,1,50,91],
-"class_ogre_1_1_scene_node.html#ade4a8283f41882f4b6c70acbe9f27c61":[5,0,1,50,95],
+"class_ogre_1_1_scene_node.html#adce32528577d71b228692df906ecd17c":[5,2,12,50,91],
 "class_ogre_1_1_scene_node.html#ade4a8283f41882f4b6c70acbe9f27c61":[5,2,12,50,95],
-"class_ogre_1_1_scene_node.html#ae17b2a4b91e5213ca68c106a3b6f79a4":[5,2,12,50,101],
+"class_ogre_1_1_scene_node.html#ade4a8283f41882f4b6c70acbe9f27c61":[5,0,1,50,95],
 "class_ogre_1_1_scene_node.html#ae17b2a4b91e5213ca68c106a3b6f79a4":[5,0,1,50,101],
-"class_ogre_1_1_scene_node.html#ae4bfe1d06442abf69042794c75d783fe":[5,0,1,50,114],
+"class_ogre_1_1_scene_node.html#ae17b2a4b91e5213ca68c106a3b6f79a4":[5,2,12,50,101],
 "class_ogre_1_1_scene_node.html#ae4bfe1d06442abf69042794c75d783fe":[5,2,12,50,114],
+"class_ogre_1_1_scene_node.html#ae4bfe1d06442abf69042794c75d783fe":[5,0,1,50,114],
 "class_ogre_1_1_scene_node.html#ae6be474c020097e3df003ba34349a14c":[5,0,1,50,50],
 "class_ogre_1_1_scene_node.html#ae6be474c020097e3df003ba34349a14c":[5,2,12,50,50],
-"class_ogre_1_1_scene_node.html#ae7b72c066884d0021bd2b2a6693a66c3":[5,2,12,50,109],
 "class_ogre_1_1_scene_node.html#ae7b72c066884d0021bd2b2a6693a66c3":[5,0,1,50,109],
+"class_ogre_1_1_scene_node.html#ae7b72c066884d0021bd2b2a6693a66c3":[5,2,12,50,109],
 "class_ogre_1_1_scene_node.html#ae94503cc4e0d2b33cd6ddbcc258c1b1e":[5,0,1,50,49],
 "class_ogre_1_1_scene_node.html#ae94503cc4e0d2b33cd6ddbcc258c1b1e":[5,2,12,50,49],
-"class_ogre_1_1_scene_node.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,50,92],
 "class_ogre_1_1_scene_node.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,50,92],
+"class_ogre_1_1_scene_node.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,50,92],
 "class_ogre_1_1_scene_node.html#aee1aa2ae574bc62969377f322dd59b2a":[5,0,1,50,10],
 "class_ogre_1_1_scene_node.html#aee1aa2ae574bc62969377f322dd59b2a":[5,2,12,50,10],
 "class_ogre_1_1_scene_node.html#aeff8334b9da08af47e6bddd0f5042b31":[5,2,12,50,55],
 "class_ogre_1_1_scene_node.html#aeff8334b9da08af47e6bddd0f5042b31":[5,0,1,50,55],
 "class_ogre_1_1_scene_node.html#af01698919040092766a3a4bfab8e7ceb":[5,0,1,50,29],
 "class_ogre_1_1_scene_node.html#af01698919040092766a3a4bfab8e7ceb":[5,2,12,50,29],
-"class_ogre_1_1_scene_node.html#af098e0fdbfba92cb06f6431d33d0b4a6":[5,2,12,50,27],
 "class_ogre_1_1_scene_node.html#af098e0fdbfba92cb06f6431d33d0b4a6":[5,0,1,50,27],
-"class_ogre_1_1_scene_node.html#af0a994b31f757ba9d3059a133712ffe7":[5,2,12,50,112],
+"class_ogre_1_1_scene_node.html#af098e0fdbfba92cb06f6431d33d0b4a6":[5,2,12,50,27],
 "class_ogre_1_1_scene_node.html#af0a994b31f757ba9d3059a133712ffe7":[5,0,1,50,112],
-"class_ogre_1_1_scene_node.html#af133224a62eb73055298c3e2a889f6f5":[5,0,1,50,131],
+"class_ogre_1_1_scene_node.html#af0a994b31f757ba9d3059a133712ffe7":[5,2,12,50,112],
 "class_ogre_1_1_scene_node.html#af133224a62eb73055298c3e2a889f6f5":[5,2,12,50,131],
+"class_ogre_1_1_scene_node.html#af133224a62eb73055298c3e2a889f6f5":[5,0,1,50,131],
 "class_ogre_1_1_scene_node.html#af62a3dc794cf46ef1c023353e1eccbfc":[5,2,12,50,119],
 "class_ogre_1_1_scene_node.html#af62a3dc794cf46ef1c023353e1eccbfc":[5,0,1,50,119],
-"class_ogre_1_1_scene_node.html#af73c4989864f0066125b37bb7a93731f":[5,0,1,50,38],
 "class_ogre_1_1_scene_node.html#af73c4989864f0066125b37bb7a93731f":[5,2,12,50,38],
+"class_ogre_1_1_scene_node.html#af73c4989864f0066125b37bb7a93731f":[5,0,1,50,38],
 "class_ogre_1_1_scene_node.html#af75a04b0835a4db48ef4ff59c4659149":[5,0,1,50,16],
 "class_ogre_1_1_scene_node.html#af75a04b0835a4db48ef4ff59c4659149":[5,2,12,50,16],
 "class_ogre_1_1_scene_node.html#afa0a0288b4e3cd278984c1d3c05d8f3e":[5,2,12,50,130],
 "class_ogre_1_1_scene_node.html#afa0a0288b4e3cd278984c1d3c05d8f3e":[5,0,1,50,130],
-"class_ogre_1_1_scene_node.html#afc15c981be15167edc61d7d4453a089d":[5,0,1,50,30],
 "class_ogre_1_1_scene_node.html#afc15c981be15167edc61d7d4453a089d":[5,2,12,50,30],
+"class_ogre_1_1_scene_node.html#afc15c981be15167edc61d7d4453a089d":[5,0,1,50,30],
 "class_ogre_1_1_scene_node.html#afc5c13c4251135f4d03ef75dbb03afe5":[5,2,12,50,110],
 "class_ogre_1_1_scene_node.html#afc5c13c4251135f4d03ef75dbb03afe5":[5,0,1,50,110],
 "class_ogre_1_1_scene_node.html#afca3fed33def0a61c677f3f1599859b0":[5,2,12,50,22],
 "class_ogre_1_1_scene_node.html#afca3fed33def0a61c677f3f1599859b0":[5,0,1,50,22],
-"class_ogre_1_1_scene_node.html#aff0bc6109e8e806dca7ee74dce2a1e2d":[5,0,1,50,82],
 "class_ogre_1_1_scene_node.html#aff0bc6109e8e806dca7ee74dce2a1e2d":[5,2,12,50,82],
-"class_ogre_1_1_scene_node.html#afff436985eb13a3dba940f4a86e1e602":[5,0,1,50,113],
+"class_ogre_1_1_scene_node.html#aff0bc6109e8e806dca7ee74dce2a1e2d":[5,0,1,50,82],
 "class_ogre_1_1_scene_node.html#afff436985eb13a3dba940f4a86e1e602":[5,2,12,50,113],
-"class_ogre_1_1_scene_query.html":[5,0,1,51],
+"class_ogre_1_1_scene_node.html#afff436985eb13a3dba940f4a86e1e602":[5,0,1,50,113],
 "class_ogre_1_1_scene_query.html":[5,2,12,51],
-"class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,0,1,51,1],
+"class_ogre_1_1_scene_query.html":[5,0,1,51],
 "class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,2,12,51,1],
-"class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,51,1,2],
+"class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,0,1,51,1],
 "class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,0,1,51,1,2],
-"class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,0,1,51,1,1],
+"class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,51,1,2],
 "class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,2,12,51,1,1],
+"class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,0,1,51,1,1],
 "class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,0,1,51,1,0],
 "class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,2,12,51,1,0],
-"class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,0,1,51,1,4],
 "class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,2,12,51,1,4],
+"class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,0,1,51,1,4],
 "class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,0,1,51,1,3],
 "class_ogre_1_1_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,2,12,51,1,3],
-"class_ogre_1_1_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,51,9],
 "class_ogre_1_1_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,51,9],
+"class_ogre_1_1_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,51,9],
 "class_ogre_1_1_scene_query.html#a373ec5891d755ecaac409e2de1e5e54e":[5,2,12,51,3],
 "class_ogre_1_1_scene_query.html#a373ec5891d755ecaac409e2de1e5e54e":[5,0,1,51,3],
-"class_ogre_1_1_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,2,12,51,20],
 "class_ogre_1_1_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,0,1,51,20],
+"class_ogre_1_1_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,2,12,51,20],
 "class_ogre_1_1_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,51,11],
 "class_ogre_1_1_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,51,11],
-"class_ogre_1_1_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,51,14],
 "class_ogre_1_1_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,51,14],
+"class_ogre_1_1_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,51,14],
 "class_ogre_1_1_scene_query.html#a672e5a9a95f02100b62cd4a6421525d6":[5,0,1,51,2],
 "class_ogre_1_1_scene_query.html#a672e5a9a95f02100b62cd4a6421525d6":[5,2,12,51,2],
 "class_ogre_1_1_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,2,12,51,5],
@@ -189,10 +191,10 @@ var NAVTREEINDEX214 =
 "class_ogre_1_1_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,51,7],
 "class_ogre_1_1_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,51,10],
 "class_ogre_1_1_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,51,10],
-"class_ogre_1_1_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,51,13],
 "class_ogre_1_1_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,51,13],
-"class_ogre_1_1_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,51,8],
+"class_ogre_1_1_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,51,13],
 "class_ogre_1_1_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,51,8],
+"class_ogre_1_1_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,51,8],
 "class_ogre_1_1_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,0,1,51,6],
 "class_ogre_1_1_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,2,12,51,6],
 "class_ogre_1_1_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,51,12],
@@ -203,51 +205,49 @@ var NAVTREEINDEX214 =
 "class_ogre_1_1_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,51,15],
 "class_ogre_1_1_scene_query.html#adfd70f00b13654735336f4360af84995":[5,0,1,51,19],
 "class_ogre_1_1_scene_query.html#adfd70f00b13654735336f4360af84995":[5,2,12,51,19],
-"class_ogre_1_1_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,1,51,18],
 "class_ogre_1_1_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,2,12,51,18],
-"class_ogre_1_1_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,51,16],
+"class_ogre_1_1_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,1,51,18],
 "class_ogre_1_1_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,51,16],
+"class_ogre_1_1_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,51,16],
 "class_ogre_1_1_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,12,51,4],
 "class_ogre_1_1_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,0,1,51,4],
-"class_ogre_1_1_scene_query_listener.html":[5,2,12,52],
 "class_ogre_1_1_scene_query_listener.html":[5,0,1,52],
+"class_ogre_1_1_scene_query_listener.html":[5,2,12,52],
 "class_ogre_1_1_scene_query_listener.html#a70936d2cd7413dd284faef05528ddb92":[5,0,1,52,1],
 "class_ogre_1_1_scene_query_listener.html#a70936d2cd7413dd284faef05528ddb92":[5,2,12,52,1],
-"class_ogre_1_1_scene_query_listener.html#ac17a072217f44693bb45ecbcd1623611":[5,0,1,52,2],
 "class_ogre_1_1_scene_query_listener.html#ac17a072217f44693bb45ecbcd1623611":[5,2,12,52,2],
+"class_ogre_1_1_scene_query_listener.html#ac17a072217f44693bb45ecbcd1623611":[5,0,1,52,2],
 "class_ogre_1_1_scene_query_listener.html#ad0ea5280ec1032a5170999eb7ae3fb2b":[5,2,12,52,0],
 "class_ogre_1_1_scene_query_listener.html#ad0ea5280ec1032a5170999eb7ae3fb2b":[5,0,1,52,0],
 "class_ogre_1_1_scoped_lock.html":[7,0,0,864],
 "class_ogre_1_1_scoped_lock.html":[6,0,0,891],
-"class_ogre_1_1_scoped_lock.html#a7fe0c08bd1bc6afbca5fa28cd6dfbf15":[6,0,0,891,0],
 "class_ogre_1_1_scoped_lock.html#a7fe0c08bd1bc6afbca5fa28cd6dfbf15":[7,0,0,864,0],
-"class_ogre_1_1_scoped_lock.html#ab88bcddc017034e6da204a72c3385034":[6,0,0,891,1],
+"class_ogre_1_1_scoped_lock.html#a7fe0c08bd1bc6afbca5fa28cd6dfbf15":[6,0,0,891,0],
 "class_ogre_1_1_scoped_lock.html#ab88bcddc017034e6da204a72c3385034":[7,0,0,864,1],
+"class_ogre_1_1_scoped_lock.html#ab88bcddc017034e6da204a72c3385034":[6,0,0,891,1],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html":[7,0,0,865],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html":[6,0,0,892],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[7,0,0,865,1],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[6,0,0,892,1],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a0834dd85d740a9f6783e10a70dfccc1b":[7,0,0,865,1],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,892,11],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,865,11],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a23ece09087d2a35c762e436fdec227c5":[6,0,0,892,8],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a23ece09087d2a35c762e436fdec227c5":[7,0,0,865,8],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a2400dc929b5f7727f0d69336b3b1e05d":[6,0,0,892,7],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a2400dc929b5f7727f0d69336b3b1e05d":[7,0,0,865,7],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a280ee76e313e85dbd47d46fcf38ce1fd":[7,0,0,865,20],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a2400dc929b5f7727f0d69336b3b1e05d":[6,0,0,892,7],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a280ee76e313e85dbd47d46fcf38ce1fd":[6,0,0,892,20],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a46a920a23f3f459a84fa675d7df0f906":[6,0,0,892,3],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a280ee76e313e85dbd47d46fcf38ce1fd":[7,0,0,865,20],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a46a920a23f3f459a84fa675d7df0f906":[7,0,0,865,3],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[7,0,0,865,19],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a46a920a23f3f459a84fa675d7df0f906":[6,0,0,892,3],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[6,0,0,892,19],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,865,13],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a4c359b8fd0935b31bfc3a0eb61bd61e8":[7,0,0,865,19],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,892,13],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,892,16],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,865,13],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,865,16],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a67c3bc6755c75d797e0478b3f226eb33":[7,0,0,865,6],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,892,16],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a67c3bc6755c75d797e0478b3f226eb33":[6,0,0,892,6],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a67c3bc6755c75d797e0478b3f226eb33":[7,0,0,865,6],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a73d681b5f30d71ace485b8290eacd660":[6,0,0,892,0],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a73d681b5f30d71ace485b8290eacd660":[7,0,0,865,0],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a75779c55ad34f69cd8c86de504a01e52":[6,0,0,892,4],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a75779c55ad34f69cd8c86de504a01e52":[7,0,0,865,4],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,865,9]
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a75779c55ad34f69cd8c86de504a01e52":[6,0,0,892,4]
 };
