@@ -1,20 +1,22 @@
 var NAVTREEINDEX215 =
 {
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a75779c55ad34f69cd8c86de504a01e52":[7,0,0,865,4],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,892,9],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,865,12],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,865,9],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,892,12],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,865,15],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,865,12],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,892,15],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,865,15],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,892,10],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,865,10],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,892,14],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,865,14],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adce32528577d71b228692df906ecd17c":[7,0,0,865,17],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adce32528577d71b228692df906ecd17c":[6,0,0,892,17],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adce32528577d71b228692df906ecd17c":[7,0,0,865,17],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[7,0,0,865,5],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#adeb7d40e283838e2f04139fc183c95d0":[6,0,0,892,5],
-"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,865,18],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,892,18],
+"class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,865,18],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#afcbca1aed7b649a98adc3393ce177fc7":[7,0,0,865,2],
 "class_ogre_1_1_screen_ratio_pixel_count_lod_strategy.html#afcbca1aed7b649a98adc3393ce177fc7":[6,0,0,892,2],
 "class_ogre_1_1_script_compiler.html":[5,2,2,99],
@@ -187,28 +189,28 @@ var NAVTREEINDEX215 =
 "class_ogre_1_1_shader_params.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,0,24,14],
 "class_ogre_1_1_shader_params.html#adce32528577d71b228692df906ecd17c":[5,0,0,24,17],
 "class_ogre_1_1_shader_params.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,0,24,18],
-"class_ogre_1_1_shadow_camera_setup.html":[5,0,1,54],
 "class_ogre_1_1_shadow_camera_setup.html":[5,2,12,54],
-"class_ogre_1_1_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,54,7],
+"class_ogre_1_1_shadow_camera_setup.html":[5,0,1,54],
 "class_ogre_1_1_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,54,7],
+"class_ogre_1_1_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,54,7],
 "class_ogre_1_1_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,54,9],
 "class_ogre_1_1_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,54,9],
-"class_ogre_1_1_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,2,12,54,2],
 "class_ogre_1_1_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,0,1,54,2],
-"class_ogre_1_1_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,54,12],
+"class_ogre_1_1_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,2,12,54,2],
 "class_ogre_1_1_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,54,12],
-"class_ogre_1_1_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,0,1,54,15],
+"class_ogre_1_1_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,54,12],
 "class_ogre_1_1_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,2,12,54,15],
-"class_ogre_1_1_shadow_camera_setup.html#a790a06721a8e3c6f48218aa659c334ef":[5,0,1,54,1],
+"class_ogre_1_1_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,0,1,54,15],
 "class_ogre_1_1_shadow_camera_setup.html#a790a06721a8e3c6f48218aa659c334ef":[5,2,12,54,1],
+"class_ogre_1_1_shadow_camera_setup.html#a790a06721a8e3c6f48218aa659c334ef":[5,0,1,54,1],
 "class_ogre_1_1_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,54,5],
 "class_ogre_1_1_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,54,5],
 "class_ogre_1_1_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,54,8],
 "class_ogre_1_1_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,54,8],
 "class_ogre_1_1_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,54,11],
 "class_ogre_1_1_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,54,11],
-"class_ogre_1_1_shadow_camera_setup.html#ab6e8a9669102634c5a9a1273133f8240":[5,0,1,54,4],
 "class_ogre_1_1_shadow_camera_setup.html#ab6e8a9669102634c5a9a1273133f8240":[5,2,12,54,4],
+"class_ogre_1_1_shadow_camera_setup.html#ab6e8a9669102634c5a9a1273133f8240":[5,0,1,54,4],
 "class_ogre_1_1_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,54,6],
 "class_ogre_1_1_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,54,6],
 "class_ogre_1_1_shadow_camera_setup.html#acdd9ee220860b6c914feb28de74e3304":[5,2,12,54,0],
@@ -217,8 +219,8 @@ var NAVTREEINDEX215 =
 "class_ogre_1_1_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,54,10],
 "class_ogre_1_1_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,2,12,54,3],
 "class_ogre_1_1_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,0,1,54,3],
-"class_ogre_1_1_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,0,1,54,13],
 "class_ogre_1_1_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,2,12,54,13],
+"class_ogre_1_1_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,0,1,54,13],
 "class_ogre_1_1_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,54,14],
 "class_ogre_1_1_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,54,14],
 "class_ogre_1_1_shadow_node_helper.html":[5,2,1,50],
@@ -247,7 +249,5 @@ var NAVTREEINDEX215 =
 "class_ogre_1_1_shadow_texture_definition.html#aa3dc808f23fdd0c33b1fcf1f02bc5783":[5,2,1,51,1],
 "class_ogre_1_1_shadow_texture_definition.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,1,51,11],
 "class_ogre_1_1_shadow_texture_definition.html#abbe758473936c89544c7c181e087eb6c":[5,2,1,51,18],
-"class_ogre_1_1_shadow_texture_definition.html#ac05b4994513eb9bad227e3e14baa5573":[5,2,1,51,2],
-"class_ogre_1_1_shadow_texture_definition.html#ac5fa1aa9cea5f1ef578cbd4b16196e42":[5,2,1,51,19],
-"class_ogre_1_1_shadow_texture_definition.html#ac6402ed16c96fb2a1f609210149367b5":[5,2,1,51,25]
+"class_ogre_1_1_shadow_texture_definition.html#ac05b4994513eb9bad227e3e14baa5573":[5,2,1,51,2]
 };
