@@ -1,26 +1,28 @@
 var NAVTREEINDEX220 =
 {
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#a9e765b3edf8b9303d380e6abb5fdaa7b":[6,0,0,936,15],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#aa5c7ed10e04b28acc1fecd075879a3e3":[6,0,0,936,28],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#aabbc326f17698c1b404fcfed47099f19":[7,0,0,909,23],
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#aa5c7ed10e04b28acc1fecd075879a3e3":[7,0,0,909,28],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#aabbc326f17698c1b404fcfed47099f19":[6,0,0,936,23],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ab3bb5e3be2e6a4f8b68b61c1c16028e4":[7,0,0,909,27],
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#aabbc326f17698c1b404fcfed47099f19":[7,0,0,909,23],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ab3bb5e3be2e6a4f8b68b61c1c16028e4":[6,0,0,936,27],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ab4fb906b0b1c29080f7e14222a7a2677":[7,0,0,909,1],
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ab3bb5e3be2e6a4f8b68b61c1c16028e4":[7,0,0,909,27],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ab4fb906b0b1c29080f7e14222a7a2677":[6,0,0,936,1],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#acd7dfa3b3e065207cd1d9923c0d81745":[7,0,0,909,7],
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ab4fb906b0b1c29080f7e14222a7a2677":[7,0,0,909,1],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#acd7dfa3b3e065207cd1d9923c0d81745":[6,0,0,936,7],
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#acd7dfa3b3e065207cd1d9923c0d81745":[7,0,0,909,7],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ad1c6b259854f9fa396fa1eee2e10b2b6":[6,0,0,936,0],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ad1c6b259854f9fa396fa1eee2e10b2b6":[7,0,0,909,0],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ad3aa63daaa8c3754f1e8be544cb617ae":[7,0,0,909,5],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ad3aa63daaa8c3754f1e8be544cb617ae":[6,0,0,936,5],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ad476fe9d6fa0faecffb16338b6a972e5":[6,0,0,936,20],
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ad3aa63daaa8c3754f1e8be544cb617ae":[7,0,0,909,5],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ad476fe9d6fa0faecffb16338b6a972e5":[7,0,0,909,20],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#add1c1041f5e7ca89feccdf57e746558b":[7,0,0,909,21],
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ad476fe9d6fa0faecffb16338b6a972e5":[6,0,0,936,20],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#add1c1041f5e7ca89feccdf57e746558b":[6,0,0,936,21],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ade708dba3d6aa380726d9e10dfd6aac7":[7,0,0,909,12],
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#add1c1041f5e7ca89feccdf57e746558b":[7,0,0,909,21],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ade708dba3d6aa380726d9e10dfd6aac7":[6,0,0,936,12],
-"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#adf2eb6c75c5a21936b9d658de1a3e132":[6,0,0,936,29],
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ade708dba3d6aa380726d9e10dfd6aac7":[7,0,0,909,12],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#adf2eb6c75c5a21936b9d658de1a3e132":[7,0,0,909,29],
+"class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#adf2eb6c75c5a21936b9d658de1a3e132":[6,0,0,936,29],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ae40a8630bf739e9fadd1162ea95bb412":[7,0,0,909,33],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#ae40a8630bf739e9fadd1162ea95bb412":[6,0,0,936,33],
 "class_ogre_1_1_small_vector_template_base_3_01_t_00_01true_01_4.html#af5c75e8908b1e44ae53d8c12d784ed96":[6,0,0,936,8],
@@ -33,68 +35,68 @@ var NAVTREEINDEX220 =
 "class_ogre_1_1_small_vector_template_common.html":[7,0,0,910],
 "class_ogre_1_1_small_vector_template_common.html#a031182e52c76c98b41e3e6e7bc084a7e":[7,0,0,910,18],
 "class_ogre_1_1_small_vector_template_common.html#a031182e52c76c98b41e3e6e7bc084a7e":[6,0,0,937,18],
-"class_ogre_1_1_small_vector_template_common.html#a2914029c53db3683e055e071cafa00c4":[6,0,0,937,11],
 "class_ogre_1_1_small_vector_template_common.html#a2914029c53db3683e055e071cafa00c4":[7,0,0,910,11],
+"class_ogre_1_1_small_vector_template_common.html#a2914029c53db3683e055e071cafa00c4":[6,0,0,937,11],
 "class_ogre_1_1_small_vector_template_common.html#a29f4c0677b9a04a1f137adc07be5be3a":[7,0,0,910,17],
 "class_ogre_1_1_small_vector_template_common.html#a29f4c0677b9a04a1f137adc07be5be3a":[6,0,0,937,17],
-"class_ogre_1_1_small_vector_template_common.html#a30c1c165d5ea9aa46fb67bec11548ade":[6,0,0,937,6],
 "class_ogre_1_1_small_vector_template_common.html#a30c1c165d5ea9aa46fb67bec11548ade":[7,0,0,910,6],
-"class_ogre_1_1_small_vector_template_common.html#a3e4105820c0f20b850e06ce43eadb92f":[6,0,0,937,29],
+"class_ogre_1_1_small_vector_template_common.html#a30c1c165d5ea9aa46fb67bec11548ade":[6,0,0,937,6],
 "class_ogre_1_1_small_vector_template_common.html#a3e4105820c0f20b850e06ce43eadb92f":[7,0,0,910,29],
-"class_ogre_1_1_small_vector_template_common.html#a3f415ae6de28aa261e1d160d7577a3f7":[6,0,0,937,3],
+"class_ogre_1_1_small_vector_template_common.html#a3e4105820c0f20b850e06ce43eadb92f":[6,0,0,937,29],
 "class_ogre_1_1_small_vector_template_common.html#a3f415ae6de28aa261e1d160d7577a3f7":[7,0,0,910,3],
+"class_ogre_1_1_small_vector_template_common.html#a3f415ae6de28aa261e1d160d7577a3f7":[6,0,0,937,3],
 "class_ogre_1_1_small_vector_template_common.html#a44c80d4f7bcd71b7cc02038fd13356de":[6,0,0,937,28],
 "class_ogre_1_1_small_vector_template_common.html#a44c80d4f7bcd71b7cc02038fd13356de":[7,0,0,910,28],
-"class_ogre_1_1_small_vector_template_common.html#a4b86aea9ff25e7749483c2431e02db41":[7,0,0,910,10],
 "class_ogre_1_1_small_vector_template_common.html#a4b86aea9ff25e7749483c2431e02db41":[6,0,0,937,10],
-"class_ogre_1_1_small_vector_template_common.html#a60eb6558693ab2020fba03c8ea5038c5":[7,0,0,910,4],
+"class_ogre_1_1_small_vector_template_common.html#a4b86aea9ff25e7749483c2431e02db41":[7,0,0,910,10],
 "class_ogre_1_1_small_vector_template_common.html#a60eb6558693ab2020fba03c8ea5038c5":[6,0,0,937,4],
+"class_ogre_1_1_small_vector_template_common.html#a60eb6558693ab2020fba03c8ea5038c5":[7,0,0,910,4],
 "class_ogre_1_1_small_vector_template_common.html#a6f3019eb35333a8ca4e10f14923298d4":[6,0,0,937,14],
 "class_ogre_1_1_small_vector_template_common.html#a6f3019eb35333a8ca4e10f14923298d4":[7,0,0,910,14],
-"class_ogre_1_1_small_vector_template_common.html#a726e02e5ed3fb393ddab4970b92e3906":[6,0,0,937,30],
 "class_ogre_1_1_small_vector_template_common.html#a726e02e5ed3fb393ddab4970b92e3906":[7,0,0,910,30],
+"class_ogre_1_1_small_vector_template_common.html#a726e02e5ed3fb393ddab4970b92e3906":[6,0,0,937,30],
 "class_ogre_1_1_small_vector_template_common.html#a7f6c13429c1adbcbcddbf33a5a8b3fe8":[6,0,0,937,23],
 "class_ogre_1_1_small_vector_template_common.html#a7f6c13429c1adbcbcddbf33a5a8b3fe8":[7,0,0,910,23],
-"class_ogre_1_1_small_vector_template_common.html#a87ee5ad0c88dbd163e58835d7990ef32":[6,0,0,937,21],
 "class_ogre_1_1_small_vector_template_common.html#a87ee5ad0c88dbd163e58835d7990ef32":[7,0,0,910,21],
-"class_ogre_1_1_small_vector_template_common.html#a8985bda74ea85da34c90a7356586e0c4":[7,0,0,910,9],
+"class_ogre_1_1_small_vector_template_common.html#a87ee5ad0c88dbd163e58835d7990ef32":[6,0,0,937,21],
 "class_ogre_1_1_small_vector_template_common.html#a8985bda74ea85da34c90a7356586e0c4":[6,0,0,937,9],
+"class_ogre_1_1_small_vector_template_common.html#a8985bda74ea85da34c90a7356586e0c4":[7,0,0,910,9],
 "class_ogre_1_1_small_vector_template_common.html#a8fd84d4c57b70b9b8111efa7d81c7d5b":[6,0,0,937,13],
 "class_ogre_1_1_small_vector_template_common.html#a8fd84d4c57b70b9b8111efa7d81c7d5b":[7,0,0,910,13],
 "class_ogre_1_1_small_vector_template_common.html#a922c12bc5de4cf0fee5c101919fecc94":[6,0,0,937,16],
 "class_ogre_1_1_small_vector_template_common.html#a922c12bc5de4cf0fee5c101919fecc94":[7,0,0,910,16],
-"class_ogre_1_1_small_vector_template_common.html#a9815c7884278cf8ae793f559d5da6d5f":[7,0,0,910,24],
 "class_ogre_1_1_small_vector_template_common.html#a9815c7884278cf8ae793f559d5da6d5f":[6,0,0,937,24],
+"class_ogre_1_1_small_vector_template_common.html#a9815c7884278cf8ae793f559d5da6d5f":[7,0,0,910,24],
 "class_ogre_1_1_small_vector_template_common.html#a9e765b3edf8b9303d380e6abb5fdaa7b":[6,0,0,937,15],
 "class_ogre_1_1_small_vector_template_common.html#a9e765b3edf8b9303d380e6abb5fdaa7b":[7,0,0,910,15],
-"class_ogre_1_1_small_vector_template_common.html#aa5c7ed10e04b28acc1fecd075879a3e3":[6,0,0,937,26],
 "class_ogre_1_1_small_vector_template_common.html#aa5c7ed10e04b28acc1fecd075879a3e3":[7,0,0,910,26],
+"class_ogre_1_1_small_vector_template_common.html#aa5c7ed10e04b28acc1fecd075879a3e3":[6,0,0,937,26],
 "class_ogre_1_1_small_vector_template_common.html#aabbc326f17698c1b404fcfed47099f19":[6,0,0,937,22],
 "class_ogre_1_1_small_vector_template_common.html#aabbc326f17698c1b404fcfed47099f19":[7,0,0,910,22],
-"class_ogre_1_1_small_vector_template_common.html#ab3bb5e3be2e6a4f8b68b61c1c16028e4":[7,0,0,910,25],
 "class_ogre_1_1_small_vector_template_common.html#ab3bb5e3be2e6a4f8b68b61c1c16028e4":[6,0,0,937,25],
+"class_ogre_1_1_small_vector_template_common.html#ab3bb5e3be2e6a4f8b68b61c1c16028e4":[7,0,0,910,25],
 "class_ogre_1_1_small_vector_template_common.html#ab4fb906b0b1c29080f7e14222a7a2677":[6,0,0,937,1],
 "class_ogre_1_1_small_vector_template_common.html#ab4fb906b0b1c29080f7e14222a7a2677":[7,0,0,910,1],
-"class_ogre_1_1_small_vector_template_common.html#acd7dfa3b3e065207cd1d9923c0d81745":[7,0,0,910,7],
 "class_ogre_1_1_small_vector_template_common.html#acd7dfa3b3e065207cd1d9923c0d81745":[6,0,0,937,7],
-"class_ogre_1_1_small_vector_template_common.html#ad1c6b259854f9fa396fa1eee2e10b2b6":[7,0,0,910,0],
+"class_ogre_1_1_small_vector_template_common.html#acd7dfa3b3e065207cd1d9923c0d81745":[7,0,0,910,7],
 "class_ogre_1_1_small_vector_template_common.html#ad1c6b259854f9fa396fa1eee2e10b2b6":[6,0,0,937,0],
+"class_ogre_1_1_small_vector_template_common.html#ad1c6b259854f9fa396fa1eee2e10b2b6":[7,0,0,910,0],
 "class_ogre_1_1_small_vector_template_common.html#ad3aa63daaa8c3754f1e8be544cb617ae":[7,0,0,910,5],
 "class_ogre_1_1_small_vector_template_common.html#ad3aa63daaa8c3754f1e8be544cb617ae":[6,0,0,937,5],
-"class_ogre_1_1_small_vector_template_common.html#ad476fe9d6fa0faecffb16338b6a972e5":[7,0,0,910,19],
 "class_ogre_1_1_small_vector_template_common.html#ad476fe9d6fa0faecffb16338b6a972e5":[6,0,0,937,19],
+"class_ogre_1_1_small_vector_template_common.html#ad476fe9d6fa0faecffb16338b6a972e5":[7,0,0,910,19],
 "class_ogre_1_1_small_vector_template_common.html#add1c1041f5e7ca89feccdf57e746558b":[7,0,0,910,20],
 "class_ogre_1_1_small_vector_template_common.html#add1c1041f5e7ca89feccdf57e746558b":[6,0,0,937,20],
-"class_ogre_1_1_small_vector_template_common.html#ade708dba3d6aa380726d9e10dfd6aac7":[7,0,0,910,12],
 "class_ogre_1_1_small_vector_template_common.html#ade708dba3d6aa380726d9e10dfd6aac7":[6,0,0,937,12],
-"class_ogre_1_1_small_vector_template_common.html#adf2eb6c75c5a21936b9d658de1a3e132":[6,0,0,937,27],
+"class_ogre_1_1_small_vector_template_common.html#ade708dba3d6aa380726d9e10dfd6aac7":[7,0,0,910,12],
 "class_ogre_1_1_small_vector_template_common.html#adf2eb6c75c5a21936b9d658de1a3e132":[7,0,0,910,27],
-"class_ogre_1_1_small_vector_template_common.html#ae40a8630bf739e9fadd1162ea95bb412":[6,0,0,937,31],
+"class_ogre_1_1_small_vector_template_common.html#adf2eb6c75c5a21936b9d658de1a3e132":[6,0,0,937,27],
 "class_ogre_1_1_small_vector_template_common.html#ae40a8630bf739e9fadd1162ea95bb412":[7,0,0,910,31],
+"class_ogre_1_1_small_vector_template_common.html#ae40a8630bf739e9fadd1162ea95bb412":[6,0,0,937,31],
 "class_ogre_1_1_small_vector_template_common.html#af5c75e8908b1e44ae53d8c12d784ed96":[6,0,0,937,8],
 "class_ogre_1_1_small_vector_template_common.html#af5c75e8908b1e44ae53d8c12d784ed96":[7,0,0,910,8],
-"class_ogre_1_1_small_vector_template_common.html#af6adada5ede6dc97e6be23bc96b286da":[6,0,0,937,2],
 "class_ogre_1_1_small_vector_template_common.html#af6adada5ede6dc97e6be23bc96b286da":[7,0,0,910,2],
+"class_ogre_1_1_small_vector_template_common.html#af6adada5ede6dc97e6be23bc96b286da":[6,0,0,937,2],
 "class_ogre_1_1_sphere.html":[5,2,6,29],
 "class_ogre_1_1_sphere.html#a01e832a0542bde80df107ab6b26b56f9":[5,2,6,29,6],
 "class_ogre_1_1_sphere.html#a4a30ba4b71475bf2da82c91dcc13e97a":[5,2,6,29,7],
@@ -111,18 +113,18 @@ var NAVTREEINDEX220 =
 "class_ogre_1_1_sphere_scene_query.html":[5,2,12,56],
 "class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,0,1,56,0],
 "class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,2,12,56,0],
-"class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,56,0,2],
 "class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,0,1,56,0,2],
-"class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,2,12,56,0,1],
+"class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,56,0,2],
 "class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,0,1,56,0,1],
-"class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,2,12,56,0,0],
+"class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,2,12,56,0,1],
 "class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,0,1,56,0,0],
-"class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,2,12,56,0,4],
+"class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,2,12,56,0,0],
 "class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,0,1,56,0,4],
+"class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,2,12,56,0,4],
 "class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,0,1,56,0,3],
 "class_ogre_1_1_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,2,12,56,0,3],
-"class_ogre_1_1_sphere_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,56,13],
 "class_ogre_1_1_sphere_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,56,13],
+"class_ogre_1_1_sphere_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,56,13],
 "class_ogre_1_1_sphere_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,0,1,56,3],
 "class_ogre_1_1_sphere_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,2,12,56,3],
 "class_ogre_1_1_sphere_scene_query.html#a20e200f7a33292e6644a44bf882ae8f6":[5,0,1,56,4],
@@ -137,44 +139,44 @@ var NAVTREEINDEX220 =
 "class_ogre_1_1_sphere_scene_query.html#a5355b72d0d8fb12e4e35f8661652f190":[5,0,1,56,1],
 "class_ogre_1_1_sphere_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,56,15],
 "class_ogre_1_1_sphere_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,56,15],
-"class_ogre_1_1_sphere_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,56,18],
 "class_ogre_1_1_sphere_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,56,18],
+"class_ogre_1_1_sphere_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,56,18],
 "class_ogre_1_1_sphere_scene_query.html#a6b8ac84df4b61cdd0abba7fcd43ae956":[5,2,12,56,24],
 "class_ogre_1_1_sphere_scene_query.html#a6b8ac84df4b61cdd0abba7fcd43ae956":[5,0,1,56,24],
 "class_ogre_1_1_sphere_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,2,12,56,9],
 "class_ogre_1_1_sphere_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,0,1,56,9],
 "class_ogre_1_1_sphere_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,56,11],
 "class_ogre_1_1_sphere_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,56,11],
-"class_ogre_1_1_sphere_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,2,12,56,6],
 "class_ogre_1_1_sphere_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,0,1,56,6],
-"class_ogre_1_1_sphere_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,56,14],
+"class_ogre_1_1_sphere_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,2,12,56,6],
 "class_ogre_1_1_sphere_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,56,14],
-"class_ogre_1_1_sphere_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,0,1,56,5],
+"class_ogre_1_1_sphere_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,56,14],
 "class_ogre_1_1_sphere_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,2,12,56,5],
-"class_ogre_1_1_sphere_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,56,17],
+"class_ogre_1_1_sphere_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,0,1,56,5],
 "class_ogre_1_1_sphere_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,56,17],
-"class_ogre_1_1_sphere_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,56,12],
+"class_ogre_1_1_sphere_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,56,17],
 "class_ogre_1_1_sphere_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,56,12],
-"class_ogre_1_1_sphere_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,0,1,56,10],
+"class_ogre_1_1_sphere_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,56,12],
 "class_ogre_1_1_sphere_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,2,12,56,10],
-"class_ogre_1_1_sphere_scene_query.html#ad0b1caec71e5feae87779d34351da924":[5,0,1,56,2],
+"class_ogre_1_1_sphere_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,0,1,56,10],
 "class_ogre_1_1_sphere_scene_query.html#ad0b1caec71e5feae87779d34351da924":[5,2,12,56,2],
+"class_ogre_1_1_sphere_scene_query.html#ad0b1caec71e5feae87779d34351da924":[5,0,1,56,2],
 "class_ogre_1_1_sphere_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,56,16],
 "class_ogre_1_1_sphere_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,56,16],
 "class_ogre_1_1_sphere_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,0,1,56,23],
 "class_ogre_1_1_sphere_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,12,56,23],
-"class_ogre_1_1_sphere_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,56,19],
 "class_ogre_1_1_sphere_scene_query.html#adce32528577d71b228692df906ecd17c":[5,2,12,56,19],
-"class_ogre_1_1_sphere_scene_query.html#adfd70f00b13654735336f4360af84995":[5,2,12,56,26],
+"class_ogre_1_1_sphere_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,56,19],
 "class_ogre_1_1_sphere_scene_query.html#adfd70f00b13654735336f4360af84995":[5,0,1,56,26],
+"class_ogre_1_1_sphere_scene_query.html#adfd70f00b13654735336f4360af84995":[5,2,12,56,26],
 "class_ogre_1_1_sphere_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,0,1,56,22],
 "class_ogre_1_1_sphere_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,2,12,56,22],
 "class_ogre_1_1_sphere_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,1,56,25],
 "class_ogre_1_1_sphere_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,2,12,56,25],
-"class_ogre_1_1_sphere_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,56,20],
 "class_ogre_1_1_sphere_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,56,20],
-"class_ogre_1_1_sphere_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,0,1,56,7],
+"class_ogre_1_1_sphere_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,56,20],
 "class_ogre_1_1_sphere_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,12,56,7],
+"class_ogre_1_1_sphere_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,0,1,56,7],
 "class_ogre_1_1_stack_vector.html":[7,0,0,913],
 "class_ogre_1_1_stack_vector.html":[6,0,0,940],
 "class_ogre_1_1_stack_vector.html#a04e7a34f3bccfacb332c72f623fc2bff":[6,0,0,940,23],
@@ -183,38 +185,38 @@ var NAVTREEINDEX220 =
 "class_ogre_1_1_stack_vector.html#a067b3ed72365b5e1512b753a1d6d01de":[7,0,0,913,21],
 "class_ogre_1_1_stack_vector.html#a06d35e21661247566a0565bcfa081b75":[6,0,0,940,3],
 "class_ogre_1_1_stack_vector.html#a06d35e21661247566a0565bcfa081b75":[7,0,0,913,3],
-"class_ogre_1_1_stack_vector.html#a08af21a0370da198ced8fa17c5d5fe41":[6,0,0,940,29],
 "class_ogre_1_1_stack_vector.html#a08af21a0370da198ced8fa17c5d5fe41":[7,0,0,913,29],
+"class_ogre_1_1_stack_vector.html#a08af21a0370da198ced8fa17c5d5fe41":[6,0,0,940,29],
 "class_ogre_1_1_stack_vector.html#a0cda5ac4b78798fac9913bb16abf9f94":[6,0,0,940,5],
 "class_ogre_1_1_stack_vector.html#a0cda5ac4b78798fac9913bb16abf9f94":[7,0,0,913,5],
-"class_ogre_1_1_stack_vector.html#a0e662834e1e17fc32d303de5db2f3dc0":[6,0,0,940,1],
 "class_ogre_1_1_stack_vector.html#a0e662834e1e17fc32d303de5db2f3dc0":[7,0,0,913,1],
-"class_ogre_1_1_stack_vector.html#a228051de3b041b3ec6d755597ac4309b":[7,0,0,913,18],
+"class_ogre_1_1_stack_vector.html#a0e662834e1e17fc32d303de5db2f3dc0":[6,0,0,940,1],
 "class_ogre_1_1_stack_vector.html#a228051de3b041b3ec6d755597ac4309b":[6,0,0,940,18],
-"class_ogre_1_1_stack_vector.html#a3598a0841f1572315fd28f67551170ea":[7,0,0,913,32],
+"class_ogre_1_1_stack_vector.html#a228051de3b041b3ec6d755597ac4309b":[7,0,0,913,18],
 "class_ogre_1_1_stack_vector.html#a3598a0841f1572315fd28f67551170ea":[6,0,0,940,32],
+"class_ogre_1_1_stack_vector.html#a3598a0841f1572315fd28f67551170ea":[7,0,0,913,32],
 "class_ogre_1_1_stack_vector.html#a3656f86bec7711bb2150f395ab70755f":[7,0,0,913,22],
 "class_ogre_1_1_stack_vector.html#a3656f86bec7711bb2150f395ab70755f":[6,0,0,940,22],
-"class_ogre_1_1_stack_vector.html#a3a6329677cbb3667facff230d787df7c":[6,0,0,940,25],
 "class_ogre_1_1_stack_vector.html#a3a6329677cbb3667facff230d787df7c":[7,0,0,913,25],
-"class_ogre_1_1_stack_vector.html#a484ffa669fa6b8702bb13d78c427e5e9":[6,0,0,940,4],
+"class_ogre_1_1_stack_vector.html#a3a6329677cbb3667facff230d787df7c":[6,0,0,940,25],
 "class_ogre_1_1_stack_vector.html#a484ffa669fa6b8702bb13d78c427e5e9":[7,0,0,913,4],
-"class_ogre_1_1_stack_vector.html#a4899beae67b931caaeca1b0ff81e0168":[6,0,0,940,34],
+"class_ogre_1_1_stack_vector.html#a484ffa669fa6b8702bb13d78c427e5e9":[6,0,0,940,4],
 "class_ogre_1_1_stack_vector.html#a4899beae67b931caaeca1b0ff81e0168":[7,0,0,913,34],
-"class_ogre_1_1_stack_vector.html#a5012a51f1f62cb58e25b56460a9e59a6":[7,0,0,913,8],
+"class_ogre_1_1_stack_vector.html#a4899beae67b931caaeca1b0ff81e0168":[6,0,0,940,34],
 "class_ogre_1_1_stack_vector.html#a5012a51f1f62cb58e25b56460a9e59a6":[6,0,0,940,8],
-"class_ogre_1_1_stack_vector.html#a6054387c7f060e4118d8b45621908e8e":[6,0,0,940,16],
+"class_ogre_1_1_stack_vector.html#a5012a51f1f62cb58e25b56460a9e59a6":[7,0,0,913,8],
 "class_ogre_1_1_stack_vector.html#a6054387c7f060e4118d8b45621908e8e":[7,0,0,913,16],
-"class_ogre_1_1_stack_vector.html#a62244fd691c679d27c007f55d56279c0":[6,0,0,940,28],
+"class_ogre_1_1_stack_vector.html#a6054387c7f060e4118d8b45621908e8e":[6,0,0,940,16],
 "class_ogre_1_1_stack_vector.html#a62244fd691c679d27c007f55d56279c0":[7,0,0,913,28],
+"class_ogre_1_1_stack_vector.html#a62244fd691c679d27c007f55d56279c0":[6,0,0,940,28],
 "class_ogre_1_1_stack_vector.html#a707fe1fb65458cc9806d3ecfb7ca0899":[7,0,0,913,26],
 "class_ogre_1_1_stack_vector.html#a707fe1fb65458cc9806d3ecfb7ca0899":[6,0,0,940,26],
-"class_ogre_1_1_stack_vector.html#a73b121ff651a388b99335fe9c5714ce3":[6,0,0,940,13],
 "class_ogre_1_1_stack_vector.html#a73b121ff651a388b99335fe9c5714ce3":[7,0,0,913,13],
-"class_ogre_1_1_stack_vector.html#a76bb7cf2742e36de3e7c4bc8b4f430b3":[7,0,0,913,2],
+"class_ogre_1_1_stack_vector.html#a73b121ff651a388b99335fe9c5714ce3":[6,0,0,940,13],
 "class_ogre_1_1_stack_vector.html#a76bb7cf2742e36de3e7c4bc8b4f430b3":[6,0,0,940,2],
-"class_ogre_1_1_stack_vector.html#a7d1082854cfa9318221e8bb7f31d09b7":[6,0,0,940,31],
+"class_ogre_1_1_stack_vector.html#a76bb7cf2742e36de3e7c4bc8b4f430b3":[7,0,0,913,2],
 "class_ogre_1_1_stack_vector.html#a7d1082854cfa9318221e8bb7f31d09b7":[7,0,0,913,31],
+"class_ogre_1_1_stack_vector.html#a7d1082854cfa9318221e8bb7f31d09b7":[6,0,0,940,31],
 "class_ogre_1_1_stack_vector.html#a7ed4677316369b6ae8b35beaf73ffd47":[7,0,0,913,19],
 "class_ogre_1_1_stack_vector.html#a7ed4677316369b6ae8b35beaf73ffd47":[6,0,0,940,19],
 "class_ogre_1_1_stack_vector.html#a81e119d00e6ac8257453522a475ba557":[7,0,0,913,24],
@@ -223,31 +225,29 @@ var NAVTREEINDEX220 =
 "class_ogre_1_1_stack_vector.html#a894eae4209ad0059aaa336f810b7ca12":[7,0,0,913,0],
 "class_ogre_1_1_stack_vector.html#a8d91e3bfe41572384d63611346f4983c":[6,0,0,940,9],
 "class_ogre_1_1_stack_vector.html#a8d91e3bfe41572384d63611346f4983c":[7,0,0,913,9],
-"class_ogre_1_1_stack_vector.html#a8edcdcf8715ebe5846c6e9263d567e49":[7,0,0,913,17],
 "class_ogre_1_1_stack_vector.html#a8edcdcf8715ebe5846c6e9263d567e49":[6,0,0,940,17],
-"class_ogre_1_1_stack_vector.html#a92a85d8f91059d5defdcb2d16a262318":[6,0,0,940,11],
+"class_ogre_1_1_stack_vector.html#a8edcdcf8715ebe5846c6e9263d567e49":[7,0,0,913,17],
 "class_ogre_1_1_stack_vector.html#a92a85d8f91059d5defdcb2d16a262318":[7,0,0,913,11],
-"class_ogre_1_1_stack_vector.html#a934e2168a86c78f87e5c408444a19e85":[6,0,0,940,14],
+"class_ogre_1_1_stack_vector.html#a92a85d8f91059d5defdcb2d16a262318":[6,0,0,940,11],
 "class_ogre_1_1_stack_vector.html#a934e2168a86c78f87e5c408444a19e85":[7,0,0,913,14],
-"class_ogre_1_1_stack_vector.html#aa6f2e428c9603bf46f779376d09bb74c":[6,0,0,940,33],
+"class_ogre_1_1_stack_vector.html#a934e2168a86c78f87e5c408444a19e85":[6,0,0,940,14],
 "class_ogre_1_1_stack_vector.html#aa6f2e428c9603bf46f779376d09bb74c":[7,0,0,913,33],
-"class_ogre_1_1_stack_vector.html#aad5412f0c8ea1ab5664d7c5ff4e83f09":[7,0,0,913,10],
+"class_ogre_1_1_stack_vector.html#aa6f2e428c9603bf46f779376d09bb74c":[6,0,0,940,33],
 "class_ogre_1_1_stack_vector.html#aad5412f0c8ea1ab5664d7c5ff4e83f09":[6,0,0,940,10],
+"class_ogre_1_1_stack_vector.html#aad5412f0c8ea1ab5664d7c5ff4e83f09":[7,0,0,913,10],
 "class_ogre_1_1_stack_vector.html#ac1cb5cb41b4eddf88551331f366982ee":[6,0,0,940,7],
 "class_ogre_1_1_stack_vector.html#ac1cb5cb41b4eddf88551331f366982ee":[7,0,0,913,7],
 "class_ogre_1_1_stack_vector.html#ac92ba0d9b5b516af975fd3a960242c14":[6,0,0,940,27],
 "class_ogre_1_1_stack_vector.html#ac92ba0d9b5b516af975fd3a960242c14":[7,0,0,913,27],
 "class_ogre_1_1_stack_vector.html#ad51ba32b7ddfada54b984d918c2bf8df":[6,0,0,940,20],
 "class_ogre_1_1_stack_vector.html#ad51ba32b7ddfada54b984d918c2bf8df":[7,0,0,913,20],
-"class_ogre_1_1_stack_vector.html#ad7b30816b65462b8d691c914b8251104":[7,0,0,913,15],
 "class_ogre_1_1_stack_vector.html#ad7b30816b65462b8d691c914b8251104":[6,0,0,940,15],
+"class_ogre_1_1_stack_vector.html#ad7b30816b65462b8d691c914b8251104":[7,0,0,913,15],
 "class_ogre_1_1_stack_vector.html#aeedbb4d274e315d6229ca55ff7b923d3":[7,0,0,913,6],
 "class_ogre_1_1_stack_vector.html#aeedbb4d274e315d6229ca55ff7b923d3":[6,0,0,940,6],
-"class_ogre_1_1_stack_vector.html#af4bb29e83084ffda1deaffea49b1a22f":[7,0,0,913,30],
 "class_ogre_1_1_stack_vector.html#af4bb29e83084ffda1deaffea49b1a22f":[6,0,0,940,30],
+"class_ogre_1_1_stack_vector.html#af4bb29e83084ffda1deaffea49b1a22f":[7,0,0,913,30],
 "class_ogre_1_1_stack_vector.html#affbd87471da12f96836e535dc854d647":[7,0,0,913,12],
 "class_ogre_1_1_stack_vector.html#affbd87471da12f96836e535dc854d647":[6,0,0,940,12],
-"class_ogre_1_1_staging_buffer.html":[7,0,0,914],
-"class_ogre_1_1_staging_buffer.html":[6,0,0,941],
-"class_ogre_1_1_staging_buffer.html#a0512e57da9c9f75e7666133a10883126":[7,0,0,914,11]
+"class_ogre_1_1_staging_buffer.html":[7,0,0,914]
 };
