@@ -1,32 +1,34 @@
 var NAVTREEINDEX221 =
 {
+"class_ogre_1_1_staging_buffer.html":[6,0,0,941],
 "class_ogre_1_1_staging_buffer.html#a0512e57da9c9f75e7666133a10883126":[6,0,0,941,11],
+"class_ogre_1_1_staging_buffer.html#a0512e57da9c9f75e7666133a10883126":[7,0,0,914,11],
 "class_ogre_1_1_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[6,0,0,941,15],
 "class_ogre_1_1_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[7,0,0,914,15],
 "class_ogre_1_1_staging_buffer.html#a06dfed7c83a6aa991b0bceef76743550":[7,0,0,914,10],
 "class_ogre_1_1_staging_buffer.html#a06dfed7c83a6aa991b0bceef76743550":[6,0,0,941,10],
 "class_ogre_1_1_staging_buffer.html#a10b28de5293c036bf7f23e87bef00de6":[7,0,0,914,7],
 "class_ogre_1_1_staging_buffer.html#a10b28de5293c036bf7f23e87bef00de6":[6,0,0,941,7],
-"class_ogre_1_1_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[6,0,0,941,9],
 "class_ogre_1_1_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[7,0,0,914,9],
-"class_ogre_1_1_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,914,19],
+"class_ogre_1_1_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[6,0,0,941,9],
 "class_ogre_1_1_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,941,19],
+"class_ogre_1_1_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,914,19],
 "class_ogre_1_1_staging_buffer.html#a29313389dacd812a8d238df458f9e979":[6,0,0,941,27],
 "class_ogre_1_1_staging_buffer.html#a29313389dacd812a8d238df458f9e979":[7,0,0,914,27],
 "class_ogre_1_1_staging_buffer.html#a3fed0b896633e63d9cb112c0ae026bd3":[7,0,0,914,4],
 "class_ogre_1_1_staging_buffer.html#a3fed0b896633e63d9cb112c0ae026bd3":[6,0,0,941,4],
 "class_ogre_1_1_staging_buffer.html#a438d82f09b5f657be30c30d7d1c0801d":[6,0,0,941,28],
 "class_ogre_1_1_staging_buffer.html#a438d82f09b5f657be30c30d7d1c0801d":[7,0,0,914,28],
-"class_ogre_1_1_staging_buffer.html#a5239fe8fda6e2de02e5c053edb69661a":[6,0,0,941,16],
 "class_ogre_1_1_staging_buffer.html#a5239fe8fda6e2de02e5c053edb69661a":[7,0,0,914,16],
+"class_ogre_1_1_staging_buffer.html#a5239fe8fda6e2de02e5c053edb69661a":[6,0,0,941,16],
 "class_ogre_1_1_staging_buffer.html#a53adbd5b91819a0e58c9d2c010eba469":[7,0,0,914,14],
 "class_ogre_1_1_staging_buffer.html#a53adbd5b91819a0e58c9d2c010eba469":[6,0,0,941,14],
 "class_ogre_1_1_staging_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,914,21],
 "class_ogre_1_1_staging_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,941,21],
-"class_ogre_1_1_staging_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,914,24],
 "class_ogre_1_1_staging_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,941,24],
-"class_ogre_1_1_staging_buffer.html#a765f26f80115c9341308fc86330ec9c2":[7,0,0,914,12],
+"class_ogre_1_1_staging_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,914,24],
 "class_ogre_1_1_staging_buffer.html#a765f26f80115c9341308fc86330ec9c2":[6,0,0,941,12],
+"class_ogre_1_1_staging_buffer.html#a765f26f80115c9341308fc86330ec9c2":[7,0,0,914,12],
 "class_ogre_1_1_staging_buffer.html#a7f67923bab757fa39e66903935a621c0":[7,0,0,914,3],
 "class_ogre_1_1_staging_buffer.html#a7f67923bab757fa39e66903935a621c0":[6,0,0,941,3],
 "class_ogre_1_1_staging_buffer.html#a8047cc93c004c2f6c5700aca44e35b2a":[7,0,0,914,6],
@@ -35,30 +37,30 @@ var NAVTREEINDEX221 =
 "class_ogre_1_1_staging_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,941,17],
 "class_ogre_1_1_staging_buffer.html#a897e0ef920699d059b273eed1fe71d4d":[7,0,0,914,13],
 "class_ogre_1_1_staging_buffer.html#a897e0ef920699d059b273eed1fe71d4d":[6,0,0,941,13],
-"class_ogre_1_1_staging_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,941,20],
 "class_ogre_1_1_staging_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,914,20],
+"class_ogre_1_1_staging_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,941,20],
 "class_ogre_1_1_staging_buffer.html#a9c8e2853c21a7418218605a0b9cdf461":[7,0,0,914,29],
 "class_ogre_1_1_staging_buffer.html#a9c8e2853c21a7418218605a0b9cdf461":[6,0,0,941,29],
 "class_ogre_1_1_staging_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,914,23],
 "class_ogre_1_1_staging_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,941,23],
 "class_ogre_1_1_staging_buffer.html#ababb860ddfb4ecdf054766f145848465":[7,0,0,914,31],
 "class_ogre_1_1_staging_buffer.html#ababb860ddfb4ecdf054766f145848465":[6,0,0,941,31],
-"class_ogre_1_1_staging_buffer.html#abb4937c4f63bd15c0650146ba554efa3":[6,0,0,941,2],
 "class_ogre_1_1_staging_buffer.html#abb4937c4f63bd15c0650146ba554efa3":[7,0,0,914,2],
+"class_ogre_1_1_staging_buffer.html#abb4937c4f63bd15c0650146ba554efa3":[6,0,0,941,2],
 "class_ogre_1_1_staging_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,914,18],
 "class_ogre_1_1_staging_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,941,18],
 "class_ogre_1_1_staging_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,914,22],
 "class_ogre_1_1_staging_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,941,22],
-"class_ogre_1_1_staging_buffer.html#ad844466b16d039d78fe762a3e32f92c2":[6,0,0,941,8],
 "class_ogre_1_1_staging_buffer.html#ad844466b16d039d78fe762a3e32f92c2":[7,0,0,914,8],
-"class_ogre_1_1_staging_buffer.html#ad9db4541715b29e151043a09a24a527a":[6,0,0,941,5],
+"class_ogre_1_1_staging_buffer.html#ad844466b16d039d78fe762a3e32f92c2":[6,0,0,941,8],
 "class_ogre_1_1_staging_buffer.html#ad9db4541715b29e151043a09a24a527a":[7,0,0,914,5],
-"class_ogre_1_1_staging_buffer.html#adce32528577d71b228692df906ecd17c":[6,0,0,941,25],
+"class_ogre_1_1_staging_buffer.html#ad9db4541715b29e151043a09a24a527a":[6,0,0,941,5],
 "class_ogre_1_1_staging_buffer.html#adce32528577d71b228692df906ecd17c":[7,0,0,914,25],
+"class_ogre_1_1_staging_buffer.html#adce32528577d71b228692df906ecd17c":[6,0,0,941,25],
 "class_ogre_1_1_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[6,0,0,941,1],
 "class_ogre_1_1_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[7,0,0,914,1],
-"class_ogre_1_1_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,941,26],
 "class_ogre_1_1_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,914,26],
+"class_ogre_1_1_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,941,26],
 "class_ogre_1_1_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[6,0,0,941,30],
 "class_ogre_1_1_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[7,0,0,914,30],
 "class_ogre_1_1_staging_texture.html":[5,2,11,122],
@@ -114,8 +116,8 @@ var NAVTREEINDEX221 =
 "class_ogre_1_1_staging_texture_manager.html":[7,0,0,917],
 "class_ogre_1_1_staging_texture_manager.html#a08032f5765443d5c35d413dd8a8e5849":[6,0,0,944,0],
 "class_ogre_1_1_staging_texture_manager.html#a08032f5765443d5c35d413dd8a8e5849":[7,0,0,917,0],
-"class_ogre_1_1_staging_texture_manager.html#a600f8465b784ef6539c6ad315c394a12":[7,0,0,917,2],
 "class_ogre_1_1_staging_texture_manager.html#a600f8465b784ef6539c6ad315c394a12":[6,0,0,944,2],
+"class_ogre_1_1_staging_texture_manager.html#a600f8465b784ef6539c6ad315c394a12":[7,0,0,917,2],
 "class_ogre_1_1_staging_texture_manager.html#ad7b9e18265cdb9427efe2cb3677b59c2":[7,0,0,917,1],
 "class_ogre_1_1_staging_texture_manager.html#ad7b9e18265cdb9427efe2cb3677b59c2":[6,0,0,944,1],
 "class_ogre_1_1_static_cache.html":[6,0,0,945],
@@ -124,10 +126,10 @@ var NAVTREEINDEX221 =
 "class_ogre_1_1_static_cache.html#a0c5c50ba8dcb899f95414093f1085789":[6,0,0,945,4],
 "class_ogre_1_1_static_cache.html#a391ccc42df8e159a6b5dd7da49ac1679":[7,0,0,918,6],
 "class_ogre_1_1_static_cache.html#a391ccc42df8e159a6b5dd7da49ac1679":[6,0,0,945,6],
-"class_ogre_1_1_static_cache.html#a3e71993f421220f6d20a42c6c7401302":[6,0,0,945,0],
 "class_ogre_1_1_static_cache.html#a3e71993f421220f6d20a42c6c7401302":[7,0,0,918,0],
-"class_ogre_1_1_static_cache.html#a5b61f6d3a1c376811aedbd7718890d99":[6,0,0,945,2],
+"class_ogre_1_1_static_cache.html#a3e71993f421220f6d20a42c6c7401302":[6,0,0,945,0],
 "class_ogre_1_1_static_cache.html#a5b61f6d3a1c376811aedbd7718890d99":[7,0,0,918,2],
+"class_ogre_1_1_static_cache.html#a5b61f6d3a1c376811aedbd7718890d99":[6,0,0,945,2],
 "class_ogre_1_1_static_cache.html#a98387ba5e5f61b22c0933ed2f3dfb303":[7,0,0,918,5],
 "class_ogre_1_1_static_cache.html#a98387ba5e5f61b22c0933ed2f3dfb303":[6,0,0,945,5],
 "class_ogre_1_1_static_cache.html#abf9d854f82e9e25fb410be84941890ee":[6,0,0,945,3],
@@ -136,14 +138,14 @@ var NAVTREEINDEX221 =
 "class_ogre_1_1_static_cache.html#af58d3151d8bbfa0a07d6fefad4df0b99":[6,0,0,945,1],
 "class_ogre_1_1_std_list.html":[7,0,0,921],
 "class_ogre_1_1_std_list.html":[6,0,0,948],
-"class_ogre_1_1_std_map.html":[6,0,0,949],
 "class_ogre_1_1_std_map.html":[7,0,0,922],
-"class_ogre_1_1_std_multi_map.html":[6,0,0,950],
+"class_ogre_1_1_std_map.html":[6,0,0,949],
 "class_ogre_1_1_std_multi_map.html":[7,0,0,923],
-"class_ogre_1_1_std_unordered_set.html":[6,0,0,951],
+"class_ogre_1_1_std_multi_map.html":[6,0,0,950],
 "class_ogre_1_1_std_unordered_set.html":[7,0,0,924],
-"class_ogre_1_1_std_vector.html":[7,0,0,925],
+"class_ogre_1_1_std_unordered_set.html":[6,0,0,951],
 "class_ogre_1_1_std_vector.html":[6,0,0,952],
+"class_ogre_1_1_std_vector.html":[7,0,0,925],
 "class_ogre_1_1_stream_serialiser.html":[5,2,11,124],
 "class_ogre_1_1_stream_serialiser.html#a072077ff56678e964608a7451db7c3f0":[5,2,11,124,1],
 "class_ogre_1_1_stream_serialiser.html#a072077ff56678e964608a7451db7c3f0a344ebede556d120f89fbfd35b544a0fb":[5,2,11,124,1,2],
@@ -247,7 +249,5 @@ var NAVTREEINDEX221 =
 "class_ogre_1_1_string_converter.html#a9633e8a5b340ca0c3b36aa51efb4cc5d":[5,2,2,120,12],
 "class_ogre_1_1_string_converter.html#a9ceacfd6e4f13f89c1ec03f5ef754b58":[5,2,2,120,10],
 "class_ogre_1_1_string_converter.html#aa05c075b14b73fbdc82f477d6da359f8":[5,2,2,120,28],
-"class_ogre_1_1_string_converter.html#aa0a2d5fb724610a66f1949511e1fb478":[5,2,2,120,27],
-"class_ogre_1_1_string_converter.html#aa1378ae68227b869fc21b4bb9110d2db":[5,2,2,120,42],
-"class_ogre_1_1_string_converter.html#aa671980d27b86d09a0f568b451ba677d":[5,2,2,120,23]
+"class_ogre_1_1_string_converter.html#aa0a2d5fb724610a66f1949511e1fb478":[5,2,2,120,27]
 };
