@@ -1,5 +1,7 @@
 var NAVTREEINDEX222 =
 {
+"class_ogre_1_1_string_converter.html#aa1378ae68227b869fc21b4bb9110d2db":[5,2,2,120,42],
+"class_ogre_1_1_string_converter.html#aa671980d27b86d09a0f568b451ba677d":[5,2,2,120,23],
 "class_ogre_1_1_string_converter.html#ab6f7c4fb9bf4be031282c8ccf5b38727":[5,2,2,120,29],
 "class_ogre_1_1_string_converter.html#abe53e5d97672c4986cb4cfb1d510faac":[5,2,2,120,34],
 "class_ogre_1_1_string_converter.html#ad0e4b311451e29ca679afa825ff68aa4":[5,2,2,120,0],
@@ -36,82 +38,82 @@ var NAVTREEINDEX222 =
 "class_ogre_1_1_string_util.html#aa08af119e6752852489de475559252a0":[5,2,2,122,9],
 "class_ogre_1_1_string_util.html#ab936109efdb3b4f224cdddbb37704cd0":[5,2,2,122,8],
 "class_ogre_1_1_string_util.html#ae36e8b6e19fef623f59d56772ed1dd7e":[5,2,2,122,14],
-"class_ogre_1_1_sub_item.html":[5,2,12,58],
 "class_ogre_1_1_sub_item.html":[5,0,1,58],
+"class_ogre_1_1_sub_item.html":[5,2,12,58],
 "class_ogre_1_1_sub_item.html#a02e8c5cc62dadc7db0ead1cccdefdb65":[5,2,12,58,40],
 "class_ogre_1_1_sub_item.html#a02e8c5cc62dadc7db0ead1cccdefdb65":[5,0,1,58,40],
 "class_ogre_1_1_sub_item.html#a040f6de2d0aa0b483acac3e69608c47c":[5,2,12,58,4],
 "class_ogre_1_1_sub_item.html#a040f6de2d0aa0b483acac3e69608c47c":[5,0,1,58,4],
-"class_ogre_1_1_sub_item.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,0,1,58,56],
 "class_ogre_1_1_sub_item.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,2,12,58,56],
-"class_ogre_1_1_sub_item.html#a0c7563dc12f2d0032121403cb4c6f5c2":[5,2,12,58,35],
+"class_ogre_1_1_sub_item.html#a0c726a0326e8a7d9e80d030541b6bddf":[5,0,1,58,56],
 "class_ogre_1_1_sub_item.html#a0c7563dc12f2d0032121403cb4c6f5c2":[5,0,1,58,35],
+"class_ogre_1_1_sub_item.html#a0c7563dc12f2d0032121403cb4c6f5c2":[5,2,12,58,35],
 "class_ogre_1_1_sub_item.html#a0f642341b106ea12f9c99cda5eb0cd52":[5,2,12,58,13],
 "class_ogre_1_1_sub_item.html#a0f642341b106ea12f9c99cda5eb0cd52":[5,0,1,58,13],
-"class_ogre_1_1_sub_item.html#a117563eda1d3affcd4a64c6bf4f8663a":[5,2,12,58,0],
 "class_ogre_1_1_sub_item.html#a117563eda1d3affcd4a64c6bf4f8663a":[5,0,1,58,0],
-"class_ogre_1_1_sub_item.html#a11ff15a191d963643c979bd222de2aaf":[5,0,1,58,41],
+"class_ogre_1_1_sub_item.html#a117563eda1d3affcd4a64c6bf4f8663a":[5,2,12,58,0],
 "class_ogre_1_1_sub_item.html#a11ff15a191d963643c979bd222de2aaf":[5,2,12,58,41],
-"class_ogre_1_1_sub_item.html#a13f1bbc23e57df9084bed76acb3b5500":[5,2,12,58,38],
+"class_ogre_1_1_sub_item.html#a11ff15a191d963643c979bd222de2aaf":[5,0,1,58,41],
 "class_ogre_1_1_sub_item.html#a13f1bbc23e57df9084bed76acb3b5500":[5,0,1,58,38],
+"class_ogre_1_1_sub_item.html#a13f1bbc23e57df9084bed76acb3b5500":[5,2,12,58,38],
 "class_ogre_1_1_sub_item.html#a173800458c92ecefcff9d037be54afea":[5,2,12,58,62],
 "class_ogre_1_1_sub_item.html#a173800458c92ecefcff9d037be54afea":[5,0,1,58,62],
 "class_ogre_1_1_sub_item.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,58,46],
 "class_ogre_1_1_sub_item.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,58,46],
-"class_ogre_1_1_sub_item.html#a2064249d3f0de7c0c838af8e3e712ac0":[5,2,12,58,19],
 "class_ogre_1_1_sub_item.html#a2064249d3f0de7c0c838af8e3e712ac0":[5,0,1,58,19],
-"class_ogre_1_1_sub_item.html#a2108dfc322953a7bd429be8b62811e56":[5,0,1,58,64],
+"class_ogre_1_1_sub_item.html#a2064249d3f0de7c0c838af8e3e712ac0":[5,2,12,58,19],
 "class_ogre_1_1_sub_item.html#a2108dfc322953a7bd429be8b62811e56":[5,2,12,58,64],
-"class_ogre_1_1_sub_item.html#a21d95904b985b26f99f88696958891c3":[5,2,12,58,58],
+"class_ogre_1_1_sub_item.html#a2108dfc322953a7bd429be8b62811e56":[5,0,1,58,64],
 "class_ogre_1_1_sub_item.html#a21d95904b985b26f99f88696958891c3":[5,0,1,58,58],
+"class_ogre_1_1_sub_item.html#a21d95904b985b26f99f88696958891c3":[5,2,12,58,58],
 "class_ogre_1_1_sub_item.html#a284464b0561a6f2915f04b0245b987f0":[5,0,1,58,72],
 "class_ogre_1_1_sub_item.html#a284464b0561a6f2915f04b0245b987f0":[5,2,12,58,72],
 "class_ogre_1_1_sub_item.html#a2a7a3226009eb5f5387be146898dab90":[5,0,1,58,32],
 "class_ogre_1_1_sub_item.html#a2a7a3226009eb5f5387be146898dab90":[5,2,12,58,32],
 "class_ogre_1_1_sub_item.html#a2f92a5741b1c1123f7f76ce2a551c9c8":[5,0,1,58,5],
 "class_ogre_1_1_sub_item.html#a2f92a5741b1c1123f7f76ce2a551c9c8":[5,2,12,58,5],
-"class_ogre_1_1_sub_item.html#a3a8fafedc41616f8ae8306409443c3e4":[5,2,12,58,10],
 "class_ogre_1_1_sub_item.html#a3a8fafedc41616f8ae8306409443c3e4":[5,0,1,58,10],
+"class_ogre_1_1_sub_item.html#a3a8fafedc41616f8ae8306409443c3e4":[5,2,12,58,10],
 "class_ogre_1_1_sub_item.html#a3bee104c7359ba6c41d65d88cfc3d418":[5,0,1,58,37],
 "class_ogre_1_1_sub_item.html#a3bee104c7359ba6c41d65d88cfc3d418":[5,2,12,58,37],
-"class_ogre_1_1_sub_item.html#a4136ce4b9d3add5203339327015d872d":[5,2,12,58,68],
 "class_ogre_1_1_sub_item.html#a4136ce4b9d3add5203339327015d872d":[5,0,1,58,68],
-"class_ogre_1_1_sub_item.html#a41b58fe7a0d317cbc00052e6668cf4ef":[5,0,1,58,12],
+"class_ogre_1_1_sub_item.html#a4136ce4b9d3add5203339327015d872d":[5,2,12,58,68],
 "class_ogre_1_1_sub_item.html#a41b58fe7a0d317cbc00052e6668cf4ef":[5,2,12,58,12],
-"class_ogre_1_1_sub_item.html#a45267a8b4917f3bbe76a2dc14f7122be":[5,0,1,58,28],
+"class_ogre_1_1_sub_item.html#a41b58fe7a0d317cbc00052e6668cf4ef":[5,0,1,58,12],
 "class_ogre_1_1_sub_item.html#a45267a8b4917f3bbe76a2dc14f7122be":[5,2,12,58,28],
-"class_ogre_1_1_sub_item.html#a47508d27a6c799998047c50ec43e9897":[5,0,1,58,21],
+"class_ogre_1_1_sub_item.html#a45267a8b4917f3bbe76a2dc14f7122be":[5,0,1,58,28],
 "class_ogre_1_1_sub_item.html#a47508d27a6c799998047c50ec43e9897":[5,2,12,58,21],
-"class_ogre_1_1_sub_item.html#a4af66c22373c90b388d2117ee904a92b":[5,0,1,58,74],
+"class_ogre_1_1_sub_item.html#a47508d27a6c799998047c50ec43e9897":[5,0,1,58,21],
 "class_ogre_1_1_sub_item.html#a4af66c22373c90b388d2117ee904a92b":[5,2,12,58,74],
+"class_ogre_1_1_sub_item.html#a4af66c22373c90b388d2117ee904a92b":[5,0,1,58,74],
 "class_ogre_1_1_sub_item.html#a4c2ae8ae38d7910d9730c025999f6b83":[5,0,1,58,14],
 "class_ogre_1_1_sub_item.html#a4c2ae8ae38d7910d9730c025999f6b83":[5,2,12,58,14],
-"class_ogre_1_1_sub_item.html#a51ba9ae3782f39ea03bee09534a982e9":[5,2,12,58,66],
 "class_ogre_1_1_sub_item.html#a51ba9ae3782f39ea03bee09534a982e9":[5,0,1,58,66],
+"class_ogre_1_1_sub_item.html#a51ba9ae3782f39ea03bee09534a982e9":[5,2,12,58,66],
 "class_ogre_1_1_sub_item.html#a55bcfecbaab92f5836dc89da5d007586":[5,2,12,58,6],
 "class_ogre_1_1_sub_item.html#a55bcfecbaab92f5836dc89da5d007586":[5,0,1,58,6],
 "class_ogre_1_1_sub_item.html#a572c0331ef2ec650d56063fdc17435f5":[5,2,12,58,57],
 "class_ogre_1_1_sub_item.html#a572c0331ef2ec650d56063fdc17435f5":[5,0,1,58,57],
-"class_ogre_1_1_sub_item.html#a57566d0e53bb1fff6506e97d222bcd1c":[5,2,12,58,61],
 "class_ogre_1_1_sub_item.html#a57566d0e53bb1fff6506e97d222bcd1c":[5,0,1,58,61],
+"class_ogre_1_1_sub_item.html#a57566d0e53bb1fff6506e97d222bcd1c":[5,2,12,58,61],
 "class_ogre_1_1_sub_item.html#a583dad5b16665689ced7226f21b74b73":[5,2,12,58,31],
 "class_ogre_1_1_sub_item.html#a583dad5b16665689ced7226f21b74b73":[5,0,1,58,31],
 "class_ogre_1_1_sub_item.html#a592f12018dc19e2022c839cb5fffa3a1":[5,2,12,58,60],
 "class_ogre_1_1_sub_item.html#a592f12018dc19e2022c839cb5fffa3a1":[5,0,1,58,60],
 "class_ogre_1_1_sub_item.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,58,48],
 "class_ogre_1_1_sub_item.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,58,48],
-"class_ogre_1_1_sub_item.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,58,51],
 "class_ogre_1_1_sub_item.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,58,51],
+"class_ogre_1_1_sub_item.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,58,51],
 "class_ogre_1_1_sub_item.html#a6496cb6bcaffcbb03e25e56f4b88bf7f":[5,0,1,58,15],
 "class_ogre_1_1_sub_item.html#a6496cb6bcaffcbb03e25e56f4b88bf7f":[5,2,12,58,15],
-"class_ogre_1_1_sub_item.html#a65246f7bdb08b9b4fb169ff5d0235eaa":[5,0,1,58,17],
 "class_ogre_1_1_sub_item.html#a65246f7bdb08b9b4fb169ff5d0235eaa":[5,2,12,58,17],
-"class_ogre_1_1_sub_item.html#a667b8876930b77c9d609b80ee5fb1515":[5,0,1,58,67],
+"class_ogre_1_1_sub_item.html#a65246f7bdb08b9b4fb169ff5d0235eaa":[5,0,1,58,17],
 "class_ogre_1_1_sub_item.html#a667b8876930b77c9d609b80ee5fb1515":[5,2,12,58,67],
-"class_ogre_1_1_sub_item.html#a6d9e689659160cac9735f00ece15c0d4":[5,0,1,58,23],
+"class_ogre_1_1_sub_item.html#a667b8876930b77c9d609b80ee5fb1515":[5,0,1,58,67],
 "class_ogre_1_1_sub_item.html#a6d9e689659160cac9735f00ece15c0d4":[5,2,12,58,23],
-"class_ogre_1_1_sub_item.html#a7209f6be28cb30aa397dd7791e78c773":[5,2,12,58,3],
+"class_ogre_1_1_sub_item.html#a6d9e689659160cac9735f00ece15c0d4":[5,0,1,58,23],
 "class_ogre_1_1_sub_item.html#a7209f6be28cb30aa397dd7791e78c773":[5,0,1,58,3],
+"class_ogre_1_1_sub_item.html#a7209f6be28cb30aa397dd7791e78c773":[5,2,12,58,3],
 "class_ogre_1_1_sub_item.html#a73de2dd2cc45eee54c7a9262ff6da180":[5,2,12,58,36],
 "class_ogre_1_1_sub_item.html#a73de2dd2cc45eee54c7a9262ff6da180":[5,0,1,58,36],
 "class_ogre_1_1_sub_item.html#a77230eea8136b7c296cc0a5db1dba9ee":[5,2,12,58,54],
@@ -122,30 +124,30 @@ var NAVTREEINDEX222 =
 "class_ogre_1_1_sub_item.html#a8096988a16728c8b7e32495146111c62":[5,0,1,58,59],
 "class_ogre_1_1_sub_item.html#a812d3b0f5df694b92084a98387d8f215":[5,2,12,58,42],
 "class_ogre_1_1_sub_item.html#a812d3b0f5df694b92084a98387d8f215":[5,0,1,58,42],
-"class_ogre_1_1_sub_item.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,58,44],
 "class_ogre_1_1_sub_item.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,58,44],
+"class_ogre_1_1_sub_item.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,58,44],
 "class_ogre_1_1_sub_item.html#a862b4efee979307bbdfe2a49924d19de":[5,2,12,58,65],
 "class_ogre_1_1_sub_item.html#a862b4efee979307bbdfe2a49924d19de":[5,0,1,58,65],
-"class_ogre_1_1_sub_item.html#a869e7226c48fbff5dafef92b2b929b5e":[5,2,12,58,34],
 "class_ogre_1_1_sub_item.html#a869e7226c48fbff5dafef92b2b929b5e":[5,0,1,58,34],
+"class_ogre_1_1_sub_item.html#a869e7226c48fbff5dafef92b2b929b5e":[5,2,12,58,34],
 "class_ogre_1_1_sub_item.html#a86b362d966ed8183911b5d3835b53e2e":[5,2,12,58,30],
 "class_ogre_1_1_sub_item.html#a86b362d966ed8183911b5d3835b53e2e":[5,0,1,58,30],
-"class_ogre_1_1_sub_item.html#a89b0d57ee33c2b90392133ae9f239efe":[5,2,12,58,29],
 "class_ogre_1_1_sub_item.html#a89b0d57ee33c2b90392133ae9f239efe":[5,0,1,58,29],
-"class_ogre_1_1_sub_item.html#a8f18715b01c0851631eb9cccd1a05552":[5,2,12,58,70],
+"class_ogre_1_1_sub_item.html#a89b0d57ee33c2b90392133ae9f239efe":[5,2,12,58,29],
 "class_ogre_1_1_sub_item.html#a8f18715b01c0851631eb9cccd1a05552":[5,0,1,58,70],
+"class_ogre_1_1_sub_item.html#a8f18715b01c0851631eb9cccd1a05552":[5,2,12,58,70],
 "class_ogre_1_1_sub_item.html#a93424273b03dc18800f42a64e7b2cc7b":[5,0,1,58,26],
 "class_ogre_1_1_sub_item.html#a93424273b03dc18800f42a64e7b2cc7b":[5,2,12,58,26],
-"class_ogre_1_1_sub_item.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,58,47],
 "class_ogre_1_1_sub_item.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,58,47],
-"class_ogre_1_1_sub_item.html#a95441b99bdec221d2fdb800c651a11e1":[5,2,12,58,1],
+"class_ogre_1_1_sub_item.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,58,47],
 "class_ogre_1_1_sub_item.html#a95441b99bdec221d2fdb800c651a11e1":[5,0,1,58,1],
-"class_ogre_1_1_sub_item.html#a9ea8c7833f3cdb031e9dae7cccf1413f":[5,2,12,58,2],
+"class_ogre_1_1_sub_item.html#a95441b99bdec221d2fdb800c651a11e1":[5,2,12,58,1],
 "class_ogre_1_1_sub_item.html#a9ea8c7833f3cdb031e9dae7cccf1413f":[5,0,1,58,2],
+"class_ogre_1_1_sub_item.html#a9ea8c7833f3cdb031e9dae7cccf1413f":[5,2,12,58,2],
 "class_ogre_1_1_sub_item.html#aab5e636e36b57dda7d301d7fa30c1d1e":[5,0,1,58,20],
 "class_ogre_1_1_sub_item.html#aab5e636e36b57dda7d301d7fa30c1d1e":[5,2,12,58,20],
-"class_ogre_1_1_sub_item.html#aad85754f188b769ff61150eaf36106c4":[5,0,1,58,71],
 "class_ogre_1_1_sub_item.html#aad85754f188b769ff61150eaf36106c4":[5,2,12,58,71],
+"class_ogre_1_1_sub_item.html#aad85754f188b769ff61150eaf36106c4":[5,0,1,58,71],
 "class_ogre_1_1_sub_item.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,58,50],
 "class_ogre_1_1_sub_item.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,58,50],
 "class_ogre_1_1_sub_item.html#ab4c66fed80a7372f7898fccd1f821eb1":[5,0,1,58,7],
@@ -154,42 +156,42 @@ var NAVTREEINDEX222 =
 "class_ogre_1_1_sub_item.html#ab682cd8eac807d059840e776f247c73f":[5,0,1,58,73],
 "class_ogre_1_1_sub_item.html#abbdb6bfe33b416976de33ee15d467674":[5,2,12,58,24],
 "class_ogre_1_1_sub_item.html#abbdb6bfe33b416976de33ee15d467674":[5,0,1,58,24],
-"class_ogre_1_1_sub_item.html#abc10ce7cf20904a17baf3934914dbf92":[5,2,12,58,16],
 "class_ogre_1_1_sub_item.html#abc10ce7cf20904a17baf3934914dbf92":[5,0,1,58,16],
+"class_ogre_1_1_sub_item.html#abc10ce7cf20904a17baf3934914dbf92":[5,2,12,58,16],
 "class_ogre_1_1_sub_item.html#abeed4a14f5d63264d9619c1fe507c018":[5,2,12,58,9],
 "class_ogre_1_1_sub_item.html#abeed4a14f5d63264d9619c1fe507c018":[5,0,1,58,9],
 "class_ogre_1_1_sub_item.html#ac511b8fdb7fc312f6d763fae3bbfa842":[5,0,1,58,75],
 "class_ogre_1_1_sub_item.html#ac511b8fdb7fc312f6d763fae3bbfa842":[5,2,12,58,75],
 "class_ogre_1_1_sub_item.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,58,45],
 "class_ogre_1_1_sub_item.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,58,45],
-"class_ogre_1_1_sub_item.html#ad1b31f45654ad2ba2ed0b80646fb6edd":[5,0,1,58,18],
 "class_ogre_1_1_sub_item.html#ad1b31f45654ad2ba2ed0b80646fb6edd":[5,2,12,58,18],
+"class_ogre_1_1_sub_item.html#ad1b31f45654ad2ba2ed0b80646fb6edd":[5,0,1,58,18],
 "class_ogre_1_1_sub_item.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,58,49],
 "class_ogre_1_1_sub_item.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,58,49],
-"class_ogre_1_1_sub_item.html#ad22289842e973a7a6b727c8cd32e9be9":[5,2,12,58,25],
 "class_ogre_1_1_sub_item.html#ad22289842e973a7a6b727c8cd32e9be9":[5,0,1,58,25],
+"class_ogre_1_1_sub_item.html#ad22289842e973a7a6b727c8cd32e9be9":[5,2,12,58,25],
 "class_ogre_1_1_sub_item.html#ad4d284fd219351af7f1ef9f9e9acab1e":[5,2,12,58,11],
 "class_ogre_1_1_sub_item.html#ad4d284fd219351af7f1ef9f9e9acab1e":[5,0,1,58,11],
 "class_ogre_1_1_sub_item.html#adce32528577d71b228692df906ecd17c":[5,0,1,58,52],
 "class_ogre_1_1_sub_item.html#adce32528577d71b228692df906ecd17c":[5,2,12,58,52],
-"class_ogre_1_1_sub_item.html#ade9262ffb93cbaf4460a44a78c49c12e":[5,0,1,58,8],
 "class_ogre_1_1_sub_item.html#ade9262ffb93cbaf4460a44a78c49c12e":[5,2,12,58,8],
+"class_ogre_1_1_sub_item.html#ade9262ffb93cbaf4460a44a78c49c12e":[5,0,1,58,8],
 "class_ogre_1_1_sub_item.html#adf2a2570b7d6c5dbdb80d8f98e620cbd":[5,2,12,58,63],
 "class_ogre_1_1_sub_item.html#adf2a2570b7d6c5dbdb80d8f98e620cbd":[5,0,1,58,63],
-"class_ogre_1_1_sub_item.html#ae53cff42a16304f582ef83ad3017d614":[5,0,1,58,69],
 "class_ogre_1_1_sub_item.html#ae53cff42a16304f582ef83ad3017d614":[5,2,12,58,69],
+"class_ogre_1_1_sub_item.html#ae53cff42a16304f582ef83ad3017d614":[5,0,1,58,69],
 "class_ogre_1_1_sub_item.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,58,53],
 "class_ogre_1_1_sub_item.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,58,53],
-"class_ogre_1_1_sub_item.html#af0d2463cff17fd4fbfb10c21ee0b8a0f":[5,2,12,58,43],
 "class_ogre_1_1_sub_item.html#af0d2463cff17fd4fbfb10c21ee0b8a0f":[5,0,1,58,43],
+"class_ogre_1_1_sub_item.html#af0d2463cff17fd4fbfb10c21ee0b8a0f":[5,2,12,58,43],
 "class_ogre_1_1_sub_item.html#af630e6230261ecca2ecbfcf0b0ee9ce9":[5,0,1,58,33],
 "class_ogre_1_1_sub_item.html#af630e6230261ecca2ecbfcf0b0ee9ce9":[5,2,12,58,33],
 "class_ogre_1_1_sub_item.html#af85238872bb197dea36acf21a578ecec":[5,0,1,58,39],
 "class_ogre_1_1_sub_item.html#af85238872bb197dea36acf21a578ecec":[5,2,12,58,39],
 "class_ogre_1_1_sub_item.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,0,1,58,55],
 "class_ogre_1_1_sub_item.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,2,12,58,55],
-"class_ogre_1_1_sub_item.html#affce28947124dd4573fb224a975fdce9":[5,0,1,58,27],
 "class_ogre_1_1_sub_item.html#affce28947124dd4573fb224a975fdce9":[5,2,12,58,27],
+"class_ogre_1_1_sub_item.html#affce28947124dd4573fb224a975fdce9":[5,0,1,58,27],
 "class_ogre_1_1_sub_mesh.html":[5,2,11,125],
 "class_ogre_1_1_sub_mesh.html#a08d3d4d7b7500f255c0836f34fd9fc2c":[5,2,11,125,18],
 "class_ogre_1_1_sub_mesh.html#a09a8bc953f8068f23c1c891785f8a6d8":[5,2,11,125,13],
@@ -247,7 +249,5 @@ var NAVTREEINDEX222 =
 "class_ogre_1_1_sub_string_ref.html#a673204912aa84ac98f6c51ad2ee06826":[5,2,11,126,16],
 "class_ogre_1_1_sub_string_ref.html#a6eda6d376867029dafce16a7b429b7bc":[5,2,11,126,12],
 "class_ogre_1_1_sub_string_ref.html#a8cb242b287692fed11a9a6e1196969f0":[5,2,11,126,0],
-"class_ogre_1_1_sub_string_ref.html#aab1fc62b46f8b14bf95c6e3e9b3589de":[5,2,11,126,7],
-"class_ogre_1_1_sub_string_ref.html#aae3687aec1c11fc9eac6510a893fec13":[5,2,11,126,1],
-"class_ogre_1_1_sub_string_ref.html#ab211c9b6bf294b979da70647a25cf15a":[5,2,11,126,3]
+"class_ogre_1_1_sub_string_ref.html#aab1fc62b46f8b14bf95c6e3e9b3589de":[5,2,11,126,7]
 };
