@@ -1,5 +1,7 @@
 var NAVTREEINDEX228 =
 {
+"class_ogre_1_1_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[5,2,11,127,45],
+"class_ogre_1_1_texture.html#ac93f17feff099035542be8b22f890417":[5,2,11,127,30],
 "class_ogre_1_1_texture.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,11,127,68],
 "class_ogre_1_1_texture.html#acce55ed43f888d8c4c5ed5c5aaf9d1db":[5,2,11,127,43],
 "class_ogre_1_1_texture.html#accfa5467ab8ccfc5920ec64101f8f532":[5,2,11,127,22],
@@ -24,12 +26,12 @@ var NAVTREEINDEX228 =
 "class_ogre_1_1_texture.html#afefa465095dd97cf22d0a43531171b51":[5,2,11,127,28],
 "class_ogre_1_1_texture_animation_controller_value.html":[7,0,0,960],
 "class_ogre_1_1_texture_animation_controller_value.html":[6,0,0,987],
-"class_ogre_1_1_texture_animation_controller_value.html#a1937d9d03d7abb3b071d23bf9b2221d5":[6,0,0,987,1],
 "class_ogre_1_1_texture_animation_controller_value.html#a1937d9d03d7abb3b071d23bf9b2221d5":[7,0,0,960,1],
-"class_ogre_1_1_texture_animation_controller_value.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,960,4],
+"class_ogre_1_1_texture_animation_controller_value.html#a1937d9d03d7abb3b071d23bf9b2221d5":[6,0,0,987,1],
 "class_ogre_1_1_texture_animation_controller_value.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,987,4],
-"class_ogre_1_1_texture_animation_controller_value.html#a362f9f548276119b41c049363549dcee":[7,0,0,960,0],
+"class_ogre_1_1_texture_animation_controller_value.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,960,4],
 "class_ogre_1_1_texture_animation_controller_value.html#a362f9f548276119b41c049363549dcee":[6,0,0,987,0],
+"class_ogre_1_1_texture_animation_controller_value.html#a362f9f548276119b41c049363549dcee":[7,0,0,960,0],
 "class_ogre_1_1_texture_animation_controller_value.html#a3670adb6239bacb6a7820282ad10cca7":[6,0,0,987,12],
 "class_ogre_1_1_texture_animation_controller_value.html#a3670adb6239bacb6a7820282ad10cca7":[7,0,0,960,12],
 "class_ogre_1_1_texture_animation_controller_value.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,987,6],
@@ -38,26 +40,26 @@ var NAVTREEINDEX228 =
 "class_ogre_1_1_texture_animation_controller_value.html#a5e8a9476f62917711643d64f1f073011":[7,0,0,960,13],
 "class_ogre_1_1_texture_animation_controller_value.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,960,9],
 "class_ogre_1_1_texture_animation_controller_value.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,987,9],
-"class_ogre_1_1_texture_animation_controller_value.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,960,2],
 "class_ogre_1_1_texture_animation_controller_value.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,987,2],
+"class_ogre_1_1_texture_animation_controller_value.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,960,2],
 "class_ogre_1_1_texture_animation_controller_value.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,960,5],
 "class_ogre_1_1_texture_animation_controller_value.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,987,5],
-"class_ogre_1_1_texture_animation_controller_value.html#a97de25f53317a5b1be4f1b557f92d9e4":[6,0,0,987,15],
 "class_ogre_1_1_texture_animation_controller_value.html#a97de25f53317a5b1be4f1b557f92d9e4":[7,0,0,960,15],
-"class_ogre_1_1_texture_animation_controller_value.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,960,8],
+"class_ogre_1_1_texture_animation_controller_value.html#a97de25f53317a5b1be4f1b557f92d9e4":[6,0,0,987,15],
 "class_ogre_1_1_texture_animation_controller_value.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,987,8],
-"class_ogre_1_1_texture_animation_controller_value.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,960,3],
+"class_ogre_1_1_texture_animation_controller_value.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,960,8],
 "class_ogre_1_1_texture_animation_controller_value.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,987,3],
-"class_ogre_1_1_texture_animation_controller_value.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,987,7],
+"class_ogre_1_1_texture_animation_controller_value.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,960,3],
 "class_ogre_1_1_texture_animation_controller_value.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,960,7],
-"class_ogre_1_1_texture_animation_controller_value.html#adce32528577d71b228692df906ecd17c":[6,0,0,987,10],
+"class_ogre_1_1_texture_animation_controller_value.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,987,7],
 "class_ogre_1_1_texture_animation_controller_value.html#adce32528577d71b228692df906ecd17c":[7,0,0,960,10],
-"class_ogre_1_1_texture_animation_controller_value.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,987,11],
+"class_ogre_1_1_texture_animation_controller_value.html#adce32528577d71b228692df906ecd17c":[6,0,0,987,10],
 "class_ogre_1_1_texture_animation_controller_value.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,960,11],
+"class_ogre_1_1_texture_animation_controller_value.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,987,11],
 "class_ogre_1_1_texture_animation_controller_value.html#af33179c10f55daaa69cf95522757d26d":[7,0,0,960,14],
 "class_ogre_1_1_texture_animation_controller_value.html#af33179c10f55daaa69cf95522757d26d":[6,0,0,987,14],
-"class_ogre_1_1_texture_animation_controller_value.html#af4c78ad512914d325008c4201f4f752b":[7,0,0,960,16],
 "class_ogre_1_1_texture_animation_controller_value.html#af4c78ad512914d325008c4201f4f752b":[6,0,0,987,16],
+"class_ogre_1_1_texture_animation_controller_value.html#af4c78ad512914d325008c4201f4f752b":[7,0,0,960,16],
 "class_ogre_1_1_texture_definition_base.html":[5,2,1,52],
 "class_ogre_1_1_texture_definition_base.html#a02ec073273bf07eb78122ddb2a4606f1":[5,2,1,52,11],
 "class_ogre_1_1_texture_definition_base.html#a0b832d936fde223d0e19076097e95054":[5,2,1,52,27],
@@ -143,64 +145,64 @@ var NAVTREEINDEX228 =
 "class_ogre_1_1_texture_definition_base_1_1_texture_definition.html#affe2a13b04aef3960decbf3b1b241c7c":[5,2,1,52,1,19],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html":[6,0,0,24,0],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html":[7,0,0,2,0],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,0,15],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,0,15],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,0,1],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,0,15],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a19c0b119d8138f02f25c13dc22a357d4":[6,0,0,24,0,1],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,0,1],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,2,0,7],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,0,7],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,0,3],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a1d8377be08adabfbf64235918e490f67":[6,0,0,24,0,3],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,0,3],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a2a99e859420c10607f648372d908343f":[7,0,0,2,0,4],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a2a99e859420c10607f648372d908343f":[6,0,0,24,0,4],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,0,9],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,2,0,9],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,0,12],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,0,9],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,0,12],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,0,12],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,0,5],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,24,0,5],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,0,8],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,0,8],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#aa0b132d6786adbf030ae46d185c5be02":[6,0,0,24,0,0],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,0,8],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#aa0b132d6786adbf030ae46d185c5be02":[7,0,0,2,0,0],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#aa0b132d6786adbf030ae46d185c5be02":[6,0,0,24,0,0],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,0,11],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,24,0,11],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,0,6],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,2,0,6],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,0,6],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,0,10],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,24,0,10],
-"class_ogre_1_1_texture_filter_1_1_filter_base.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,0,13],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#adce32528577d71b228692df906ecd17c":[6,0,0,24,0,13],
+"class_ogre_1_1_texture_filter_1_1_filter_base.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,0,13],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,24,0,14],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,0,14],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#af7b658ad3dd698ff5c59575d18bae278":[7,0,0,2,0,2],
 "class_ogre_1_1_texture_filter_1_1_filter_base.html#af7b658ad3dd698ff5c59575d18bae278":[6,0,0,24,0,2],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html":[7,0,0,2,1],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html":[6,0,0,24,1],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,1,15],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,1,15],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,1,15],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,1,7],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,2,1,7],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[6,0,0,24,1,3],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,1,3],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[6,0,0,24,1,3],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a2a99e859420c10607f648372d908343f":[6,0,0,24,1,4],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a2a99e859420c10607f648372d908343f":[7,0,0,2,1,4],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,1,9],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,2,1,9],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,1,9],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,1,12],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,1,12],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a6f93b5d571d91c00586be8e3abb8d4c7":[7,0,0,2,1,1],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a6f93b5d571d91c00586be8e3abb8d4c7":[6,0,0,24,1,1],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,1,5],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,24,1,5],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a91003a67da6e06bc7b7f8f9d103f35f3":[6,0,0,24,1,0],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,1,5],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a91003a67da6e06bc7b7f8f9d103f35f3":[7,0,0,2,1,0],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,1,8],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a91003a67da6e06bc7b7f8f9d103f35f3":[6,0,0,24,1,0],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,1,8],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,1,11],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,1,8],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,24,1,11],
-"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ac7f9d8c4ac1ec6006fa88995e47fe538":[6,0,0,24,1,2],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,1,11],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ac7f9d8c4ac1ec6006fa88995e47fe538":[7,0,0,2,1,2],
+"class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ac7f9d8c4ac1ec6006fa88995e47fe538":[6,0,0,24,1,2],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,2,1,6],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,1,6],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,1,10],
@@ -209,14 +211,14 @@ var NAVTREEINDEX228 =
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,1,13],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,1,14],
 "class_ogre_1_1_texture_filter_1_1_generate_hw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,24,1,14],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html":[7,0,0,2,2],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html":[6,0,0,24,2],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,2,15],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html":[7,0,0,2,2],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,2,15],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,2,0],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,2,15],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a19c0b119d8138f02f25c13dc22a357d4":[6,0,0,24,2,0],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,2,7],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,2,0],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,2,2,7],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,2,7],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[7,0,0,2,2,2],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a1d8377be08adabfbf64235918e490f67":[6,0,0,24,2,2],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a2a99e859420c10607f648372d908343f":[7,0,0,2,2,3],
@@ -225,29 +227,27 @@ var NAVTREEINDEX228 =
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a48ad2345ced0892a122118db87b918cd":[6,0,0,24,2,1],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,24,2,9],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,2,2,9],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,2,12],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,24,2,12],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,2,5],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,2,2,12],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,24,2,5],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,2,8],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,2,2,5],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,24,2,8],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,2,2,8],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,2,2,11],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,24,2,11],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,2,6],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,2,2,6],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ace721c5339ef577ca1c896b8798ee847":[7,0,0,2,2,4],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,24,2,6],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ace721c5339ef577ca1c896b8798ee847":[6,0,0,24,2,4],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ace721c5339ef577ca1c896b8798ee847":[7,0,0,2,2,4],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,2,2,10],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,24,2,10],
-"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,2,13],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#adce32528577d71b228692df906ecd17c":[6,0,0,24,2,13],
+"class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#adce32528577d71b228692df906ecd17c":[7,0,0,2,2,13],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,24,2,14],
 "class_ogre_1_1_texture_filter_1_1_generate_sw_mipmaps.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,2,2,14],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html":[7,0,0,2,3],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html":[6,0,0,24,3],
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html":[7,0,0,2,3],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[7,0,0,2,3,15],
 "class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a037eeaf32c0d8df71ba2f8ea4f4cbc75":[6,0,0,24,3,15],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a19c0b119d8138f02f25c13dc22a357d4":[7,0,0,2,3,0],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a19c0b119d8138f02f25c13dc22a357d4":[6,0,0,24,3,0],
-"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,24,3,7]
+"class_ogre_1_1_texture_filter_1_1_leave_channel_r.html#a19c0b119d8138f02f25c13dc22a357d4":[6,0,0,24,3,0]
 };
