@@ -1,5 +1,7 @@
 var NAVTREEINDEX230 =
 {
+"class_ogre_1_1_texture_gpu_manager.html#a763c9420839cf914f7a5c1901c53539b":[5,2,11,130,71],
+"class_ogre_1_1_texture_gpu_manager.html#a7cc799aa12f7b03c686cec13d09d9c0b":[5,2,11,130,7],
 "class_ogre_1_1_texture_gpu_manager.html#a7dc898578da3113affb78ed60f209b71":[5,2,11,130,32],
 "class_ogre_1_1_texture_gpu_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,11,130,55],
 "class_ogre_1_1_texture_gpu_manager.html#a841f10a656bbd24ed92b87f616e33f74":[5,2,11,130,33],
@@ -247,7 +249,5 @@ var NAVTREEINDEX230 =
 "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626addf3dd2bc4eeabca2968c71600c347aa":[5,2,5,20,7,2],
 "class_ogre_1_1_texture_unit_state.html#a717b14961a636b3a18b8ab3dcef61626ae6f4dff5b324b7aa28253c37702a5131":[5,2,5,20,7,1],
 "class_ogre_1_1_texture_unit_state.html#a719be065c5457565e744410f3ec16a3f":[5,2,5,20,23],
-"class_ogre_1_1_texture_unit_state.html#a71b18f9c8f0bcfc7324b5ebbcee40ae3":[5,2,5,20,82],
-"class_ogre_1_1_texture_unit_state.html#a72a88b1cf11053da98fa25f98689931e":[5,2,5,20,4],
-"class_ogre_1_1_texture_unit_state.html#a72a88b1cf11053da98fa25f98689931ea3983cce37fbce61c118d202278166be9":[5,2,5,20,4,2]
+"class_ogre_1_1_texture_unit_state.html#a71b18f9c8f0bcfc7324b5ebbcee40ae3":[5,2,5,20,82]
 };
