@@ -1,8 +1,10 @@
 var NAVTREEINDEX234 =
 {
+"class_ogre_1_1_vct_image_voxelizer.html#a9300b4fbb95831c0cd522425feb4ec08":[6,0,0,1022,14],
+"class_ogre_1_1_vct_image_voxelizer.html#a9e9d6a701188ebad524e9d77f066d871":[6,0,0,1022,4],
 "class_ogre_1_1_vct_image_voxelizer.html#a9e9d6a701188ebad524e9d77f066d871":[7,0,0,995,4],
-"class_ogre_1_1_vct_image_voxelizer.html#aa48b31bd0e72742be0f30776c6bbb723":[6,0,0,1022,5],
 "class_ogre_1_1_vct_image_voxelizer.html#aa48b31bd0e72742be0f30776c6bbb723":[7,0,0,995,5],
+"class_ogre_1_1_vct_image_voxelizer.html#aa48b31bd0e72742be0f30776c6bbb723":[6,0,0,1022,5],
 "class_ogre_1_1_vct_image_voxelizer.html#aa9fb146b475e13fd80f1b5e8a4beb00a":[6,0,0,1022,18],
 "class_ogre_1_1_vct_image_voxelizer.html#aa9fb146b475e13fd80f1b5e8a4beb00a":[7,0,0,995,18],
 "class_ogre_1_1_vct_image_voxelizer.html#aaafa872fc1489d94c6b86e26acfa1279":[6,0,0,1022,16],
@@ -11,20 +13,20 @@ var NAVTREEINDEX234 =
 "class_ogre_1_1_vct_image_voxelizer.html#aae99ad29d73eba95d315a27120692496":[7,0,0,995,23],
 "class_ogre_1_1_vct_image_voxelizer.html#ab152c8f646a835c2f88585ad4fe0413a":[7,0,0,995,13],
 "class_ogre_1_1_vct_image_voxelizer.html#ab152c8f646a835c2f88585ad4fe0413a":[6,0,0,1022,13],
-"class_ogre_1_1_vct_image_voxelizer.html#ac67b1811288e24c859d763ca76fc382b":[7,0,0,995,24],
 "class_ogre_1_1_vct_image_voxelizer.html#ac67b1811288e24c859d763ca76fc382b":[6,0,0,1022,24],
+"class_ogre_1_1_vct_image_voxelizer.html#ac67b1811288e24c859d763ca76fc382b":[7,0,0,995,24],
 "class_ogre_1_1_vct_image_voxelizer.html#acec9f231f99329be140217bf4b56902b":[6,0,0,1022,1],
 "class_ogre_1_1_vct_image_voxelizer.html#acec9f231f99329be140217bf4b56902b":[7,0,0,995,1],
 "class_ogre_1_1_vct_image_voxelizer.html#adf2b5318f28edb0e7e0d102abb4ea200":[7,0,0,995,3],
 "class_ogre_1_1_vct_image_voxelizer.html#adf2b5318f28edb0e7e0d102abb4ea200":[6,0,0,1022,3],
-"class_ogre_1_1_vct_image_voxelizer.html#ae1dd87bb0f9954ce9f34dbc716cdda61":[6,0,0,1022,11],
 "class_ogre_1_1_vct_image_voxelizer.html#ae1dd87bb0f9954ce9f34dbc716cdda61":[7,0,0,995,11],
+"class_ogre_1_1_vct_image_voxelizer.html#ae1dd87bb0f9954ce9f34dbc716cdda61":[6,0,0,1022,11],
 "class_ogre_1_1_vct_image_voxelizer.html#aec43c2bc20b2e6635eaf3d341c8a94f5":[7,0,0,995,20],
 "class_ogre_1_1_vct_image_voxelizer.html#aec43c2bc20b2e6635eaf3d341c8a94f5":[6,0,0,1022,20],
 "class_ogre_1_1_vct_image_voxelizer.html#af5ef4dbfe33896567d0400b06769b090":[6,0,0,1022,2],
 "class_ogre_1_1_vct_image_voxelizer.html#af5ef4dbfe33896567d0400b06769b090":[7,0,0,995,2],
-"class_ogre_1_1_vct_image_voxelizer.html#af8b649bc09c0bfb2bc200bba692f0f89":[6,0,0,1022,26],
 "class_ogre_1_1_vct_image_voxelizer.html#af8b649bc09c0bfb2bc200bba692f0f89":[7,0,0,995,26],
+"class_ogre_1_1_vct_image_voxelizer.html#af8b649bc09c0bfb2bc200bba692f0f89":[6,0,0,1022,26],
 "class_ogre_1_1_vct_image_voxelizer.html#af9a1cd11f34676b4ef13f3254cbbea3c":[7,0,0,995,10],
 "class_ogre_1_1_vct_image_voxelizer.html#af9a1cd11f34676b4ef13f3254cbbea3c":[6,0,0,1022,10],
 "class_ogre_1_1_vct_image_voxelizer.html#afc7e7be68b57ea410b4cb57ec7ddc80b":[7,0,0,995,17],
@@ -33,8 +35,8 @@ var NAVTREEINDEX234 =
 "class_ogre_1_1_vct_image_voxelizer.html#aff65435f0724cfd63779d474a6d45520":[6,0,0,1022,12],
 "class_ogre_1_1_vct_lighting.html":[6,0,0,1023],
 "class_ogre_1_1_vct_lighting.html":[7,0,0,996],
-"class_ogre_1_1_vct_lighting.html#a01276e4d0e9277fcdeac8deee196fbf9":[7,0,0,996,25],
 "class_ogre_1_1_vct_lighting.html#a01276e4d0e9277fcdeac8deee196fbf9":[6,0,0,1023,25],
+"class_ogre_1_1_vct_lighting.html#a01276e4d0e9277fcdeac8deee196fbf9":[7,0,0,996,25],
 "class_ogre_1_1_vct_lighting.html#a03265d0ed16c63b85e1712b17479e6ec":[7,0,0,996,17],
 "class_ogre_1_1_vct_lighting.html#a03265d0ed16c63b85e1712b17479e6ec":[6,0,0,1023,17],
 "class_ogre_1_1_vct_lighting.html#a07ccd81156c405c58951d12eb105fa1c":[6,0,0,1023,5],
@@ -49,46 +51,46 @@ var NAVTREEINDEX234 =
 "class_ogre_1_1_vct_lighting.html#a28d80d34c961bcefd21614e4541805d0":[6,0,0,1023,28],
 "class_ogre_1_1_vct_lighting.html#a43dba41de2fb7e29abc3e06c1b286799":[6,0,0,1023,33],
 "class_ogre_1_1_vct_lighting.html#a43dba41de2fb7e29abc3e06c1b286799":[7,0,0,996,33],
-"class_ogre_1_1_vct_lighting.html#a47f95e656a09ffdb90066b38478ec03c":[6,0,0,1023,30],
 "class_ogre_1_1_vct_lighting.html#a47f95e656a09ffdb90066b38478ec03c":[7,0,0,996,30],
+"class_ogre_1_1_vct_lighting.html#a47f95e656a09ffdb90066b38478ec03c":[6,0,0,1023,30],
 "class_ogre_1_1_vct_lighting.html#a49749a93a2281dfd3ecaaa4a84940399":[7,0,0,996,7],
 "class_ogre_1_1_vct_lighting.html#a49749a93a2281dfd3ecaaa4a84940399":[6,0,0,1023,7],
-"class_ogre_1_1_vct_lighting.html#a4d8ac1e10807d6f774238abe40dab2ff":[6,0,0,1023,2],
 "class_ogre_1_1_vct_lighting.html#a4d8ac1e10807d6f774238abe40dab2ff":[7,0,0,996,2],
-"class_ogre_1_1_vct_lighting.html#a4f8115c79c05f8a897764b5e23e2a817":[6,0,0,1023,31],
+"class_ogre_1_1_vct_lighting.html#a4d8ac1e10807d6f774238abe40dab2ff":[6,0,0,1023,2],
 "class_ogre_1_1_vct_lighting.html#a4f8115c79c05f8a897764b5e23e2a817":[7,0,0,996,31],
+"class_ogre_1_1_vct_lighting.html#a4f8115c79c05f8a897764b5e23e2a817":[6,0,0,1023,31],
 "class_ogre_1_1_vct_lighting.html#a4f91fa3f461e2abec6cb895b2804dad3":[7,0,0,996,8],
 "class_ogre_1_1_vct_lighting.html#a4f91fa3f461e2abec6cb895b2804dad3":[6,0,0,1023,8],
 "class_ogre_1_1_vct_lighting.html#a57e0523432c6e5133ff4fc251111a60e":[7,0,0,996,20],
 "class_ogre_1_1_vct_lighting.html#a57e0523432c6e5133ff4fc251111a60e":[6,0,0,1023,20],
-"class_ogre_1_1_vct_lighting.html#a59d64a287b1aae2ff2311d81b7bc754d":[6,0,0,1023,9],
 "class_ogre_1_1_vct_lighting.html#a59d64a287b1aae2ff2311d81b7bc754d":[7,0,0,996,9],
-"class_ogre_1_1_vct_lighting.html#a62ee72e8cb09c4943bdd95ff22babaa4":[7,0,0,996,4],
+"class_ogre_1_1_vct_lighting.html#a59d64a287b1aae2ff2311d81b7bc754d":[6,0,0,1023,9],
 "class_ogre_1_1_vct_lighting.html#a62ee72e8cb09c4943bdd95ff22babaa4":[6,0,0,1023,4],
+"class_ogre_1_1_vct_lighting.html#a62ee72e8cb09c4943bdd95ff22babaa4":[7,0,0,996,4],
 "class_ogre_1_1_vct_lighting.html#a710f534aa786508657dea5cedae0a46e":[6,0,0,1023,12],
 "class_ogre_1_1_vct_lighting.html#a710f534aa786508657dea5cedae0a46e":[7,0,0,996,12],
-"class_ogre_1_1_vct_lighting.html#a9a4950df6bf272853112fd88a5326f29":[6,0,0,1023,23],
 "class_ogre_1_1_vct_lighting.html#a9a4950df6bf272853112fd88a5326f29":[7,0,0,996,23],
+"class_ogre_1_1_vct_lighting.html#a9a4950df6bf272853112fd88a5326f29":[6,0,0,1023,23],
 "class_ogre_1_1_vct_lighting.html#a9b10546edc1b4f0c0ab833bdf7b3413e":[6,0,0,1023,3],
 "class_ogre_1_1_vct_lighting.html#a9b10546edc1b4f0c0ab833bdf7b3413e":[7,0,0,996,3],
-"class_ogre_1_1_vct_lighting.html#aa764dce11aae628b1efc414ce3ee74ba":[7,0,0,996,19],
 "class_ogre_1_1_vct_lighting.html#aa764dce11aae628b1efc414ce3ee74ba":[6,0,0,1023,19],
-"class_ogre_1_1_vct_lighting.html#aabade530fb0eb873e0d5f1d93618cd9c":[7,0,0,996,16],
+"class_ogre_1_1_vct_lighting.html#aa764dce11aae628b1efc414ce3ee74ba":[7,0,0,996,19],
 "class_ogre_1_1_vct_lighting.html#aabade530fb0eb873e0d5f1d93618cd9c":[6,0,0,1023,16],
+"class_ogre_1_1_vct_lighting.html#aabade530fb0eb873e0d5f1d93618cd9c":[7,0,0,996,16],
 "class_ogre_1_1_vct_lighting.html#ab152c8f646a835c2f88585ad4fe0413a":[6,0,0,1023,11],
 "class_ogre_1_1_vct_lighting.html#ab152c8f646a835c2f88585ad4fe0413a":[7,0,0,996,11],
 "class_ogre_1_1_vct_lighting.html#ab74daaae1515055e32973d2b5846e7d9":[6,0,0,1023,1],
 "class_ogre_1_1_vct_lighting.html#ab74daaae1515055e32973d2b5846e7d9":[7,0,0,996,1],
-"class_ogre_1_1_vct_lighting.html#abe0c843c456dc032983f1aebe56e7ac9":[6,0,0,1023,32],
 "class_ogre_1_1_vct_lighting.html#abe0c843c456dc032983f1aebe56e7ac9":[7,0,0,996,32],
+"class_ogre_1_1_vct_lighting.html#abe0c843c456dc032983f1aebe56e7ac9":[6,0,0,1023,32],
 "class_ogre_1_1_vct_lighting.html#abe3557846da87bde3fbac283bf94aff4":[6,0,0,1023,22],
 "class_ogre_1_1_vct_lighting.html#abe3557846da87bde3fbac283bf94aff4":[7,0,0,996,22],
-"class_ogre_1_1_vct_lighting.html#ac1f369e42029121504f471875b03c5ba":[6,0,0,1023,15],
 "class_ogre_1_1_vct_lighting.html#ac1f369e42029121504f471875b03c5ba":[7,0,0,996,15],
-"class_ogre_1_1_vct_lighting.html#ac4b76e54bd1ce01fdaf51076fe928fa7":[7,0,0,996,10],
+"class_ogre_1_1_vct_lighting.html#ac1f369e42029121504f471875b03c5ba":[6,0,0,1023,15],
 "class_ogre_1_1_vct_lighting.html#ac4b76e54bd1ce01fdaf51076fe928fa7":[6,0,0,1023,10],
-"class_ogre_1_1_vct_lighting.html#ad517f0a122e69f0be376d9502a5b51a4":[6,0,0,1023,34],
+"class_ogre_1_1_vct_lighting.html#ac4b76e54bd1ce01fdaf51076fe928fa7":[7,0,0,996,10],
 "class_ogre_1_1_vct_lighting.html#ad517f0a122e69f0be376d9502a5b51a4":[7,0,0,996,34],
+"class_ogre_1_1_vct_lighting.html#ad517f0a122e69f0be376d9502a5b51a4":[6,0,0,1023,34],
 "class_ogre_1_1_vct_lighting.html#ad5548f8c921aa7b87c1cb506809bc1be":[7,0,0,996,18],
 "class_ogre_1_1_vct_lighting.html#ad5548f8c921aa7b87c1cb506809bc1be":[6,0,0,1023,18],
 "class_ogre_1_1_vct_lighting.html#ad79c3c211dc25670bf35cf08ca346554":[6,0,0,1023,6],
@@ -99,20 +101,20 @@ var NAVTREEINDEX234 =
 "class_ogre_1_1_vct_lighting.html#af3f9f563af82aae206a12f850d7c347e":[6,0,0,1023,26],
 "class_ogre_1_1_vct_lighting.html#afaa0b37a3b16f8826d4b8671898750df":[6,0,0,1023,14],
 "class_ogre_1_1_vct_lighting.html#afaa0b37a3b16f8826d4b8671898750df":[7,0,0,996,14],
-"class_ogre_1_1_vct_lighting.html#afde888d085cf39fe3ce81e3f7952c243":[7,0,0,996,24],
 "class_ogre_1_1_vct_lighting.html#afde888d085cf39fe3ce81e3f7952c243":[6,0,0,1023,24],
-"class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7d":[6,0,0,1023,0],
+"class_ogre_1_1_vct_lighting.html#afde888d085cf39fe3ce81e3f7952c243":[7,0,0,996,24],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7d":[7,0,0,996,0],
-"class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da058c0eecb9f3f188fccc4d0018bf337b":[7,0,0,996,0,2],
+"class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7d":[6,0,0,1023,0],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da058c0eecb9f3f188fccc4d0018bf337b":[6,0,0,1023,0,2],
+"class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da058c0eecb9f3f188fccc4d0018bf337b":[7,0,0,996,0,2],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da218a4243be85ec9c989b777119d5ff47":[6,0,0,1023,0,6],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da218a4243be85ec9c989b777119d5ff47":[7,0,0,996,0,6],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da2b732a317de0915527e291485ca42e82":[6,0,0,1023,0,0],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da2b732a317de0915527e291485ca42e82":[7,0,0,996,0,0],
-"class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da4f559ca1853a24a28b40caae1acda604":[7,0,0,996,0,7],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da4f559ca1853a24a28b40caae1acda604":[6,0,0,1023,0,7],
-"class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da55066351a26967068b944c2170e51af1":[6,0,0,1023,0,3],
+"class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da4f559ca1853a24a28b40caae1acda604":[7,0,0,996,0,7],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da55066351a26967068b944c2170e51af1":[7,0,0,996,0,3],
+"class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da55066351a26967068b944c2170e51af1":[6,0,0,1023,0,3],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da58fd07194714679ed3ba9857d7656f27":[7,0,0,996,0,1],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da58fd07194714679ed3ba9857d7656f27":[6,0,0,1023,0,1],
 "class_ogre_1_1_vct_lighting.html#afe11bd546cf7315f4526488e7078cc7da61729c4ae25807d6132d5bc46580ff3d":[6,0,0,1023,0,4],
@@ -133,121 +135,119 @@ var NAVTREEINDEX234 =
 "class_ogre_1_1_vct_material.html#a005cf94c454b6247ae39a6ae85759f2d":[6,0,0,1024,3],
 "class_ogre_1_1_vct_material.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[7,0,0,997,9],
 "class_ogre_1_1_vct_material.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[6,0,0,1024,9],
-"class_ogre_1_1_vct_material.html#a2da7912154d4308db7736e64b7d2ee3d":[7,0,0,997,6],
 "class_ogre_1_1_vct_material.html#a2da7912154d4308db7736e64b7d2ee3d":[6,0,0,1024,6],
+"class_ogre_1_1_vct_material.html#a2da7912154d4308db7736e64b7d2ee3d":[7,0,0,997,6],
 "class_ogre_1_1_vct_material.html#a4ef6fcf123f37dc7c6f49e05e09db068":[7,0,0,997,4],
 "class_ogre_1_1_vct_material.html#a4ef6fcf123f37dc7c6f49e05e09db068":[6,0,0,1024,4],
-"class_ogre_1_1_vct_material.html#a57e0523432c6e5133ff4fc251111a60e":[7,0,0,997,8],
 "class_ogre_1_1_vct_material.html#a57e0523432c6e5133ff4fc251111a60e":[6,0,0,1024,8],
-"class_ogre_1_1_vct_material.html#a5d673fc0669ae3c41af972725f5411ea":[7,0,0,997,2],
+"class_ogre_1_1_vct_material.html#a57e0523432c6e5133ff4fc251111a60e":[7,0,0,997,8],
 "class_ogre_1_1_vct_material.html#a5d673fc0669ae3c41af972725f5411ea":[6,0,0,1024,2],
+"class_ogre_1_1_vct_material.html#a5d673fc0669ae3c41af972725f5411ea":[7,0,0,997,2],
 "class_ogre_1_1_vct_material.html#aaef0bcb3269d43d7e4b687a8669a2fc0":[6,0,0,1024,1],
 "class_ogre_1_1_vct_material.html#aaef0bcb3269d43d7e4b687a8669a2fc0":[7,0,0,997,1],
-"class_ogre_1_1_vct_material.html#ab152c8f646a835c2f88585ad4fe0413a":[7,0,0,997,5],
 "class_ogre_1_1_vct_material.html#ab152c8f646a835c2f88585ad4fe0413a":[6,0,0,1024,5],
-"class_ogre_1_1_vct_material.html#ac1d874682cd4c2c753517922c8c97969":[7,0,0,997,7],
+"class_ogre_1_1_vct_material.html#ab152c8f646a835c2f88585ad4fe0413a":[7,0,0,997,5],
 "class_ogre_1_1_vct_material.html#ac1d874682cd4c2c753517922c8c97969":[6,0,0,1024,7],
-"class_ogre_1_1_vct_voxelizer.html":[7,0,0,998],
+"class_ogre_1_1_vct_material.html#ac1d874682cd4c2c753517922c8c97969":[7,0,0,997,7],
 "class_ogre_1_1_vct_voxelizer.html":[6,0,0,1025],
+"class_ogre_1_1_vct_voxelizer.html":[7,0,0,998],
 "class_ogre_1_1_vct_voxelizer.html#a0227ad7c237b72e7717d35df0039df0d":[6,0,0,1025,5],
 "class_ogre_1_1_vct_voxelizer.html#a0227ad7c237b72e7717d35df0039df0d":[7,0,0,998,5],
 "class_ogre_1_1_vct_voxelizer.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[6,0,0,1025,21],
 "class_ogre_1_1_vct_voxelizer.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[7,0,0,998,21],
-"class_ogre_1_1_vct_voxelizer.html#a0d399e3016b11ce9f42e727939e3f026":[6,0,0,1025,23],
 "class_ogre_1_1_vct_voxelizer.html#a0d399e3016b11ce9f42e727939e3f026":[7,0,0,998,23],
-"class_ogre_1_1_vct_voxelizer.html#a18749ebfd48fe4f3f92917d07e6898a9":[7,0,0,998,8],
+"class_ogre_1_1_vct_voxelizer.html#a0d399e3016b11ce9f42e727939e3f026":[6,0,0,1025,23],
 "class_ogre_1_1_vct_voxelizer.html#a18749ebfd48fe4f3f92917d07e6898a9":[6,0,0,1025,8],
-"class_ogre_1_1_vct_voxelizer.html#a2998d60ec6ee24f237052fa04c4465b5":[7,0,0,998,7],
+"class_ogre_1_1_vct_voxelizer.html#a18749ebfd48fe4f3f92917d07e6898a9":[7,0,0,998,8],
 "class_ogre_1_1_vct_voxelizer.html#a2998d60ec6ee24f237052fa04c4465b5":[6,0,0,1025,7],
-"class_ogre_1_1_vct_voxelizer.html#a376aa29cd29cddcbc3f7a860516bd09c":[6,0,0,1025,3],
+"class_ogre_1_1_vct_voxelizer.html#a2998d60ec6ee24f237052fa04c4465b5":[7,0,0,998,7],
 "class_ogre_1_1_vct_voxelizer.html#a376aa29cd29cddcbc3f7a860516bd09c":[7,0,0,998,3],
-"class_ogre_1_1_vct_voxelizer.html#a47eabebe58c2532c9115e9022b9d462d":[6,0,0,1025,26],
+"class_ogre_1_1_vct_voxelizer.html#a376aa29cd29cddcbc3f7a860516bd09c":[6,0,0,1025,3],
 "class_ogre_1_1_vct_voxelizer.html#a47eabebe58c2532c9115e9022b9d462d":[7,0,0,998,26],
+"class_ogre_1_1_vct_voxelizer.html#a47eabebe58c2532c9115e9022b9d462d":[6,0,0,1025,26],
 "class_ogre_1_1_vct_voxelizer.html#a57e0523432c6e5133ff4fc251111a60e":[7,0,0,998,20],
 "class_ogre_1_1_vct_voxelizer.html#a57e0523432c6e5133ff4fc251111a60e":[6,0,0,1025,20],
 "class_ogre_1_1_vct_voxelizer.html#a74224ea25b439cc81afc63746a31f3d0":[7,0,0,998,18],
 "class_ogre_1_1_vct_voxelizer.html#a74224ea25b439cc81afc63746a31f3d0":[6,0,0,1025,18],
 "class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9":[7,0,0,998,0],
 "class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9":[6,0,0,1025,0],
-"class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9a4121b680dcfb911290c619e178db860c":[7,0,0,998,0,2],
 "class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9a4121b680dcfb911290c619e178db860c":[6,0,0,1025,0,2],
+"class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9a4121b680dcfb911290c619e178db860c":[7,0,0,998,0,2],
 "class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9a52a37b012fb6f0a5d66d270e87a2f3c0":[7,0,0,998,0,0],
 "class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9a52a37b012fb6f0a5d66d270e87a2f3c0":[6,0,0,1025,0,0],
 "class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9a77aa9415bc2c0d2bae69c7eed3b758f1":[6,0,0,1025,0,1],
 "class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9a77aa9415bc2c0d2bae69c7eed3b758f1":[7,0,0,998,0,1],
-"class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9a95f7e42a500bed2bc953377d46852678":[6,0,0,1025,0,3],
 "class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9a95f7e42a500bed2bc953377d46852678":[7,0,0,998,0,3],
-"class_ogre_1_1_vct_voxelizer.html#a85aa512cdf979a2aecce8f363da5ed19":[7,0,0,998,14],
+"class_ogre_1_1_vct_voxelizer.html#a81d9aa7659e492c2e3c9fd08dca322c9a95f7e42a500bed2bc953377d46852678":[6,0,0,1025,0,3],
 "class_ogre_1_1_vct_voxelizer.html#a85aa512cdf979a2aecce8f363da5ed19":[6,0,0,1025,14],
-"class_ogre_1_1_vct_voxelizer.html#a9300b4fbb95831c0cd522425feb4ec08":[7,0,0,998,13],
+"class_ogre_1_1_vct_voxelizer.html#a85aa512cdf979a2aecce8f363da5ed19":[7,0,0,998,14],
 "class_ogre_1_1_vct_voxelizer.html#a9300b4fbb95831c0cd522425feb4ec08":[6,0,0,1025,13],
+"class_ogre_1_1_vct_voxelizer.html#a9300b4fbb95831c0cd522425feb4ec08":[7,0,0,998,13],
 "class_ogre_1_1_vct_voxelizer.html#a9fd9f54fc458e9ad3b7a95433f83ee27":[6,0,0,1025,22],
 "class_ogre_1_1_vct_voxelizer.html#a9fd9f54fc458e9ad3b7a95433f83ee27":[7,0,0,998,22],
-"class_ogre_1_1_vct_voxelizer.html#aa9fb146b475e13fd80f1b5e8a4beb00a":[6,0,0,1025,17],
 "class_ogre_1_1_vct_voxelizer.html#aa9fb146b475e13fd80f1b5e8a4beb00a":[7,0,0,998,17],
-"class_ogre_1_1_vct_voxelizer.html#aaafa872fc1489d94c6b86e26acfa1279":[7,0,0,998,15],
+"class_ogre_1_1_vct_voxelizer.html#aa9fb146b475e13fd80f1b5e8a4beb00a":[6,0,0,1025,17],
 "class_ogre_1_1_vct_voxelizer.html#aaafa872fc1489d94c6b86e26acfa1279":[6,0,0,1025,15],
-"class_ogre_1_1_vct_voxelizer.html#ab152c8f646a835c2f88585ad4fe0413a":[6,0,0,1025,12],
+"class_ogre_1_1_vct_voxelizer.html#aaafa872fc1489d94c6b86e26acfa1279":[7,0,0,998,15],
 "class_ogre_1_1_vct_voxelizer.html#ab152c8f646a835c2f88585ad4fe0413a":[7,0,0,998,12],
-"class_ogre_1_1_vct_voxelizer.html#ab9f124307f73b47e5df7c1bd583cec0f":[7,0,0,998,4],
+"class_ogre_1_1_vct_voxelizer.html#ab152c8f646a835c2f88585ad4fe0413a":[6,0,0,1025,12],
 "class_ogre_1_1_vct_voxelizer.html#ab9f124307f73b47e5df7c1bd583cec0f":[6,0,0,1025,4],
-"class_ogre_1_1_vct_voxelizer.html#ad6b6c6c4f01fddf9e648aee5fd964e3c":[6,0,0,1025,6],
+"class_ogre_1_1_vct_voxelizer.html#ab9f124307f73b47e5df7c1bd583cec0f":[7,0,0,998,4],
 "class_ogre_1_1_vct_voxelizer.html#ad6b6c6c4f01fddf9e648aee5fd964e3c":[7,0,0,998,6],
+"class_ogre_1_1_vct_voxelizer.html#ad6b6c6c4f01fddf9e648aee5fd964e3c":[6,0,0,1025,6],
 "class_ogre_1_1_vct_voxelizer.html#ae1dd87bb0f9954ce9f34dbc716cdda61":[7,0,0,998,10],
 "class_ogre_1_1_vct_voxelizer.html#ae1dd87bb0f9954ce9f34dbc716cdda61":[6,0,0,1025,10],
-"class_ogre_1_1_vct_voxelizer.html#ae5394248841ead3a58ca765b0a64ee9f":[6,0,0,1025,2],
 "class_ogre_1_1_vct_voxelizer.html#ae5394248841ead3a58ca765b0a64ee9f":[7,0,0,998,2],
+"class_ogre_1_1_vct_voxelizer.html#ae5394248841ead3a58ca765b0a64ee9f":[6,0,0,1025,2],
 "class_ogre_1_1_vct_voxelizer.html#aec43c2bc20b2e6635eaf3d341c8a94f5":[7,0,0,998,19],
 "class_ogre_1_1_vct_voxelizer.html#aec43c2bc20b2e6635eaf3d341c8a94f5":[6,0,0,1025,19],
 "class_ogre_1_1_vct_voxelizer.html#af30e2aff9ae2155aacb9552eee27b35b":[7,0,0,998,25],
 "class_ogre_1_1_vct_voxelizer.html#af30e2aff9ae2155aacb9552eee27b35b":[6,0,0,1025,25],
-"class_ogre_1_1_vct_voxelizer.html#af8b649bc09c0bfb2bc200bba692f0f89":[6,0,0,1025,24],
 "class_ogre_1_1_vct_voxelizer.html#af8b649bc09c0bfb2bc200bba692f0f89":[7,0,0,998,24],
-"class_ogre_1_1_vct_voxelizer.html#af9a1cd11f34676b4ef13f3254cbbea3c":[6,0,0,1025,9],
+"class_ogre_1_1_vct_voxelizer.html#af8b649bc09c0bfb2bc200bba692f0f89":[6,0,0,1025,24],
 "class_ogre_1_1_vct_voxelizer.html#af9a1cd11f34676b4ef13f3254cbbea3c":[7,0,0,998,9],
-"class_ogre_1_1_vct_voxelizer.html#afc7e7be68b57ea410b4cb57ec7ddc80b":[6,0,0,1025,16],
+"class_ogre_1_1_vct_voxelizer.html#af9a1cd11f34676b4ef13f3254cbbea3c":[6,0,0,1025,9],
 "class_ogre_1_1_vct_voxelizer.html#afc7e7be68b57ea410b4cb57ec7ddc80b":[7,0,0,998,16],
+"class_ogre_1_1_vct_voxelizer.html#afc7e7be68b57ea410b4cb57ec7ddc80b":[6,0,0,1025,16],
 "class_ogre_1_1_vct_voxelizer.html#afdb521793f3e2c05ea16520026a75f17":[7,0,0,998,1],
 "class_ogre_1_1_vct_voxelizer.html#afdb521793f3e2c05ea16520026a75f17":[6,0,0,1025,1],
-"class_ogre_1_1_vct_voxelizer.html#aff65435f0724cfd63779d474a6d45520":[6,0,0,1025,11],
 "class_ogre_1_1_vct_voxelizer.html#aff65435f0724cfd63779d474a6d45520":[7,0,0,998,11],
-"class_ogre_1_1_vct_voxelizer_source_base.html":[6,0,0,1026],
+"class_ogre_1_1_vct_voxelizer.html#aff65435f0724cfd63779d474a6d45520":[6,0,0,1025,11],
 "class_ogre_1_1_vct_voxelizer_source_base.html":[7,0,0,999],
+"class_ogre_1_1_vct_voxelizer_source_base.html":[6,0,0,1026],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[6,0,0,1026,16],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[7,0,0,999,16],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a18749ebfd48fe4f3f92917d07e6898a9":[6,0,0,1026,3],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a18749ebfd48fe4f3f92917d07e6898a9":[7,0,0,999,3],
-"class_ogre_1_1_vct_voxelizer_source_base.html#a57e0523432c6e5133ff4fc251111a60e":[7,0,0,999,15],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a57e0523432c6e5133ff4fc251111a60e":[6,0,0,1026,15],
+"class_ogre_1_1_vct_voxelizer_source_base.html#a57e0523432c6e5133ff4fc251111a60e":[7,0,0,999,15],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a74224ea25b439cc81afc63746a31f3d0":[6,0,0,1026,13],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a74224ea25b439cc81afc63746a31f3d0":[7,0,0,999,13],
-"class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9":[7,0,0,999,0],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9":[6,0,0,1026,0],
+"class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9":[7,0,0,999,0],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9a4121b680dcfb911290c619e178db860c":[6,0,0,1026,0,2],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9a4121b680dcfb911290c619e178db860c":[7,0,0,999,0,2],
-"class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9a52a37b012fb6f0a5d66d270e87a2f3c0":[6,0,0,1026,0,0],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9a52a37b012fb6f0a5d66d270e87a2f3c0":[7,0,0,999,0,0],
-"class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9a77aa9415bc2c0d2bae69c7eed3b758f1":[7,0,0,999,0,1],
+"class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9a52a37b012fb6f0a5d66d270e87a2f3c0":[6,0,0,1026,0,0],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9a77aa9415bc2c0d2bae69c7eed3b758f1":[6,0,0,1026,0,1],
+"class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9a77aa9415bc2c0d2bae69c7eed3b758f1":[7,0,0,999,0,1],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9a95f7e42a500bed2bc953377d46852678":[6,0,0,1026,0,3],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a81d9aa7659e492c2e3c9fd08dca322c9a95f7e42a500bed2bc953377d46852678":[7,0,0,999,0,3],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a85aa512cdf979a2aecce8f363da5ed19":[7,0,0,999,9],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a85aa512cdf979a2aecce8f363da5ed19":[6,0,0,1026,9],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a87402f1f1921e91a7e7d55bea62312d1":[7,0,0,999,1],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a87402f1f1921e91a7e7d55bea62312d1":[6,0,0,1026,1],
-"class_ogre_1_1_vct_voxelizer_source_base.html#a9300b4fbb95831c0cd522425feb4ec08":[6,0,0,1026,8],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a9300b4fbb95831c0cd522425feb4ec08":[7,0,0,999,8],
+"class_ogre_1_1_vct_voxelizer_source_base.html#a9300b4fbb95831c0cd522425feb4ec08":[6,0,0,1026,8],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a945082a4376a1ee5da69d19c06c3f3c9":[7,0,0,999,2],
 "class_ogre_1_1_vct_voxelizer_source_base.html#a945082a4376a1ee5da69d19c06c3f3c9":[6,0,0,1026,2],
 "class_ogre_1_1_vct_voxelizer_source_base.html#aa9fb146b475e13fd80f1b5e8a4beb00a":[7,0,0,999,12],
 "class_ogre_1_1_vct_voxelizer_source_base.html#aa9fb146b475e13fd80f1b5e8a4beb00a":[6,0,0,1026,12],
-"class_ogre_1_1_vct_voxelizer_source_base.html#aaafa872fc1489d94c6b86e26acfa1279":[7,0,0,999,10],
 "class_ogre_1_1_vct_voxelizer_source_base.html#aaafa872fc1489d94c6b86e26acfa1279":[6,0,0,1026,10],
+"class_ogre_1_1_vct_voxelizer_source_base.html#aaafa872fc1489d94c6b86e26acfa1279":[7,0,0,999,10],
 "class_ogre_1_1_vct_voxelizer_source_base.html#ab152c8f646a835c2f88585ad4fe0413a":[6,0,0,1026,7],
 "class_ogre_1_1_vct_voxelizer_source_base.html#ab152c8f646a835c2f88585ad4fe0413a":[7,0,0,999,7],
-"class_ogre_1_1_vct_voxelizer_source_base.html#ae1dd87bb0f9954ce9f34dbc716cdda61":[7,0,0,999,5],
 "class_ogre_1_1_vct_voxelizer_source_base.html#ae1dd87bb0f9954ce9f34dbc716cdda61":[6,0,0,1026,5],
-"class_ogre_1_1_vct_voxelizer_source_base.html#aec43c2bc20b2e6635eaf3d341c8a94f5":[7,0,0,999,14],
-"class_ogre_1_1_vct_voxelizer_source_base.html#aec43c2bc20b2e6635eaf3d341c8a94f5":[6,0,0,1026,14],
-"class_ogre_1_1_vct_voxelizer_source_base.html#af8b649bc09c0bfb2bc200bba692f0f89":[6,0,0,1026,17]
+"class_ogre_1_1_vct_voxelizer_source_base.html#ae1dd87bb0f9954ce9f34dbc716cdda61":[7,0,0,999,5],
+"class_ogre_1_1_vct_voxelizer_source_base.html#aec43c2bc20b2e6635eaf3d341c8a94f5":[6,0,0,1026,14]
 };
