@@ -1,156 +1,158 @@
 var NAVTREEINDEX241 =
 {
+"class_ogre_1_1_voxel_visualizer.html#afe1f2a1009e3f14f36e1bcc9b1b9557e":[7,0,0,1018,131],
+"class_ogre_1_1_voxel_visualizer.html#aff35a0dcf855331bdd0fe72fe0f66824":[7,0,0,1018,34],
 "class_ogre_1_1_voxel_visualizer.html#aff35a0dcf855331bdd0fe72fe0f66824":[6,0,0,1045,34],
-"class_ogre_1_1_voxel_visualizer.html#aff8dd8756aba9a9ecb276270e6614c96":[7,0,0,1018,57],
 "class_ogre_1_1_voxel_visualizer.html#aff8dd8756aba9a9ecb276270e6614c96":[6,0,0,1045,57],
-"class_ogre_1_1_voxelized_mesh_cache.html":[7,0,0,1016],
+"class_ogre_1_1_voxel_visualizer.html#aff8dd8756aba9a9ecb276270e6614c96":[7,0,0,1018,57],
 "class_ogre_1_1_voxelized_mesh_cache.html":[6,0,0,1043],
-"class_ogre_1_1_voxelized_mesh_cache.html#a3d50316ad6b2308b66438ce2477cb6dd":[6,0,0,1043,6],
+"class_ogre_1_1_voxelized_mesh_cache.html":[7,0,0,1016],
 "class_ogre_1_1_voxelized_mesh_cache.html#a3d50316ad6b2308b66438ce2477cb6dd":[7,0,0,1016,6],
-"class_ogre_1_1_voxelized_mesh_cache.html#a757a3a10741726c2393c1b8dd84236b8":[6,0,0,1043,1],
+"class_ogre_1_1_voxelized_mesh_cache.html#a3d50316ad6b2308b66438ce2477cb6dd":[6,0,0,1043,6],
 "class_ogre_1_1_voxelized_mesh_cache.html#a757a3a10741726c2393c1b8dd84236b8":[7,0,0,1016,1],
+"class_ogre_1_1_voxelized_mesh_cache.html#a757a3a10741726c2393c1b8dd84236b8":[6,0,0,1043,1],
 "class_ogre_1_1_voxelized_mesh_cache.html#aba3bb68c27edb4934c2b1aa756e5574e":[6,0,0,1043,2],
 "class_ogre_1_1_voxelized_mesh_cache.html#aba3bb68c27edb4934c2b1aa756e5574e":[7,0,0,1016,2],
-"class_ogre_1_1_voxelized_mesh_cache.html#ac6309296e607d50d08b5460583fa1852":[6,0,0,1043,4],
 "class_ogre_1_1_voxelized_mesh_cache.html#ac6309296e607d50d08b5460583fa1852":[7,0,0,1016,4],
+"class_ogre_1_1_voxelized_mesh_cache.html#ac6309296e607d50d08b5460583fa1852":[6,0,0,1043,4],
 "class_ogre_1_1_voxelized_mesh_cache.html#ad71b7ea32e95aa9cdcafc2ed276a3def":[6,0,0,1043,3],
 "class_ogre_1_1_voxelized_mesh_cache.html#ad71b7ea32e95aa9cdcafc2ed276a3def":[7,0,0,1016,3],
 "class_ogre_1_1_voxelized_mesh_cache.html#ad7b6e52800896fef7f4af2f669ee7988":[7,0,0,1016,5],
 "class_ogre_1_1_voxelized_mesh_cache.html#ad7b6e52800896fef7f4af2f669ee7988":[6,0,0,1043,5],
-"class_ogre_1_1_vulkan_android_support.html":[7,0,0,1020],
 "class_ogre_1_1_vulkan_android_support.html":[6,0,0,1047],
+"class_ogre_1_1_vulkan_android_support.html":[7,0,0,1020],
 "class_ogre_1_1_vulkan_android_support.html#a12d5ee1fcb2c72c8e3553c45daea8971":[6,0,0,1047,1],
 "class_ogre_1_1_vulkan_android_support.html#a12d5ee1fcb2c72c8e3553c45daea8971":[7,0,0,1020,1],
 "class_ogre_1_1_vulkan_android_support.html#a36fba22aab78a8edf13890ca94622f21":[6,0,0,1047,7],
 "class_ogre_1_1_vulkan_android_support.html#a36fba22aab78a8edf13890ca94622f21":[7,0,0,1020,7],
-"class_ogre_1_1_vulkan_android_support.html#a436a6ed3d18e3122a6165b476ff72c97":[7,0,0,1020,4],
 "class_ogre_1_1_vulkan_android_support.html#a436a6ed3d18e3122a6165b476ff72c97":[6,0,0,1047,4],
-"class_ogre_1_1_vulkan_android_support.html#a44407107990c241cc13cc357d836ff8c":[7,0,0,1020,0],
+"class_ogre_1_1_vulkan_android_support.html#a436a6ed3d18e3122a6165b476ff72c97":[7,0,0,1020,4],
 "class_ogre_1_1_vulkan_android_support.html#a44407107990c241cc13cc357d836ff8c":[6,0,0,1047,0],
+"class_ogre_1_1_vulkan_android_support.html#a44407107990c241cc13cc357d836ff8c":[7,0,0,1020,0],
 "class_ogre_1_1_vulkan_android_support.html#a822908ab3850c50828dc4e02da37152c":[7,0,0,1020,8],
 "class_ogre_1_1_vulkan_android_support.html#a822908ab3850c50828dc4e02da37152c":[6,0,0,1047,8],
 "class_ogre_1_1_vulkan_android_support.html#a86746d239ebe765693db1f1b46f55fd7":[6,0,0,1047,10],
 "class_ogre_1_1_vulkan_android_support.html#a86746d239ebe765693db1f1b46f55fd7":[7,0,0,1020,10],
-"class_ogre_1_1_vulkan_android_support.html#a86bef7a792e9c3450da2fd697ff766c4":[6,0,0,1047,6],
 "class_ogre_1_1_vulkan_android_support.html#a86bef7a792e9c3450da2fd697ff766c4":[7,0,0,1020,6],
-"class_ogre_1_1_vulkan_android_support.html#a97b72f6fcab0c9513c6c2b8aace60476":[6,0,0,1047,2],
+"class_ogre_1_1_vulkan_android_support.html#a86bef7a792e9c3450da2fd697ff766c4":[6,0,0,1047,6],
 "class_ogre_1_1_vulkan_android_support.html#a97b72f6fcab0c9513c6c2b8aace60476":[7,0,0,1020,2],
+"class_ogre_1_1_vulkan_android_support.html#a97b72f6fcab0c9513c6c2b8aace60476":[6,0,0,1047,2],
 "class_ogre_1_1_vulkan_android_support.html#abce0d5d7a77ce2824d5186dfe303d976":[7,0,0,1020,9],
 "class_ogre_1_1_vulkan_android_support.html#abce0d5d7a77ce2824d5186dfe303d976":[6,0,0,1047,9],
-"class_ogre_1_1_vulkan_android_support.html#ad828542a84b6f9bcb4dbf3eff836d81d":[6,0,0,1047,5],
 "class_ogre_1_1_vulkan_android_support.html#ad828542a84b6f9bcb4dbf3eff836d81d":[7,0,0,1020,5],
-"class_ogre_1_1_vulkan_android_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9":[6,0,0,1047,3],
+"class_ogre_1_1_vulkan_android_support.html#ad828542a84b6f9bcb4dbf3eff836d81d":[6,0,0,1047,5],
 "class_ogre_1_1_vulkan_android_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9":[7,0,0,1020,3],
-"class_ogre_1_1_vulkan_android_window.html":[6,0,0,1048],
+"class_ogre_1_1_vulkan_android_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9":[6,0,0,1047,3],
 "class_ogre_1_1_vulkan_android_window.html":[7,0,0,1021],
+"class_ogre_1_1_vulkan_android_window.html":[6,0,0,1048],
 "class_ogre_1_1_vulkan_android_window.html#a09ff80100ca52995038ce8b404330c24":[7,0,0,1021,69],
 "class_ogre_1_1_vulkan_android_window.html#a09ff80100ca52995038ce8b404330c24":[6,0,0,1048,69],
-"class_ogre_1_1_vulkan_android_window.html#a0e8ae8b1cc1827631a7487ac7aff4256":[7,0,0,1021,23],
 "class_ogre_1_1_vulkan_android_window.html#a0e8ae8b1cc1827631a7487ac7aff4256":[6,0,0,1048,23],
-"class_ogre_1_1_vulkan_android_window.html#a0e960d623b65169a6ccff4b0815c8751":[7,0,0,1021,76],
+"class_ogre_1_1_vulkan_android_window.html#a0e8ae8b1cc1827631a7487ac7aff4256":[7,0,0,1021,23],
 "class_ogre_1_1_vulkan_android_window.html#a0e960d623b65169a6ccff4b0815c8751":[6,0,0,1048,76],
+"class_ogre_1_1_vulkan_android_window.html#a0e960d623b65169a6ccff4b0815c8751":[7,0,0,1021,76],
 "class_ogre_1_1_vulkan_android_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[7,0,0,1021,60],
 "class_ogre_1_1_vulkan_android_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,1048,60],
-"class_ogre_1_1_vulkan_android_window.html#a123eb1645adc5c9f7b7f85b65d33f5ae":[6,0,0,1048,14],
 "class_ogre_1_1_vulkan_android_window.html#a123eb1645adc5c9f7b7f85b65d33f5ae":[7,0,0,1021,14],
-"class_ogre_1_1_vulkan_android_window.html#a12411d378aa0623e29287964eeb261c4":[7,0,0,1021,33],
+"class_ogre_1_1_vulkan_android_window.html#a123eb1645adc5c9f7b7f85b65d33f5ae":[6,0,0,1048,14],
 "class_ogre_1_1_vulkan_android_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,1048,33],
-"class_ogre_1_1_vulkan_android_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1021,46],
+"class_ogre_1_1_vulkan_android_window.html#a12411d378aa0623e29287964eeb261c4":[7,0,0,1021,33],
 "class_ogre_1_1_vulkan_android_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1048,46],
-"class_ogre_1_1_vulkan_android_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,1021,41],
+"class_ogre_1_1_vulkan_android_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1021,46],
 "class_ogre_1_1_vulkan_android_window.html#a22779bbfb123c76e922942ba876e330a":[6,0,0,1048,41],
+"class_ogre_1_1_vulkan_android_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,1021,41],
 "class_ogre_1_1_vulkan_android_window.html#a24faacfa4584e67e19bb04cf11d83323":[7,0,0,1021,77],
 "class_ogre_1_1_vulkan_android_window.html#a24faacfa4584e67e19bb04cf11d83323":[6,0,0,1048,77],
 "class_ogre_1_1_vulkan_android_window.html#a26e48774201b2ea86d0928ffdda4f583":[6,0,0,1048,72],
 "class_ogre_1_1_vulkan_android_window.html#a26e48774201b2ea86d0928ffdda4f583":[7,0,0,1021,72],
-"class_ogre_1_1_vulkan_android_window.html#a2d5423c38fb53d7346a00c0e7e582347":[6,0,0,1048,56],
 "class_ogre_1_1_vulkan_android_window.html#a2d5423c38fb53d7346a00c0e7e582347":[7,0,0,1021,56],
+"class_ogre_1_1_vulkan_android_window.html#a2d5423c38fb53d7346a00c0e7e582347":[6,0,0,1048,56],
 "class_ogre_1_1_vulkan_android_window.html#a2fe57c70494680bee514f7d75e61852f":[7,0,0,1021,13],
 "class_ogre_1_1_vulkan_android_window.html#a2fe57c70494680bee514f7d75e61852f":[6,0,0,1048,13],
 "class_ogre_1_1_vulkan_android_window.html#a319d7bba3d2a578b0c846f0b419692ff":[7,0,0,1021,9],
 "class_ogre_1_1_vulkan_android_window.html#a319d7bba3d2a578b0c846f0b419692ff":[6,0,0,1048,9],
 "class_ogre_1_1_vulkan_android_window.html#a3766e755970279f575ec9e80db978b2d":[7,0,0,1021,30],
 "class_ogre_1_1_vulkan_android_window.html#a3766e755970279f575ec9e80db978b2d":[6,0,0,1048,30],
-"class_ogre_1_1_vulkan_android_window.html#a39e1b46f2145825d0620bc2ea50f6567":[6,0,0,1048,21],
 "class_ogre_1_1_vulkan_android_window.html#a39e1b46f2145825d0620bc2ea50f6567":[7,0,0,1021,21],
+"class_ogre_1_1_vulkan_android_window.html#a39e1b46f2145825d0620bc2ea50f6567":[6,0,0,1048,21],
 "class_ogre_1_1_vulkan_android_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,1021,32],
 "class_ogre_1_1_vulkan_android_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[6,0,0,1048,32],
 "class_ogre_1_1_vulkan_android_window.html#a452c19b6161f1ae310dfd92b026f7ed9":[7,0,0,1021,71],
 "class_ogre_1_1_vulkan_android_window.html#a452c19b6161f1ae310dfd92b026f7ed9":[6,0,0,1048,71],
 "class_ogre_1_1_vulkan_android_window.html#a462859aeb6b4db7290622623dae2a6a4":[6,0,0,1048,38],
 "class_ogre_1_1_vulkan_android_window.html#a462859aeb6b4db7290622623dae2a6a4":[7,0,0,1021,38],
-"class_ogre_1_1_vulkan_android_window.html#a4d6df7bad3cfacc62a7790d91a5af11c":[6,0,0,1048,5],
 "class_ogre_1_1_vulkan_android_window.html#a4d6df7bad3cfacc62a7790d91a5af11c":[7,0,0,1021,5],
+"class_ogre_1_1_vulkan_android_window.html#a4d6df7bad3cfacc62a7790d91a5af11c":[6,0,0,1048,5],
 "class_ogre_1_1_vulkan_android_window.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1048,48],
 "class_ogre_1_1_vulkan_android_window.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1021,48],
-"class_ogre_1_1_vulkan_android_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1048,51],
 "class_ogre_1_1_vulkan_android_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1021,51],
+"class_ogre_1_1_vulkan_android_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1048,51],
 "class_ogre_1_1_vulkan_android_window.html#a67ba7307754a41632bb41c383191bba7":[6,0,0,1048,15],
 "class_ogre_1_1_vulkan_android_window.html#a67ba7307754a41632bb41c383191bba7":[7,0,0,1021,15],
-"class_ogre_1_1_vulkan_android_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[7,0,0,1021,35],
 "class_ogre_1_1_vulkan_android_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[6,0,0,1048,35],
-"class_ogre_1_1_vulkan_android_window.html#a6e731d4414d454716620f0b401b9c823":[6,0,0,1048,64],
+"class_ogre_1_1_vulkan_android_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[7,0,0,1021,35],
 "class_ogre_1_1_vulkan_android_window.html#a6e731d4414d454716620f0b401b9c823":[7,0,0,1021,64],
+"class_ogre_1_1_vulkan_android_window.html#a6e731d4414d454716620f0b401b9c823":[6,0,0,1048,64],
 "class_ogre_1_1_vulkan_android_window.html#a70cfe4412cfa68a9423854fc1b19872e":[6,0,0,1048,18],
 "class_ogre_1_1_vulkan_android_window.html#a70cfe4412cfa68a9423854fc1b19872e":[7,0,0,1021,18],
-"class_ogre_1_1_vulkan_android_window.html#a723b2d3d2bd22c44014e0fff494d44b2":[7,0,0,1021,61],
 "class_ogre_1_1_vulkan_android_window.html#a723b2d3d2bd22c44014e0fff494d44b2":[6,0,0,1048,61],
-"class_ogre_1_1_vulkan_android_window.html#a7359904108c9c7ac2cd3a3c1fdd891ad":[7,0,0,1021,75],
+"class_ogre_1_1_vulkan_android_window.html#a723b2d3d2bd22c44014e0fff494d44b2":[7,0,0,1021,61],
 "class_ogre_1_1_vulkan_android_window.html#a7359904108c9c7ac2cd3a3c1fdd891ad":[6,0,0,1048,75],
-"class_ogre_1_1_vulkan_android_window.html#a75261d46e5f123e31ab4f889b8788e5f":[6,0,0,1048,31],
+"class_ogre_1_1_vulkan_android_window.html#a7359904108c9c7ac2cd3a3c1fdd891ad":[7,0,0,1021,75],
 "class_ogre_1_1_vulkan_android_window.html#a75261d46e5f123e31ab4f889b8788e5f":[7,0,0,1021,31],
+"class_ogre_1_1_vulkan_android_window.html#a75261d46e5f123e31ab4f889b8788e5f":[6,0,0,1048,31],
 "class_ogre_1_1_vulkan_android_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[6,0,0,1048,59],
 "class_ogre_1_1_vulkan_android_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[7,0,0,1021,59],
-"class_ogre_1_1_vulkan_android_window.html#a7f7db089d78132c7a62c0fd0c2344185":[7,0,0,1021,74],
 "class_ogre_1_1_vulkan_android_window.html#a7f7db089d78132c7a62c0fd0c2344185":[6,0,0,1048,74],
-"class_ogre_1_1_vulkan_android_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[6,0,0,1048,36],
+"class_ogre_1_1_vulkan_android_window.html#a7f7db089d78132c7a62c0fd0c2344185":[7,0,0,1021,74],
 "class_ogre_1_1_vulkan_android_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[7,0,0,1021,36],
-"class_ogre_1_1_vulkan_android_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1021,44],
+"class_ogre_1_1_vulkan_android_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[6,0,0,1048,36],
 "class_ogre_1_1_vulkan_android_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1048,44],
+"class_ogre_1_1_vulkan_android_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1021,44],
 "class_ogre_1_1_vulkan_android_window.html#a84739cd779700fa8d7991c9cf11c289d":[6,0,0,1048,34],
 "class_ogre_1_1_vulkan_android_window.html#a84739cd779700fa8d7991c9cf11c289d":[7,0,0,1021,34],
 "class_ogre_1_1_vulkan_android_window.html#a8816fd24c769894c73f57a4b0927f08f":[7,0,0,1021,16],
 "class_ogre_1_1_vulkan_android_window.html#a8816fd24c769894c73f57a4b0927f08f":[6,0,0,1048,16],
-"class_ogre_1_1_vulkan_android_window.html#a8910e9cedfc8c484ac0e0ec8618461d7":[6,0,0,1048,55],
 "class_ogre_1_1_vulkan_android_window.html#a8910e9cedfc8c484ac0e0ec8618461d7":[7,0,0,1021,55],
-"class_ogre_1_1_vulkan_android_window.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,1021,22],
+"class_ogre_1_1_vulkan_android_window.html#a8910e9cedfc8c484ac0e0ec8618461d7":[6,0,0,1048,55],
 "class_ogre_1_1_vulkan_android_window.html#a8a464e98db9c09042b866bdb95b210f4":[6,0,0,1048,22],
+"class_ogre_1_1_vulkan_android_window.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,1021,22],
 "class_ogre_1_1_vulkan_android_window.html#a8b05fabc7b8b6cf3129279629562476d":[7,0,0,1021,25],
 "class_ogre_1_1_vulkan_android_window.html#a8b05fabc7b8b6cf3129279629562476d":[6,0,0,1048,25],
-"class_ogre_1_1_vulkan_android_window.html#a8d6f1accac3551566dc3de3a44cfc9ac":[7,0,0,1021,11],
 "class_ogre_1_1_vulkan_android_window.html#a8d6f1accac3551566dc3de3a44cfc9ac":[6,0,0,1048,11],
+"class_ogre_1_1_vulkan_android_window.html#a8d6f1accac3551566dc3de3a44cfc9ac":[7,0,0,1021,11],
 "class_ogre_1_1_vulkan_android_window.html#a8d7e786602979fc29169555056834c65":[7,0,0,1021,19],
 "class_ogre_1_1_vulkan_android_window.html#a8d7e786602979fc29169555056834c65":[6,0,0,1048,19],
-"class_ogre_1_1_vulkan_android_window.html#a90000b8f4464974732dbc282b2ac1f64":[7,0,0,1021,27],
 "class_ogre_1_1_vulkan_android_window.html#a90000b8f4464974732dbc282b2ac1f64":[6,0,0,1048,27],
+"class_ogre_1_1_vulkan_android_window.html#a90000b8f4464974732dbc282b2ac1f64":[7,0,0,1021,27],
 "class_ogre_1_1_vulkan_android_window.html#a914fd94d31d836a6cff2f65844fb743c":[6,0,0,1048,68],
 "class_ogre_1_1_vulkan_android_window.html#a914fd94d31d836a6cff2f65844fb743c":[7,0,0,1021,68],
 "class_ogre_1_1_vulkan_android_window.html#a92d426a5762a35639ab102cfcbcaedf5":[7,0,0,1021,42],
 "class_ogre_1_1_vulkan_android_window.html#a92d426a5762a35639ab102cfcbcaedf5":[6,0,0,1048,42],
-"class_ogre_1_1_vulkan_android_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1021,47],
 "class_ogre_1_1_vulkan_android_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1048,47],
+"class_ogre_1_1_vulkan_android_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1021,47],
 "class_ogre_1_1_vulkan_android_window.html#a9439f12db8a964f79f4b743493a0fd75":[6,0,0,1048,24],
 "class_ogre_1_1_vulkan_android_window.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,1021,24],
-"class_ogre_1_1_vulkan_android_window.html#a95c79431ef5e02a234b0119e288324ee":[7,0,0,1021,4],
 "class_ogre_1_1_vulkan_android_window.html#a95c79431ef5e02a234b0119e288324ee":[6,0,0,1048,4],
-"class_ogre_1_1_vulkan_android_window.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,1048,26],
+"class_ogre_1_1_vulkan_android_window.html#a95c79431ef5e02a234b0119e288324ee":[7,0,0,1021,4],
 "class_ogre_1_1_vulkan_android_window.html#a98f49dbefa207210a2f4c0025848b93c":[7,0,0,1021,26],
-"class_ogre_1_1_vulkan_android_window.html#a9af2d2b27cf6a53c60aca59598f631b2":[7,0,0,1021,10],
+"class_ogre_1_1_vulkan_android_window.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,1048,26],
 "class_ogre_1_1_vulkan_android_window.html#a9af2d2b27cf6a53c60aca59598f631b2":[6,0,0,1048,10],
-"class_ogre_1_1_vulkan_android_window.html#a9cb93665880140bab36cfb817c1b900b":[7,0,0,1021,43],
+"class_ogre_1_1_vulkan_android_window.html#a9af2d2b27cf6a53c60aca59598f631b2":[7,0,0,1021,10],
 "class_ogre_1_1_vulkan_android_window.html#a9cb93665880140bab36cfb817c1b900b":[6,0,0,1048,43],
+"class_ogre_1_1_vulkan_android_window.html#a9cb93665880140bab36cfb817c1b900b":[7,0,0,1021,43],
 "class_ogre_1_1_vulkan_android_window.html#a9d564070b8a0c811871c56391fc24dc9":[6,0,0,1048,3],
 "class_ogre_1_1_vulkan_android_window.html#a9d564070b8a0c811871c56391fc24dc9":[7,0,0,1021,3],
-"class_ogre_1_1_vulkan_android_window.html#aa562105b8ede44dd4bba7704ffcf763c":[7,0,0,1021,70],
 "class_ogre_1_1_vulkan_android_window.html#aa562105b8ede44dd4bba7704ffcf763c":[6,0,0,1048,70],
-"class_ogre_1_1_vulkan_android_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[6,0,0,1048,58],
+"class_ogre_1_1_vulkan_android_window.html#aa562105b8ede44dd4bba7704ffcf763c":[7,0,0,1021,70],
 "class_ogre_1_1_vulkan_android_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[7,0,0,1021,58],
+"class_ogre_1_1_vulkan_android_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[6,0,0,1048,58],
 "class_ogre_1_1_vulkan_android_window.html#aa9b818b17537b57b0006d9bdbf84a774":[7,0,0,1021,57],
 "class_ogre_1_1_vulkan_android_window.html#aa9b818b17537b57b0006d9bdbf84a774":[6,0,0,1048,57],
 "class_ogre_1_1_vulkan_android_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[7,0,0,1021,67],
 "class_ogre_1_1_vulkan_android_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[6,0,0,1048,67],
-"class_ogre_1_1_vulkan_android_window.html#aadf0d4f9a81f5217c467f3306941d973":[7,0,0,1021,1],
 "class_ogre_1_1_vulkan_android_window.html#aadf0d4f9a81f5217c467f3306941d973":[6,0,0,1048,1],
+"class_ogre_1_1_vulkan_android_window.html#aadf0d4f9a81f5217c467f3306941d973":[7,0,0,1021,1],
 "class_ogre_1_1_vulkan_android_window.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7":[6,0,0,1048,1,2],
 "class_ogre_1_1_vulkan_android_window.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7":[7,0,0,1021,1,2],
 "class_ogre_1_1_vulkan_android_window.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24":[7,0,0,1021,1,1],
@@ -161,93 +163,91 @@ var NAVTREEINDEX241 =
 "class_ogre_1_1_vulkan_android_window.html#aadf0d4f9a81f5217c467f3306941d973ae6e7b9212a61d76de37b5ea4a733a17d":[6,0,0,1048,1,3],
 "class_ogre_1_1_vulkan_android_window.html#ab12be5918fc0d0c3a827250bf4f4d281":[6,0,0,1048,0],
 "class_ogre_1_1_vulkan_android_window.html#ab12be5918fc0d0c3a827250bf4f4d281":[7,0,0,1021,0],
-"class_ogre_1_1_vulkan_android_window.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259":[7,0,0,1021,0,0],
 "class_ogre_1_1_vulkan_android_window.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259":[6,0,0,1048,0,0],
+"class_ogre_1_1_vulkan_android_window.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259":[7,0,0,1021,0,0],
 "class_ogre_1_1_vulkan_android_window.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1021,50],
 "class_ogre_1_1_vulkan_android_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1048,50],
-"class_ogre_1_1_vulkan_android_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[7,0,0,1021,7],
 "class_ogre_1_1_vulkan_android_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,1048,7],
+"class_ogre_1_1_vulkan_android_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[7,0,0,1021,7],
 "class_ogre_1_1_vulkan_android_window.html#abf412fe12f3a9e516e4571d431d0911a":[6,0,0,1048,2],
 "class_ogre_1_1_vulkan_android_window.html#abf412fe12f3a9e516e4571d431d0911a":[7,0,0,1021,2],
 "class_ogre_1_1_vulkan_android_window.html#ac344214fa2a1ead13bb78f73712f69a3":[7,0,0,1021,66],
 "class_ogre_1_1_vulkan_android_window.html#ac344214fa2a1ead13bb78f73712f69a3":[6,0,0,1048,66],
-"class_ogre_1_1_vulkan_android_window.html#ac4782abeb9698a9d72469dde923bc714":[7,0,0,1021,12],
 "class_ogre_1_1_vulkan_android_window.html#ac4782abeb9698a9d72469dde923bc714":[6,0,0,1048,12],
-"class_ogre_1_1_vulkan_android_window.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,1048,17],
+"class_ogre_1_1_vulkan_android_window.html#ac4782abeb9698a9d72469dde923bc714":[7,0,0,1021,12],
 "class_ogre_1_1_vulkan_android_window.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,1021,17],
-"class_ogre_1_1_vulkan_android_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1021,45],
+"class_ogre_1_1_vulkan_android_window.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,1048,17],
 "class_ogre_1_1_vulkan_android_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1048,45],
-"class_ogre_1_1_vulkan_android_window.html#acd46202d3fd921f029d029fa2f5ed59b":[6,0,0,1048,6],
+"class_ogre_1_1_vulkan_android_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1021,45],
 "class_ogre_1_1_vulkan_android_window.html#acd46202d3fd921f029d029fa2f5ed59b":[7,0,0,1021,6],
+"class_ogre_1_1_vulkan_android_window.html#acd46202d3fd921f029d029fa2f5ed59b":[6,0,0,1048,6],
 "class_ogre_1_1_vulkan_android_window.html#acdd6b0970df5b1dbc96510a3e4cb67ed":[7,0,0,1021,62],
 "class_ogre_1_1_vulkan_android_window.html#acdd6b0970df5b1dbc96510a3e4cb67ed":[6,0,0,1048,62],
-"class_ogre_1_1_vulkan_android_window.html#ace91bf4e71780132056f8dc70d53810c":[7,0,0,1021,8],
 "class_ogre_1_1_vulkan_android_window.html#ace91bf4e71780132056f8dc70d53810c":[6,0,0,1048,8],
-"class_ogre_1_1_vulkan_android_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,1048,28],
+"class_ogre_1_1_vulkan_android_window.html#ace91bf4e71780132056f8dc70d53810c":[7,0,0,1021,8],
 "class_ogre_1_1_vulkan_android_window.html#ad15462609bf45808fb04668cc1c28c78":[7,0,0,1021,28],
+"class_ogre_1_1_vulkan_android_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,1048,28],
 "class_ogre_1_1_vulkan_android_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1021,49],
 "class_ogre_1_1_vulkan_android_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1048,49],
-"class_ogre_1_1_vulkan_android_window.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,1021,63],
 "class_ogre_1_1_vulkan_android_window.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,1048,63],
+"class_ogre_1_1_vulkan_android_window.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,1021,63],
 "class_ogre_1_1_vulkan_android_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[6,0,0,1048,39],
 "class_ogre_1_1_vulkan_android_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[7,0,0,1021,39],
-"class_ogre_1_1_vulkan_android_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,1048,29],
 "class_ogre_1_1_vulkan_android_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[7,0,0,1021,29],
-"class_ogre_1_1_vulkan_android_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,1021,52],
+"class_ogre_1_1_vulkan_android_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,1048,29],
 "class_ogre_1_1_vulkan_android_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,1048,52],
+"class_ogre_1_1_vulkan_android_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,1021,52],
 "class_ogre_1_1_vulkan_android_window.html#add8e20491fc0e054c9cab3c75297c6ec":[7,0,0,1021,20],
 "class_ogre_1_1_vulkan_android_window.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,1048,20],
-"class_ogre_1_1_vulkan_android_window.html#adfbd4f24b29343958aba5af0708a0683":[6,0,0,1048,54],
 "class_ogre_1_1_vulkan_android_window.html#adfbd4f24b29343958aba5af0708a0683":[7,0,0,1021,54],
-"class_ogre_1_1_vulkan_android_window.html#ae17370ecf70be39d53d5da016eb1ac9c":[7,0,0,1021,40],
+"class_ogre_1_1_vulkan_android_window.html#adfbd4f24b29343958aba5af0708a0683":[6,0,0,1048,54],
 "class_ogre_1_1_vulkan_android_window.html#ae17370ecf70be39d53d5da016eb1ac9c":[6,0,0,1048,40],
+"class_ogre_1_1_vulkan_android_window.html#ae17370ecf70be39d53d5da016eb1ac9c":[7,0,0,1021,40],
 "class_ogre_1_1_vulkan_android_window.html#aecf38609606a498bc552a6cbbd5b3c38":[7,0,0,1021,37],
 "class_ogre_1_1_vulkan_android_window.html#aecf38609606a498bc552a6cbbd5b3c38":[6,0,0,1048,37],
-"class_ogre_1_1_vulkan_android_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1048,53],
 "class_ogre_1_1_vulkan_android_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1021,53],
+"class_ogre_1_1_vulkan_android_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1048,53],
 "class_ogre_1_1_vulkan_android_window.html#af574272c60f388e4c4712fa5d358ef7a":[6,0,0,1048,65],
 "class_ogre_1_1_vulkan_android_window.html#af574272c60f388e4c4712fa5d358ef7a":[7,0,0,1021,65],
 "class_ogre_1_1_vulkan_android_window.html#afb956dde983e96a95394aa55215c55da":[7,0,0,1021,73],
 "class_ogre_1_1_vulkan_android_window.html#afb956dde983e96a95394aa55215c55da":[6,0,0,1048,73],
 "class_ogre_1_1_vulkan_async_texture_ticket.html":[6,0,0,1049],
 "class_ogre_1_1_vulkan_async_texture_ticket.html":[7,0,0,1022],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#a1427f0b635a4186cd6083a9bab879fa2":[7,0,0,1022,28],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a1427f0b635a4186cd6083a9bab879fa2":[6,0,0,1049,28],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1049,19],
+"class_ogre_1_1_vulkan_async_texture_ticket.html#a1427f0b635a4186cd6083a9bab879fa2":[7,0,0,1022,28],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1022,19],
+"class_ogre_1_1_vulkan_async_texture_ticket.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1049,19],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a25041a6b2f21149ddfd4a85d82006b00":[7,0,0,1022,11],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a25041a6b2f21149ddfd4a85d82006b00":[6,0,0,1049,11],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#a45ecf267d33f2105fe425c792e554aa4":[6,0,0,1049,4],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a45ecf267d33f2105fe425c792e554aa4":[7,0,0,1022,4],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8":[7,0,0,1022,1],
+"class_ogre_1_1_vulkan_async_texture_ticket.html#a45ecf267d33f2105fe425c792e554aa4":[6,0,0,1049,4],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8":[6,0,0,1049,1],
+"class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8":[7,0,0,1022,1],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8a4feb213276cf5c06ea03a33b7087acf3":[7,0,0,1022,1,0],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8a4feb213276cf5c06ea03a33b7087acf3":[6,0,0,1049,1,0],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8a716e827841a8f5ca43f8fa5b5a0208a4":[7,0,0,1022,1,1],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8a716e827841a8f5ca43f8fa5b5a0208a4":[6,0,0,1049,1,1],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8a8f850db29927b5a749d4b4d3a2771035":[7,0,0,1022,1,2],
+"class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8a716e827841a8f5ca43f8fa5b5a0208a4":[7,0,0,1022,1,1],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8a8f850db29927b5a749d4b4d3a2771035":[6,0,0,1049,1,2],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1049,21],
+"class_ogre_1_1_vulkan_async_texture_ticket.html#a4e4a25bb4d7cf6f3c5ab091432c3cbe8a8f850db29927b5a749d4b4d3a2771035":[7,0,0,1022,1,2],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1022,21],
+"class_ogre_1_1_vulkan_async_texture_ticket.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1049,21],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1022,24],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1049,24],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a6c76b44f26be0d76c764fe2d5597a26f":[6,0,0,1049,15],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a6c76b44f26be0d76c764fe2d5597a26f":[7,0,0,1022,15],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a6e241ead9a326169fc27ab8be527a76d":[6,0,0,1049,2],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a6e241ead9a326169fc27ab8be527a76d":[7,0,0,1022,2],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#a702a84d7ff30d07b7e547aa8e5ff5cc3":[6,0,0,1049,10],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a702a84d7ff30d07b7e547aa8e5ff5cc3":[7,0,0,1022,10],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1022,17],
+"class_ogre_1_1_vulkan_async_texture_ticket.html#a702a84d7ff30d07b7e547aa8e5ff5cc3":[6,0,0,1049,10],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1049,17],
+"class_ogre_1_1_vulkan_async_texture_ticket.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1022,17],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a89bea6111361e89646624550ea24c83a":[6,0,0,1049,5],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a89bea6111361e89646624550ea24c83a":[7,0,0,1022,5],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1022,20],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1049,20],
+"class_ogre_1_1_vulkan_async_texture_ticket.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1022,20],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a9b0edb7a3599c8e661ab768f940c6296":[7,0,0,1022,9],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#a9b0edb7a3599c8e661ab768f940c6296":[6,0,0,1049,9],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#ab129b874eb976f570bee6f8510039b50":[7,0,0,1022,3],
 "class_ogre_1_1_vulkan_async_texture_ticket.html#ab129b874eb976f570bee6f8510039b50":[6,0,0,1049,3],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#ab1e2325da309a80f83edcfab5300cbb4":[7,0,0,1022,13],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#ab1e2325da309a80f83edcfab5300cbb4":[6,0,0,1049,13],
-"class_ogre_1_1_vulkan_async_texture_ticket.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1022,23]
+"class_ogre_1_1_vulkan_async_texture_ticket.html#ab1e2325da309a80f83edcfab5300cbb4":[7,0,0,1022,13]
 };
