@@ -1,30 +1,32 @@
 var NAVTREEINDEX243 =
 {
+"class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html":[6,0,0,1056],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#a4a28f7bc1381c7ed4b85690b1bc8c656":[7,0,0,1029,4],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#a4a28f7bc1381c7ed4b85690b1bc8c656":[6,0,0,1056,4],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#a6be209e27bca4397d3bbae95163626ff":[7,0,0,1029,3],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#a6be209e27bca4397d3bbae95163626ff":[6,0,0,1056,3],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#aa62e50c3a413126399969df43539d239":[7,0,0,1029,0],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#aa62e50c3a413126399969df43539d239":[6,0,0,1056,0],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#adfc0f32108ff444ffe7f36d636e6f152":[6,0,0,1056,2],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#adfc0f32108ff444ffe7f36d636e6f152":[7,0,0,1029,2],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#adfc0f32108ff444ffe7f36d636e6f152":[6,0,0,1056,2],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#ae4c113d8a5f17627e26f90e188d885f5":[7,0,0,1029,1],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_framebuffer.html#ae4c113d8a5f17627e26f90e188d885f5":[6,0,0,1056,1],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_image.html":[7,0,0,1030],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html":[6,0,0,1057],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a46e7b7c4953829f6ab04201fc2d1c414":[6,0,0,1057,3],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_image.html":[7,0,0,1030],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a46e7b7c4953829f6ab04201fc2d1c414":[7,0,0,1030,3],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a46e7b7c4953829f6ab04201fc2d1c414":[6,0,0,1057,3],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a58c29ad1d7df685e0253219f7e60744e":[6,0,0,1057,0],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a58c29ad1d7df685e0253219f7e60744e":[7,0,0,1030,0],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a670f8b15d94aeda5c25be8b3c1139a32":[6,0,0,1057,4],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a670f8b15d94aeda5c25be8b3c1139a32":[7,0,0,1030,4],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a670f8b15d94aeda5c25be8b3c1139a32":[6,0,0,1057,4],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a6be209e27bca4397d3bbae95163626ff":[7,0,0,1030,2],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a6be209e27bca4397d3bbae95163626ff":[6,0,0,1057,2],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a71eb03f50026a0e83ac116342c7f35f1":[7,0,0,1030,1],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image.html#a71eb03f50026a0e83ac116342c7f35f1":[6,0,0,1057,1],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html":[6,0,0,1058],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html":[7,0,0,1031],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html#a26bf814a369a7716c20613a9889be3c0":[6,0,0,1058,0],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html":[6,0,0,1058],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html#a26bf814a369a7716c20613a9889be3c0":[7,0,0,1031,0],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html#a26bf814a369a7716c20613a9889be3c0":[6,0,0,1058,0],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html#a440a88e31971ef624e4782575f4356d0":[7,0,0,1031,3],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html#a440a88e31971ef624e4782575f4356d0":[6,0,0,1058,3],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html#a6be209e27bca4397d3bbae95163626ff":[7,0,0,1031,2],
@@ -35,16 +37,16 @@ var NAVTREEINDEX243 =
 "class_ogre_1_1_vulkan_delayed__vk_destroy_image_view.html#aeb894bb008b43995a25e0bd88a9b5fc4":[6,0,0,1058,4],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html":[7,0,0,1032],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html":[6,0,0,1059],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a015ab1dea2597093b6a4ae8b25430be4":[6,0,0,1059,0],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a015ab1dea2597093b6a4ae8b25430be4":[7,0,0,1032,0],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a6be209e27bca4397d3bbae95163626ff":[7,0,0,1032,2],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a015ab1dea2597093b6a4ae8b25430be4":[6,0,0,1059,0],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a6be209e27bca4397d3bbae95163626ff":[6,0,0,1059,2],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a7fe1ac4047a1455f1175b66b6b1aaeea":[7,0,0,1032,4],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a6be209e27bca4397d3bbae95163626ff":[7,0,0,1032,2],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a7fe1ac4047a1455f1175b66b6b1aaeea":[6,0,0,1059,4],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a7fe1ac4047a1455f1175b66b6b1aaeea":[7,0,0,1032,4],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a95b97da3a02df58e7730ad3adb4f1c68":[7,0,0,1032,3],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a95b97da3a02df58e7730ad3adb4f1c68":[6,0,0,1059,3],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a9c9e213c155877a1acd320a23a8501da":[7,0,0,1032,1],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a9c9e213c155877a1acd320a23a8501da":[6,0,0,1059,1],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_pipeline.html#a9c9e213c155877a1acd320a23a8501da":[7,0,0,1032,1],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html":[6,0,0,1060],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html":[7,0,0,1033],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#a0c7cb53e647ac932fa94d867aee39e08":[7,0,0,1033,1],
@@ -53,48 +55,48 @@ var NAVTREEINDEX243 =
 "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#a56fe17a8780fcb680cbde6fb4e4398a1":[6,0,0,1060,0],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#a6be209e27bca4397d3bbae95163626ff":[7,0,0,1033,2],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#a6be209e27bca4397d3bbae95163626ff":[6,0,0,1060,2],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#a813150978ba9eb43adc1f1f36ae28dfa":[6,0,0,1060,4],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#a813150978ba9eb43adc1f1f36ae28dfa":[7,0,0,1033,4],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#aa050f0838acf77c9718fcb1d4ab91d29":[7,0,0,1033,3],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#a813150978ba9eb43adc1f1f36ae28dfa":[6,0,0,1060,4],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#aa050f0838acf77c9718fcb1d4ab91d29":[6,0,0,1060,3],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_render_pass.html#aa050f0838acf77c9718fcb1d4ab91d29":[7,0,0,1033,3],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html":[6,0,0,1061],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html":[7,0,0,1034],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#a17492c87a9cb83b352ef2411a30336d4":[6,0,0,1061,4],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#a17492c87a9cb83b352ef2411a30336d4":[7,0,0,1034,4],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#a6be209e27bca4397d3bbae95163626ff":[7,0,0,1034,2],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#a6be209e27bca4397d3bbae95163626ff":[6,0,0,1061,2],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#a6be209e27bca4397d3bbae95163626ff":[7,0,0,1034,2],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#a80b7f5f74871baa65113f8ee8baec92e":[6,0,0,1061,0],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#a80b7f5f74871baa65113f8ee8baec92e":[7,0,0,1034,0],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#a8bd830cc1cded9d4e4f3f108d6cad459":[7,0,0,1034,3],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#a8bd830cc1cded9d4e4f3f108d6cad459":[6,0,0,1061,3],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#aca102fedb5b9d8c3c4a8db4abfcd7763":[6,0,0,1061,1],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#a8bd830cc1cded9d4e4f3f108d6cad459":[7,0,0,1034,3],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#aca102fedb5b9d8c3c4a8db4abfcd7763":[7,0,0,1034,1],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html":[6,0,0,1062],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_sampler.html#aca102fedb5b9d8c3c4a8db4abfcd7763":[6,0,0,1061,1],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html":[7,0,0,1035],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a19ff90f827671b137217bb91f5d71205":[6,0,0,1062,1],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html":[6,0,0,1062],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a19ff90f827671b137217bb91f5d71205":[7,0,0,1035,1],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a19ff90f827671b137217bb91f5d71205":[6,0,0,1062,1],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a2b9342aeb7d0ebb91beb3aca4a0d0836":[7,0,0,1035,4],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a2b9342aeb7d0ebb91beb3aca4a0d0836":[6,0,0,1062,4],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a38ce61946e28492d08d8241e8fb25d89":[7,0,0,1035,0],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a38ce61946e28492d08d8241e8fb25d89":[6,0,0,1062,0],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a38ce61946e28492d08d8241e8fb25d89":[7,0,0,1035,0],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a6be209e27bca4397d3bbae95163626ff":[6,0,0,1062,2],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a6be209e27bca4397d3bbae95163626ff":[7,0,0,1035,2],
-"class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a991e0a0e6562ac12c47b5cc796752bbf":[7,0,0,1035,3],
 "class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a991e0a0e6562ac12c47b5cc796752bbf":[6,0,0,1062,3],
-"class_ogre_1_1_vulkan_delayed_func_base.html":[7,0,0,1036],
+"class_ogre_1_1_vulkan_delayed__vk_destroy_shader_module.html#a991e0a0e6562ac12c47b5cc796752bbf":[7,0,0,1035,3],
 "class_ogre_1_1_vulkan_delayed_func_base.html":[6,0,0,1063],
+"class_ogre_1_1_vulkan_delayed_func_base.html":[7,0,0,1036],
 "class_ogre_1_1_vulkan_delayed_func_base.html#a6be209e27bca4397d3bbae95163626ff":[7,0,0,1036,2],
 "class_ogre_1_1_vulkan_delayed_func_base.html#a6be209e27bca4397d3bbae95163626ff":[6,0,0,1063,2],
-"class_ogre_1_1_vulkan_delayed_func_base.html#a7d12e5aa0abec59f3c27cb449152c78b":[6,0,0,1063,1],
 "class_ogre_1_1_vulkan_delayed_func_base.html#a7d12e5aa0abec59f3c27cb449152c78b":[7,0,0,1036,1],
+"class_ogre_1_1_vulkan_delayed_func_base.html#a7d12e5aa0abec59f3c27cb449152c78b":[6,0,0,1063,1],
 "class_ogre_1_1_vulkan_delayed_func_base.html#aeca7ba5abbed9731bbddbbb1a72cb13d":[6,0,0,1063,0],
 "class_ogre_1_1_vulkan_delayed_func_base.html#aeca7ba5abbed9731bbddbbb1a72cb13d":[7,0,0,1036,0],
 "class_ogre_1_1_vulkan_descriptor_pool.html":[6,0,0,1064],
 "class_ogre_1_1_vulkan_descriptor_pool.html":[7,0,0,1037],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1064,9],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1037,9],
-"class_ogre_1_1_vulkan_descriptor_pool.html#a28f518a4ef525b1263182d58ccf8548d":[7,0,0,1037,4],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a28f518a4ef525b1263182d58ccf8548d":[6,0,0,1064,4],
+"class_ogre_1_1_vulkan_descriptor_pool.html#a28f518a4ef525b1263182d58ccf8548d":[7,0,0,1037,4],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a50967092ab42c872d158560784a2d614":[6,0,0,1064,0],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a50967092ab42c872d158560784a2d614":[7,0,0,1037,0],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1037,11],
@@ -103,20 +105,20 @@ var NAVTREEINDEX243 =
 "class_ogre_1_1_vulkan_descriptor_pool.html#a6263f478109dc42daebcbeb54e1f0eb6":[6,0,0,1064,2],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1037,14],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1064,14],
-"class_ogre_1_1_vulkan_descriptor_pool.html#a685f5a2feb9eeee221f8fffbb310a920":[6,0,0,1064,17],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a685f5a2feb9eeee221f8fffbb310a920":[7,0,0,1037,17],
-"class_ogre_1_1_vulkan_descriptor_pool.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1037,7],
+"class_ogre_1_1_vulkan_descriptor_pool.html#a685f5a2feb9eeee221f8fffbb310a920":[6,0,0,1064,17],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1064,7],
+"class_ogre_1_1_vulkan_descriptor_pool.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1037,7],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1064,10],
 "class_ogre_1_1_vulkan_descriptor_pool.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1037,10],
-"class_ogre_1_1_vulkan_descriptor_pool.html#aa4b56c28e9e75425308ac95188ac4bb3":[7,0,0,1037,6],
 "class_ogre_1_1_vulkan_descriptor_pool.html#aa4b56c28e9e75425308ac95188ac4bb3":[6,0,0,1064,6],
+"class_ogre_1_1_vulkan_descriptor_pool.html#aa4b56c28e9e75425308ac95188ac4bb3":[7,0,0,1037,6],
 "class_ogre_1_1_vulkan_descriptor_pool.html#aa9fa3528cfd8eb39224e04064604654a":[6,0,0,1064,5],
 "class_ogre_1_1_vulkan_descriptor_pool.html#aa9fa3528cfd8eb39224e04064604654a":[7,0,0,1037,5],
 "class_ogre_1_1_vulkan_descriptor_pool.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1064,13],
 "class_ogre_1_1_vulkan_descriptor_pool.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1037,13],
-"class_ogre_1_1_vulkan_descriptor_pool.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1064,8],
 "class_ogre_1_1_vulkan_descriptor_pool.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1037,8],
+"class_ogre_1_1_vulkan_descriptor_pool.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1064,8],
 "class_ogre_1_1_vulkan_descriptor_pool.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1064,12],
 "class_ogre_1_1_vulkan_descriptor_pool.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1037,12],
 "class_ogre_1_1_vulkan_descriptor_pool.html#ad3a1715cb0628d5cca41b4f905718231":[7,0,0,1037,1],
@@ -125,60 +127,60 @@ var NAVTREEINDEX243 =
 "class_ogre_1_1_vulkan_descriptor_pool.html#adce32528577d71b228692df906ecd17c":[7,0,0,1037,15],
 "class_ogre_1_1_vulkan_descriptor_pool.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1064,16],
 "class_ogre_1_1_vulkan_descriptor_pool.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1037,16],
-"class_ogre_1_1_vulkan_descriptor_pool.html#afb44444f3ff740a5057f1a8971fd3e20":[7,0,0,1037,3],
 "class_ogre_1_1_vulkan_descriptor_pool.html#afb44444f3ff740a5057f1a8971fd3e20":[6,0,0,1064,3],
-"class_ogre_1_1_vulkan_discard_buffer.html":[7,0,0,1043],
+"class_ogre_1_1_vulkan_descriptor_pool.html#afb44444f3ff740a5057f1a8971fd3e20":[7,0,0,1037,3],
 "class_ogre_1_1_vulkan_discard_buffer.html":[6,0,0,1070],
+"class_ogre_1_1_vulkan_discard_buffer.html":[7,0,0,1043],
 "class_ogre_1_1_vulkan_discard_buffer.html#a0c2da9451ed69f23f1f10e27a7d9cfd2":[6,0,0,1070,5],
 "class_ogre_1_1_vulkan_discard_buffer.html#a0c2da9451ed69f23f1f10e27a7d9cfd2":[7,0,0,1043,5],
-"class_ogre_1_1_vulkan_discard_buffer.html#a1c0faf8035c84945332107680afb638e":[6,0,0,1070,20],
 "class_ogre_1_1_vulkan_discard_buffer.html#a1c0faf8035c84945332107680afb638e":[7,0,0,1043,20],
+"class_ogre_1_1_vulkan_discard_buffer.html#a1c0faf8035c84945332107680afb638e":[6,0,0,1070,20],
 "class_ogre_1_1_vulkan_discard_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1043,11],
 "class_ogre_1_1_vulkan_discard_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1070,11],
 "class_ogre_1_1_vulkan_discard_buffer.html#a23508b755c61230ee2c6cd44a346323c":[6,0,0,1070,19],
 "class_ogre_1_1_vulkan_discard_buffer.html#a23508b755c61230ee2c6cd44a346323c":[7,0,0,1043,19],
 "class_ogre_1_1_vulkan_discard_buffer.html#a38cb600842e34461cb4cebdc3a3b0383":[6,0,0,1070,4],
 "class_ogre_1_1_vulkan_discard_buffer.html#a38cb600842e34461cb4cebdc3a3b0383":[7,0,0,1043,4],
-"class_ogre_1_1_vulkan_discard_buffer.html#a5752c6192c1afac51655659d98876968":[6,0,0,1070,2],
 "class_ogre_1_1_vulkan_discard_buffer.html#a5752c6192c1afac51655659d98876968":[7,0,0,1043,2],
-"class_ogre_1_1_vulkan_discard_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1043,13],
+"class_ogre_1_1_vulkan_discard_buffer.html#a5752c6192c1afac51655659d98876968":[6,0,0,1070,2],
 "class_ogre_1_1_vulkan_discard_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1070,13],
-"class_ogre_1_1_vulkan_discard_buffer.html#a5bc4c00a860c1186340952677df45df3":[6,0,0,1070,1],
+"class_ogre_1_1_vulkan_discard_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1043,13],
 "class_ogre_1_1_vulkan_discard_buffer.html#a5bc4c00a860c1186340952677df45df3":[7,0,0,1043,1],
-"class_ogre_1_1_vulkan_discard_buffer.html#a5e832767a647d79438cd07285ca3b93c":[7,0,0,1043,8],
+"class_ogre_1_1_vulkan_discard_buffer.html#a5bc4c00a860c1186340952677df45df3":[6,0,0,1070,1],
 "class_ogre_1_1_vulkan_discard_buffer.html#a5e832767a647d79438cd07285ca3b93c":[6,0,0,1070,8],
-"class_ogre_1_1_vulkan_discard_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1070,16],
+"class_ogre_1_1_vulkan_discard_buffer.html#a5e832767a647d79438cd07285ca3b93c":[7,0,0,1043,8],
 "class_ogre_1_1_vulkan_discard_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1043,16],
+"class_ogre_1_1_vulkan_discard_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1070,16],
 "class_ogre_1_1_vulkan_discard_buffer.html#a7526bacc6ea6e5bab1d6617af20d71a7":[7,0,0,1043,3],
 "class_ogre_1_1_vulkan_discard_buffer.html#a7526bacc6ea6e5bab1d6617af20d71a7":[6,0,0,1070,3],
-"class_ogre_1_1_vulkan_discard_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1070,9],
 "class_ogre_1_1_vulkan_discard_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1043,9],
+"class_ogre_1_1_vulkan_discard_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1070,9],
 "class_ogre_1_1_vulkan_discard_buffer.html#a8f9e8f739c90439a3ffb91aafb91dee5":[7,0,0,1043,7],
 "class_ogre_1_1_vulkan_discard_buffer.html#a8f9e8f739c90439a3ffb91aafb91dee5":[6,0,0,1070,7],
-"class_ogre_1_1_vulkan_discard_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1070,12],
 "class_ogre_1_1_vulkan_discard_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1043,12],
+"class_ogre_1_1_vulkan_discard_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1070,12],
 "class_ogre_1_1_vulkan_discard_buffer.html#a99620f2fb054246e5fc45177042c3d1d":[7,0,0,1043,6],
 "class_ogre_1_1_vulkan_discard_buffer.html#a99620f2fb054246e5fc45177042c3d1d":[6,0,0,1070,6],
 "class_ogre_1_1_vulkan_discard_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1043,15],
 "class_ogre_1_1_vulkan_discard_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1070,15],
-"class_ogre_1_1_vulkan_discard_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1043,10],
 "class_ogre_1_1_vulkan_discard_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1070,10],
+"class_ogre_1_1_vulkan_discard_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1043,10],
 "class_ogre_1_1_vulkan_discard_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1043,14],
 "class_ogre_1_1_vulkan_discard_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1070,14],
-"class_ogre_1_1_vulkan_discard_buffer.html#adce32528577d71b228692df906ecd17c":[6,0,0,1070,17],
 "class_ogre_1_1_vulkan_discard_buffer.html#adce32528577d71b228692df906ecd17c":[7,0,0,1043,17],
-"class_ogre_1_1_vulkan_discard_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1070,18],
+"class_ogre_1_1_vulkan_discard_buffer.html#adce32528577d71b228692df906ecd17c":[6,0,0,1070,17],
 "class_ogre_1_1_vulkan_discard_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1043,18],
-"class_ogre_1_1_vulkan_discard_buffer.html#aeecd14c4ca5c244c304c6b215d4f9b5a":[6,0,0,1070,0],
+"class_ogre_1_1_vulkan_discard_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1070,18],
 "class_ogre_1_1_vulkan_discard_buffer.html#aeecd14c4ca5c244c304c6b215d4f9b5a":[7,0,0,1043,0],
-"class_ogre_1_1_vulkan_discard_buffer_manager.html":[6,0,0,1071],
+"class_ogre_1_1_vulkan_discard_buffer.html#aeecd14c4ca5c244c304c6b215d4f9b5a":[6,0,0,1070,0],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html":[7,0,0,1044],
-"class_ogre_1_1_vulkan_discard_buffer_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1044,13],
+"class_ogre_1_1_vulkan_discard_buffer_manager.html":[6,0,0,1071],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1071,13],
+"class_ogre_1_1_vulkan_discard_buffer_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1044,13],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a2d144ca837c29108dfdc82daea54e887":[6,0,0,1071,2],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a2d144ca837c29108dfdc82daea54e887":[7,0,0,1044,2],
-"class_ogre_1_1_vulkan_discard_buffer_manager.html#a2e4b4853c8d7ab81c678db4d3e7db658":[7,0,0,1044,4],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a2e4b4853c8d7ab81c678db4d3e7db658":[6,0,0,1071,4],
+"class_ogre_1_1_vulkan_discard_buffer_manager.html#a2e4b4853c8d7ab81c678db4d3e7db658":[7,0,0,1044,4],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a31cc71ce6861395f03d97e76d644436f":[6,0,0,1071,3],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a31cc71ce6861395f03d97e76d644436f":[7,0,0,1044,3],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a33a0b1462a6b6284254f6c5343a871c1":[7,0,0,1044,9],
@@ -189,28 +191,28 @@ var NAVTREEINDEX243 =
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a5d41afbb6ab442ee5a231d366b8b2074":[6,0,0,1071,10],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1044,18],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1071,18],
-"class_ogre_1_1_vulkan_discard_buffer_manager.html#a67a04a614b0918e1f698fed85c6da742":[7,0,0,1044,8],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a67a04a614b0918e1f698fed85c6da742":[6,0,0,1071,8],
+"class_ogre_1_1_vulkan_discard_buffer_manager.html#a67a04a614b0918e1f698fed85c6da742":[7,0,0,1044,8],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a7f09d19433e5b4f441873440ee217ef8":[7,0,0,1044,6],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a7f09d19433e5b4f441873440ee217ef8":[6,0,0,1071,6],
-"class_ogre_1_1_vulkan_discard_buffer_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1071,11],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1044,11],
-"class_ogre_1_1_vulkan_discard_buffer_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1071,14],
+"class_ogre_1_1_vulkan_discard_buffer_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1071,11],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1044,14],
+"class_ogre_1_1_vulkan_discard_buffer_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1071,14],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#ab1c67584902d5c96beac8796eeb98c1e":[7,0,0,1044,1],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#ab1c67584902d5c96beac8796eeb98c1e":[6,0,0,1071,1],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1071,17],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1044,17],
-"class_ogre_1_1_vulkan_discard_buffer_manager.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1044,12],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1071,12],
+"class_ogre_1_1_vulkan_discard_buffer_manager.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1044,12],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1071,16],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1044,16],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#ad6bf748ad9a36bd6d01b14e86f598153":[7,0,0,1044,7],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#ad6bf748ad9a36bd6d01b14e86f598153":[6,0,0,1071,7],
-"class_ogre_1_1_vulkan_discard_buffer_manager.html#adce32528577d71b228692df906ecd17c":[6,0,0,1071,19],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#adce32528577d71b228692df906ecd17c":[7,0,0,1044,19],
-"class_ogre_1_1_vulkan_discard_buffer_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1071,20],
+"class_ogre_1_1_vulkan_discard_buffer_manager.html#adce32528577d71b228692df906ecd17c":[6,0,0,1071,19],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1044,20],
+"class_ogre_1_1_vulkan_discard_buffer_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1071,20],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#af26e92383fdf7a150429e63cf13210b8":[6,0,0,1071,5],
 "class_ogre_1_1_vulkan_discard_buffer_manager.html#af26e92383fdf7a150429e63cf13210b8":[7,0,0,1044,5],
 "class_ogre_1_1_vulkan_dynamic_buffer.html":[7,0,0,1045],
@@ -221,33 +223,31 @@ var NAVTREEINDEX243 =
 "class_ogre_1_1_vulkan_dynamic_buffer.html#a345e4583a228d36d78bb7ddc9ae55f1d":[7,0,0,1045,0],
 "class_ogre_1_1_vulkan_dynamic_buffer.html#a34d2249c90567be33f6acf91c1395b01":[7,0,0,1045,1],
 "class_ogre_1_1_vulkan_dynamic_buffer.html#a34d2249c90567be33f6acf91c1395b01":[6,0,0,1072,1],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#a6b8e75fbcce84d06c1e4c8870a22a211":[7,0,0,1045,6],
 "class_ogre_1_1_vulkan_dynamic_buffer.html#a6b8e75fbcce84d06c1e4c8870a22a211":[6,0,0,1072,6],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#aa24bed0666c1554569243ba3748f52c9":[7,0,0,1045,2],
+"class_ogre_1_1_vulkan_dynamic_buffer.html#a6b8e75fbcce84d06c1e4c8870a22a211":[7,0,0,1045,6],
 "class_ogre_1_1_vulkan_dynamic_buffer.html#aa24bed0666c1554569243ba3748f52c9":[6,0,0,1072,2],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#adfad704654c931d96827c49fc6165142":[7,0,0,1045,5],
+"class_ogre_1_1_vulkan_dynamic_buffer.html#aa24bed0666c1554569243ba3748f52c9":[7,0,0,1045,2],
 "class_ogre_1_1_vulkan_dynamic_buffer.html#adfad704654c931d96827c49fc6165142":[6,0,0,1072,5],
-"class_ogre_1_1_vulkan_dynamic_buffer.html#af1266978fe2a746af99b88ffb2e90598":[7,0,0,1045,4],
+"class_ogre_1_1_vulkan_dynamic_buffer.html#adfad704654c931d96827c49fc6165142":[7,0,0,1045,5],
 "class_ogre_1_1_vulkan_dynamic_buffer.html#af1266978fe2a746af99b88ffb2e90598":[6,0,0,1072,4],
+"class_ogre_1_1_vulkan_dynamic_buffer.html#af1266978fe2a746af99b88ffb2e90598":[7,0,0,1045,4],
 "class_ogre_1_1_vulkan_gpu_program_manager.html":[6,0,0,1079],
 "class_ogre_1_1_vulkan_gpu_program_manager.html":[7,0,0,1052],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[6,0,0,1079,27],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[7,0,0,1052,27],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[6,0,0,1079,27],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[6,0,0,1079,46],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[7,0,0,1052,46],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a02228d2937847ffae1a620633cf0c3a3":[6,0,0,1079,49],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a02228d2937847ffae1a620633cf0c3a3":[7,0,0,1052,49],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a02228d2937847ffae1a620633cf0c3a3":[6,0,0,1079,49],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a0b3d897dacdf542d029ea2d2a5a988c7":[6,0,0,1079,78],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a0b3d897dacdf542d029ea2d2a5a988c7":[7,0,0,1052,78],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[7,0,0,1052,41],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[6,0,0,1079,41],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a117a3887bbf9e83e0585777beb0501dc":[7,0,0,1052,7],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a117a3887bbf9e83e0585777beb0501dc":[6,0,0,1079,7],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1079,60],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a117a3887bbf9e83e0585777beb0501dc":[7,0,0,1052,7],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1052,60],
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1079,60],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a1eadda53bbed16d5a3804cdba2ad687e":[7,0,0,1052,23],
 "class_ogre_1_1_vulkan_gpu_program_manager.html#a1eadda53bbed16d5a3804cdba2ad687e":[6,0,0,1079,23],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[6,0,0,1079,88],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[7,0,0,1052,88],
-"class_ogre_1_1_vulkan_gpu_program_manager.html#a2208200adc00affea9fee67fec2f393e":[6,0,0,1079,19]
+"class_ogre_1_1_vulkan_gpu_program_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[6,0,0,1079,88]
 };
