@@ -1,106 +1,108 @@
 var NAVTREEINDEX249 =
 {
+"class_ogre_1_1_vulkan_render_system.html#af6c4d0d09a50986e45a2badc5ebfd8e5":[6,0,0,1090,117],
+"class_ogre_1_1_vulkan_render_system.html#af6e6be5710a412edd5d35b967d2aa7fe":[6,0,0,1090,126],
 "class_ogre_1_1_vulkan_render_system.html#af6e6be5710a412edd5d35b967d2aa7fe":[7,0,0,1063,126],
-"class_ogre_1_1_vulkan_render_system.html#af74fe84bbf79115f60978a0d2e237ec0":[7,0,0,1063,116],
 "class_ogre_1_1_vulkan_render_system.html#af74fe84bbf79115f60978a0d2e237ec0":[6,0,0,1090,116],
-"class_ogre_1_1_vulkan_render_system.html#af771f5b74fd9f09e4abb9d934c45c4c2":[6,0,0,1090,32],
+"class_ogre_1_1_vulkan_render_system.html#af74fe84bbf79115f60978a0d2e237ec0":[7,0,0,1063,116],
 "class_ogre_1_1_vulkan_render_system.html#af771f5b74fd9f09e4abb9d934c45c4c2":[7,0,0,1063,32],
-"class_ogre_1_1_vulkan_render_system.html#af8273ee1ce0d05357003e8f4b663a59a":[7,0,0,1063,78],
+"class_ogre_1_1_vulkan_render_system.html#af771f5b74fd9f09e4abb9d934c45c4c2":[6,0,0,1090,32],
 "class_ogre_1_1_vulkan_render_system.html#af8273ee1ce0d05357003e8f4b663a59a":[6,0,0,1090,78],
+"class_ogre_1_1_vulkan_render_system.html#af8273ee1ce0d05357003e8f4b663a59a":[7,0,0,1063,78],
 "class_ogre_1_1_vulkan_render_system.html#afb6f61d5c70531c1eb718cdfbefb0330":[7,0,0,1063,139],
 "class_ogre_1_1_vulkan_render_system.html#afb6f61d5c70531c1eb718cdfbefb0330":[6,0,0,1090,139],
-"class_ogre_1_1_vulkan_render_system.html#afe7705e26f10dccebf2e6db0b3d6859e":[6,0,0,1090,231],
 "class_ogre_1_1_vulkan_render_system.html#afe7705e26f10dccebf2e6db0b3d6859e":[7,0,0,1063,231],
+"class_ogre_1_1_vulkan_render_system.html#afe7705e26f10dccebf2e6db0b3d6859e":[6,0,0,1090,231],
 "class_ogre_1_1_vulkan_render_system.html#afed3a97961723f4beee7d0e041861537":[7,0,0,1063,86],
 "class_ogre_1_1_vulkan_render_system.html#afed3a97961723f4beee7d0e041861537":[6,0,0,1090,86],
 "class_ogre_1_1_vulkan_render_system.html#aff153290d3133c817fede28a2adb6765":[7,0,0,1063,232],
 "class_ogre_1_1_vulkan_render_system.html#aff153290d3133c817fede28a2adb6765":[6,0,0,1090,232],
 "class_ogre_1_1_vulkan_root_layout.html":[6,0,0,1092],
 "class_ogre_1_1_vulkan_root_layout.html":[7,0,0,1065],
-"class_ogre_1_1_vulkan_root_layout.html#a0d927a71ab1acfa3931b1188a6e1480a":[6,0,0,1092,9],
 "class_ogre_1_1_vulkan_root_layout.html#a0d927a71ab1acfa3931b1188a6e1480a":[7,0,0,1065,9],
-"class_ogre_1_1_vulkan_root_layout.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1065,15],
+"class_ogre_1_1_vulkan_root_layout.html#a0d927a71ab1acfa3931b1188a6e1480a":[6,0,0,1092,9],
 "class_ogre_1_1_vulkan_root_layout.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1092,15],
+"class_ogre_1_1_vulkan_root_layout.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1065,15],
 "class_ogre_1_1_vulkan_root_layout.html#a25608d1929f65056de8e0e5996e209a5":[6,0,0,1092,11],
 "class_ogre_1_1_vulkan_root_layout.html#a25608d1929f65056de8e0e5996e209a5":[7,0,0,1065,11],
-"class_ogre_1_1_vulkan_root_layout.html#a27333b345d35a516d87acb27254f5e04":[6,0,0,1092,10],
 "class_ogre_1_1_vulkan_root_layout.html#a27333b345d35a516d87acb27254f5e04":[7,0,0,1065,10],
-"class_ogre_1_1_vulkan_root_layout.html#a318c84cc19da854cb57455e7198b1fb7":[6,0,0,1092,1],
+"class_ogre_1_1_vulkan_root_layout.html#a27333b345d35a516d87acb27254f5e04":[6,0,0,1092,10],
 "class_ogre_1_1_vulkan_root_layout.html#a318c84cc19da854cb57455e7198b1fb7":[7,0,0,1065,1],
+"class_ogre_1_1_vulkan_root_layout.html#a318c84cc19da854cb57455e7198b1fb7":[6,0,0,1092,1],
 "class_ogre_1_1_vulkan_root_layout.html#a361b85faf30f42c8ac64156cfe5a95a3":[6,0,0,1092,23],
 "class_ogre_1_1_vulkan_root_layout.html#a361b85faf30f42c8ac64156cfe5a95a3":[7,0,0,1065,23],
 "class_ogre_1_1_vulkan_root_layout.html#a36999a994bdb79682e5129ce9ac203d8":[7,0,0,1065,12],
 "class_ogre_1_1_vulkan_root_layout.html#a36999a994bdb79682e5129ce9ac203d8":[6,0,0,1092,12],
-"class_ogre_1_1_vulkan_root_layout.html#a3ef67efe4ad643c10b343e3232b34a9d":[7,0,0,1065,5],
 "class_ogre_1_1_vulkan_root_layout.html#a3ef67efe4ad643c10b343e3232b34a9d":[6,0,0,1092,5],
+"class_ogre_1_1_vulkan_root_layout.html#a3ef67efe4ad643c10b343e3232b34a9d":[7,0,0,1065,5],
 "class_ogre_1_1_vulkan_root_layout.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1065,17],
 "class_ogre_1_1_vulkan_root_layout.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1092,17],
-"class_ogre_1_1_vulkan_root_layout.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1092,20],
 "class_ogre_1_1_vulkan_root_layout.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1065,20],
+"class_ogre_1_1_vulkan_root_layout.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1092,20],
 "class_ogre_1_1_vulkan_root_layout.html#a6e51554ba393692d98e24c6146a29bf3":[6,0,0,1092,8],
 "class_ogre_1_1_vulkan_root_layout.html#a6e51554ba393692d98e24c6146a29bf3":[7,0,0,1065,8],
-"class_ogre_1_1_vulkan_root_layout.html#a79f0e0981e96957aa9a39719b8e70444":[7,0,0,1065,4],
 "class_ogre_1_1_vulkan_root_layout.html#a79f0e0981e96957aa9a39719b8e70444":[6,0,0,1092,4],
-"class_ogre_1_1_vulkan_root_layout.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1065,13],
+"class_ogre_1_1_vulkan_root_layout.html#a79f0e0981e96957aa9a39719b8e70444":[7,0,0,1065,4],
 "class_ogre_1_1_vulkan_root_layout.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1092,13],
+"class_ogre_1_1_vulkan_root_layout.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1065,13],
 "class_ogre_1_1_vulkan_root_layout.html#a8ace64a521d831703a6f6881f0d1e318":[7,0,0,1065,25],
 "class_ogre_1_1_vulkan_root_layout.html#a8ace64a521d831703a6f6881f0d1e318":[6,0,0,1092,25],
-"class_ogre_1_1_vulkan_root_layout.html#a916a788bbf6b7d28d82a7a55c40bdef2":[6,0,0,1092,2],
 "class_ogre_1_1_vulkan_root_layout.html#a916a788bbf6b7d28d82a7a55c40bdef2":[7,0,0,1065,2],
+"class_ogre_1_1_vulkan_root_layout.html#a916a788bbf6b7d28d82a7a55c40bdef2":[6,0,0,1092,2],
 "class_ogre_1_1_vulkan_root_layout.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1092,16],
 "class_ogre_1_1_vulkan_root_layout.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1065,16],
 "class_ogre_1_1_vulkan_root_layout.html#aa948ba479d75b0920922eb309a1e7a27":[6,0,0,1092,6],
 "class_ogre_1_1_vulkan_root_layout.html#aa948ba479d75b0920922eb309a1e7a27":[7,0,0,1065,6],
 "class_ogre_1_1_vulkan_root_layout.html#aade6b1af85f8aef53ff225c7d8034fe8":[7,0,0,1065,7],
 "class_ogre_1_1_vulkan_root_layout.html#aade6b1af85f8aef53ff225c7d8034fe8":[6,0,0,1092,7],
-"class_ogre_1_1_vulkan_root_layout.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1065,19],
 "class_ogre_1_1_vulkan_root_layout.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1092,19],
+"class_ogre_1_1_vulkan_root_layout.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1065,19],
 "class_ogre_1_1_vulkan_root_layout.html#abf9d8c87c8aefe908e3214d60a2d7d9c":[7,0,0,1065,24],
 "class_ogre_1_1_vulkan_root_layout.html#abf9d8c87c8aefe908e3214d60a2d7d9c":[6,0,0,1092,24],
 "class_ogre_1_1_vulkan_root_layout.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1092,14],
 "class_ogre_1_1_vulkan_root_layout.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1065,14],
-"class_ogre_1_1_vulkan_root_layout.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1065,18],
 "class_ogre_1_1_vulkan_root_layout.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1092,18],
+"class_ogre_1_1_vulkan_root_layout.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1065,18],
 "class_ogre_1_1_vulkan_root_layout.html#adce32528577d71b228692df906ecd17c":[6,0,0,1092,21],
 "class_ogre_1_1_vulkan_root_layout.html#adce32528577d71b228692df906ecd17c":[7,0,0,1065,21],
 "class_ogre_1_1_vulkan_root_layout.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1065,22],
 "class_ogre_1_1_vulkan_root_layout.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1092,22],
 "class_ogre_1_1_vulkan_root_layout.html#aef40f58e9a630efbd881f99a5b81e7df":[6,0,0,1092,3],
 "class_ogre_1_1_vulkan_root_layout.html#aef40f58e9a630efbd881f99a5b81e7df":[7,0,0,1065,3],
-"class_ogre_1_1_vulkan_root_layout.html#af0d0e6f18e612dc23ba3fc66a91fe169":[6,0,0,1092,0],
 "class_ogre_1_1_vulkan_root_layout.html#af0d0e6f18e612dc23ba3fc66a91fe169":[7,0,0,1065,0],
-"class_ogre_1_1_vulkan_staging_buffer.html":[6,0,0,1093],
+"class_ogre_1_1_vulkan_root_layout.html#af0d0e6f18e612dc23ba3fc66a91fe169":[6,0,0,1092,0],
 "class_ogre_1_1_vulkan_staging_buffer.html":[7,0,0,1066],
-"class_ogre_1_1_vulkan_staging_buffer.html#a0512e57da9c9f75e7666133a10883126":[6,0,0,1093,13],
+"class_ogre_1_1_vulkan_staging_buffer.html":[6,0,0,1093],
 "class_ogre_1_1_vulkan_staging_buffer.html#a0512e57da9c9f75e7666133a10883126":[7,0,0,1066,13],
-"class_ogre_1_1_vulkan_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[6,0,0,1093,17],
+"class_ogre_1_1_vulkan_staging_buffer.html#a0512e57da9c9f75e7666133a10883126":[6,0,0,1093,13],
 "class_ogre_1_1_vulkan_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[7,0,0,1066,17],
-"class_ogre_1_1_vulkan_staging_buffer.html#a06b3928d00037b776f2adcab1964adac":[6,0,0,1093,1],
+"class_ogre_1_1_vulkan_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[6,0,0,1093,17],
 "class_ogre_1_1_vulkan_staging_buffer.html#a06b3928d00037b776f2adcab1964adac":[7,0,0,1066,1],
+"class_ogre_1_1_vulkan_staging_buffer.html#a06b3928d00037b776f2adcab1964adac":[6,0,0,1093,1],
 "class_ogre_1_1_vulkan_staging_buffer.html#a06dfed7c83a6aa991b0bceef76743550":[6,0,0,1093,12],
 "class_ogre_1_1_vulkan_staging_buffer.html#a06dfed7c83a6aa991b0bceef76743550":[7,0,0,1066,12],
-"class_ogre_1_1_vulkan_staging_buffer.html#a10b28de5293c036bf7f23e87bef00de6":[7,0,0,1066,9],
 "class_ogre_1_1_vulkan_staging_buffer.html#a10b28de5293c036bf7f23e87bef00de6":[6,0,0,1093,9],
+"class_ogre_1_1_vulkan_staging_buffer.html#a10b28de5293c036bf7f23e87bef00de6":[7,0,0,1066,9],
 "class_ogre_1_1_vulkan_staging_buffer.html#a151f289bc3b042bd3e63b7f9e4869856":[7,0,0,1066,3],
 "class_ogre_1_1_vulkan_staging_buffer.html#a151f289bc3b042bd3e63b7f9e4869856":[6,0,0,1093,3],
 "class_ogre_1_1_vulkan_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[6,0,0,1093,11],
 "class_ogre_1_1_vulkan_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[7,0,0,1066,11],
 "class_ogre_1_1_vulkan_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1066,21],
 "class_ogre_1_1_vulkan_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1093,21],
-"class_ogre_1_1_vulkan_staging_buffer.html#a29313389dacd812a8d238df458f9e979":[7,0,0,1066,29],
 "class_ogre_1_1_vulkan_staging_buffer.html#a29313389dacd812a8d238df458f9e979":[6,0,0,1093,29],
+"class_ogre_1_1_vulkan_staging_buffer.html#a29313389dacd812a8d238df458f9e979":[7,0,0,1066,29],
 "class_ogre_1_1_vulkan_staging_buffer.html#a438d82f09b5f657be30c30d7d1c0801d":[7,0,0,1066,30],
 "class_ogre_1_1_vulkan_staging_buffer.html#a438d82f09b5f657be30c30d7d1c0801d":[6,0,0,1093,30],
-"class_ogre_1_1_vulkan_staging_buffer.html#a5239fe8fda6e2de02e5c053edb69661a":[7,0,0,1066,18],
 "class_ogre_1_1_vulkan_staging_buffer.html#a5239fe8fda6e2de02e5c053edb69661a":[6,0,0,1093,18],
+"class_ogre_1_1_vulkan_staging_buffer.html#a5239fe8fda6e2de02e5c053edb69661a":[7,0,0,1066,18],
 "class_ogre_1_1_vulkan_staging_buffer.html#a53adbd5b91819a0e58c9d2c010eba469":[7,0,0,1066,16],
 "class_ogre_1_1_vulkan_staging_buffer.html#a53adbd5b91819a0e58c9d2c010eba469":[6,0,0,1093,16],
 "class_ogre_1_1_vulkan_staging_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1093,23],
 "class_ogre_1_1_vulkan_staging_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1066,23],
-"class_ogre_1_1_vulkan_staging_buffer.html#a5bbcbfc7e6f414cb12a89fafd3e38d61":[7,0,0,1066,2],
 "class_ogre_1_1_vulkan_staging_buffer.html#a5bbcbfc7e6f414cb12a89fafd3e38d61":[6,0,0,1093,2],
-"class_ogre_1_1_vulkan_staging_buffer.html#a63009ab3e7ed3826fc4c7766887c9984":[6,0,0,1093,33],
+"class_ogre_1_1_vulkan_staging_buffer.html#a5bbcbfc7e6f414cb12a89fafd3e38d61":[7,0,0,1066,2],
 "class_ogre_1_1_vulkan_staging_buffer.html#a63009ab3e7ed3826fc4c7766887c9984":[7,0,0,1066,33],
+"class_ogre_1_1_vulkan_staging_buffer.html#a63009ab3e7ed3826fc4c7766887c9984":[6,0,0,1093,33],
 "class_ogre_1_1_vulkan_staging_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1093,26],
 "class_ogre_1_1_vulkan_staging_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1066,26],
 "class_ogre_1_1_vulkan_staging_buffer.html#a765f26f80115c9341308fc86330ec9c2":[7,0,0,1066,14],
@@ -109,50 +111,50 @@ var NAVTREEINDEX249 =
 "class_ogre_1_1_vulkan_staging_buffer.html#a8047cc93c004c2f6c5700aca44e35b2a":[7,0,0,1066,6],
 "class_ogre_1_1_vulkan_staging_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1093,19],
 "class_ogre_1_1_vulkan_staging_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1066,19],
-"class_ogre_1_1_vulkan_staging_buffer.html#a897e0ef920699d059b273eed1fe71d4d":[6,0,0,1093,15],
 "class_ogre_1_1_vulkan_staging_buffer.html#a897e0ef920699d059b273eed1fe71d4d":[7,0,0,1066,15],
+"class_ogre_1_1_vulkan_staging_buffer.html#a897e0ef920699d059b273eed1fe71d4d":[6,0,0,1093,15],
 "class_ogre_1_1_vulkan_staging_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1066,22],
 "class_ogre_1_1_vulkan_staging_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1093,22],
 "class_ogre_1_1_vulkan_staging_buffer.html#a9c8e2853c21a7418218605a0b9cdf461":[6,0,0,1093,31],
 "class_ogre_1_1_vulkan_staging_buffer.html#a9c8e2853c21a7418218605a0b9cdf461":[7,0,0,1066,31],
 "class_ogre_1_1_vulkan_staging_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1066,25],
 "class_ogre_1_1_vulkan_staging_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1093,25],
-"class_ogre_1_1_vulkan_staging_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1093,20],
 "class_ogre_1_1_vulkan_staging_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1066,20],
-"class_ogre_1_1_vulkan_staging_buffer.html#ad19e1f4f9852de0682a98ebb662ee591":[7,0,0,1066,8],
+"class_ogre_1_1_vulkan_staging_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1093,20],
 "class_ogre_1_1_vulkan_staging_buffer.html#ad19e1f4f9852de0682a98ebb662ee591":[6,0,0,1093,8],
+"class_ogre_1_1_vulkan_staging_buffer.html#ad19e1f4f9852de0682a98ebb662ee591":[7,0,0,1066,8],
 "class_ogre_1_1_vulkan_staging_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1093,24],
 "class_ogre_1_1_vulkan_staging_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1066,24],
-"class_ogre_1_1_vulkan_staging_buffer.html#ad844466b16d039d78fe762a3e32f92c2":[6,0,0,1093,10],
 "class_ogre_1_1_vulkan_staging_buffer.html#ad844466b16d039d78fe762a3e32f92c2":[7,0,0,1066,10],
+"class_ogre_1_1_vulkan_staging_buffer.html#ad844466b16d039d78fe762a3e32f92c2":[6,0,0,1093,10],
 "class_ogre_1_1_vulkan_staging_buffer.html#ad9db4541715b29e151043a09a24a527a":[7,0,0,1066,5],
 "class_ogre_1_1_vulkan_staging_buffer.html#ad9db4541715b29e151043a09a24a527a":[6,0,0,1093,5],
-"class_ogre_1_1_vulkan_staging_buffer.html#adce32528577d71b228692df906ecd17c":[6,0,0,1093,27],
 "class_ogre_1_1_vulkan_staging_buffer.html#adce32528577d71b228692df906ecd17c":[7,0,0,1066,27],
-"class_ogre_1_1_vulkan_staging_buffer.html#ae10b1ca31103509cc93580707f9c081c":[6,0,0,1093,4],
+"class_ogre_1_1_vulkan_staging_buffer.html#adce32528577d71b228692df906ecd17c":[6,0,0,1093,27],
 "class_ogre_1_1_vulkan_staging_buffer.html#ae10b1ca31103509cc93580707f9c081c":[7,0,0,1066,4],
-"class_ogre_1_1_vulkan_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[6,0,0,1093,0],
+"class_ogre_1_1_vulkan_staging_buffer.html#ae10b1ca31103509cc93580707f9c081c":[6,0,0,1093,4],
 "class_ogre_1_1_vulkan_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[7,0,0,1066,0],
-"class_ogre_1_1_vulkan_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1066,28],
+"class_ogre_1_1_vulkan_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[6,0,0,1093,0],
 "class_ogre_1_1_vulkan_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1093,28],
-"class_ogre_1_1_vulkan_staging_buffer.html#af302f0f2418222952fdc3f1b46499638":[6,0,0,1093,7],
+"class_ogre_1_1_vulkan_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1066,28],
 "class_ogre_1_1_vulkan_staging_buffer.html#af302f0f2418222952fdc3f1b46499638":[7,0,0,1066,7],
-"class_ogre_1_1_vulkan_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[7,0,0,1066,32],
+"class_ogre_1_1_vulkan_staging_buffer.html#af302f0f2418222952fdc3f1b46499638":[6,0,0,1093,7],
 "class_ogre_1_1_vulkan_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[6,0,0,1093,32],
-"class_ogre_1_1_vulkan_staging_texture.html":[6,0,0,1094],
+"class_ogre_1_1_vulkan_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[7,0,0,1066,32],
 "class_ogre_1_1_vulkan_staging_texture.html":[7,0,0,1067],
-"class_ogre_1_1_vulkan_staging_texture.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1094,16],
+"class_ogre_1_1_vulkan_staging_texture.html":[6,0,0,1094],
 "class_ogre_1_1_vulkan_staging_texture.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1067,16],
-"class_ogre_1_1_vulkan_staging_texture.html#a20b8f55c40f5a54344feb86af13bc7f6":[7,0,0,1067,4],
+"class_ogre_1_1_vulkan_staging_texture.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1094,16],
 "class_ogre_1_1_vulkan_staging_texture.html#a20b8f55c40f5a54344feb86af13bc7f6":[6,0,0,1094,4],
-"class_ogre_1_1_vulkan_staging_texture.html#a2c77f84776623ba4ed6d5e0cf29d2c57":[7,0,0,1067,12],
+"class_ogre_1_1_vulkan_staging_texture.html#a20b8f55c40f5a54344feb86af13bc7f6":[7,0,0,1067,4],
 "class_ogre_1_1_vulkan_staging_texture.html#a2c77f84776623ba4ed6d5e0cf29d2c57":[6,0,0,1094,12],
+"class_ogre_1_1_vulkan_staging_texture.html#a2c77f84776623ba4ed6d5e0cf29d2c57":[7,0,0,1067,12],
 "class_ogre_1_1_vulkan_staging_texture.html#a3b415effaa2eb00ce82916ee24b2e131":[6,0,0,1094,11],
 "class_ogre_1_1_vulkan_staging_texture.html#a3b415effaa2eb00ce82916ee24b2e131":[7,0,0,1067,11],
-"class_ogre_1_1_vulkan_staging_texture.html#a3b6678af690403bd1273489583a166a7":[7,0,0,1067,8],
 "class_ogre_1_1_vulkan_staging_texture.html#a3b6678af690403bd1273489583a166a7":[6,0,0,1094,8],
-"class_ogre_1_1_vulkan_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1094,18],
+"class_ogre_1_1_vulkan_staging_texture.html#a3b6678af690403bd1273489583a166a7":[7,0,0,1067,8],
 "class_ogre_1_1_vulkan_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1067,18],
+"class_ogre_1_1_vulkan_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1094,18],
 "class_ogre_1_1_vulkan_staging_texture.html#a6128b622f7b8df0fb9cf94d2a99db4d8":[6,0,0,1094,2],
 "class_ogre_1_1_vulkan_staging_texture.html#a6128b622f7b8df0fb9cf94d2a99db4d8":[7,0,0,1067,2],
 "class_ogre_1_1_vulkan_staging_texture.html#a63e494e2f4ba1c65ff3ea79e25bfbfc6":[6,0,0,1094,9],
@@ -163,14 +165,14 @@ var NAVTREEINDEX249 =
 "class_ogre_1_1_vulkan_staging_texture.html#a78811a1f476d18f8ba184ac2a7bdd168":[6,0,0,1094,26],
 "class_ogre_1_1_vulkan_staging_texture.html#a81c473630ec227390cd73cd258350b1b":[7,0,0,1067,7],
 "class_ogre_1_1_vulkan_staging_texture.html#a81c473630ec227390cd73cd258350b1b":[6,0,0,1094,7],
-"class_ogre_1_1_vulkan_staging_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1067,14],
 "class_ogre_1_1_vulkan_staging_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1094,14],
+"class_ogre_1_1_vulkan_staging_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1067,14],
 "class_ogre_1_1_vulkan_staging_texture.html#a8996efde036324ee9c422d11d91a6215":[6,0,0,1094,28],
 "class_ogre_1_1_vulkan_staging_texture.html#a8996efde036324ee9c422d11d91a6215":[7,0,0,1067,28],
 "class_ogre_1_1_vulkan_staging_texture.html#a8b006d42b9d0fc4c5e84a98ff61dd862":[7,0,0,1067,1],
 "class_ogre_1_1_vulkan_staging_texture.html#a8b006d42b9d0fc4c5e84a98ff61dd862":[6,0,0,1094,1],
-"class_ogre_1_1_vulkan_staging_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1067,17],
 "class_ogre_1_1_vulkan_staging_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1094,17],
+"class_ogre_1_1_vulkan_staging_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1067,17],
 "class_ogre_1_1_vulkan_staging_texture.html#a9c55be7d477bda7d0e8616a45ac8611d":[6,0,0,1094,5],
 "class_ogre_1_1_vulkan_staging_texture.html#a9c55be7d477bda7d0e8616a45ac8611d":[7,0,0,1067,5],
 "class_ogre_1_1_vulkan_staging_texture.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1067,20],
@@ -179,48 +181,48 @@ var NAVTREEINDEX249 =
 "class_ogre_1_1_vulkan_staging_texture.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1094,15],
 "class_ogre_1_1_vulkan_staging_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1067,19],
 "class_ogre_1_1_vulkan_staging_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1094,19],
-"class_ogre_1_1_vulkan_staging_texture.html#ad34f6bc75407060643f55f4537a5ca6c":[6,0,0,1094,3],
 "class_ogre_1_1_vulkan_staging_texture.html#ad34f6bc75407060643f55f4537a5ca6c":[7,0,0,1067,3],
+"class_ogre_1_1_vulkan_staging_texture.html#ad34f6bc75407060643f55f4537a5ca6c":[6,0,0,1094,3],
 "class_ogre_1_1_vulkan_staging_texture.html#ad77c4ab01bab775ae95c3ff5eb0228f9":[6,0,0,1094,25],
 "class_ogre_1_1_vulkan_staging_texture.html#ad77c4ab01bab775ae95c3ff5eb0228f9":[7,0,0,1067,25],
-"class_ogre_1_1_vulkan_staging_texture.html#ad9cdc02161b43fe630598e4102de2943":[6,0,0,1094,0],
 "class_ogre_1_1_vulkan_staging_texture.html#ad9cdc02161b43fe630598e4102de2943":[7,0,0,1067,0],
-"class_ogre_1_1_vulkan_staging_texture.html#adce32528577d71b228692df906ecd17c":[6,0,0,1094,22],
+"class_ogre_1_1_vulkan_staging_texture.html#ad9cdc02161b43fe630598e4102de2943":[6,0,0,1094,0],
 "class_ogre_1_1_vulkan_staging_texture.html#adce32528577d71b228692df906ecd17c":[7,0,0,1067,22],
+"class_ogre_1_1_vulkan_staging_texture.html#adce32528577d71b228692df906ecd17c":[6,0,0,1094,22],
 "class_ogre_1_1_vulkan_staging_texture.html#adf5cc3adc54a4ab2ea4e83cde01b3398":[7,0,0,1067,13],
 "class_ogre_1_1_vulkan_staging_texture.html#adf5cc3adc54a4ab2ea4e83cde01b3398":[6,0,0,1094,13],
-"class_ogre_1_1_vulkan_staging_texture.html#aebe758a62fff05256e61214a8176dcb1":[7,0,0,1067,27],
 "class_ogre_1_1_vulkan_staging_texture.html#aebe758a62fff05256e61214a8176dcb1":[6,0,0,1094,27],
-"class_ogre_1_1_vulkan_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1067,23],
+"class_ogre_1_1_vulkan_staging_texture.html#aebe758a62fff05256e61214a8176dcb1":[7,0,0,1067,27],
 "class_ogre_1_1_vulkan_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1094,23],
-"class_ogre_1_1_vulkan_staging_texture.html#aedad317c892dbc0c079de8452a91fcff":[7,0,0,1067,24],
+"class_ogre_1_1_vulkan_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1067,23],
 "class_ogre_1_1_vulkan_staging_texture.html#aedad317c892dbc0c079de8452a91fcff":[6,0,0,1094,24],
-"class_ogre_1_1_vulkan_staging_texture.html#af880dfa4d3f849a20ffb03a4c248d997":[6,0,0,1094,10],
+"class_ogre_1_1_vulkan_staging_texture.html#aedad317c892dbc0c079de8452a91fcff":[7,0,0,1067,24],
 "class_ogre_1_1_vulkan_staging_texture.html#af880dfa4d3f849a20ffb03a4c248d997":[7,0,0,1067,10],
-"class_ogre_1_1_vulkan_staging_texture.html#afa13e8aebac574c7d9ed23b1dafd17cc":[6,0,0,1094,6],
+"class_ogre_1_1_vulkan_staging_texture.html#af880dfa4d3f849a20ffb03a4c248d997":[6,0,0,1094,10],
 "class_ogre_1_1_vulkan_staging_texture.html#afa13e8aebac574c7d9ed23b1dafd17cc":[7,0,0,1067,6],
+"class_ogre_1_1_vulkan_staging_texture.html#afa13e8aebac574c7d9ed23b1dafd17cc":[6,0,0,1094,6],
 "class_ogre_1_1_vulkan_support.html":[6,0,0,1095],
 "class_ogre_1_1_vulkan_support.html":[7,0,0,1068],
 "class_ogre_1_1_vulkan_support.html#a36fba22aab78a8edf13890ca94622f21":[6,0,0,1095,8],
 "class_ogre_1_1_vulkan_support.html#a36fba22aab78a8edf13890ca94622f21":[7,0,0,1068,8],
 "class_ogre_1_1_vulkan_support.html#a86746d239ebe765693db1f1b46f55fd7":[7,0,0,1068,11],
 "class_ogre_1_1_vulkan_support.html#a86746d239ebe765693db1f1b46f55fd7":[6,0,0,1095,11],
-"class_ogre_1_1_vulkan_support.html#a86bef7a792e9c3450da2fd697ff766c4":[7,0,0,1068,7],
 "class_ogre_1_1_vulkan_support.html#a86bef7a792e9c3450da2fd697ff766c4":[6,0,0,1095,7],
-"class_ogre_1_1_vulkan_support.html#a892fd0e6f60c161825d5bb06f2cb8eba":[6,0,0,1095,6],
+"class_ogre_1_1_vulkan_support.html#a86bef7a792e9c3450da2fd697ff766c4":[7,0,0,1068,7],
 "class_ogre_1_1_vulkan_support.html#a892fd0e6f60c161825d5bb06f2cb8eba":[7,0,0,1068,6],
-"class_ogre_1_1_vulkan_support.html#a8e415519f2a765ea62fac84f83e91b50":[7,0,0,1068,0],
+"class_ogre_1_1_vulkan_support.html#a892fd0e6f60c161825d5bb06f2cb8eba":[6,0,0,1095,6],
 "class_ogre_1_1_vulkan_support.html#a8e415519f2a765ea62fac84f83e91b50":[6,0,0,1095,0],
+"class_ogre_1_1_vulkan_support.html#a8e415519f2a765ea62fac84f83e91b50":[7,0,0,1068,0],
 "class_ogre_1_1_vulkan_support.html#a8fe7e04815023b25d4be5454386f6ac2":[7,0,0,1068,9],
 "class_ogre_1_1_vulkan_support.html#a8fe7e04815023b25d4be5454386f6ac2":[6,0,0,1095,9],
-"class_ogre_1_1_vulkan_support.html#a937704d31ee2446d22e4f2185fcf5f9b":[7,0,0,1068,1],
 "class_ogre_1_1_vulkan_support.html#a937704d31ee2446d22e4f2185fcf5f9b":[6,0,0,1095,1],
+"class_ogre_1_1_vulkan_support.html#a937704d31ee2446d22e4f2185fcf5f9b":[7,0,0,1068,1],
 "class_ogre_1_1_vulkan_support.html#a97b72f6fcab0c9513c6c2b8aace60476":[7,0,0,1068,3],
 "class_ogre_1_1_vulkan_support.html#a97b72f6fcab0c9513c6c2b8aace60476":[6,0,0,1095,3],
-"class_ogre_1_1_vulkan_support.html#a9baf3e657b4ef34f76709cfc0751ff50":[6,0,0,1095,5],
 "class_ogre_1_1_vulkan_support.html#a9baf3e657b4ef34f76709cfc0751ff50":[7,0,0,1068,5],
-"class_ogre_1_1_vulkan_support.html#abce0d5d7a77ce2824d5186dfe303d976":[7,0,0,1068,10],
+"class_ogre_1_1_vulkan_support.html#a9baf3e657b4ef34f76709cfc0751ff50":[6,0,0,1095,5],
 "class_ogre_1_1_vulkan_support.html#abce0d5d7a77ce2824d5186dfe303d976":[6,0,0,1095,10],
+"class_ogre_1_1_vulkan_support.html#abce0d5d7a77ce2824d5186dfe303d976":[7,0,0,1068,10],
 "class_ogre_1_1_vulkan_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9":[7,0,0,1068,4],
 "class_ogre_1_1_vulkan_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9":[6,0,0,1095,4],
 "class_ogre_1_1_vulkan_support.html#afc956785bff8c4a1446bc768b372999b":[7,0,0,1068,2],
@@ -229,25 +231,23 @@ var NAVTREEINDEX249 =
 "class_ogre_1_1_vulkan_tex_buffer_packed.html":[7,0,0,1069],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[6,0,0,1096,45],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[7,0,0,1069,45],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a0f04eced368e43eb51a35c58aa2834c5":[6,0,0,1096,0],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a0f04eced368e43eb51a35c58aa2834c5":[7,0,0,1069,0],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[7,0,0,1069,28],
+"class_ogre_1_1_vulkan_tex_buffer_packed.html#a0f04eced368e43eb51a35c58aa2834c5":[6,0,0,1096,0],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[6,0,0,1096,28],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[7,0,0,1069,17],
+"class_ogre_1_1_vulkan_tex_buffer_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[7,0,0,1069,28],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[6,0,0,1096,17],
+"class_ogre_1_1_vulkan_tex_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[7,0,0,1069,17],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a16bcbc91582374a3d69c23ab21646c54":[7,0,0,1069,1],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a16bcbc91582374a3d69c23ab21646c54":[6,0,0,1096,1],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1096,34],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1069,34],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[7,0,0,1069,10],
+"class_ogre_1_1_vulkan_tex_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1096,34],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[6,0,0,1096,10],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[6,0,0,1096,31],
+"class_ogre_1_1_vulkan_tex_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[7,0,0,1069,10],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[7,0,0,1069,31],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a275270a46543311f69bbc7ed45b6f395":[6,0,0,1096,2],
+"class_ogre_1_1_vulkan_tex_buffer_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[6,0,0,1096,31],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a275270a46543311f69bbc7ed45b6f395":[7,0,0,1069,2],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[7,0,0,1069,19],
+"class_ogre_1_1_vulkan_tex_buffer_packed.html#a275270a46543311f69bbc7ed45b6f395":[6,0,0,1096,2],
 "class_ogre_1_1_vulkan_tex_buffer_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[6,0,0,1096,19],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[6,0,0,1096,27],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[7,0,0,1069,27],
-"class_ogre_1_1_vulkan_tex_buffer_packed.html#a35b465c05a47ee960720d91c3271ecb8":[6,0,0,1096,12]
+"class_ogre_1_1_vulkan_tex_buffer_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[7,0,0,1069,19],
+"class_ogre_1_1_vulkan_tex_buffer_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[7,0,0,1069,27]
 };
