@@ -1,16 +1,18 @@
 var NAVTREEINDEX254 =
 {
+"class_ogre_1_1_vulkan_vao_manager.html#af7c18af1342b5ae1a15d55838b667935":[7,0,0,1075,28],
 "class_ogre_1_1_vulkan_vao_manager.html#afafd75ba72857e13a55e540a2d0ed414":[7,0,0,1075,17],
-"class_ogre_1_1_vulkan_vao_manager.html#afbc41371222b8bad4d0df08b1edeba2a":[6,0,0,1102,20],
+"class_ogre_1_1_vulkan_vao_manager.html#afafd75ba72857e13a55e540a2d0ed414":[6,0,0,1102,17],
 "class_ogre_1_1_vulkan_vao_manager.html#afbc41371222b8bad4d0df08b1edeba2a":[7,0,0,1075,20],
+"class_ogre_1_1_vulkan_vao_manager.html#afbc41371222b8bad4d0df08b1edeba2a":[6,0,0,1102,20],
 "class_ogre_1_1_vulkan_vao_manager.html#afce1736c1c28af8657aaf863d366240f":[7,0,0,1075,87],
 "class_ogre_1_1_vulkan_vao_manager.html#afce1736c1c28af8657aaf863d366240f":[6,0,0,1102,87],
 "class_ogre_1_1_vulkan_win32_support.html":[7,0,0,1076],
 "class_ogre_1_1_vulkan_win32_support.html":[6,0,0,1103],
 "class_ogre_1_1_vulkan_win32_support.html#a3541d8a86a2a9301f0ae66850473f1b4":[7,0,0,1076,0],
 "class_ogre_1_1_vulkan_win32_support.html#a3541d8a86a2a9301f0ae66850473f1b4":[6,0,0,1103,0],
-"class_ogre_1_1_vulkan_win32_support.html#a36fba22aab78a8edf13890ca94622f21":[6,0,0,1103,7],
 "class_ogre_1_1_vulkan_win32_support.html#a36fba22aab78a8edf13890ca94622f21":[7,0,0,1076,7],
+"class_ogre_1_1_vulkan_win32_support.html#a36fba22aab78a8edf13890ca94622f21":[6,0,0,1103,7],
 "class_ogre_1_1_vulkan_win32_support.html#a4642b454eea1ff29326cd2642ef113ad":[6,0,0,1103,8],
 "class_ogre_1_1_vulkan_win32_support.html#a4642b454eea1ff29326cd2642ef113ad":[7,0,0,1076,8],
 "class_ogre_1_1_vulkan_win32_support.html#a6094e391cfa31b2c6ff4c6fc7696b2b1":[7,0,0,1076,1],
@@ -19,36 +21,36 @@ var NAVTREEINDEX254 =
 "class_ogre_1_1_vulkan_win32_support.html#a7f07eb14fd8792dac968a09c6434cdb0":[6,0,0,1103,4],
 "class_ogre_1_1_vulkan_win32_support.html#a86746d239ebe765693db1f1b46f55fd7":[6,0,0,1103,10],
 "class_ogre_1_1_vulkan_win32_support.html#a86746d239ebe765693db1f1b46f55fd7":[7,0,0,1076,10],
-"class_ogre_1_1_vulkan_win32_support.html#a86bef7a792e9c3450da2fd697ff766c4":[7,0,0,1076,6],
 "class_ogre_1_1_vulkan_win32_support.html#a86bef7a792e9c3450da2fd697ff766c4":[6,0,0,1103,6],
+"class_ogre_1_1_vulkan_win32_support.html#a86bef7a792e9c3450da2fd697ff766c4":[7,0,0,1076,6],
 "class_ogre_1_1_vulkan_win32_support.html#a97b72f6fcab0c9513c6c2b8aace60476":[7,0,0,1076,2],
 "class_ogre_1_1_vulkan_win32_support.html#a97b72f6fcab0c9513c6c2b8aace60476":[6,0,0,1103,2],
 "class_ogre_1_1_vulkan_win32_support.html#abce0d5d7a77ce2824d5186dfe303d976":[6,0,0,1103,9],
 "class_ogre_1_1_vulkan_win32_support.html#abce0d5d7a77ce2824d5186dfe303d976":[7,0,0,1076,9],
-"class_ogre_1_1_vulkan_win32_support.html#adcc864490a8e79fb7526045d5326777b":[7,0,0,1076,5],
 "class_ogre_1_1_vulkan_win32_support.html#adcc864490a8e79fb7526045d5326777b":[6,0,0,1103,5],
-"class_ogre_1_1_vulkan_win32_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9":[6,0,0,1103,3],
+"class_ogre_1_1_vulkan_win32_support.html#adcc864490a8e79fb7526045d5326777b":[7,0,0,1076,5],
 "class_ogre_1_1_vulkan_win32_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9":[7,0,0,1076,3],
-"class_ogre_1_1_vulkan_win32_window.html":[7,0,0,1077],
+"class_ogre_1_1_vulkan_win32_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9":[6,0,0,1103,3],
 "class_ogre_1_1_vulkan_win32_window.html":[6,0,0,1104],
-"class_ogre_1_1_vulkan_win32_window.html#a09ff80100ca52995038ce8b404330c24":[7,0,0,1077,68],
+"class_ogre_1_1_vulkan_win32_window.html":[7,0,0,1077],
 "class_ogre_1_1_vulkan_win32_window.html#a09ff80100ca52995038ce8b404330c24":[6,0,0,1104,68],
-"class_ogre_1_1_vulkan_win32_window.html#a0e8ae8b1cc1827631a7487ac7aff4256":[6,0,0,1104,23],
+"class_ogre_1_1_vulkan_win32_window.html#a09ff80100ca52995038ce8b404330c24":[7,0,0,1077,68],
 "class_ogre_1_1_vulkan_win32_window.html#a0e8ae8b1cc1827631a7487ac7aff4256":[7,0,0,1077,23],
-"class_ogre_1_1_vulkan_win32_window.html#a0e960d623b65169a6ccff4b0815c8751":[6,0,0,1104,75],
+"class_ogre_1_1_vulkan_win32_window.html#a0e8ae8b1cc1827631a7487ac7aff4256":[6,0,0,1104,23],
 "class_ogre_1_1_vulkan_win32_window.html#a0e960d623b65169a6ccff4b0815c8751":[7,0,0,1077,75],
+"class_ogre_1_1_vulkan_win32_window.html#a0e960d623b65169a6ccff4b0815c8751":[6,0,0,1104,75],
 "class_ogre_1_1_vulkan_win32_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,1104,60],
 "class_ogre_1_1_vulkan_win32_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[7,0,0,1077,60],
 "class_ogre_1_1_vulkan_win32_window.html#a123eb1645adc5c9f7b7f85b65d33f5ae":[7,0,0,1077,14],
 "class_ogre_1_1_vulkan_win32_window.html#a123eb1645adc5c9f7b7f85b65d33f5ae":[6,0,0,1104,14],
 "class_ogre_1_1_vulkan_win32_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,1104,33],
 "class_ogre_1_1_vulkan_win32_window.html#a12411d378aa0623e29287964eeb261c4":[7,0,0,1077,33],
-"class_ogre_1_1_vulkan_win32_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1077,46],
 "class_ogre_1_1_vulkan_win32_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1104,46],
+"class_ogre_1_1_vulkan_win32_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1077,46],
 "class_ogre_1_1_vulkan_win32_window.html#a22779bbfb123c76e922942ba876e330a":[6,0,0,1104,41],
 "class_ogre_1_1_vulkan_win32_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,1077,41],
-"class_ogre_1_1_vulkan_win32_window.html#a24faacfa4584e67e19bb04cf11d83323":[6,0,0,1104,76],
 "class_ogre_1_1_vulkan_win32_window.html#a24faacfa4584e67e19bb04cf11d83323":[7,0,0,1077,76],
+"class_ogre_1_1_vulkan_win32_window.html#a24faacfa4584e67e19bb04cf11d83323":[6,0,0,1104,76],
 "class_ogre_1_1_vulkan_win32_window.html#a26e48774201b2ea86d0928ffdda4f583":[6,0,0,1104,71],
 "class_ogre_1_1_vulkan_win32_window.html#a26e48774201b2ea86d0928ffdda4f583":[7,0,0,1077,71],
 "class_ogre_1_1_vulkan_win32_window.html#a319d7bba3d2a578b0c846f0b419692ff":[6,0,0,1104,9],
@@ -61,193 +63,191 @@ var NAVTREEINDEX254 =
 "class_ogre_1_1_vulkan_win32_window.html#a39ae14533345421adc5a3ea516b9785f":[7,0,0,1077,5],
 "class_ogre_1_1_vulkan_win32_window.html#a39e1b46f2145825d0620bc2ea50f6567":[7,0,0,1077,21],
 "class_ogre_1_1_vulkan_win32_window.html#a39e1b46f2145825d0620bc2ea50f6567":[6,0,0,1104,21],
-"class_ogre_1_1_vulkan_win32_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[6,0,0,1104,32],
 "class_ogre_1_1_vulkan_win32_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,1077,32],
+"class_ogre_1_1_vulkan_win32_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[6,0,0,1104,32],
 "class_ogre_1_1_vulkan_win32_window.html#a452c19b6161f1ae310dfd92b026f7ed9":[6,0,0,1104,70],
 "class_ogre_1_1_vulkan_win32_window.html#a452c19b6161f1ae310dfd92b026f7ed9":[7,0,0,1077,70],
-"class_ogre_1_1_vulkan_win32_window.html#a462859aeb6b4db7290622623dae2a6a4":[6,0,0,1104,38],
 "class_ogre_1_1_vulkan_win32_window.html#a462859aeb6b4db7290622623dae2a6a4":[7,0,0,1077,38],
-"class_ogre_1_1_vulkan_win32_window.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1104,48],
+"class_ogre_1_1_vulkan_win32_window.html#a462859aeb6b4db7290622623dae2a6a4":[6,0,0,1104,38],
 "class_ogre_1_1_vulkan_win32_window.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1077,48],
+"class_ogre_1_1_vulkan_win32_window.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1104,48],
 "class_ogre_1_1_vulkan_win32_window.html#a5f7321eee280bd67504cf8ba601df662":[7,0,0,1077,56],
 "class_ogre_1_1_vulkan_win32_window.html#a5f7321eee280bd67504cf8ba601df662":[6,0,0,1104,56],
-"class_ogre_1_1_vulkan_win32_window.html#a62c4b56e664f7ea5646591266ddc835a":[6,0,0,1104,61],
 "class_ogre_1_1_vulkan_win32_window.html#a62c4b56e664f7ea5646591266ddc835a":[7,0,0,1077,61],
+"class_ogre_1_1_vulkan_win32_window.html#a62c4b56e664f7ea5646591266ddc835a":[6,0,0,1104,61],
 "class_ogre_1_1_vulkan_win32_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1104,51],
 "class_ogre_1_1_vulkan_win32_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1077,51],
-"class_ogre_1_1_vulkan_win32_window.html#a67ba7307754a41632bb41c383191bba7":[7,0,0,1077,15],
 "class_ogre_1_1_vulkan_win32_window.html#a67ba7307754a41632bb41c383191bba7":[6,0,0,1104,15],
+"class_ogre_1_1_vulkan_win32_window.html#a67ba7307754a41632bb41c383191bba7":[7,0,0,1077,15],
 "class_ogre_1_1_vulkan_win32_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[7,0,0,1077,35],
 "class_ogre_1_1_vulkan_win32_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[6,0,0,1104,35],
 "class_ogre_1_1_vulkan_win32_window.html#a6e731d4414d454716620f0b401b9c823":[7,0,0,1077,63],
 "class_ogre_1_1_vulkan_win32_window.html#a6e731d4414d454716620f0b401b9c823":[6,0,0,1104,63],
-"class_ogre_1_1_vulkan_win32_window.html#a70cfe4412cfa68a9423854fc1b19872e":[6,0,0,1104,18],
 "class_ogre_1_1_vulkan_win32_window.html#a70cfe4412cfa68a9423854fc1b19872e":[7,0,0,1077,18],
+"class_ogre_1_1_vulkan_win32_window.html#a70cfe4412cfa68a9423854fc1b19872e":[6,0,0,1104,18],
 "class_ogre_1_1_vulkan_win32_window.html#a7359904108c9c7ac2cd3a3c1fdd891ad":[6,0,0,1104,74],
 "class_ogre_1_1_vulkan_win32_window.html#a7359904108c9c7ac2cd3a3c1fdd891ad":[7,0,0,1077,74],
-"class_ogre_1_1_vulkan_win32_window.html#a75261d46e5f123e31ab4f889b8788e5f":[7,0,0,1077,31],
 "class_ogre_1_1_vulkan_win32_window.html#a75261d46e5f123e31ab4f889b8788e5f":[6,0,0,1104,31],
-"class_ogre_1_1_vulkan_win32_window.html#a7f7db089d78132c7a62c0fd0c2344185":[6,0,0,1104,73],
+"class_ogre_1_1_vulkan_win32_window.html#a75261d46e5f123e31ab4f889b8788e5f":[7,0,0,1077,31],
 "class_ogre_1_1_vulkan_win32_window.html#a7f7db089d78132c7a62c0fd0c2344185":[7,0,0,1077,73],
-"class_ogre_1_1_vulkan_win32_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[6,0,0,1104,36],
+"class_ogre_1_1_vulkan_win32_window.html#a7f7db089d78132c7a62c0fd0c2344185":[6,0,0,1104,73],
 "class_ogre_1_1_vulkan_win32_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[7,0,0,1077,36],
-"class_ogre_1_1_vulkan_win32_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1077,44],
+"class_ogre_1_1_vulkan_win32_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[6,0,0,1104,36],
 "class_ogre_1_1_vulkan_win32_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1104,44],
+"class_ogre_1_1_vulkan_win32_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1077,44],
 "class_ogre_1_1_vulkan_win32_window.html#a84739cd779700fa8d7991c9cf11c289d":[6,0,0,1104,34],
 "class_ogre_1_1_vulkan_win32_window.html#a84739cd779700fa8d7991c9cf11c289d":[7,0,0,1077,34],
-"class_ogre_1_1_vulkan_win32_window.html#a89e3a20bf46b9b58923568b76937eb0d":[6,0,0,1104,59],
 "class_ogre_1_1_vulkan_win32_window.html#a89e3a20bf46b9b58923568b76937eb0d":[7,0,0,1077,59],
-"class_ogre_1_1_vulkan_win32_window.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,1077,22],
+"class_ogre_1_1_vulkan_win32_window.html#a89e3a20bf46b9b58923568b76937eb0d":[6,0,0,1104,59],
 "class_ogre_1_1_vulkan_win32_window.html#a8a464e98db9c09042b866bdb95b210f4":[6,0,0,1104,22],
-"class_ogre_1_1_vulkan_win32_window.html#a8b05fabc7b8b6cf3129279629562476d":[7,0,0,1077,25],
+"class_ogre_1_1_vulkan_win32_window.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,1077,22],
 "class_ogre_1_1_vulkan_win32_window.html#a8b05fabc7b8b6cf3129279629562476d":[6,0,0,1104,25],
+"class_ogre_1_1_vulkan_win32_window.html#a8b05fabc7b8b6cf3129279629562476d":[7,0,0,1077,25],
 "class_ogre_1_1_vulkan_win32_window.html#a8d6f1accac3551566dc3de3a44cfc9ac":[6,0,0,1104,11],
 "class_ogre_1_1_vulkan_win32_window.html#a8d6f1accac3551566dc3de3a44cfc9ac":[7,0,0,1077,11],
-"class_ogre_1_1_vulkan_win32_window.html#a8d7e786602979fc29169555056834c65":[7,0,0,1077,19],
 "class_ogre_1_1_vulkan_win32_window.html#a8d7e786602979fc29169555056834c65":[6,0,0,1104,19],
+"class_ogre_1_1_vulkan_win32_window.html#a8d7e786602979fc29169555056834c65":[7,0,0,1077,19],
 "class_ogre_1_1_vulkan_win32_window.html#a8f88cfd53a8f1dafa9889f901b26d757":[6,0,0,1104,3],
 "class_ogre_1_1_vulkan_win32_window.html#a8f88cfd53a8f1dafa9889f901b26d757":[7,0,0,1077,3],
 "class_ogre_1_1_vulkan_win32_window.html#a91b3dada6cde1e857a8592138c3e5e6c":[7,0,0,1077,55],
 "class_ogre_1_1_vulkan_win32_window.html#a91b3dada6cde1e857a8592138c3e5e6c":[6,0,0,1104,55],
-"class_ogre_1_1_vulkan_win32_window.html#a92d426a5762a35639ab102cfcbcaedf5":[7,0,0,1077,42],
 "class_ogre_1_1_vulkan_win32_window.html#a92d426a5762a35639ab102cfcbcaedf5":[6,0,0,1104,42],
-"class_ogre_1_1_vulkan_win32_window.html#a93d2bec45320d712464bca2d04e1da5b":[7,0,0,1077,8],
+"class_ogre_1_1_vulkan_win32_window.html#a92d426a5762a35639ab102cfcbcaedf5":[7,0,0,1077,42],
 "class_ogre_1_1_vulkan_win32_window.html#a93d2bec45320d712464bca2d04e1da5b":[6,0,0,1104,8],
-"class_ogre_1_1_vulkan_win32_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1077,47],
+"class_ogre_1_1_vulkan_win32_window.html#a93d2bec45320d712464bca2d04e1da5b":[7,0,0,1077,8],
 "class_ogre_1_1_vulkan_win32_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1104,47],
-"class_ogre_1_1_vulkan_win32_window.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,1077,24],
+"class_ogre_1_1_vulkan_win32_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1077,47],
 "class_ogre_1_1_vulkan_win32_window.html#a9439f12db8a964f79f4b743493a0fd75":[6,0,0,1104,24],
+"class_ogre_1_1_vulkan_win32_window.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,1077,24],
 "class_ogre_1_1_vulkan_win32_window.html#a95c79431ef5e02a234b0119e288324ee":[6,0,0,1104,4],
 "class_ogre_1_1_vulkan_win32_window.html#a95c79431ef5e02a234b0119e288324ee":[7,0,0,1077,4],
 "class_ogre_1_1_vulkan_win32_window.html#a98f49dbefa207210a2f4c0025848b93c":[7,0,0,1077,26],
 "class_ogre_1_1_vulkan_win32_window.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,1104,26],
-"class_ogre_1_1_vulkan_win32_window.html#a98fc94011c5321f39483f1ab23da62ce":[6,0,0,1104,40],
 "class_ogre_1_1_vulkan_win32_window.html#a98fc94011c5321f39483f1ab23da62ce":[7,0,0,1077,40],
-"class_ogre_1_1_vulkan_win32_window.html#a9ad310599e0f52d2c704bc27b8f255bf":[7,0,0,1077,67],
+"class_ogre_1_1_vulkan_win32_window.html#a98fc94011c5321f39483f1ab23da62ce":[6,0,0,1104,40],
 "class_ogre_1_1_vulkan_win32_window.html#a9ad310599e0f52d2c704bc27b8f255bf":[6,0,0,1104,67],
+"class_ogre_1_1_vulkan_win32_window.html#a9ad310599e0f52d2c704bc27b8f255bf":[7,0,0,1077,67],
 "class_ogre_1_1_vulkan_win32_window.html#a9af2d2b27cf6a53c60aca59598f631b2":[6,0,0,1104,10],
 "class_ogre_1_1_vulkan_win32_window.html#a9af2d2b27cf6a53c60aca59598f631b2":[7,0,0,1077,10],
-"class_ogre_1_1_vulkan_win32_window.html#aa562105b8ede44dd4bba7704ffcf763c":[7,0,0,1077,69],
 "class_ogre_1_1_vulkan_win32_window.html#aa562105b8ede44dd4bba7704ffcf763c":[6,0,0,1104,69],
+"class_ogre_1_1_vulkan_win32_window.html#aa562105b8ede44dd4bba7704ffcf763c":[7,0,0,1077,69],
 "class_ogre_1_1_vulkan_win32_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[7,0,0,1077,58],
 "class_ogre_1_1_vulkan_win32_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[6,0,0,1104,58],
 "class_ogre_1_1_vulkan_win32_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[6,0,0,1104,66],
 "class_ogre_1_1_vulkan_win32_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[7,0,0,1077,66],
-"class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973":[7,0,0,1077,1],
 "class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973":[6,0,0,1104,1],
+"class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973":[7,0,0,1077,1],
 "class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7":[6,0,0,1104,1,2],
 "class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7":[7,0,0,1077,1,2],
 "class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24":[7,0,0,1077,1,1],
 "class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24":[6,0,0,1104,1,1],
-"class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973a7a984b0fc998101009bed7b9e5692ada":[6,0,0,1104,1,0],
 "class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973a7a984b0fc998101009bed7b9e5692ada":[7,0,0,1077,1,0],
+"class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973a7a984b0fc998101009bed7b9e5692ada":[6,0,0,1104,1,0],
 "class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973ae6e7b9212a61d76de37b5ea4a733a17d":[7,0,0,1077,1,3],
 "class_ogre_1_1_vulkan_win32_window.html#aadf0d4f9a81f5217c467f3306941d973ae6e7b9212a61d76de37b5ea4a733a17d":[6,0,0,1104,1,3],
-"class_ogre_1_1_vulkan_win32_window.html#ab12be5918fc0d0c3a827250bf4f4d281":[6,0,0,1104,0],
 "class_ogre_1_1_vulkan_win32_window.html#ab12be5918fc0d0c3a827250bf4f4d281":[7,0,0,1077,0],
+"class_ogre_1_1_vulkan_win32_window.html#ab12be5918fc0d0c3a827250bf4f4d281":[6,0,0,1104,0],
 "class_ogre_1_1_vulkan_win32_window.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259":[7,0,0,1077,0,0],
 "class_ogre_1_1_vulkan_win32_window.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259":[6,0,0,1104,0,0],
-"class_ogre_1_1_vulkan_win32_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1104,50],
 "class_ogre_1_1_vulkan_win32_window.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1077,50],
+"class_ogre_1_1_vulkan_win32_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1104,50],
 "class_ogre_1_1_vulkan_win32_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,1104,7],
 "class_ogre_1_1_vulkan_win32_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[7,0,0,1077,7],
-"class_ogre_1_1_vulkan_win32_window.html#ac344214fa2a1ead13bb78f73712f69a3":[7,0,0,1077,65],
 "class_ogre_1_1_vulkan_win32_window.html#ac344214fa2a1ead13bb78f73712f69a3":[6,0,0,1104,65],
-"class_ogre_1_1_vulkan_win32_window.html#ac4782abeb9698a9d72469dde923bc714":[6,0,0,1104,12],
+"class_ogre_1_1_vulkan_win32_window.html#ac344214fa2a1ead13bb78f73712f69a3":[7,0,0,1077,65],
 "class_ogre_1_1_vulkan_win32_window.html#ac4782abeb9698a9d72469dde923bc714":[7,0,0,1077,12],
+"class_ogre_1_1_vulkan_win32_window.html#ac4782abeb9698a9d72469dde923bc714":[6,0,0,1104,12],
 "class_ogre_1_1_vulkan_win32_window.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,1104,17],
 "class_ogre_1_1_vulkan_win32_window.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,1077,17],
-"class_ogre_1_1_vulkan_win32_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1077,45],
 "class_ogre_1_1_vulkan_win32_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1104,45],
+"class_ogre_1_1_vulkan_win32_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1077,45],
 "class_ogre_1_1_vulkan_win32_window.html#acc15e72c6b6e8e90a93ca44f07a8b1e8":[7,0,0,1077,16],
 "class_ogre_1_1_vulkan_win32_window.html#acc15e72c6b6e8e90a93ca44f07a8b1e8":[6,0,0,1104,16],
-"class_ogre_1_1_vulkan_win32_window.html#acd46202d3fd921f029d029fa2f5ed59b":[6,0,0,1104,6],
 "class_ogre_1_1_vulkan_win32_window.html#acd46202d3fd921f029d029fa2f5ed59b":[7,0,0,1077,6],
-"class_ogre_1_1_vulkan_win32_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,1104,28],
+"class_ogre_1_1_vulkan_win32_window.html#acd46202d3fd921f029d029fa2f5ed59b":[6,0,0,1104,6],
 "class_ogre_1_1_vulkan_win32_window.html#ad15462609bf45808fb04668cc1c28c78":[7,0,0,1077,28],
-"class_ogre_1_1_vulkan_win32_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1077,49],
+"class_ogre_1_1_vulkan_win32_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,1104,28],
 "class_ogre_1_1_vulkan_win32_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1104,49],
-"class_ogre_1_1_vulkan_win32_window.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,1077,62],
+"class_ogre_1_1_vulkan_win32_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1077,49],
 "class_ogre_1_1_vulkan_win32_window.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,1104,62],
+"class_ogre_1_1_vulkan_win32_window.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,1077,62],
 "class_ogre_1_1_vulkan_win32_window.html#ada0ea4ca14d6cb1ea814806cf35a338f":[7,0,0,1077,2],
 "class_ogre_1_1_vulkan_win32_window.html#ada0ea4ca14d6cb1ea814806cf35a338f":[6,0,0,1104,2],
-"class_ogre_1_1_vulkan_win32_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[7,0,0,1077,39],
 "class_ogre_1_1_vulkan_win32_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[6,0,0,1104,39],
+"class_ogre_1_1_vulkan_win32_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[7,0,0,1077,39],
 "class_ogre_1_1_vulkan_win32_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[7,0,0,1077,29],
 "class_ogre_1_1_vulkan_win32_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,1104,29],
 "class_ogre_1_1_vulkan_win32_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,1077,52],
 "class_ogre_1_1_vulkan_win32_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,1104,52],
 "class_ogre_1_1_vulkan_win32_window.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,1104,20],
 "class_ogre_1_1_vulkan_win32_window.html#add8e20491fc0e054c9cab3c75297c6ec":[7,0,0,1077,20],
-"class_ogre_1_1_vulkan_win32_window.html#adf06d1debff5285b48488e96a5f9c143":[7,0,0,1077,43],
 "class_ogre_1_1_vulkan_win32_window.html#adf06d1debff5285b48488e96a5f9c143":[6,0,0,1104,43],
+"class_ogre_1_1_vulkan_win32_window.html#adf06d1debff5285b48488e96a5f9c143":[7,0,0,1077,43],
 "class_ogre_1_1_vulkan_win32_window.html#adfbd4f24b29343958aba5af0708a0683":[7,0,0,1077,54],
 "class_ogre_1_1_vulkan_win32_window.html#adfbd4f24b29343958aba5af0708a0683":[6,0,0,1104,54],
-"class_ogre_1_1_vulkan_win32_window.html#aecf38609606a498bc552a6cbbd5b3c38":[7,0,0,1077,37],
 "class_ogre_1_1_vulkan_win32_window.html#aecf38609606a498bc552a6cbbd5b3c38":[6,0,0,1104,37],
+"class_ogre_1_1_vulkan_win32_window.html#aecf38609606a498bc552a6cbbd5b3c38":[7,0,0,1077,37],
 "class_ogre_1_1_vulkan_win32_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1104,53],
 "class_ogre_1_1_vulkan_win32_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1077,53],
-"class_ogre_1_1_vulkan_win32_window.html#aee499e5625bdf21c40b3c166ab304476":[6,0,0,1104,27],
 "class_ogre_1_1_vulkan_win32_window.html#aee499e5625bdf21c40b3c166ab304476":[7,0,0,1077,27],
+"class_ogre_1_1_vulkan_win32_window.html#aee499e5625bdf21c40b3c166ab304476":[6,0,0,1104,27],
 "class_ogre_1_1_vulkan_win32_window.html#af574272c60f388e4c4712fa5d358ef7a":[6,0,0,1104,64],
 "class_ogre_1_1_vulkan_win32_window.html#af574272c60f388e4c4712fa5d358ef7a":[7,0,0,1077,64],
 "class_ogre_1_1_vulkan_win32_window.html#afb956dde983e96a95394aa55215c55da":[7,0,0,1077,72],
 "class_ogre_1_1_vulkan_win32_window.html#afb956dde983e96a95394aa55215c55da":[6,0,0,1104,72],
-"class_ogre_1_1_vulkan_win32_window.html#afe1ddfa1c815d130c63ed73b0774bb66":[6,0,0,1104,57],
 "class_ogre_1_1_vulkan_win32_window.html#afe1ddfa1c815d130c63ed73b0774bb66":[7,0,0,1077,57],
+"class_ogre_1_1_vulkan_win32_window.html#afe1ddfa1c815d130c63ed73b0774bb66":[6,0,0,1104,57],
 "class_ogre_1_1_vulkan_window.html":[7,0,0,1078],
 "class_ogre_1_1_vulkan_window.html":[6,0,0,1105],
 "class_ogre_1_1_vulkan_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[7,0,0,1078,47],
 "class_ogre_1_1_vulkan_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,1105,47],
-"class_ogre_1_1_vulkan_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,1105,21],
 "class_ogre_1_1_vulkan_window.html#a12411d378aa0623e29287964eeb261c4":[7,0,0,1078,21],
-"class_ogre_1_1_vulkan_window.html#a1284a6c13adf9c244e4dcc2f973d7749":[7,0,0,1078,44],
+"class_ogre_1_1_vulkan_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,1105,21],
 "class_ogre_1_1_vulkan_window.html#a1284a6c13adf9c244e4dcc2f973d7749":[6,0,0,1105,44],
-"class_ogre_1_1_vulkan_window.html#a1332cb4dcf166db4b604a655821302ab":[7,0,0,1078,0],
+"class_ogre_1_1_vulkan_window.html#a1284a6c13adf9c244e4dcc2f973d7749":[7,0,0,1078,44],
 "class_ogre_1_1_vulkan_window.html#a1332cb4dcf166db4b604a655821302ab":[6,0,0,1105,0],
-"class_ogre_1_1_vulkan_window.html#a14c0ef3312945158ad042463bef69e74":[7,0,0,1078,31],
+"class_ogre_1_1_vulkan_window.html#a1332cb4dcf166db4b604a655821302ab":[7,0,0,1078,0],
 "class_ogre_1_1_vulkan_window.html#a14c0ef3312945158ad042463bef69e74":[6,0,0,1105,31],
+"class_ogre_1_1_vulkan_window.html#a14c0ef3312945158ad042463bef69e74":[7,0,0,1078,31],
 "class_ogre_1_1_vulkan_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1105,34],
 "class_ogre_1_1_vulkan_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1078,34],
-"class_ogre_1_1_vulkan_window.html#a1ddfa4bf1c7c366ad92a8a6c93aeec8c":[7,0,0,1078,2],
 "class_ogre_1_1_vulkan_window.html#a1ddfa4bf1c7c366ad92a8a6c93aeec8c":[6,0,0,1105,2],
-"class_ogre_1_1_vulkan_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,1078,29],
+"class_ogre_1_1_vulkan_window.html#a1ddfa4bf1c7c366ad92a8a6c93aeec8c":[7,0,0,1078,2],
 "class_ogre_1_1_vulkan_window.html#a22779bbfb123c76e922942ba876e330a":[6,0,0,1105,29],
+"class_ogre_1_1_vulkan_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,1078,29],
 "class_ogre_1_1_vulkan_window.html#a2d5423c38fb53d7346a00c0e7e582347":[7,0,0,1078,43],
 "class_ogre_1_1_vulkan_window.html#a2d5423c38fb53d7346a00c0e7e582347":[6,0,0,1105,43],
-"class_ogre_1_1_vulkan_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,1078,20],
 "class_ogre_1_1_vulkan_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[6,0,0,1105,20],
-"class_ogre_1_1_vulkan_window.html#a4134fbf0e0302588fd92f7a3d9bd852c":[6,0,0,1105,28],
+"class_ogre_1_1_vulkan_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,1078,20],
 "class_ogre_1_1_vulkan_window.html#a4134fbf0e0302588fd92f7a3d9bd852c":[7,0,0,1078,28],
+"class_ogre_1_1_vulkan_window.html#a4134fbf0e0302588fd92f7a3d9bd852c":[6,0,0,1105,28],
 "class_ogre_1_1_vulkan_window.html#a462859aeb6b4db7290622623dae2a6a4":[6,0,0,1105,26],
 "class_ogre_1_1_vulkan_window.html#a462859aeb6b4db7290622623dae2a6a4":[7,0,0,1078,26],
 "class_ogre_1_1_vulkan_window.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1105,36],
 "class_ogre_1_1_vulkan_window.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1078,36],
 "class_ogre_1_1_vulkan_window.html#a5d39c20103e51bd756ebc97956b3c98d":[6,0,0,1105,42],
 "class_ogre_1_1_vulkan_window.html#a5d39c20103e51bd756ebc97956b3c98d":[7,0,0,1078,42],
-"class_ogre_1_1_vulkan_window.html#a6222c12d52c1b0b2cc3fa612b7e45a69":[6,0,0,1105,8],
 "class_ogre_1_1_vulkan_window.html#a6222c12d52c1b0b2cc3fa612b7e45a69":[7,0,0,1078,8],
-"class_ogre_1_1_vulkan_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1105,39],
+"class_ogre_1_1_vulkan_window.html#a6222c12d52c1b0b2cc3fa612b7e45a69":[6,0,0,1105,8],
 "class_ogre_1_1_vulkan_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1078,39],
-"class_ogre_1_1_vulkan_window.html#a67ba7307754a41632bb41c383191bba7":[6,0,0,1105,7],
+"class_ogre_1_1_vulkan_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,1105,39],
 "class_ogre_1_1_vulkan_window.html#a67ba7307754a41632bb41c383191bba7":[7,0,0,1078,7],
+"class_ogre_1_1_vulkan_window.html#a67ba7307754a41632bb41c383191bba7":[6,0,0,1105,7],
 "class_ogre_1_1_vulkan_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[7,0,0,1078,23],
 "class_ogre_1_1_vulkan_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[6,0,0,1105,23],
 "class_ogre_1_1_vulkan_window.html#a70cfe4412cfa68a9423854fc1b19872e":[7,0,0,1078,10],
 "class_ogre_1_1_vulkan_window.html#a70cfe4412cfa68a9423854fc1b19872e":[6,0,0,1105,10],
-"class_ogre_1_1_vulkan_window.html#a75261d46e5f123e31ab4f889b8788e5f":[7,0,0,1078,19],
 "class_ogre_1_1_vulkan_window.html#a75261d46e5f123e31ab4f889b8788e5f":[6,0,0,1105,19],
+"class_ogre_1_1_vulkan_window.html#a75261d46e5f123e31ab4f889b8788e5f":[7,0,0,1078,19],
 "class_ogre_1_1_vulkan_window.html#a76b56f475ba7474c83760b557c34c6a5":[6,0,0,1105,50],
 "class_ogre_1_1_vulkan_window.html#a76b56f475ba7474c83760b557c34c6a5":[7,0,0,1078,50],
-"class_ogre_1_1_vulkan_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[7,0,0,1078,46],
 "class_ogre_1_1_vulkan_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[6,0,0,1105,46],
+"class_ogre_1_1_vulkan_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[7,0,0,1078,46],
 "class_ogre_1_1_vulkan_window.html#a80738edbd5cf6649ca46331426137ccf":[6,0,0,1105,48],
 "class_ogre_1_1_vulkan_window.html#a80738edbd5cf6649ca46331426137ccf":[7,0,0,1078,48],
-"class_ogre_1_1_vulkan_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[6,0,0,1105,24],
 "class_ogre_1_1_vulkan_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[7,0,0,1078,24],
-"class_ogre_1_1_vulkan_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1105,32],
+"class_ogre_1_1_vulkan_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[6,0,0,1105,24],
 "class_ogre_1_1_vulkan_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1078,32],
-"class_ogre_1_1_vulkan_window.html#a84739cd779700fa8d7991c9cf11c289d":[6,0,0,1105,22],
-"class_ogre_1_1_vulkan_window.html#a84739cd779700fa8d7991c9cf11c289d":[7,0,0,1078,22],
-"class_ogre_1_1_vulkan_window.html#a8a464e98db9c09042b866bdb95b210f4":[6,0,0,1105,13]
+"class_ogre_1_1_vulkan_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1105,32],
+"class_ogre_1_1_vulkan_window.html#a84739cd779700fa8d7991c9cf11c289d":[6,0,0,1105,22]
 };
