@@ -1,160 +1,162 @@
 var NAVTREEINDEX256 =
 {
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#a84739cd779700fa8d7991c9cf11c289d":[6,0,0,1107,33],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a85f87e6c41a86bde631a893d0f1c0b26":[7,0,0,1080,13],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,1080,22],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#a85f87e6c41a86bde631a893d0f1c0b26":[6,0,0,1107,13],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a8a464e98db9c09042b866bdb95b210f4":[6,0,0,1107,22],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#a8b05fabc7b8b6cf3129279629562476d":[7,0,0,1080,25],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,1080,22],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a8b05fabc7b8b6cf3129279629562476d":[6,0,0,1107,25],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#a8d6f1accac3551566dc3de3a44cfc9ac":[6,0,0,1107,11],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#a8b05fabc7b8b6cf3129279629562476d":[7,0,0,1080,25],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a8d6f1accac3551566dc3de3a44cfc9ac":[7,0,0,1080,11],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#a8d7e786602979fc29169555056834c65":[6,0,0,1107,19],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#a8d6f1accac3551566dc3de3a44cfc9ac":[6,0,0,1107,11],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a8d7e786602979fc29169555056834c65":[7,0,0,1080,19],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#a92d426a5762a35639ab102cfcbcaedf5":[6,0,0,1107,41],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#a8d7e786602979fc29169555056834c65":[6,0,0,1107,19],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a92d426a5762a35639ab102cfcbcaedf5":[7,0,0,1080,41],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1107,46],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#a92d426a5762a35639ab102cfcbcaedf5":[6,0,0,1107,41],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1080,46],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#a9439f12db8a964f79f4b743493a0fd75":[6,0,0,1107,24],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1107,46],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,1080,24],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#a9439f12db8a964f79f4b743493a0fd75":[6,0,0,1107,24],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a95c79431ef5e02a234b0119e288324ee":[7,0,0,1080,4],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a95c79431ef5e02a234b0119e288324ee":[6,0,0,1107,4],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,1107,26],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a98f49dbefa207210a2f4c0025848b93c":[7,0,0,1080,26],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#a9af2d2b27cf6a53c60aca59598f631b2":[6,0,0,1107,10],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#a9af2d2b27cf6a53c60aca59598f631b2":[7,0,0,1080,10],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#a9af2d2b27cf6a53c60aca59598f631b2":[6,0,0,1107,10],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aa562105b8ede44dd4bba7704ffcf763c":[6,0,0,1107,68],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aa562105b8ede44dd4bba7704ffcf763c":[7,0,0,1080,68],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aa6ee76edb7111f8feefbb1f73aae50be":[6,0,0,1107,57],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aa6ee76edb7111f8feefbb1f73aae50be":[7,0,0,1080,57],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aa7ac08a06bc2a2c4d2638a844f6b4351":[6,0,0,1107,8],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aa7ac08a06bc2a2c4d2638a844f6b4351":[7,0,0,1080,8],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[6,0,0,1107,65],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[7,0,0,1080,65],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[6,0,0,1107,65],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973":[6,0,0,1107,1],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973":[7,0,0,1080,1],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7":[7,0,0,1080,1,2],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7":[6,0,0,1107,1,2],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24":[6,0,0,1107,1,1],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7":[7,0,0,1080,1,2],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24":[7,0,0,1080,1,1],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24":[6,0,0,1107,1,1],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a7a984b0fc998101009bed7b9e5692ada":[7,0,0,1080,1,0],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973a7a984b0fc998101009bed7b9e5692ada":[6,0,0,1107,1,0],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973ae6e7b9212a61d76de37b5ea4a733a17d":[7,0,0,1080,1,3],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973ae6e7b9212a61d76de37b5ea4a733a17d":[6,0,0,1107,1,3],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#ab12be5918fc0d0c3a827250bf4f4d281":[7,0,0,1080,0],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#aadf0d4f9a81f5217c467f3306941d973ae6e7b9212a61d76de37b5ea4a733a17d":[7,0,0,1080,1,3],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab12be5918fc0d0c3a827250bf4f4d281":[6,0,0,1107,0],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259":[7,0,0,1080,0,0],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#ab12be5918fc0d0c3a827250bf4f4d281":[7,0,0,1080,0],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259":[6,0,0,1107,0,0],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259":[7,0,0,1080,0,0],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1080,49],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1107,49],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,1107,7],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[7,0,0,1080,7],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,1107,7],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#abffec246be83d1df9c7a8c6ecb0249ea":[7,0,0,1080,66],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#abffec246be83d1df9c7a8c6ecb0249ea":[6,0,0,1107,66],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#ac344214fa2a1ead13bb78f73712f69a3":[6,0,0,1107,64],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ac344214fa2a1ead13bb78f73712f69a3":[7,0,0,1080,64],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#ac344214fa2a1ead13bb78f73712f69a3":[6,0,0,1107,64],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ac4782abeb9698a9d72469dde923bc714":[7,0,0,1080,12],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ac4782abeb9698a9d72469dde923bc714":[6,0,0,1107,12],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,1080,17],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,1107,17],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1080,44],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,1080,17],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1107,44],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#acd46202d3fd921f029d029fa2f5ed59b":[7,0,0,1080,6],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1080,44],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#acd46202d3fd921f029d029fa2f5ed59b":[6,0,0,1107,6],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#acd46202d3fd921f029d029fa2f5ed59b":[7,0,0,1080,6],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad15462609bf45808fb04668cc1c28c78":[7,0,0,1080,27],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,1107,27],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1080,48],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1107,48],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1080,48],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad2fb682ca82f8ea974a64cfef5c622b4":[7,0,0,1080,2],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad2fb682ca82f8ea974a64cfef5c622b4":[6,0,0,1107,2],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,1080,61],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,1107,61],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,1080,61],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[7,0,0,1080,38],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[6,0,0,1107,38],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#adb9f92d4da00b9e48328a1c3e19151c4":[7,0,0,1080,28],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,1107,28],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#adce32528577d71b228692df906ecd17c":[6,0,0,1107,51],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#adce32528577d71b228692df906ecd17c":[7,0,0,1080,51],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,1107,20],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#add8e20491fc0e054c9cab3c75297c6ec":[7,0,0,1080,20],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,1107,20],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#adfbd4f24b29343958aba5af0708a0683":[7,0,0,1080,53],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#adfbd4f24b29343958aba5af0708a0683":[6,0,0,1107,53],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aecf38609606a498bc552a6cbbd5b3c38":[7,0,0,1080,36],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aecf38609606a498bc552a6cbbd5b3c38":[6,0,0,1107,36],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1107,52],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1080,52],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1107,52],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#af574272c60f388e4c4712fa5d358ef7a":[6,0,0,1107,63],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#af574272c60f388e4c4712fa5d358ef7a":[7,0,0,1080,63],
-"class_ogre_1_1_vulkan_window_swap_chain_based.html#afb956dde983e96a95394aa55215c55da":[7,0,0,1080,71],
 "class_ogre_1_1_vulkan_window_swap_chain_based.html#afb956dde983e96a95394aa55215c55da":[6,0,0,1107,71],
-"class_ogre_1_1_vulkan_xcb_support.html":[7,0,0,1081],
+"class_ogre_1_1_vulkan_window_swap_chain_based.html#afb956dde983e96a95394aa55215c55da":[7,0,0,1080,71],
 "class_ogre_1_1_vulkan_xcb_support.html":[6,0,0,1108],
+"class_ogre_1_1_vulkan_xcb_support.html":[7,0,0,1081],
 "class_ogre_1_1_vulkan_xcb_support.html#a36fba22aab78a8edf13890ca94622f21":[7,0,0,1081,7],
 "class_ogre_1_1_vulkan_xcb_support.html#a36fba22aab78a8edf13890ca94622f21":[6,0,0,1108,7],
 "class_ogre_1_1_vulkan_xcb_support.html#a7adc367da6b4dc47298930687436d294":[6,0,0,1108,0],
 "class_ogre_1_1_vulkan_xcb_support.html#a7adc367da6b4dc47298930687436d294":[7,0,0,1081,0],
-"class_ogre_1_1_vulkan_xcb_support.html#a86746d239ebe765693db1f1b46f55fd7":[7,0,0,1081,10],
 "class_ogre_1_1_vulkan_xcb_support.html#a86746d239ebe765693db1f1b46f55fd7":[6,0,0,1108,10],
-"class_ogre_1_1_vulkan_xcb_support.html#a86bef7a792e9c3450da2fd697ff766c4":[7,0,0,1081,6],
+"class_ogre_1_1_vulkan_xcb_support.html#a86746d239ebe765693db1f1b46f55fd7":[7,0,0,1081,10],
 "class_ogre_1_1_vulkan_xcb_support.html#a86bef7a792e9c3450da2fd697ff766c4":[6,0,0,1108,6],
+"class_ogre_1_1_vulkan_xcb_support.html#a86bef7a792e9c3450da2fd697ff766c4":[7,0,0,1081,6],
 "class_ogre_1_1_vulkan_xcb_support.html#a895ceaaa6a6a699a59c8f03cf73b5eeb":[6,0,0,1108,5],
 "class_ogre_1_1_vulkan_xcb_support.html#a895ceaaa6a6a699a59c8f03cf73b5eeb":[7,0,0,1081,5],
-"class_ogre_1_1_vulkan_xcb_support.html#a8f4cc0f02165e1529bd27c75f1aff645":[6,0,0,1108,1],
 "class_ogre_1_1_vulkan_xcb_support.html#a8f4cc0f02165e1529bd27c75f1aff645":[7,0,0,1081,1],
-"class_ogre_1_1_vulkan_xcb_support.html#a9564750c269290683f26799f561effea":[7,0,0,1081,4],
+"class_ogre_1_1_vulkan_xcb_support.html#a8f4cc0f02165e1529bd27c75f1aff645":[6,0,0,1108,1],
 "class_ogre_1_1_vulkan_xcb_support.html#a9564750c269290683f26799f561effea":[6,0,0,1108,4],
+"class_ogre_1_1_vulkan_xcb_support.html#a9564750c269290683f26799f561effea":[7,0,0,1081,4],
 "class_ogre_1_1_vulkan_xcb_support.html#a97b72f6fcab0c9513c6c2b8aace60476":[7,0,0,1081,2],
 "class_ogre_1_1_vulkan_xcb_support.html#a97b72f6fcab0c9513c6c2b8aace60476":[6,0,0,1108,2],
 "class_ogre_1_1_vulkan_xcb_support.html#abcb12df33945325331c3cc0b704688ed":[7,0,0,1081,8],
 "class_ogre_1_1_vulkan_xcb_support.html#abcb12df33945325331c3cc0b704688ed":[6,0,0,1108,8],
-"class_ogre_1_1_vulkan_xcb_support.html#abce0d5d7a77ce2824d5186dfe303d976":[7,0,0,1081,9],
 "class_ogre_1_1_vulkan_xcb_support.html#abce0d5d7a77ce2824d5186dfe303d976":[6,0,0,1108,9],
+"class_ogre_1_1_vulkan_xcb_support.html#abce0d5d7a77ce2824d5186dfe303d976":[7,0,0,1081,9],
 "class_ogre_1_1_vulkan_xcb_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9":[6,0,0,1108,3],
 "class_ogre_1_1_vulkan_xcb_support.html#ae031d6dfdd4b3f304d76a43d1ba2aae9":[7,0,0,1081,3],
-"class_ogre_1_1_vulkan_xcb_window.html":[6,0,0,1109],
 "class_ogre_1_1_vulkan_xcb_window.html":[7,0,0,1082],
+"class_ogre_1_1_vulkan_xcb_window.html":[6,0,0,1109],
 "class_ogre_1_1_vulkan_xcb_window.html#a09ff80100ca52995038ce8b404330c24":[7,0,0,1082,70],
 "class_ogre_1_1_vulkan_xcb_window.html#a09ff80100ca52995038ce8b404330c24":[6,0,0,1109,70],
-"class_ogre_1_1_vulkan_xcb_window.html#a0e8ae8b1cc1827631a7487ac7aff4256":[6,0,0,1109,23],
 "class_ogre_1_1_vulkan_xcb_window.html#a0e8ae8b1cc1827631a7487ac7aff4256":[7,0,0,1082,23],
-"class_ogre_1_1_vulkan_xcb_window.html#a0e960d623b65169a6ccff4b0815c8751":[7,0,0,1082,77],
+"class_ogre_1_1_vulkan_xcb_window.html#a0e8ae8b1cc1827631a7487ac7aff4256":[6,0,0,1109,23],
 "class_ogre_1_1_vulkan_xcb_window.html#a0e960d623b65169a6ccff4b0815c8751":[6,0,0,1109,77],
-"class_ogre_1_1_vulkan_xcb_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,1109,60],
+"class_ogre_1_1_vulkan_xcb_window.html#a0e960d623b65169a6ccff4b0815c8751":[7,0,0,1082,77],
 "class_ogre_1_1_vulkan_xcb_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[7,0,0,1082,60],
-"class_ogre_1_1_vulkan_xcb_window.html#a0f8b322e0d3a21bb8c2ba431904920ed":[6,0,0,1109,56],
+"class_ogre_1_1_vulkan_xcb_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,1109,60],
 "class_ogre_1_1_vulkan_xcb_window.html#a0f8b322e0d3a21bb8c2ba431904920ed":[7,0,0,1082,56],
-"class_ogre_1_1_vulkan_xcb_window.html#a123eb1645adc5c9f7b7f85b65d33f5ae":[6,0,0,1109,14],
+"class_ogre_1_1_vulkan_xcb_window.html#a0f8b322e0d3a21bb8c2ba431904920ed":[6,0,0,1109,56],
 "class_ogre_1_1_vulkan_xcb_window.html#a123eb1645adc5c9f7b7f85b65d33f5ae":[7,0,0,1082,14],
+"class_ogre_1_1_vulkan_xcb_window.html#a123eb1645adc5c9f7b7f85b65d33f5ae":[6,0,0,1109,14],
 "class_ogre_1_1_vulkan_xcb_window.html#a12411d378aa0623e29287964eeb261c4":[7,0,0,1082,33],
 "class_ogre_1_1_vulkan_xcb_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,1109,33],
 "class_ogre_1_1_vulkan_xcb_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1109,46],
 "class_ogre_1_1_vulkan_xcb_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1082,46],
-"class_ogre_1_1_vulkan_xcb_window.html#a20cffb72ac177422466e7cad8930c254":[7,0,0,1082,69],
 "class_ogre_1_1_vulkan_xcb_window.html#a20cffb72ac177422466e7cad8930c254":[6,0,0,1109,69],
+"class_ogre_1_1_vulkan_xcb_window.html#a20cffb72ac177422466e7cad8930c254":[7,0,0,1082,69],
 "class_ogre_1_1_vulkan_xcb_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,1082,41],
 "class_ogre_1_1_vulkan_xcb_window.html#a22779bbfb123c76e922942ba876e330a":[6,0,0,1109,41],
 "class_ogre_1_1_vulkan_xcb_window.html#a24faacfa4584e67e19bb04cf11d83323":[7,0,0,1082,78],
 "class_ogre_1_1_vulkan_xcb_window.html#a24faacfa4584e67e19bb04cf11d83323":[6,0,0,1109,78],
-"class_ogre_1_1_vulkan_xcb_window.html#a26e48774201b2ea86d0928ffdda4f583":[7,0,0,1082,73],
 "class_ogre_1_1_vulkan_xcb_window.html#a26e48774201b2ea86d0928ffdda4f583":[6,0,0,1109,73],
+"class_ogre_1_1_vulkan_xcb_window.html#a26e48774201b2ea86d0928ffdda4f583":[7,0,0,1082,73],
 "class_ogre_1_1_vulkan_xcb_window.html#a319d7bba3d2a578b0c846f0b419692ff":[6,0,0,1109,9],
 "class_ogre_1_1_vulkan_xcb_window.html#a319d7bba3d2a578b0c846f0b419692ff":[7,0,0,1082,9],
 "class_ogre_1_1_vulkan_xcb_window.html#a36453c99a5e3ac481ba7f59e40c94b55":[6,0,0,1109,55],
 "class_ogre_1_1_vulkan_xcb_window.html#a36453c99a5e3ac481ba7f59e40c94b55":[7,0,0,1082,55],
-"class_ogre_1_1_vulkan_xcb_window.html#a3766e755970279f575ec9e80db978b2d":[7,0,0,1082,30],
 "class_ogre_1_1_vulkan_xcb_window.html#a3766e755970279f575ec9e80db978b2d":[6,0,0,1109,30],
+"class_ogre_1_1_vulkan_xcb_window.html#a3766e755970279f575ec9e80db978b2d":[7,0,0,1082,30],
 "class_ogre_1_1_vulkan_xcb_window.html#a39e1b46f2145825d0620bc2ea50f6567":[7,0,0,1082,21],
 "class_ogre_1_1_vulkan_xcb_window.html#a39e1b46f2145825d0620bc2ea50f6567":[6,0,0,1109,21],
-"class_ogre_1_1_vulkan_xcb_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,1082,32],
 "class_ogre_1_1_vulkan_xcb_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[6,0,0,1109,32],
+"class_ogre_1_1_vulkan_xcb_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,1082,32],
 "class_ogre_1_1_vulkan_xcb_window.html#a452c19b6161f1ae310dfd92b026f7ed9":[6,0,0,1109,72],
 "class_ogre_1_1_vulkan_xcb_window.html#a452c19b6161f1ae310dfd92b026f7ed9":[7,0,0,1082,72],
 "class_ogre_1_1_vulkan_xcb_window.html#a462859aeb6b4db7290622623dae2a6a4":[6,0,0,1109,38],
 "class_ogre_1_1_vulkan_xcb_window.html#a462859aeb6b4db7290622623dae2a6a4":[7,0,0,1082,38],
 "class_ogre_1_1_vulkan_xcb_window.html#a52a89088aeae2102a509d740cbc19544":[6,0,0,1109,5],
 "class_ogre_1_1_vulkan_xcb_window.html#a52a89088aeae2102a509d740cbc19544":[7,0,0,1082,5],
-"class_ogre_1_1_vulkan_xcb_window.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1082,48],
 "class_ogre_1_1_vulkan_xcb_window.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,1109,48],
-"class_ogre_1_1_vulkan_xcb_window.html#a5c0fc2686c6ae1721340fed3687fb8aa":[6,0,0,1109,66],
+"class_ogre_1_1_vulkan_xcb_window.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,1082,48],
 "class_ogre_1_1_vulkan_xcb_window.html#a5c0fc2686c6ae1721340fed3687fb8aa":[7,0,0,1082,66],
+"class_ogre_1_1_vulkan_xcb_window.html#a5c0fc2686c6ae1721340fed3687fb8aa":[6,0,0,1109,66],
 "class_ogre_1_1_vulkan_xcb_window.html#a6126a1e71020b71712fb24b669e4ae23":[7,0,0,1082,8],
 "class_ogre_1_1_vulkan_xcb_window.html#a6126a1e71020b71712fb24b669e4ae23":[6,0,0,1109,8],
 "class_ogre_1_1_vulkan_xcb_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,1082,51],
@@ -163,66 +165,66 @@ var NAVTREEINDEX256 =
 "class_ogre_1_1_vulkan_xcb_window.html#a67ba7307754a41632bb41c383191bba7":[7,0,0,1082,15],
 "class_ogre_1_1_vulkan_xcb_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[7,0,0,1082,35],
 "class_ogre_1_1_vulkan_xcb_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[6,0,0,1109,35],
-"class_ogre_1_1_vulkan_xcb_window.html#a6e731d4414d454716620f0b401b9c823":[6,0,0,1109,63],
 "class_ogre_1_1_vulkan_xcb_window.html#a6e731d4414d454716620f0b401b9c823":[7,0,0,1082,63],
+"class_ogre_1_1_vulkan_xcb_window.html#a6e731d4414d454716620f0b401b9c823":[6,0,0,1109,63],
 "class_ogre_1_1_vulkan_xcb_window.html#a70cfe4412cfa68a9423854fc1b19872e":[7,0,0,1082,18],
 "class_ogre_1_1_vulkan_xcb_window.html#a70cfe4412cfa68a9423854fc1b19872e":[6,0,0,1109,18],
-"class_ogre_1_1_vulkan_xcb_window.html#a7359904108c9c7ac2cd3a3c1fdd891ad":[7,0,0,1082,76],
 "class_ogre_1_1_vulkan_xcb_window.html#a7359904108c9c7ac2cd3a3c1fdd891ad":[6,0,0,1109,76],
-"class_ogre_1_1_vulkan_xcb_window.html#a75261d46e5f123e31ab4f889b8788e5f":[6,0,0,1109,31],
+"class_ogre_1_1_vulkan_xcb_window.html#a7359904108c9c7ac2cd3a3c1fdd891ad":[7,0,0,1082,76],
 "class_ogre_1_1_vulkan_xcb_window.html#a75261d46e5f123e31ab4f889b8788e5f":[7,0,0,1082,31],
+"class_ogre_1_1_vulkan_xcb_window.html#a75261d46e5f123e31ab4f889b8788e5f":[6,0,0,1109,31],
 "class_ogre_1_1_vulkan_xcb_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[6,0,0,1109,59],
 "class_ogre_1_1_vulkan_xcb_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[7,0,0,1082,59],
-"class_ogre_1_1_vulkan_xcb_window.html#a7f7db089d78132c7a62c0fd0c2344185":[7,0,0,1082,75],
 "class_ogre_1_1_vulkan_xcb_window.html#a7f7db089d78132c7a62c0fd0c2344185":[6,0,0,1109,75],
-"class_ogre_1_1_vulkan_xcb_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[6,0,0,1109,36],
+"class_ogre_1_1_vulkan_xcb_window.html#a7f7db089d78132c7a62c0fd0c2344185":[7,0,0,1082,75],
 "class_ogre_1_1_vulkan_xcb_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[7,0,0,1082,36],
+"class_ogre_1_1_vulkan_xcb_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[6,0,0,1109,36],
 "class_ogre_1_1_vulkan_xcb_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,1082,44],
 "class_ogre_1_1_vulkan_xcb_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,1109,44],
-"class_ogre_1_1_vulkan_xcb_window.html#a84739cd779700fa8d7991c9cf11c289d":[6,0,0,1109,34],
 "class_ogre_1_1_vulkan_xcb_window.html#a84739cd779700fa8d7991c9cf11c289d":[7,0,0,1082,34],
-"class_ogre_1_1_vulkan_xcb_window.html#a8913d15f838a4fffcec0eb7a385e0e8d":[6,0,0,1109,61],
+"class_ogre_1_1_vulkan_xcb_window.html#a84739cd779700fa8d7991c9cf11c289d":[6,0,0,1109,34],
 "class_ogre_1_1_vulkan_xcb_window.html#a8913d15f838a4fffcec0eb7a385e0e8d":[7,0,0,1082,61],
-"class_ogre_1_1_vulkan_xcb_window.html#a8a464e98db9c09042b866bdb95b210f4":[6,0,0,1109,22],
+"class_ogre_1_1_vulkan_xcb_window.html#a8913d15f838a4fffcec0eb7a385e0e8d":[6,0,0,1109,61],
 "class_ogre_1_1_vulkan_xcb_window.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,1082,22],
-"class_ogre_1_1_vulkan_xcb_window.html#a8b05fabc7b8b6cf3129279629562476d":[6,0,0,1109,25],
+"class_ogre_1_1_vulkan_xcb_window.html#a8a464e98db9c09042b866bdb95b210f4":[6,0,0,1109,22],
 "class_ogre_1_1_vulkan_xcb_window.html#a8b05fabc7b8b6cf3129279629562476d":[7,0,0,1082,25],
+"class_ogre_1_1_vulkan_xcb_window.html#a8b05fabc7b8b6cf3129279629562476d":[6,0,0,1109,25],
 "class_ogre_1_1_vulkan_xcb_window.html#a8d6f1accac3551566dc3de3a44cfc9ac":[6,0,0,1109,11],
 "class_ogre_1_1_vulkan_xcb_window.html#a8d6f1accac3551566dc3de3a44cfc9ac":[7,0,0,1082,11],
 "class_ogre_1_1_vulkan_xcb_window.html#a8d7e786602979fc29169555056834c65":[7,0,0,1082,19],
 "class_ogre_1_1_vulkan_xcb_window.html#a8d7e786602979fc29169555056834c65":[6,0,0,1109,19],
-"class_ogre_1_1_vulkan_xcb_window.html#a8da820d27fbf472f0c8d210dc94561c1":[7,0,0,1082,3],
 "class_ogre_1_1_vulkan_xcb_window.html#a8da820d27fbf472f0c8d210dc94561c1":[6,0,0,1109,3],
+"class_ogre_1_1_vulkan_xcb_window.html#a8da820d27fbf472f0c8d210dc94561c1":[7,0,0,1082,3],
 "class_ogre_1_1_vulkan_xcb_window.html#a8ee456748696fb0e4e987e103781623f":[7,0,0,1082,57],
 "class_ogre_1_1_vulkan_xcb_window.html#a8ee456748696fb0e4e987e103781623f":[6,0,0,1109,57],
 "class_ogre_1_1_vulkan_xcb_window.html#a92d426a5762a35639ab102cfcbcaedf5":[6,0,0,1109,42],
 "class_ogre_1_1_vulkan_xcb_window.html#a92d426a5762a35639ab102cfcbcaedf5":[7,0,0,1082,42],
-"class_ogre_1_1_vulkan_xcb_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1109,47],
 "class_ogre_1_1_vulkan_xcb_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,1082,47],
-"class_ogre_1_1_vulkan_xcb_window.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,1082,24],
+"class_ogre_1_1_vulkan_xcb_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,1109,47],
 "class_ogre_1_1_vulkan_xcb_window.html#a9439f12db8a964f79f4b743493a0fd75":[6,0,0,1109,24],
+"class_ogre_1_1_vulkan_xcb_window.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,1082,24],
 "class_ogre_1_1_vulkan_xcb_window.html#a95c79431ef5e02a234b0119e288324ee":[6,0,0,1109,4],
 "class_ogre_1_1_vulkan_xcb_window.html#a95c79431ef5e02a234b0119e288324ee":[7,0,0,1082,4],
 "class_ogre_1_1_vulkan_xcb_window.html#a98f49dbefa207210a2f4c0025848b93c":[7,0,0,1082,26],
 "class_ogre_1_1_vulkan_xcb_window.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,1109,26],
-"class_ogre_1_1_vulkan_xcb_window.html#a9990c25b943d4fa0c0fc75979e0caf2e":[6,0,0,1109,13],
 "class_ogre_1_1_vulkan_xcb_window.html#a9990c25b943d4fa0c0fc75979e0caf2e":[7,0,0,1082,13],
+"class_ogre_1_1_vulkan_xcb_window.html#a9990c25b943d4fa0c0fc75979e0caf2e":[6,0,0,1109,13],
 "class_ogre_1_1_vulkan_xcb_window.html#a9af2d2b27cf6a53c60aca59598f631b2":[7,0,0,1082,10],
 "class_ogre_1_1_vulkan_xcb_window.html#a9af2d2b27cf6a53c60aca59598f631b2":[6,0,0,1109,10],
-"class_ogre_1_1_vulkan_xcb_window.html#aa1d1ac669cf59413e461d3d75ebd788a":[7,0,0,1082,40],
 "class_ogre_1_1_vulkan_xcb_window.html#aa1d1ac669cf59413e461d3d75ebd788a":[6,0,0,1109,40],
-"class_ogre_1_1_vulkan_xcb_window.html#aa562105b8ede44dd4bba7704ffcf763c":[7,0,0,1082,71],
+"class_ogre_1_1_vulkan_xcb_window.html#aa1d1ac669cf59413e461d3d75ebd788a":[7,0,0,1082,40],
 "class_ogre_1_1_vulkan_xcb_window.html#aa562105b8ede44dd4bba7704ffcf763c":[6,0,0,1109,71],
-"class_ogre_1_1_vulkan_xcb_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[7,0,0,1082,58],
+"class_ogre_1_1_vulkan_xcb_window.html#aa562105b8ede44dd4bba7704ffcf763c":[7,0,0,1082,71],
 "class_ogre_1_1_vulkan_xcb_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[6,0,0,1109,58],
+"class_ogre_1_1_vulkan_xcb_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[7,0,0,1082,58],
 "class_ogre_1_1_vulkan_xcb_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[6,0,0,1109,68],
 "class_ogre_1_1_vulkan_xcb_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[7,0,0,1082,68],
-"class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973":[6,0,0,1109,1],
 "class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973":[7,0,0,1082,1],
+"class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973":[6,0,0,1109,1],
 "class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7":[6,0,0,1109,1,2],
 "class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973a171bcac955fb078e482c0b88805000e7":[7,0,0,1082,1,2],
-"class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24":[6,0,0,1109,1,1],
 "class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24":[7,0,0,1082,1,1],
+"class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973a4ff72b5bd88dbf089a83d957e47aab24":[6,0,0,1109,1,1],
 "class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973a7a984b0fc998101009bed7b9e5692ada":[6,0,0,1109,1,0],
 "class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973a7a984b0fc998101009bed7b9e5692ada":[7,0,0,1082,1,0],
 "class_ogre_1_1_vulkan_xcb_window.html#aadf0d4f9a81f5217c467f3306941d973ae6e7b9212a61d76de37b5ea4a733a17d":[7,0,0,1082,1,3],
@@ -233,21 +235,19 @@ var NAVTREEINDEX256 =
 "class_ogre_1_1_vulkan_xcb_window.html#ab12be5918fc0d0c3a827250bf4f4d281a38c0af4dede0c20c83e78cf054666259":[6,0,0,1109,0,0],
 "class_ogre_1_1_vulkan_xcb_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,1109,50],
 "class_ogre_1_1_vulkan_xcb_window.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,1082,50],
-"class_ogre_1_1_vulkan_xcb_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,1109,7],
 "class_ogre_1_1_vulkan_xcb_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[7,0,0,1082,7],
-"class_ogre_1_1_vulkan_xcb_window.html#abbd5b7389535208fef6a357102b9afb9":[7,0,0,1082,2],
+"class_ogre_1_1_vulkan_xcb_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,1109,7],
 "class_ogre_1_1_vulkan_xcb_window.html#abbd5b7389535208fef6a357102b9afb9":[6,0,0,1109,2],
+"class_ogre_1_1_vulkan_xcb_window.html#abbd5b7389535208fef6a357102b9afb9":[7,0,0,1082,2],
 "class_ogre_1_1_vulkan_xcb_window.html#abca8be051e394795927805bb4b42b723":[7,0,0,1082,65],
 "class_ogre_1_1_vulkan_xcb_window.html#abca8be051e394795927805bb4b42b723":[6,0,0,1109,65],
-"class_ogre_1_1_vulkan_xcb_window.html#ac32922acc8ed420ebc9449595fb13acd":[6,0,0,1109,43],
 "class_ogre_1_1_vulkan_xcb_window.html#ac32922acc8ed420ebc9449595fb13acd":[7,0,0,1082,43],
+"class_ogre_1_1_vulkan_xcb_window.html#ac32922acc8ed420ebc9449595fb13acd":[6,0,0,1109,43],
 "class_ogre_1_1_vulkan_xcb_window.html#ac344214fa2a1ead13bb78f73712f69a3":[7,0,0,1082,67],
 "class_ogre_1_1_vulkan_xcb_window.html#ac344214fa2a1ead13bb78f73712f69a3":[6,0,0,1109,67],
 "class_ogre_1_1_vulkan_xcb_window.html#ac4782abeb9698a9d72469dde923bc714":[6,0,0,1109,12],
 "class_ogre_1_1_vulkan_xcb_window.html#ac4782abeb9698a9d72469dde923bc714":[7,0,0,1082,12],
 "class_ogre_1_1_vulkan_xcb_window.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,1082,17],
 "class_ogre_1_1_vulkan_xcb_window.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,1109,17],
-"class_ogre_1_1_vulkan_xcb_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1082,45],
-"class_ogre_1_1_vulkan_xcb_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1109,45],
-"class_ogre_1_1_vulkan_xcb_window.html#acd46202d3fd921f029d029fa2f5ed59b":[7,0,0,1082,6]
+"class_ogre_1_1_vulkan_xcb_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,1109,45]
 };
