@@ -1,44 +1,46 @@
 var NAVTREEINDEX257 =
 {
+"class_ogre_1_1_vulkan_xcb_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,1082,45],
+"class_ogre_1_1_vulkan_xcb_window.html#acd46202d3fd921f029d029fa2f5ed59b":[7,0,0,1082,6],
 "class_ogre_1_1_vulkan_xcb_window.html#acd46202d3fd921f029d029fa2f5ed59b":[6,0,0,1109,6],
 "class_ogre_1_1_vulkan_xcb_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,1109,28],
 "class_ogre_1_1_vulkan_xcb_window.html#ad15462609bf45808fb04668cc1c28c78":[7,0,0,1082,28],
-"class_ogre_1_1_vulkan_xcb_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1082,49],
 "class_ogre_1_1_vulkan_xcb_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,1109,49],
-"class_ogre_1_1_vulkan_xcb_window.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,1109,62],
+"class_ogre_1_1_vulkan_xcb_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,1082,49],
 "class_ogre_1_1_vulkan_xcb_window.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,1082,62],
+"class_ogre_1_1_vulkan_xcb_window.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,1109,62],
 "class_ogre_1_1_vulkan_xcb_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[7,0,0,1082,39],
 "class_ogre_1_1_vulkan_xcb_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[6,0,0,1109,39],
-"class_ogre_1_1_vulkan_xcb_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[7,0,0,1082,29],
 "class_ogre_1_1_vulkan_xcb_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,1109,29],
+"class_ogre_1_1_vulkan_xcb_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[7,0,0,1082,29],
 "class_ogre_1_1_vulkan_xcb_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,1082,52],
 "class_ogre_1_1_vulkan_xcb_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,1109,52],
 "class_ogre_1_1_vulkan_xcb_window.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,1109,20],
 "class_ogre_1_1_vulkan_xcb_window.html#add8e20491fc0e054c9cab3c75297c6ec":[7,0,0,1082,20],
 "class_ogre_1_1_vulkan_xcb_window.html#adfbd4f24b29343958aba5af0708a0683":[6,0,0,1109,54],
 "class_ogre_1_1_vulkan_xcb_window.html#adfbd4f24b29343958aba5af0708a0683":[7,0,0,1082,54],
-"class_ogre_1_1_vulkan_xcb_window.html#aecf38609606a498bc552a6cbbd5b3c38":[6,0,0,1109,37],
 "class_ogre_1_1_vulkan_xcb_window.html#aecf38609606a498bc552a6cbbd5b3c38":[7,0,0,1082,37],
-"class_ogre_1_1_vulkan_xcb_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1082,53],
+"class_ogre_1_1_vulkan_xcb_window.html#aecf38609606a498bc552a6cbbd5b3c38":[6,0,0,1109,37],
 "class_ogre_1_1_vulkan_xcb_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,1109,53],
-"class_ogre_1_1_vulkan_xcb_window.html#af574272c60f388e4c4712fa5d358ef7a":[7,0,0,1082,64],
+"class_ogre_1_1_vulkan_xcb_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,1082,53],
 "class_ogre_1_1_vulkan_xcb_window.html#af574272c60f388e4c4712fa5d358ef7a":[6,0,0,1109,64],
+"class_ogre_1_1_vulkan_xcb_window.html#af574272c60f388e4c4712fa5d358ef7a":[7,0,0,1082,64],
 "class_ogre_1_1_vulkan_xcb_window.html#af84c22b86889bef2ecc6d550264c880e":[6,0,0,1109,16],
 "class_ogre_1_1_vulkan_xcb_window.html#af84c22b86889bef2ecc6d550264c880e":[7,0,0,1082,16],
-"class_ogre_1_1_vulkan_xcb_window.html#afb956dde983e96a95394aa55215c55da":[6,0,0,1109,74],
 "class_ogre_1_1_vulkan_xcb_window.html#afb956dde983e96a95394aa55215c55da":[7,0,0,1082,74],
-"class_ogre_1_1_vulkan_xcb_window.html#afdcb5ee44409922a366fcb2b8f40a849":[7,0,0,1082,27],
+"class_ogre_1_1_vulkan_xcb_window.html#afb956dde983e96a95394aa55215c55da":[6,0,0,1109,74],
 "class_ogre_1_1_vulkan_xcb_window.html#afdcb5ee44409922a366fcb2b8f40a849":[6,0,0,1109,27],
-"class_ogre_1_1_waitable_event.html":[6,0,0,1110],
+"class_ogre_1_1_vulkan_xcb_window.html#afdcb5ee44409922a366fcb2b8f40a849":[7,0,0,1082,27],
 "class_ogre_1_1_waitable_event.html":[7,0,0,1083],
+"class_ogre_1_1_waitable_event.html":[6,0,0,1110],
 "class_ogre_1_1_waitable_event.html#a1a0392b8ecd2b3cecb4b70f0065993bd":[7,0,0,1083,0],
 "class_ogre_1_1_waitable_event.html#a1a0392b8ecd2b3cecb4b70f0065993bd":[6,0,0,1110,0],
 "class_ogre_1_1_waitable_event.html#a22e889e3724c8ed0d1d954fb267e75cb":[7,0,0,1083,1],
 "class_ogre_1_1_waitable_event.html#a22e889e3724c8ed0d1d954fb267e75cb":[6,0,0,1110,1],
 "class_ogre_1_1_waitable_event.html#ad9f80c2a326f5ec55c1b28b939d2dcba":[6,0,0,1110,2],
 "class_ogre_1_1_waitable_event.html#ad9f80c2a326f5ec55c1b28b939d2dcba":[7,0,0,1083,2],
-"class_ogre_1_1_waitable_event.html#adb23e55e733abc9656bc2fe90b0f1578":[7,0,0,1083,3],
 "class_ogre_1_1_waitable_event.html#adb23e55e733abc9656bc2fe90b0f1578":[6,0,0,1110,3],
+"class_ogre_1_1_waitable_event.html#adb23e55e733abc9656bc2fe90b0f1578":[7,0,0,1083,3],
 "class_ogre_1_1_waveform_controller_function.html":[5,2,2,132],
 "class_ogre_1_1_waveform_controller_function.html#a1b83f439aae8d785f1db065ac7e59139":[5,2,2,132,0],
 "class_ogre_1_1_waveform_controller_function.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,2,132,4],
@@ -52,118 +54,118 @@ var NAVTREEINDEX257 =
 "class_ogre_1_1_waveform_controller_function.html#adce32528577d71b228692df906ecd17c":[5,2,2,132,10],
 "class_ogre_1_1_waveform_controller_function.html#aec4afc09add54fd7872f78e299e1d276":[5,2,2,132,1],
 "class_ogre_1_1_waveform_controller_function.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,2,132,11],
-"class_ogre_1_1_win32_context.html":[7,0,0,1085],
 "class_ogre_1_1_win32_context.html":[6,0,0,1112],
-"class_ogre_1_1_win32_context.html#a02724e124a37133de86907ad3c4a65e9":[7,0,0,1085,3],
+"class_ogre_1_1_win32_context.html":[7,0,0,1085],
 "class_ogre_1_1_win32_context.html#a02724e124a37133de86907ad3c4a65e9":[6,0,0,1112,3],
-"class_ogre_1_1_win32_context.html#a0ec054266a14ef720813434d42b035c7":[7,0,0,1085,0],
+"class_ogre_1_1_win32_context.html#a02724e124a37133de86907ad3c4a65e9":[7,0,0,1085,3],
 "class_ogre_1_1_win32_context.html#a0ec054266a14ef720813434d42b035c7":[6,0,0,1112,0],
-"class_ogre_1_1_win32_context.html#a291525177116254970385db2fab2536d":[6,0,0,1112,8],
+"class_ogre_1_1_win32_context.html#a0ec054266a14ef720813434d42b035c7":[7,0,0,1085,0],
 "class_ogre_1_1_win32_context.html#a291525177116254970385db2fab2536d":[7,0,0,1085,8],
+"class_ogre_1_1_win32_context.html#a291525177116254970385db2fab2536d":[6,0,0,1112,8],
 "class_ogre_1_1_win32_context.html#a5c58d3129786f5a8d5cb95a56c3492b4":[6,0,0,1112,4],
 "class_ogre_1_1_win32_context.html#a5c58d3129786f5a8d5cb95a56c3492b4":[7,0,0,1085,4],
-"class_ogre_1_1_win32_context.html#a5f1d94dbef0a4021eb4d93eefb59e7c5":[7,0,0,1085,7],
 "class_ogre_1_1_win32_context.html#a5f1d94dbef0a4021eb4d93eefb59e7c5":[6,0,0,1112,7],
-"class_ogre_1_1_win32_context.html#aa5a289fe65c137eaf0ba5760fa88c5a1":[7,0,0,1085,6],
+"class_ogre_1_1_win32_context.html#a5f1d94dbef0a4021eb4d93eefb59e7c5":[7,0,0,1085,7],
 "class_ogre_1_1_win32_context.html#aa5a289fe65c137eaf0ba5760fa88c5a1":[6,0,0,1112,6],
-"class_ogre_1_1_win32_context.html#acc5f8635eda869d7848234b6c35659ca":[7,0,0,1085,5],
+"class_ogre_1_1_win32_context.html#aa5a289fe65c137eaf0ba5760fa88c5a1":[7,0,0,1085,6],
 "class_ogre_1_1_win32_context.html#acc5f8635eda869d7848234b6c35659ca":[6,0,0,1112,5],
-"class_ogre_1_1_win32_context.html#ad637775955c14f8e59296683f2694b6f":[7,0,0,1085,2],
+"class_ogre_1_1_win32_context.html#acc5f8635eda869d7848234b6c35659ca":[7,0,0,1085,5],
 "class_ogre_1_1_win32_context.html#ad637775955c14f8e59296683f2694b6f":[6,0,0,1112,2],
+"class_ogre_1_1_win32_context.html#ad637775955c14f8e59296683f2694b6f":[7,0,0,1085,2],
 "class_ogre_1_1_win32_context.html#ad9815a3c7611621bba3f194b278a70c5":[6,0,0,1112,1],
 "class_ogre_1_1_win32_context.html#ad9815a3c7611621bba3f194b278a70c5":[7,0,0,1085,1],
-"class_ogre_1_1_win32_e_g_l_context.html":[7,0,0,1086],
 "class_ogre_1_1_win32_e_g_l_context.html":[6,0,0,1113],
-"class_ogre_1_1_win32_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[7,0,0,1086,5],
-"class_ogre_1_1_win32_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[6,0,0,1113,6],
-"class_ogre_1_1_win32_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[7,0,0,1086,6],
+"class_ogre_1_1_win32_e_g_l_context.html":[7,0,0,1086],
 "class_ogre_1_1_win32_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[6,0,0,1113,5],
-"class_ogre_1_1_win32_e_g_l_context.html#a0f2b47f53f419897c04ccf676ace35e5":[6,0,0,1113,3],
+"class_ogre_1_1_win32_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[6,0,0,1113,6],
+"class_ogre_1_1_win32_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[7,0,0,1086,5],
+"class_ogre_1_1_win32_e_g_l_context.html#a08612fd3eea707121938bb0197e454c6":[7,0,0,1086,6],
 "class_ogre_1_1_win32_e_g_l_context.html#a0f2b47f53f419897c04ccf676ace35e5":[7,0,0,1086,3],
+"class_ogre_1_1_win32_e_g_l_context.html#a0f2b47f53f419897c04ccf676ace35e5":[6,0,0,1113,3],
 "class_ogre_1_1_win32_e_g_l_context.html#a15cc115c6f857dad066218f1225c4283":[7,0,0,1086,11],
 "class_ogre_1_1_win32_e_g_l_context.html#a15cc115c6f857dad066218f1225c4283":[6,0,0,1113,11],
-"class_ogre_1_1_win32_e_g_l_context.html#a1773206dd73cb2d134a18f0c90db2335":[7,0,0,1086,7],
 "class_ogre_1_1_win32_e_g_l_context.html#a1773206dd73cb2d134a18f0c90db2335":[6,0,0,1113,7],
-"class_ogre_1_1_win32_e_g_l_context.html#a1adbc39dc51e3c5dd91795544c2fa352":[7,0,0,1086,10],
+"class_ogre_1_1_win32_e_g_l_context.html#a1773206dd73cb2d134a18f0c90db2335":[7,0,0,1086,7],
 "class_ogre_1_1_win32_e_g_l_context.html#a1adbc39dc51e3c5dd91795544c2fa352":[6,0,0,1113,10],
-"class_ogre_1_1_win32_e_g_l_context.html#a291525177116254970385db2fab2536d":[7,0,0,1086,14],
+"class_ogre_1_1_win32_e_g_l_context.html#a1adbc39dc51e3c5dd91795544c2fa352":[7,0,0,1086,10],
 "class_ogre_1_1_win32_e_g_l_context.html#a291525177116254970385db2fab2536d":[6,0,0,1113,14],
+"class_ogre_1_1_win32_e_g_l_context.html#a291525177116254970385db2fab2536d":[7,0,0,1086,14],
 "class_ogre_1_1_win32_e_g_l_context.html#a4378c54b9b62bf679d5a774660e2d68a":[6,0,0,1113,0],
 "class_ogre_1_1_win32_e_g_l_context.html#a4378c54b9b62bf679d5a774660e2d68a":[7,0,0,1086,0],
-"class_ogre_1_1_win32_e_g_l_context.html#aa7b87d8031a667931b402d8f96346da8":[6,0,0,1113,2],
 "class_ogre_1_1_win32_e_g_l_context.html#aa7b87d8031a667931b402d8f96346da8":[7,0,0,1086,2],
+"class_ogre_1_1_win32_e_g_l_context.html#aa7b87d8031a667931b402d8f96346da8":[6,0,0,1113,2],
+"class_ogre_1_1_win32_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[6,0,0,1113,12],
+"class_ogre_1_1_win32_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[6,0,0,1113,13],
 "class_ogre_1_1_win32_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[7,0,0,1086,12],
 "class_ogre_1_1_win32_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[7,0,0,1086,13],
-"class_ogre_1_1_win32_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[6,0,0,1113,13],
-"class_ogre_1_1_win32_e_g_l_context.html#aa817ff5a5ae3fbb16d8ad182016b212d":[6,0,0,1113,12],
-"class_ogre_1_1_win32_e_g_l_context.html#aae3d4471c090572da0ced04cde4b87bf":[7,0,0,1086,15],
 "class_ogre_1_1_win32_e_g_l_context.html#aae3d4471c090572da0ced04cde4b87bf":[6,0,0,1113,15],
+"class_ogre_1_1_win32_e_g_l_context.html#aae3d4471c090572da0ced04cde4b87bf":[7,0,0,1086,15],
 "class_ogre_1_1_win32_e_g_l_context.html#ab3c52ee07a08ce5f9c352baafd8b1dac":[7,0,0,1086,1],
 "class_ogre_1_1_win32_e_g_l_context.html#ab3c52ee07a08ce5f9c352baafd8b1dac":[6,0,0,1113,1],
-"class_ogre_1_1_win32_e_g_l_context.html#abd71a4bfddbdf111e429e9ff825af985":[7,0,0,1086,9],
 "class_ogre_1_1_win32_e_g_l_context.html#abd71a4bfddbdf111e429e9ff825af985":[6,0,0,1113,9],
+"class_ogre_1_1_win32_e_g_l_context.html#abd71a4bfddbdf111e429e9ff825af985":[7,0,0,1086,9],
 "class_ogre_1_1_win32_e_g_l_context.html#acc5f8635eda869d7848234b6c35659ca":[7,0,0,1086,8],
 "class_ogre_1_1_win32_e_g_l_context.html#acc5f8635eda869d7848234b6c35659ca":[6,0,0,1113,8],
 "class_ogre_1_1_win32_e_g_l_context.html#ad99e2c0a1f2e9a5cd1d8133550f889ef":[7,0,0,1086,4],
 "class_ogre_1_1_win32_e_g_l_context.html#ad99e2c0a1f2e9a5cd1d8133550f889ef":[6,0,0,1113,4],
 "class_ogre_1_1_win32_e_g_l_context.html#ae0deff82440f162380917cbc211ad800":[6,0,0,1113,16],
 "class_ogre_1_1_win32_e_g_l_context.html#ae0deff82440f162380917cbc211ad800":[7,0,0,1086,16],
-"class_ogre_1_1_win32_e_g_l_support.html":[6,0,0,1114],
 "class_ogre_1_1_win32_e_g_l_support.html":[7,0,0,1087],
+"class_ogre_1_1_win32_e_g_l_support.html":[6,0,0,1114],
 "class_ogre_1_1_win32_e_g_l_support.html#a033156d669f87cdff8d4d1e077172439":[7,0,0,1087,23],
 "class_ogre_1_1_win32_e_g_l_support.html#a033156d669f87cdff8d4d1e077172439":[6,0,0,1114,23],
-"class_ogre_1_1_win32_e_g_l_support.html#a07c4b0572b1adc4104e6a5d6044cd30b":[7,0,0,1087,20],
 "class_ogre_1_1_win32_e_g_l_support.html#a07c4b0572b1adc4104e6a5d6044cd30b":[6,0,0,1114,20],
+"class_ogre_1_1_win32_e_g_l_support.html#a07c4b0572b1adc4104e6a5d6044cd30b":[7,0,0,1087,20],
 "class_ogre_1_1_win32_e_g_l_support.html#a17408d3e5d0fbb9ee32c85b477fa6b9c":[7,0,0,1087,5],
 "class_ogre_1_1_win32_e_g_l_support.html#a17408d3e5d0fbb9ee32c85b477fa6b9c":[6,0,0,1114,5],
-"class_ogre_1_1_win32_e_g_l_support.html#a1b2f582872d8c79698d93e7aa02ba4c6":[6,0,0,1114,22],
 "class_ogre_1_1_win32_e_g_l_support.html#a1b2f582872d8c79698d93e7aa02ba4c6":[7,0,0,1087,22],
+"class_ogre_1_1_win32_e_g_l_support.html#a1b2f582872d8c79698d93e7aa02ba4c6":[6,0,0,1114,22],
 "class_ogre_1_1_win32_e_g_l_support.html#a26716c668eb93c41ed05507772450100":[7,0,0,1087,7],
 "class_ogre_1_1_win32_e_g_l_support.html#a26716c668eb93c41ed05507772450100":[6,0,0,1114,7],
 "class_ogre_1_1_win32_e_g_l_support.html#a2ad75109633640f575021360dfad5a5f":[7,0,0,1087,0],
 "class_ogre_1_1_win32_e_g_l_support.html#a2ad75109633640f575021360dfad5a5f":[6,0,0,1114,0],
 "class_ogre_1_1_win32_e_g_l_support.html#a3231189db20cf0b36594703aaafbabd2":[7,0,0,1087,4],
 "class_ogre_1_1_win32_e_g_l_support.html#a3231189db20cf0b36594703aaafbabd2":[6,0,0,1114,4],
-"class_ogre_1_1_win32_e_g_l_support.html#a396d18d9c6fd316f8a032386735ad6bc":[7,0,0,1087,25],
 "class_ogre_1_1_win32_e_g_l_support.html#a396d18d9c6fd316f8a032386735ad6bc":[6,0,0,1114,25],
-"class_ogre_1_1_win32_e_g_l_support.html#a3bb7ba22015a2517d13d48fb94d7c236":[6,0,0,1114,15],
+"class_ogre_1_1_win32_e_g_l_support.html#a396d18d9c6fd316f8a032386735ad6bc":[7,0,0,1087,25],
 "class_ogre_1_1_win32_e_g_l_support.html#a3bb7ba22015a2517d13d48fb94d7c236":[7,0,0,1087,15],
-"class_ogre_1_1_win32_e_g_l_support.html#a43d180a4897f40c624a7213fadb15798":[6,0,0,1114,32],
+"class_ogre_1_1_win32_e_g_l_support.html#a3bb7ba22015a2517d13d48fb94d7c236":[6,0,0,1114,15],
 "class_ogre_1_1_win32_e_g_l_support.html#a43d180a4897f40c624a7213fadb15798":[7,0,0,1087,32],
-"class_ogre_1_1_win32_e_g_l_support.html#a47ed5f3e606d96a913494b7831a4db0c":[6,0,0,1114,29],
+"class_ogre_1_1_win32_e_g_l_support.html#a43d180a4897f40c624a7213fadb15798":[6,0,0,1114,32],
 "class_ogre_1_1_win32_e_g_l_support.html#a47ed5f3e606d96a913494b7831a4db0c":[7,0,0,1087,29],
-"class_ogre_1_1_win32_e_g_l_support.html#a4c4122eb5ca0cd660c95e593e35e684b":[7,0,0,1087,12],
+"class_ogre_1_1_win32_e_g_l_support.html#a47ed5f3e606d96a913494b7831a4db0c":[6,0,0,1114,29],
 "class_ogre_1_1_win32_e_g_l_support.html#a4c4122eb5ca0cd660c95e593e35e684b":[6,0,0,1114,12],
-"class_ogre_1_1_win32_e_g_l_support.html#a52e33d95fd49c5fffbb641b99adcec6e":[6,0,0,1114,19],
+"class_ogre_1_1_win32_e_g_l_support.html#a4c4122eb5ca0cd660c95e593e35e684b":[7,0,0,1087,12],
 "class_ogre_1_1_win32_e_g_l_support.html#a52e33d95fd49c5fffbb641b99adcec6e":[7,0,0,1087,19],
-"class_ogre_1_1_win32_e_g_l_support.html#a5812077a3463f0ad9ca639a9ec768d6d":[6,0,0,1114,33],
+"class_ogre_1_1_win32_e_g_l_support.html#a52e33d95fd49c5fffbb641b99adcec6e":[6,0,0,1114,19],
 "class_ogre_1_1_win32_e_g_l_support.html#a5812077a3463f0ad9ca639a9ec768d6d":[7,0,0,1087,33],
-"class_ogre_1_1_win32_e_g_l_support.html#a80901e793c70a24a680064a9836dd022":[7,0,0,1087,16],
+"class_ogre_1_1_win32_e_g_l_support.html#a5812077a3463f0ad9ca639a9ec768d6d":[6,0,0,1114,33],
 "class_ogre_1_1_win32_e_g_l_support.html#a80901e793c70a24a680064a9836dd022":[6,0,0,1114,16],
-"class_ogre_1_1_win32_e_g_l_support.html#a9045ff50fe96c0cc75f846a701958969":[7,0,0,1087,3],
+"class_ogre_1_1_win32_e_g_l_support.html#a80901e793c70a24a680064a9836dd022":[7,0,0,1087,16],
 "class_ogre_1_1_win32_e_g_l_support.html#a9045ff50fe96c0cc75f846a701958969":[6,0,0,1114,3],
+"class_ogre_1_1_win32_e_g_l_support.html#a9045ff50fe96c0cc75f846a701958969":[7,0,0,1087,3],
 "class_ogre_1_1_win32_e_g_l_support.html#a95d41b6cdcaae14ef909a0a230c4b273":[7,0,0,1087,26],
 "class_ogre_1_1_win32_e_g_l_support.html#a95d41b6cdcaae14ef909a0a230c4b273":[6,0,0,1114,26],
 "class_ogre_1_1_win32_e_g_l_support.html#a9d9194fbf90d661ea24d3714bef59579":[6,0,0,1114,2],
 "class_ogre_1_1_win32_e_g_l_support.html#a9d9194fbf90d661ea24d3714bef59579":[7,0,0,1087,2],
-"class_ogre_1_1_win32_e_g_l_support.html#aa380156afd8961c1d4470e5d9039549d":[7,0,0,1087,14],
 "class_ogre_1_1_win32_e_g_l_support.html#aa380156afd8961c1d4470e5d9039549d":[6,0,0,1114,14],
+"class_ogre_1_1_win32_e_g_l_support.html#aa380156afd8961c1d4470e5d9039549d":[7,0,0,1087,14],
 "class_ogre_1_1_win32_e_g_l_support.html#aa52a532cd85238d5227f23d4b3de35e4":[7,0,0,1087,27],
 "class_ogre_1_1_win32_e_g_l_support.html#aa52a532cd85238d5227f23d4b3de35e4":[6,0,0,1114,27],
 "class_ogre_1_1_win32_e_g_l_support.html#aa5e7365bb25af2e2e4694d9e1053487e":[6,0,0,1114,13],
 "class_ogre_1_1_win32_e_g_l_support.html#aa5e7365bb25af2e2e4694d9e1053487e":[7,0,0,1087,13],
 "class_ogre_1_1_win32_e_g_l_support.html#aa6270b9b75c58546e3a56b342172f3e3":[6,0,0,1114,11],
 "class_ogre_1_1_win32_e_g_l_support.html#aa6270b9b75c58546e3a56b342172f3e3":[7,0,0,1087,11],
-"class_ogre_1_1_win32_e_g_l_support.html#aa71343d5875a622df88b2a9e329ce260":[7,0,0,1087,1],
 "class_ogre_1_1_win32_e_g_l_support.html#aa71343d5875a622df88b2a9e329ce260":[6,0,0,1114,1],
+"class_ogre_1_1_win32_e_g_l_support.html#aa71343d5875a622df88b2a9e329ce260":[7,0,0,1087,1],
 "class_ogre_1_1_win32_e_g_l_support.html#aac4192667d89adb4ecdd72bd4e00621c":[7,0,0,1087,6],
 "class_ogre_1_1_win32_e_g_l_support.html#aac4192667d89adb4ecdd72bd4e00621c":[6,0,0,1114,6],
-"class_ogre_1_1_win32_e_g_l_support.html#aba7b889aca8da4dcfd98d5864aca3eaf":[7,0,0,1087,24],
 "class_ogre_1_1_win32_e_g_l_support.html#aba7b889aca8da4dcfd98d5864aca3eaf":[6,0,0,1114,24],
-"class_ogre_1_1_win32_e_g_l_support.html#ac3b4eec713bd275e2094c034622db0eb":[7,0,0,1087,8],
+"class_ogre_1_1_win32_e_g_l_support.html#aba7b889aca8da4dcfd98d5864aca3eaf":[7,0,0,1087,24],
 "class_ogre_1_1_win32_e_g_l_support.html#ac3b4eec713bd275e2094c034622db0eb":[6,0,0,1114,8],
-"class_ogre_1_1_win32_e_g_l_support.html#ac8559d5d6fbb007a30774351e3eb0741":[6,0,0,1114,30],
+"class_ogre_1_1_win32_e_g_l_support.html#ac3b4eec713bd275e2094c034622db0eb":[7,0,0,1087,8],
 "class_ogre_1_1_win32_e_g_l_support.html#ac8559d5d6fbb007a30774351e3eb0741":[7,0,0,1087,30],
+"class_ogre_1_1_win32_e_g_l_support.html#ac8559d5d6fbb007a30774351e3eb0741":[6,0,0,1114,30],
 "class_ogre_1_1_win32_e_g_l_support.html#ae1ce9edd38de8894aa362964c1329998":[6,0,0,1114,21],
 "class_ogre_1_1_win32_e_g_l_support.html#ae1ce9edd38de8894aa362964c1329998":[7,0,0,1087,21],
 "class_ogre_1_1_win32_e_g_l_support.html#ae3d6f4ffada30b202f71a717a346ba22":[7,0,0,1087,17],
@@ -172,82 +174,80 @@ var NAVTREEINDEX257 =
 "class_ogre_1_1_win32_e_g_l_support.html#ae4373407c04f1cab7743ae4c99bfd3cb":[6,0,0,1114,10],
 "class_ogre_1_1_win32_e_g_l_support.html#ae7e90590f2038fbc475d2d857add5e2e":[6,0,0,1114,9],
 "class_ogre_1_1_win32_e_g_l_support.html#ae7e90590f2038fbc475d2d857add5e2e":[7,0,0,1087,9],
-"class_ogre_1_1_win32_e_g_l_support.html#aee71411b493ff1737308b311577f04da":[7,0,0,1087,31],
 "class_ogre_1_1_win32_e_g_l_support.html#aee71411b493ff1737308b311577f04da":[6,0,0,1114,31],
-"class_ogre_1_1_win32_e_g_l_support.html#aee9a5957c98ac70592dc9ec82a862d68":[6,0,0,1114,28],
+"class_ogre_1_1_win32_e_g_l_support.html#aee71411b493ff1737308b311577f04da":[7,0,0,1087,31],
 "class_ogre_1_1_win32_e_g_l_support.html#aee9a5957c98ac70592dc9ec82a862d68":[7,0,0,1087,28],
+"class_ogre_1_1_win32_e_g_l_support.html#aee9a5957c98ac70592dc9ec82a862d68":[6,0,0,1114,28],
 "class_ogre_1_1_win32_e_g_l_support.html#af910fe0f36bcec0b5908fdb9be22ad7f":[6,0,0,1114,18],
 "class_ogre_1_1_win32_e_g_l_support.html#af910fe0f36bcec0b5908fdb9be22ad7f":[7,0,0,1087,18],
-"class_ogre_1_1_win32_e_g_l_window.html":[6,0,0,1115],
 "class_ogre_1_1_win32_e_g_l_window.html":[7,0,0,1088],
-"class_ogre_1_1_win32_e_g_l_window.html#a008f63c8d729fe7328366170b5ed2d72":[7,0,0,1088,8],
+"class_ogre_1_1_win32_e_g_l_window.html":[6,0,0,1115],
 "class_ogre_1_1_win32_e_g_l_window.html#a008f63c8d729fe7328366170b5ed2d72":[6,0,0,1115,8],
-"class_ogre_1_1_win32_e_g_l_window.html#a03ae803c4754c6008fb5b898fb8090b8":[7,0,0,1088,126],
+"class_ogre_1_1_win32_e_g_l_window.html#a008f63c8d729fe7328366170b5ed2d72":[7,0,0,1088,8],
 "class_ogre_1_1_win32_e_g_l_window.html#a03ae803c4754c6008fb5b898fb8090b8":[6,0,0,1115,126],
+"class_ogre_1_1_win32_e_g_l_window.html#a03ae803c4754c6008fb5b898fb8090b8":[7,0,0,1088,126],
 "class_ogre_1_1_win32_e_g_l_window.html#a0411214c1513cf32e55edc5be3008ec0":[7,0,0,1088,75],
 "class_ogre_1_1_win32_e_g_l_window.html#a0411214c1513cf32e55edc5be3008ec0":[6,0,0,1115,75],
-"class_ogre_1_1_win32_e_g_l_window.html#a0c00ca9d1ba7f3efc248ae86511fbff9":[6,0,0,1115,105],
 "class_ogre_1_1_win32_e_g_l_window.html#a0c00ca9d1ba7f3efc248ae86511fbff9":[7,0,0,1088,105],
+"class_ogre_1_1_win32_e_g_l_window.html#a0c00ca9d1ba7f3efc248ae86511fbff9":[6,0,0,1115,105],
 "class_ogre_1_1_win32_e_g_l_window.html#a0d3f944eab02d9dccb9e937e7f534e10":[7,0,0,1088,33],
 "class_ogre_1_1_win32_e_g_l_window.html#a0d3f944eab02d9dccb9e937e7f534e10":[6,0,0,1115,33],
 "class_ogre_1_1_win32_e_g_l_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[7,0,0,1088,119],
 "class_ogre_1_1_win32_e_g_l_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,1115,119],
-"class_ogre_1_1_win32_e_g_l_window.html#a0fcddbd42767a6f35d3660e3bd5f02be":[7,0,0,1088,26],
 "class_ogre_1_1_win32_e_g_l_window.html#a0fcddbd42767a6f35d3660e3bd5f02be":[6,0,0,1115,26],
-"class_ogre_1_1_win32_e_g_l_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,1115,56],
+"class_ogre_1_1_win32_e_g_l_window.html#a0fcddbd42767a6f35d3660e3bd5f02be":[7,0,0,1088,26],
 "class_ogre_1_1_win32_e_g_l_window.html#a12411d378aa0623e29287964eeb261c4":[7,0,0,1088,56],
-"class_ogre_1_1_win32_e_g_l_window.html#a154bf76eb66058a0135bad1e7be04bd1":[6,0,0,1115,124],
+"class_ogre_1_1_win32_e_g_l_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,1115,56],
 "class_ogre_1_1_win32_e_g_l_window.html#a154bf76eb66058a0135bad1e7be04bd1":[7,0,0,1088,124],
-"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490":[7,0,0,1088,1],
+"class_ogre_1_1_win32_e_g_l_window.html#a154bf76eb66058a0135bad1e7be04bd1":[6,0,0,1115,124],
 "class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490":[6,0,0,1115,1],
-"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a18416c60c9b82d928db766bef672ecea":[6,0,0,1115,1,6],
+"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490":[7,0,0,1088,1],
 "class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a18416c60c9b82d928db766bef672ecea":[7,0,0,1088,1,6],
-"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a19ef0adeaa177d49fc4ca4c9b87adec1":[6,0,0,1115,1,5],
+"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a18416c60c9b82d928db766bef672ecea":[6,0,0,1115,1,6],
 "class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a19ef0adeaa177d49fc4ca4c9b87adec1":[7,0,0,1088,1,5],
-"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a1f0cd329c7ff6d5d81b2162c65d04afa":[7,0,0,1088,1,1],
+"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a19ef0adeaa177d49fc4ca4c9b87adec1":[6,0,0,1115,1,5],
 "class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a1f0cd329c7ff6d5d81b2162c65d04afa":[6,0,0,1115,1,1],
+"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a1f0cd329c7ff6d5d81b2162c65d04afa":[7,0,0,1088,1,1],
 "class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a5ee29312d754f2244987dc0d1f5894e8":[6,0,0,1115,1,2],
 "class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a5ee29312d754f2244987dc0d1f5894e8":[7,0,0,1088,1,2],
-"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a6df94556ae07dfa0384808dca8dedb64":[7,0,0,1088,1,0],
 "class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a6df94556ae07dfa0384808dca8dedb64":[6,0,0,1115,1,0],
+"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490a6df94556ae07dfa0384808dca8dedb64":[7,0,0,1088,1,0],
 "class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490aba6283bc81ca4e5e6cd2b85497a2cc2f":[7,0,0,1088,1,4],
 "class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490aba6283bc81ca4e5e6cd2b85497a2cc2f":[6,0,0,1115,1,4],
-"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490ac08101cb24d35c29eb7064886081e386":[6,0,0,1115,1,3],
 "class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490ac08101cb24d35c29eb7064886081e386":[7,0,0,1088,1,3],
+"class_ogre_1_1_win32_e_g_l_window.html#a15f59cd1b4a2b2e65fcee349d78ae490ac08101cb24d35c29eb7064886081e386":[6,0,0,1115,1,3],
 "class_ogre_1_1_win32_e_g_l_window.html#a1799514a8ad7958919ca48c654a47e8e":[7,0,0,1088,14],
 "class_ogre_1_1_win32_e_g_l_window.html#a1799514a8ad7958919ca48c654a47e8e":[6,0,0,1115,14],
-"class_ogre_1_1_win32_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[7,0,0,1088,134],
-"class_ogre_1_1_win32_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[7,0,0,1088,133],
-"class_ogre_1_1_win32_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[6,0,0,1115,133],
 "class_ogre_1_1_win32_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[6,0,0,1115,134],
-"class_ogre_1_1_win32_e_g_l_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1115,87],
+"class_ogre_1_1_win32_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[6,0,0,1115,133],
+"class_ogre_1_1_win32_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[7,0,0,1088,133],
+"class_ogre_1_1_win32_e_g_l_window.html#a1be793f362f5e766574e8256a7099baa":[7,0,0,1088,134],
 "class_ogre_1_1_win32_e_g_l_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1115,88],
+"class_ogre_1_1_win32_e_g_l_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,1115,87],
 "class_ogre_1_1_win32_e_g_l_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1088,88],
 "class_ogre_1_1_win32_e_g_l_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,1088,87],
 "class_ogre_1_1_win32_e_g_l_window.html#a1d8e7ae222973449defdfe63d3981c70":[6,0,0,1115,72],
 "class_ogre_1_1_win32_e_g_l_window.html#a1d8e7ae222973449defdfe63d3981c70":[7,0,0,1088,72],
 "class_ogre_1_1_win32_e_g_l_window.html#a22779bbfb123c76e922942ba876e330a":[6,0,0,1115,74],
 "class_ogre_1_1_win32_e_g_l_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,1088,74],
-"class_ogre_1_1_win32_e_g_l_window.html#a24b847657d58db6ab5e14f7972e38a5d":[6,0,0,1115,120],
 "class_ogre_1_1_win32_e_g_l_window.html#a24b847657d58db6ab5e14f7972e38a5d":[7,0,0,1088,120],
-"class_ogre_1_1_win32_e_g_l_window.html#a279914cf4611a750e94b6fb54bc1b2d1":[6,0,0,1115,113],
+"class_ogre_1_1_win32_e_g_l_window.html#a24b847657d58db6ab5e14f7972e38a5d":[6,0,0,1115,120],
 "class_ogre_1_1_win32_e_g_l_window.html#a279914cf4611a750e94b6fb54bc1b2d1":[7,0,0,1088,113],
+"class_ogre_1_1_win32_e_g_l_window.html#a279914cf4611a750e94b6fb54bc1b2d1":[6,0,0,1115,113],
 "class_ogre_1_1_win32_e_g_l_window.html#a2ba802f4884b0db42bd5248a79696f3b":[7,0,0,1088,128],
 "class_ogre_1_1_win32_e_g_l_window.html#a2ba802f4884b0db42bd5248a79696f3b":[6,0,0,1115,128],
-"class_ogre_1_1_win32_e_g_l_window.html#a2bdfaa76a186e49b807b06c7a92b720e":[6,0,0,1115,121],
 "class_ogre_1_1_win32_e_g_l_window.html#a2bdfaa76a186e49b807b06c7a92b720e":[7,0,0,1088,121],
-"class_ogre_1_1_win32_e_g_l_window.html#a2ec6bf8518f8e3c66126fbc7be2215b6":[6,0,0,1115,2],
+"class_ogre_1_1_win32_e_g_l_window.html#a2bdfaa76a186e49b807b06c7a92b720e":[6,0,0,1115,121],
 "class_ogre_1_1_win32_e_g_l_window.html#a2ec6bf8518f8e3c66126fbc7be2215b6":[7,0,0,1088,2],
+"class_ogre_1_1_win32_e_g_l_window.html#a2ec6bf8518f8e3c66126fbc7be2215b6":[6,0,0,1115,2],
 "class_ogre_1_1_win32_e_g_l_window.html#a2fe16ffcf13b12bcf7d16022c47e645e":[6,0,0,1115,50],
 "class_ogre_1_1_win32_e_g_l_window.html#a2fe16ffcf13b12bcf7d16022c47e645e":[7,0,0,1088,50],
-"class_ogre_1_1_win32_e_g_l_window.html#a32f2e646a09dcdaef810ea402bc92155":[6,0,0,1115,23],
 "class_ogre_1_1_win32_e_g_l_window.html#a32f2e646a09dcdaef810ea402bc92155":[7,0,0,1088,23],
+"class_ogre_1_1_win32_e_g_l_window.html#a32f2e646a09dcdaef810ea402bc92155":[6,0,0,1115,23],
 "class_ogre_1_1_win32_e_g_l_window.html#a3649200bc76f575f6241beff14dd80d0":[7,0,0,1088,30],
 "class_ogre_1_1_win32_e_g_l_window.html#a3649200bc76f575f6241beff14dd80d0":[6,0,0,1115,30],
-"class_ogre_1_1_win32_e_g_l_window.html#a3956ee83f63d971774bde68000f60f53":[7,0,0,1088,122],
 "class_ogre_1_1_win32_e_g_l_window.html#a3956ee83f63d971774bde68000f60f53":[6,0,0,1115,122],
-"class_ogre_1_1_win32_e_g_l_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[6,0,0,1115,53],
+"class_ogre_1_1_win32_e_g_l_window.html#a3956ee83f63d971774bde68000f60f53":[7,0,0,1088,122],
 "class_ogre_1_1_win32_e_g_l_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,1088,53],
-"class_ogre_1_1_win32_e_g_l_window.html#a3c1b90c776b100ac3f5b23683dc660ec":[7,0,0,1088,123],
-"class_ogre_1_1_win32_e_g_l_window.html#a3c1b90c776b100ac3f5b23683dc660ec":[6,0,0,1115,123]
+"class_ogre_1_1_win32_e_g_l_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[6,0,0,1115,53]
 };
