@@ -1,5 +1,7 @@
 var NAVTREEINDEX267 =
 {
+"class_ogre_1_1v1_1_1_border_panel_overlay_element.html#a3ecc3570673272f34e36a1f325f1a11d":[5,2,8,1,58],
+"class_ogre_1_1v1_1_1_border_panel_overlay_element.html#a3ff5200cfcbfe0243007727738fc2353":[5,2,8,1,49],
 "class_ogre_1_1v1_1_1_border_panel_overlay_element.html#a407b6feed54a0dd33281e1006baa34d7":[5,2,8,1,104],
 "class_ogre_1_1v1_1_1_border_panel_overlay_element.html#a4112a1a12c93be572c768ebe5838fbcf":[5,2,8,1,19],
 "class_ogre_1_1v1_1_1_border_panel_overlay_element.html#a4136ce4b9d3add5203339327015d872d":[5,2,8,1,188],
@@ -247,7 +249,5 @@ var NAVTREEINDEX267 =
 "class_ogre_1_1v1_1_1_border_renderable.html#af85238872bb197dea36acf21a578ecec":[5,2,8,3,33],
 "class_ogre_1_1v1_1_1_border_renderable.html#afcbf4cb36d5911a9d40a40c57e94f23b":[5,2,8,3,49],
 "class_ogre_1_1v1_1_1_d3_d11_depth_pixel_buffer.html":[7,0,0,3,22],
-"class_ogre_1_1v1_1_1_d3_d11_depth_pixel_buffer.html":[6,0,0,28,22],
-"class_ogre_1_1v1_1_1_d3_d11_depth_pixel_buffer.html#a07805731df6ad3b13adfb036e0f52762":[6,0,0,28,22,5],
-"class_ogre_1_1v1_1_1_d3_d11_depth_pixel_buffer.html#a07805731df6ad3b13adfb036e0f52762":[7,0,0,3,22,5]
+"class_ogre_1_1v1_1_1_d3_d11_depth_pixel_buffer.html":[6,0,0,28,22]
 };
