@@ -1,95 +1,97 @@
 var NAVTREEINDEX274 =
 {
-"class_ogre_1_1v1_1_1_entity.html#af5e87f0d34dd3df4b5d26128bee66624":[5,2,12,62,103],
+"class_ogre_1_1v1_1_1_entity.html#af451deb769cb42d69dcdb475fb8fc260":[5,2,12,62,18],
+"class_ogre_1_1v1_1_1_entity.html#af451deb769cb42d69dcdb475fb8fc260":[5,0,1,62,18],
 "class_ogre_1_1v1_1_1_entity.html#af5e87f0d34dd3df4b5d26128bee66624":[5,0,1,62,103],
+"class_ogre_1_1v1_1_1_entity.html#af5e87f0d34dd3df4b5d26128bee66624":[5,2,12,62,103],
 "class_ogre_1_1v1_1_1_entity.html#af6788ed3697ab34c561c0afcf39ac8c3":[5,0,1,62,69],
 "class_ogre_1_1v1_1_1_entity.html#af6788ed3697ab34c561c0afcf39ac8c3":[5,2,12,62,69],
-"class_ogre_1_1v1_1_1_entity.html#afb58624fb567bb790c55d8a716b472da":[5,0,1,62,1],
 "class_ogre_1_1v1_1_1_entity.html#afb58624fb567bb790c55d8a716b472da":[5,2,12,62,1],
+"class_ogre_1_1v1_1_1_entity.html#afb58624fb567bb790c55d8a716b472da":[5,0,1,62,1],
 "class_ogre_1_1v1_1_1_entity.html#afdf18128b8f4f8be71566ce2d5d5a30a":[5,0,1,62,136],
 "class_ogre_1_1v1_1_1_entity.html#afdf18128b8f4f8be71566ce2d5d5a30a":[5,2,12,62,136],
 "class_ogre_1_1v1_1_1_entity.html#afe1f2a1009e3f14f36e1bcc9b1b9557e":[5,0,1,62,139],
 "class_ogre_1_1v1_1_1_entity.html#afe1f2a1009e3f14f36e1bcc9b1b9557e":[5,2,12,62,139],
-"class_ogre_1_1v1_1_1_entity.html#aff35a0dcf855331bdd0fe72fe0f66824":[5,0,1,62,49],
 "class_ogre_1_1v1_1_1_entity.html#aff35a0dcf855331bdd0fe72fe0f66824":[5,2,12,62,49],
-"class_ogre_1_1v1_1_1_entity.html#aff8dd8756aba9a9ecb276270e6614c96":[5,0,1,62,67],
+"class_ogre_1_1v1_1_1_entity.html#aff35a0dcf855331bdd0fe72fe0f66824":[5,0,1,62,49],
 "class_ogre_1_1v1_1_1_entity.html#aff8dd8756aba9a9ecb276270e6614c96":[5,2,12,62,67],
-"class_ogre_1_1v1_1_1_entity_factory.html":[5,2,12,63],
+"class_ogre_1_1v1_1_1_entity.html#aff8dd8756aba9a9ecb276270e6614c96":[5,0,1,62,67],
 "class_ogre_1_1v1_1_1_entity_factory.html":[5,0,1,63],
-"class_ogre_1_1v1_1_1_entity_factory.html#a087a11b1538cb14c18a6271b1de3023d":[5,2,12,63,1],
+"class_ogre_1_1v1_1_1_entity_factory.html":[5,2,12,63],
 "class_ogre_1_1v1_1_1_entity_factory.html#a087a11b1538cb14c18a6271b1de3023d":[5,0,1,63,1],
+"class_ogre_1_1v1_1_1_entity_factory.html#a087a11b1538cb14c18a6271b1de3023d":[5,2,12,63,1],
 "class_ogre_1_1v1_1_1_entity_factory.html#a0b65acc56f5642a203bff3c24846801b":[5,0,1,63,15],
 "class_ogre_1_1v1_1_1_entity_factory.html#a0b65acc56f5642a203bff3c24846801b":[5,2,12,63,15],
-"class_ogre_1_1v1_1_1_entity_factory.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,63,7],
 "class_ogre_1_1v1_1_1_entity_factory.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,63,7],
+"class_ogre_1_1v1_1_1_entity_factory.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,63,7],
 "class_ogre_1_1v1_1_1_entity_factory.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,63,9],
 "class_ogre_1_1v1_1_1_entity_factory.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,63,9],
-"class_ogre_1_1v1_1_1_entity_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,63,12],
 "class_ogre_1_1v1_1_1_entity_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,63,12],
-"class_ogre_1_1v1_1_1_entity_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,63,5],
+"class_ogre_1_1v1_1_1_entity_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,63,12],
 "class_ogre_1_1v1_1_1_entity_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,63,5],
+"class_ogre_1_1v1_1_1_entity_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,63,5],
 "class_ogre_1_1v1_1_1_entity_factory.html#a8963c927e809a05b8cbd4631fa9ca577":[5,0,1,63,3],
 "class_ogre_1_1v1_1_1_entity_factory.html#a8963c927e809a05b8cbd4631fa9ca577":[5,2,12,63,3],
-"class_ogre_1_1v1_1_1_entity_factory.html#a8f72783690dcad09ba7668e3f5d81910":[5,0,1,63,0],
 "class_ogre_1_1v1_1_1_entity_factory.html#a8f72783690dcad09ba7668e3f5d81910":[5,2,12,63,0],
-"class_ogre_1_1v1_1_1_entity_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,63,8],
+"class_ogre_1_1v1_1_1_entity_factory.html#a8f72783690dcad09ba7668e3f5d81910":[5,0,1,63,0],
 "class_ogre_1_1v1_1_1_entity_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,63,8],
+"class_ogre_1_1v1_1_1_entity_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,63,8],
 "class_ogre_1_1v1_1_1_entity_factory.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,63,11],
 "class_ogre_1_1v1_1_1_entity_factory.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,63,11],
 "class_ogre_1_1v1_1_1_entity_factory.html#abbdbb84815669ce98b48c41c95632772":[5,2,12,63,4],
 "class_ogre_1_1v1_1_1_entity_factory.html#abbdbb84815669ce98b48c41c95632772":[5,0,1,63,4],
 "class_ogre_1_1v1_1_1_entity_factory.html#abd16dae5dd18b58f57d2e0d8bdbb26e0":[5,2,12,63,2],
 "class_ogre_1_1v1_1_1_entity_factory.html#abd16dae5dd18b58f57d2e0d8bdbb26e0":[5,0,1,63,2],
-"class_ogre_1_1v1_1_1_entity_factory.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,63,6],
 "class_ogre_1_1v1_1_1_entity_factory.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,63,6],
-"class_ogre_1_1v1_1_1_entity_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,63,10],
+"class_ogre_1_1v1_1_1_entity_factory.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,63,6],
 "class_ogre_1_1v1_1_1_entity_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,63,10],
+"class_ogre_1_1v1_1_1_entity_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,63,10],
 "class_ogre_1_1v1_1_1_entity_factory.html#adce32528577d71b228692df906ecd17c":[5,2,12,63,13],
 "class_ogre_1_1v1_1_1_entity_factory.html#adce32528577d71b228692df906ecd17c":[5,0,1,63,13],
-"class_ogre_1_1v1_1_1_entity_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,63,14],
 "class_ogre_1_1v1_1_1_entity_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,63,14],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html":[6,0,0,28,42],
+"class_ogre_1_1v1_1_1_entity_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,63,14],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html":[7,0,0,3,42],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a15077ee295a2fa1e0673b55b1ad7f944":[6,0,0,28,42,19],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html":[6,0,0,28,42],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a15077ee295a2fa1e0673b55b1ad7f944":[7,0,0,3,42,19],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a15077ee295a2fa1e0673b55b1ad7f944":[6,0,0,28,42,19],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,3,42,25],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,28,42,25],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a25212a887a5b5616651e468b48868876":[6,0,0,28,42,1],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a25212a887a5b5616651e468b48868876":[7,0,0,3,42,1],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a4568b7f182a39d73002b8750a02d5d6a":[6,0,0,28,42,13],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a25212a887a5b5616651e468b48868876":[6,0,0,28,42,1],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a4568b7f182a39d73002b8750a02d5d6a":[7,0,0,3,42,13],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a4568b7f182a39d73002b8750a02d5d6a":[6,0,0,28,42,13],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,3,42,27],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,28,42,27],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a5e54670f601ad021692fc8e7caf06d11":[6,0,0,28,42,2],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a5e54670f601ad021692fc8e7caf06d11":[7,0,0,3,42,2],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a5f397c5d2b7531013df318234802202a":[7,0,0,3,42,22],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a5f397c5d2b7531013df318234802202a":[6,0,0,28,42,22],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a616686687f3ebc57f10abef0c634dd20":[7,0,0,3,42,16],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a5f397c5d2b7531013df318234802202a":[7,0,0,3,42,22],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a616686687f3ebc57f10abef0c634dd20":[6,0,0,28,42,16],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a616686687f3ebc57f10abef0c634dd20":[7,0,0,3,42,16],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,28,42,30],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,3,42,30],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a6b5f314937bcb39945c7d5da862b0416":[7,0,0,3,42,21],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a6b5f314937bcb39945c7d5da862b0416":[6,0,0,28,42,21],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a73af0e384fffafd30ec13438507d31eb":[6,0,0,28,42,0],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a73af0e384fffafd30ec13438507d31eb":[7,0,0,3,42,0],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a73af0e384fffafd30ec13438507d31eba2b12eec76abb4c56344b6c6ff1cdb65f":[6,0,0,28,42,0,1],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a73af0e384fffafd30ec13438507d31eb":[6,0,0,28,42,0],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a73af0e384fffafd30ec13438507d31eba2b12eec76abb4c56344b6c6ff1cdb65f":[7,0,0,3,42,0,1],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a73af0e384fffafd30ec13438507d31eba2b12eec76abb4c56344b6c6ff1cdb65f":[6,0,0,28,42,0,1],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a73af0e384fffafd30ec13438507d31ebaefbef8f3135135145a860b8647faba4c":[6,0,0,28,42,0,0],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a73af0e384fffafd30ec13438507d31ebaefbef8f3135135145a860b8647faba4c":[7,0,0,3,42,0,0],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a76b2f5feb458d7de2e8f79a1900b3124":[7,0,0,3,42,15],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a76b2f5feb458d7de2e8f79a1900b3124":[6,0,0,28,42,15],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a78d100749d4bc2d491fa77ab3b92d5b7":[6,0,0,28,42,33],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a78d100749d4bc2d491fa77ab3b92d5b7":[7,0,0,3,42,33],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a81a86fb9b9f772c6ae0296ca01b322f0":[6,0,0,28,42,17],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a78d100749d4bc2d491fa77ab3b92d5b7":[6,0,0,28,42,33],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a81a86fb9b9f772c6ae0296ca01b322f0":[7,0,0,3,42,17],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,3,42,23],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a81a86fb9b9f772c6ae0296ca01b322f0":[6,0,0,28,42,17],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,28,42,23],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a837b8d79883d0776fde7a0ccc3a4c905":[7,0,0,3,42,11],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,3,42,23],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a837b8d79883d0776fde7a0ccc3a4c905":[6,0,0,28,42,11],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a837b8d79883d0776fde7a0ccc3a4c905":[7,0,0,3,42,11],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,3,42,26],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,28,42,26],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a95108cb8cebac0fae72bc4439fdd6e65":[6,0,0,28,42,9],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a95108cb8cebac0fae72bc4439fdd6e65":[7,0,0,3,42,9],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a95108cb8cebac0fae72bc4439fdd6e65":[6,0,0,28,42,9],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a9cbf1bd5a5a6a7665ae98a7cfca4e225":[7,0,0,3,42,12],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#a9cbf1bd5a5a6a7665ae98a7cfca4e225":[6,0,0,28,42,12],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ab11718cef3f0b0ee27b3de9ce147328a":[6,0,0,28,42,14],
@@ -98,14 +100,14 @@ var NAVTREEINDEX274 =
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ab2742dc658728cee814970926f85e1d0":[7,0,0,3,42,18],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ab3fc128d148ce3954e184a505199e0d2":[6,0,0,28,42,10],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ab3fc128d148ce3954e184a505199e0d2":[7,0,0,3,42,10],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,3,42,29],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,28,42,29],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,3,42,29],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ab89c749b1de0d07abf2d10cdde39d457":[7,0,0,3,42,4],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ab89c749b1de0d07abf2d10cdde39d457":[6,0,0,28,42,4],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,3,42,24],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,28,42,24],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#acf84c58415d8da16909c212929dbf825":[7,0,0,3,42,34],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#acf84c58415d8da16909c212929dbf825":[6,0,0,28,42,34],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#acf84c58415d8da16909c212929dbf825":[7,0,0,3,42,34],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ad1a0ad696cd4a4a56f31ed5a2d954351":[7,0,0,3,42,7],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ad1a0ad696cd4a4a56f31ed5a2d954351":[6,0,0,28,42,7],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,28,42,28],
@@ -114,16 +116,16 @@ var NAVTREEINDEX274 =
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ad31a801ac5e410a06a20706f437cdebd":[6,0,0,28,42,3],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#adce32528577d71b228692df906ecd17c":[7,0,0,3,42,31],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#adce32528577d71b228692df906ecd17c":[6,0,0,28,42,31],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ae3e26b4572d8f07a6a393f4d04dea36c":[6,0,0,28,42,35],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ae3e26b4572d8f07a6a393f4d04dea36c":[7,0,0,3,42,35],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#ae3e26b4572d8f07a6a393f4d04dea36c":[6,0,0,28,42,35],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,3,42,32],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,28,42,32],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#aefebeab1dc9817a749f72d6c6a66c07f":[7,0,0,3,42,5],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#aefebeab1dc9817a749f72d6c6a66c07f":[6,0,0,28,42,5],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#aefebeab1dc9817a749f72d6c6a66c07f":[7,0,0,3,42,5],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#af806a0585b212d4b179e77770b22eaef":[6,0,0,28,42,6],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#af806a0585b212d4b179e77770b22eaef":[7,0,0,3,42,6],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#afae0e3c4fb95f96b60147cde62b0bacb":[7,0,0,3,42,20],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#afae0e3c4fb95f96b60147cde62b0bacb":[6,0,0,28,42,20],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#afae0e3c4fb95f96b60147cde62b0bacb":[7,0,0,3,42,20],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#affc9ded1625ecbd07556ba24a15b6429":[6,0,0,28,42,8],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager.html#affc9ded1625ecbd07556ba24a15b6429":[7,0,0,3,42,8],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html":[7,0,0,3,43],
@@ -132,32 +134,32 @@ var NAVTREEINDEX274 =
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a08297892d344182b4daa24b1b6bde626":[7,0,0,3,43,10],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a09c24edf06c085c0d4493eb027f830cb":[7,0,0,3,43,30],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a09c24edf06c085c0d4493eb027f830cb":[6,0,0,28,43,30],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,28,43,22],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,3,43,22],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,28,43,22],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a22f7b5d00a1b22864ae34ad7819da935":[6,0,0,28,43,2],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a22f7b5d00a1b22864ae34ad7819da935":[7,0,0,3,43,2],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a271d83c31cdaf53704673460b39755ea":[6,0,0,28,43,12],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a271d83c31cdaf53704673460b39755ea":[7,0,0,3,43,12],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a271d83c31cdaf53704673460b39755ea":[6,0,0,28,43,12],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a28b1ee3a62509c78ab8c6c7a13ad8059":[7,0,0,3,43,32],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a28b1ee3a62509c78ab8c6c7a13ad8059":[6,0,0,28,43,32],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a3d598f5c8dd22d52ce27fd9e73a7b23a":[6,0,0,28,43,9],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a3d598f5c8dd22d52ce27fd9e73a7b23a":[7,0,0,3,43,9],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a4b495397711f2183c49b4900bb425e78":[7,0,0,3,43,11],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a3d598f5c8dd22d52ce27fd9e73a7b23a":[6,0,0,28,43,9],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a4b495397711f2183c49b4900bb425e78":[6,0,0,28,43,11],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a4b495397711f2183c49b4900bb425e78":[7,0,0,3,43,11],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a543acaeaaa456051bbe24a35f896e584":[6,0,0,28,43,14],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a543acaeaaa456051bbe24a35f896e584":[7,0,0,3,43,14],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,28,43,24],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,3,43,24],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,28,43,24],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a5b732d773d680492f36f23c5d217bade":[6,0,0,28,43,19],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a5b732d773d680492f36f23c5d217bade":[7,0,0,3,43,19],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,28,43,27],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,3,43,27],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a73af0e384fffafd30ec13438507d31eb":[7,0,0,3,43,0],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,28,43,27],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a73af0e384fffafd30ec13438507d31eb":[6,0,0,28,43,0],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a73af0e384fffafd30ec13438507d31eba2b12eec76abb4c56344b6c6ff1cdb65f":[6,0,0,28,43,0,1],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a73af0e384fffafd30ec13438507d31eb":[7,0,0,3,43,0],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a73af0e384fffafd30ec13438507d31eba2b12eec76abb4c56344b6c6ff1cdb65f":[7,0,0,3,43,0,1],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a73af0e384fffafd30ec13438507d31ebaefbef8f3135135145a860b8647faba4c":[7,0,0,3,43,0,0],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a73af0e384fffafd30ec13438507d31eba2b12eec76abb4c56344b6c6ff1cdb65f":[6,0,0,28,43,0,1],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a73af0e384fffafd30ec13438507d31ebaefbef8f3135135145a860b8647faba4c":[6,0,0,28,43,0,0],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a73af0e384fffafd30ec13438507d31ebaefbef8f3135135145a860b8647faba4c":[7,0,0,3,43,0,0],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a79513a524782fcac13a6d91e68013ad7":[7,0,0,3,43,5],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a79513a524782fcac13a6d91e68013ad7":[6,0,0,28,43,5],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a7f51811f14dcf9cc9c62311bf5952ce1":[7,0,0,3,43,3],
@@ -168,62 +170,62 @@ var NAVTREEINDEX274 =
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a811fe109c1329bdb8357e93f001c7cee":[6,0,0,28,43,16],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,28,43,20],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,3,43,20],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,28,43,23],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,3,43,23],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a94c13bc52c3f653b254d0c21a16fa2f4":[7,0,0,3,43,1],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,28,43,23],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a94c13bc52c3f653b254d0c21a16fa2f4":[6,0,0,28,43,1],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a99d79f386a09e77e911112e9988838d1":[7,0,0,3,43,7],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a94c13bc52c3f653b254d0c21a16fa2f4":[7,0,0,3,43,1],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a99d79f386a09e77e911112e9988838d1":[6,0,0,28,43,7],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#aaec7f834aff615ec9efd3169658950b0":[6,0,0,28,43,18],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#a99d79f386a09e77e911112e9988838d1":[7,0,0,3,43,7],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#aaec7f834aff615ec9efd3169658950b0":[7,0,0,3,43,18],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#aaec7f834aff615ec9efd3169658950b0":[6,0,0,28,43,18],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,28,43,26],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,3,43,26],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,28,43,21],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,3,43,21],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,28,43,21],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad14593f984cbbcc9b99ab6db1e1b0e8e":[7,0,0,3,43,17],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad14593f984cbbcc9b99ab6db1e1b0e8e":[6,0,0,28,43,17],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad1a0ad696cd4a4a56f31ed5a2d954351":[7,0,0,3,43,6],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad1a0ad696cd4a4a56f31ed5a2d954351":[6,0,0,28,43,6],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad1a0ad696cd4a4a56f31ed5a2d954351":[7,0,0,3,43,6],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,28,43,25],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,3,43,25],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad39247a31786d77e3da0200052e5be0c":[6,0,0,28,43,31],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad39247a31786d77e3da0200052e5be0c":[7,0,0,3,43,31],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad39247a31786d77e3da0200052e5be0c":[6,0,0,28,43,31],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad7858c87b21a22eb251aef043bf04285":[7,0,0,3,43,8],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#ad7858c87b21a22eb251aef043bf04285":[6,0,0,28,43,8],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#adac7eb3844eae2dbceecfab0e0eb034c":[7,0,0,3,43,4],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#adac7eb3844eae2dbceecfab0e0eb034c":[6,0,0,28,43,4],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#adce32528577d71b228692df906ecd17c":[6,0,0,28,43,28],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#adce32528577d71b228692df906ecd17c":[7,0,0,3,43,28],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#aece0bdb58852c105d459bdcbbc4dea39":[6,0,0,28,43,13],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#aece0bdb58852c105d459bdcbbc4dea39":[7,0,0,3,43,13],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,28,43,29],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#aece0bdb58852c105d459bdcbbc4dea39":[6,0,0,28,43,13],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,3,43,29],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_buffer_manager_base.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,28,43,29],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html":[6,0,0,28,44],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html":[7,0,0,3,44],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a15616b1645a8d88b0824b77a3cca3a78":[6,0,0,28,44,17],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a15616b1645a8d88b0824b77a3cca3a78":[7,0,0,3,44,17],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a1a1a5e9fd1743fdd09d2b1cfa740bcd4":[7,0,0,3,44,5],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a15616b1645a8d88b0824b77a3cca3a78":[6,0,0,28,44,17],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a1a1a5e9fd1743fdd09d2b1cfa740bcd4":[6,0,0,28,44,5],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a1a1a5e9fd1743fdd09d2b1cfa740bcd4":[7,0,0,3,44,5],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,3,44,21],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,28,44,21],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a4674ce75bfc84fa7e6ac03a059f0dbb5":[7,0,0,3,44,30],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a4674ce75bfc84fa7e6ac03a059f0dbb5":[6,0,0,28,44,30],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a4c89e8f3e555b5baf18bcae16d5fb8dd":[7,0,0,3,44,7],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a4674ce75bfc84fa7e6ac03a059f0dbb5":[7,0,0,3,44,30],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a4c89e8f3e555b5baf18bcae16d5fb8dd":[6,0,0,28,44,7],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,28,44,23],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a4c89e8f3e555b5baf18bcae16d5fb8dd":[7,0,0,3,44,7],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,3,44,23],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a5caebd4b5db7696029eb412351d7767f":[6,0,0,28,44,6],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,28,44,23],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a5caebd4b5db7696029eb412351d7767f":[7,0,0,3,44,6],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a61887d011495f5c237f44e055412eff8":[6,0,0,28,44,31],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a5caebd4b5db7696029eb412351d7767f":[6,0,0,28,44,6],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a61887d011495f5c237f44e055412eff8":[7,0,0,3,44,31],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,28,44,26],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a61887d011495f5c237f44e055412eff8":[6,0,0,28,44,31],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,3,44,26],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a657cbc73068640506bfc8ee5e9a05fd2":[6,0,0,28,44,2],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,28,44,26],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a657cbc73068640506bfc8ee5e9a05fd2":[7,0,0,3,44,2],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a6776e40af767f8db7d428f35d9b3055c":[7,0,0,3,44,12],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a657cbc73068640506bfc8ee5e9a05fd2":[6,0,0,28,44,2],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a6776e40af767f8db7d428f35d9b3055c":[6,0,0,28,44,12],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a717486c4bd8761808c05d8d96fbd365c":[7,0,0,3,44,8],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a6776e40af767f8db7d428f35d9b3055c":[7,0,0,3,44,12],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a717486c4bd8761808c05d8d96fbd365c":[6,0,0,28,44,8],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a717486c4bd8761808c05d8d96fbd365c":[7,0,0,3,44,8],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a82d667c1abc2577fa7754ea44dd684b3":[6,0,0,28,44,13],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a82d667c1abc2577fa7754ea44dd684b3":[7,0,0,3,44,13],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,3,44,19],
@@ -236,8 +238,8 @@ var NAVTREEINDEX274 =
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a87632db14ce9c10e113f1966c6a97c6da1de64eadc98dfb60e9dcdf7fe6287c09":[7,0,0,3,44,1,1],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a87632db14ce9c10e113f1966c6a97c6da3756a6536dc4f8a6c3434b704537c0eb":[6,0,0,28,44,1,6],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a87632db14ce9c10e113f1966c6a97c6da3756a6536dc4f8a6c3434b704537c0eb":[7,0,0,3,44,1,6],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a87632db14ce9c10e113f1966c6a97c6da905091fc68f6e649aaa4e4aa0d5002ad":[7,0,0,3,44,1,2],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a87632db14ce9c10e113f1966c6a97c6da905091fc68f6e649aaa4e4aa0d5002ad":[6,0,0,28,44,1,2],
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a87632db14ce9c10e113f1966c6a97c6da905091fc68f6e649aaa4e4aa0d5002ad":[7,0,0,3,44,1,2],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a87632db14ce9c10e113f1966c6a97c6da951a42185ad1d0df6294822dedcafce7":[7,0,0,3,44,1,5],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a87632db14ce9c10e113f1966c6a97c6da951a42185ad1d0df6294822dedcafce7":[6,0,0,28,44,1,5],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a87632db14ce9c10e113f1966c6a97c6dab5fe6ef729ea615265721a10ff7d9e57":[7,0,0,3,44,1,4],
@@ -247,7 +249,5 @@ var NAVTREEINDEX274 =
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,3,44,22],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,28,44,22],
 "class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a9f7b1a5624f5a89781b0870f919152e4":[7,0,0,3,44,32],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a9f7b1a5624f5a89781b0870f919152e4":[6,0,0,28,44,32],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,3,44,25],
-"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,28,44,25]
+"class_ogre_1_1v1_1_1_g_l3_plus_default_hardware_counter_buffer.html#a9f7b1a5624f5a89781b0870f919152e4":[6,0,0,28,44,32]
 };
