@@ -1,5 +1,7 @@
 var NAVTREEINDEX29 =
 {
+"class_ogre_1_1_compositor_shadow_node_def.html":[5,2,1,29],
+"class_ogre_1_1_compositor_shadow_node_def.html#a089581e77581d21192ad3358fd604c74":[5,2,1,29,6],
 "class_ogre_1_1_compositor_shadow_node_def.html#a0b832d936fde223d0e19076097e95054":[5,2,1,29,41],
 "class_ogre_1_1_compositor_shadow_node_def.html#a0ea411a6f2944383e0c023ce79847dc3":[5,2,1,29,7],
 "class_ogre_1_1_compositor_shadow_node_def.html#a0eca52e558fdf26b3fe1726de03fa4a0":[5,2,1,29,60],
@@ -247,7 +249,5 @@ var NAVTREEINDEX29 =
 "class_ogre_1_1_compositor_workspace_def.html#a75c56b297f28418b9b4e74386d95e66b":[5,2,1,33,32],
 "class_ogre_1_1_compositor_workspace_def.html#a76379729c7816cf2e8f0d0b839e58cc5":[5,2,1,33,38],
 "class_ogre_1_1_compositor_workspace_def.html#a7c2e6e1337065e18f6bc0abe8cd6428a":[5,2,1,33,1],
-"class_ogre_1_1_compositor_workspace_def.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,1,33,45],
-"class_ogre_1_1_compositor_workspace_def.html#a83cfd0eeffd0897cf48e2bff18400cc7":[5,2,1,33,17],
-"class_ogre_1_1_compositor_workspace_def.html#a84368fee8cf553e65ea43b5086aa1be2":[5,2,1,33,19]
+"class_ogre_1_1_compositor_workspace_def.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,1,33,45]
 };
