@@ -1,44 +1,46 @@
 var NAVTREEINDEX46 =
 {
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a629ce6c74ec3b4b565ce5b85a98e0482":[6,0,0,224,56],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a62a35f19422bd10282b044909e757b2e":[6,0,0,224,70],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a62fc766a70a6f080caf04f4387b85f3b":[7,0,0,197,52],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a62a35f19422bd10282b044909e757b2e":[7,0,0,197,70],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a62fc766a70a6f080caf04f4387b85f3b":[6,0,0,224,52],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a62fc766a70a6f080caf04f4387b85f3b":[7,0,0,197,52],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,224,67],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,197,67],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a68bd7eab7040d56b092605ab45923799":[7,0,0,197,48],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a68bd7eab7040d56b092605ab45923799":[6,0,0,224,48],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a6b30100a4fd844f70ec3b2fea153c392":[6,0,0,224,95],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a68bd7eab7040d56b092605ab45923799":[7,0,0,197,48],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a6b30100a4fd844f70ec3b2fea153c392":[7,0,0,197,95],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a6dd357cb57f1020fb11de230f7fee61a":[6,0,0,224,34],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a6b30100a4fd844f70ec3b2fea153c392":[6,0,0,224,95],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a6dd357cb57f1020fb11de230f7fee61a":[7,0,0,197,34],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a6fc748317d2951512cd42d19e3445352":[7,0,0,197,71],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a6dd357cb57f1020fb11de230f7fee61a":[6,0,0,224,34],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a6fc748317d2951512cd42d19e3445352":[6,0,0,224,71],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a6fc748317d2951512cd42d19e3445352":[7,0,0,197,71],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a70c43cd6bebbdea84711eb49bb9f1375":[6,0,0,224,73],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a70c43cd6bebbdea84711eb49bb9f1375":[7,0,0,197,73],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a7229cc54eb6791b5fc2e251601276bbf":[7,0,0,197,14],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a7229cc54eb6791b5fc2e251601276bbf":[6,0,0,224,14],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a74f922747c11f98718be00c2fa86165c":[7,0,0,197,88],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a74f922747c11f98718be00c2fa86165c":[6,0,0,224,88],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a74f922747c11f98718be00c2fa86165c":[7,0,0,197,88],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a756b752e30cad1f8f71b69c86bc2f6f2":[6,0,0,224,96],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a756b752e30cad1f8f71b69c86bc2f6f2":[7,0,0,197,96],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a7bd367fcadf2aba85f08cf9c5fd27e22":[7,0,0,197,20],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a7bd367fcadf2aba85f08cf9c5fd27e22":[6,0,0,224,20],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a7d3b9733299948a95c0202f40f7400ef":[6,0,0,224,47],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a7d3b9733299948a95c0202f40f7400ef":[7,0,0,197,47],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a812eadaec07bee20d103a948920e615c":[7,0,0,197,74],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a7d3b9733299948a95c0202f40f7400ef":[6,0,0,224,47],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a812eadaec07bee20d103a948920e615c":[6,0,0,224,74],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,224,60],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a812eadaec07bee20d103a948920e615c":[7,0,0,197,74],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,197,60],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a8c07a9eff234ae9ce99360d7b0feb41b":[6,0,0,224,39],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,224,60],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a8c07a9eff234ae9ce99360d7b0feb41b":[7,0,0,197,39],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a8c07a9eff234ae9ce99360d7b0feb41b":[6,0,0,224,39],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a8e1a9f2c62e6524921b2983413e01e67":[7,0,0,197,43],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a8e1a9f2c62e6524921b2983413e01e67":[6,0,0,224,43],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,224,63],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,197,63],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,224,63],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a95768aeda225df73c3636f228f9f770b":[6,0,0,224,51],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a95768aeda225df73c3636f228f9f770b":[7,0,0,197,51],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a96ec12856ec5384456c9d0a86bd76568":[6,0,0,224,80],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a96ec12856ec5384456c9d0a86bd76568":[7,0,0,197,80],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a96ec12856ec5384456c9d0a86bd76568":[6,0,0,224,80],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a97b2d63554ec8e515789ac65c6200a33":[6,0,0,224,53],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#a97b2d63554ec8e515789ac65c6200a33":[7,0,0,197,53],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aa1d5570996e2e5ccf219257ec48d8d7f":[6,0,0,224,16],
@@ -55,26 +57,26 @@ var NAVTREEINDEX46 =
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab02f58cb99451d6c34235a3e78bb9417":[6,0,0,224,19],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab16d079db49b93e915e9386b4e27880b":[7,0,0,197,10],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab16d079db49b93e915e9386b4e27880b":[6,0,0,224,10],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,197,66],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,224,66],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab757d8a24dead55af8e773a036ee141d":[6,0,0,224,94],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,197,66],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab757d8a24dead55af8e773a036ee141d":[7,0,0,197,94],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab82d2cf13a93ae6406cee9d2d044aa06":[7,0,0,197,38],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab757d8a24dead55af8e773a036ee141d":[6,0,0,224,94],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab82d2cf13a93ae6406cee9d2d044aa06":[6,0,0,224,38],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#abb4fa5e6970515a4d6cb9a16501557b5":[7,0,0,197,45],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ab82d2cf13a93ae6406cee9d2d044aa06":[7,0,0,197,38],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#abb4fa5e6970515a4d6cb9a16501557b5":[6,0,0,224,45],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ac2b77b29188e2dd5e85ad0d9e1a4ad79":[6,0,0,224,58],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#abb4fa5e6970515a4d6cb9a16501557b5":[7,0,0,197,45],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ac2b77b29188e2dd5e85ad0d9e1a4ad79":[7,0,0,197,58],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aca21c0cb66c690e35847a1cf30aef357":[7,0,0,197,41],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ac2b77b29188e2dd5e85ad0d9e1a4ad79":[6,0,0,224,58],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aca21c0cb66c690e35847a1cf30aef357":[6,0,0,224,41],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aca21c0cb66c690e35847a1cf30aef357":[7,0,0,197,41],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,224,61],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,197,61],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#acdd2df1d7b419b61d1abd82b72e0d0a5":[6,0,0,224,49],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#acdd2df1d7b419b61d1abd82b72e0d0a5":[7,0,0,197,49],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#acfb338c927b445144253ce6893bbbb55":[6,0,0,224,13],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#acfb338c927b445144253ce6893bbbb55":[7,0,0,197,13],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ad0b724596d2b9e278293aee6e55a5273":[6,0,0,224,4],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#acfb338c927b445144253ce6893bbbb55":[6,0,0,224,13],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ad0b724596d2b9e278293aee6e55a5273":[7,0,0,197,4],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ad0b724596d2b9e278293aee6e55a5273":[6,0,0,224,4],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,224,65],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,197,65],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ad4e95b76827cb41d936ccb4a8c308c6e":[7,0,0,197,35],
@@ -89,26 +91,26 @@ var NAVTREEINDEX46 =
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#adc5ae8e1b69ca1a62df88d52471910db":[7,0,0,197,82],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#adce32528577d71b228692df906ecd17c":[6,0,0,224,68],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#adce32528577d71b228692df906ecd17c":[7,0,0,197,68],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ade152eccc493171229171c0dda4395d3":[7,0,0,197,3],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ade152eccc493171229171c0dda4395d3":[6,0,0,224,3],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ade23b0e64aea68657b81833b99868802":[7,0,0,197,30],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ade152eccc493171229171c0dda4395d3":[7,0,0,197,3],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ade23b0e64aea68657b81833b99868802":[6,0,0,224,30],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ade23b0e64aea68657b81833b99868802":[7,0,0,197,30],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ae2bd3003533d24447f883d9035b7aed0":[6,0,0,224,77],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ae2bd3003533d24447f883d9035b7aed0":[7,0,0,197,77],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ae68eb2ce228a55811c058de85e369a29":[7,0,0,197,5],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ae68eb2ce228a55811c058de85e369a29":[6,0,0,224,5],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ae78e25805a045b8834c831d452ab6e07":[6,0,0,224,97],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ae78e25805a045b8834c831d452ab6e07":[7,0,0,197,97],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,224,69],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#ae78e25805a045b8834c831d452ab6e07":[6,0,0,224,97],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,197,69],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aed998d281e1f82753372e3a457fa366b":[7,0,0,197,18],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,224,69],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aed998d281e1f82753372e3a457fa366b":[6,0,0,224,18],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aed998d281e1f82753372e3a457fa366b":[7,0,0,197,18],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aef01aef07c52dd58fe07e68e602931a1":[6,0,0,224,50],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#aef01aef07c52dd58fe07e68e602931a1":[7,0,0,197,50],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af31a02e64d08c411b8873f9f7b006b55":[7,0,0,197,17],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af31a02e64d08c411b8873f9f7b006b55":[6,0,0,224,17],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af72cb6156c72e9d9568591dadcc54217":[7,0,0,197,36],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af31a02e64d08c411b8873f9f7b006b55":[7,0,0,197,17],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af72cb6156c72e9d9568591dadcc54217":[6,0,0,224,36],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af72cb6156c72e9d9568591dadcc54217":[7,0,0,197,36],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af77a2b45550db00c0ca364d762a5ca36":[7,0,0,197,27],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af77a2b45550db00c0ca364d762a5ca36":[6,0,0,224,27],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af8615122f9bc57a80ffc8c73a75d2852":[6,0,0,224,92],
@@ -117,28 +119,28 @@ var NAVTREEINDEX46 =
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af8854efa9b905e9becd10e062a53ae3a":[7,0,0,197,55],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af8ca9d240bd48662c37dbdf8fa881bad":[7,0,0,197,81],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af8ca9d240bd48662c37dbdf8fa881bad":[6,0,0,224,81],
-"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af9153ad94900ca36534f25537b35a9cd":[6,0,0,224,90],
 "class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af9153ad94900ca36534f25537b35a9cd":[7,0,0,197,90],
-"class_ogre_1_1_d3_d11_staging_buffer.html":[7,0,0,198],
+"class_ogre_1_1_d3_d11_render_window_swap_chain_based.html#af9153ad94900ca36534f25537b35a9cd":[6,0,0,224,90],
 "class_ogre_1_1_d3_d11_staging_buffer.html":[6,0,0,225],
+"class_ogre_1_1_d3_d11_staging_buffer.html":[7,0,0,198],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a0512e57da9c9f75e7666133a10883126":[6,0,0,225,11],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a0512e57da9c9f75e7666133a10883126":[7,0,0,198,11],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a05d68f22a81bde0dfb9bc17752052078":[6,0,0,225,2],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a05d68f22a81bde0dfb9bc17752052078":[7,0,0,198,2],
-"class_ogre_1_1_d3_d11_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[7,0,0,198,15],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[6,0,0,225,15],
+"class_ogre_1_1_d3_d11_staging_buffer.html#a0661bd8e72511fe7e946991db7fee5d6":[7,0,0,198,15],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a06dfed7c83a6aa991b0bceef76743550":[7,0,0,198,10],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a06dfed7c83a6aa991b0bceef76743550":[6,0,0,225,10],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a10b28de5293c036bf7f23e87bef00de6":[6,0,0,225,6],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a10b28de5293c036bf7f23e87bef00de6":[7,0,0,198,6],
-"class_ogre_1_1_d3_d11_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[6,0,0,225,9],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[7,0,0,198,9],
-"class_ogre_1_1_d3_d11_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,198,19],
+"class_ogre_1_1_d3_d11_staging_buffer.html#a1bb62ecc6017c1d0b86a80d8b54c6150":[6,0,0,225,9],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,225,19],
+"class_ogre_1_1_d3_d11_staging_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,198,19],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a1f6eb9001d6240dd9f743a54cfddab30":[6,0,0,225,8],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a1f6eb9001d6240dd9f743a54cfddab30":[7,0,0,198,8],
-"class_ogre_1_1_d3_d11_staging_buffer.html#a240f4261cb238ed9b1325856f6f5d772":[6,0,0,225,3],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a240f4261cb238ed9b1325856f6f5d772":[7,0,0,198,3],
+"class_ogre_1_1_d3_d11_staging_buffer.html#a240f4261cb238ed9b1325856f6f5d772":[6,0,0,225,3],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a29313389dacd812a8d238df458f9e979":[6,0,0,225,27],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a29313389dacd812a8d238df458f9e979":[7,0,0,198,27],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a438d82f09b5f657be30c30d7d1c0801d":[6,0,0,225,28],
@@ -147,74 +149,74 @@ var NAVTREEINDEX46 =
 "class_ogre_1_1_d3_d11_staging_buffer.html#a5239fe8fda6e2de02e5c053edb69661a":[7,0,0,198,16],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a53adbd5b91819a0e58c9d2c010eba469":[7,0,0,198,14],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a53adbd5b91819a0e58c9d2c010eba469":[6,0,0,225,14],
-"class_ogre_1_1_d3_d11_staging_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,198,21],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,225,21],
+"class_ogre_1_1_d3_d11_staging_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,198,21],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,225,24],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,198,24],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a73cd3b649225c35a756a88070fd88e86":[7,0,0,198,31],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a73cd3b649225c35a756a88070fd88e86":[6,0,0,225,31],
-"class_ogre_1_1_d3_d11_staging_buffer.html#a765f26f80115c9341308fc86330ec9c2":[7,0,0,198,12],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a765f26f80115c9341308fc86330ec9c2":[6,0,0,225,12],
-"class_ogre_1_1_d3_d11_staging_buffer.html#a8047cc93c004c2f6c5700aca44e35b2a":[6,0,0,225,5],
+"class_ogre_1_1_d3_d11_staging_buffer.html#a765f26f80115c9341308fc86330ec9c2":[7,0,0,198,12],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a8047cc93c004c2f6c5700aca44e35b2a":[7,0,0,198,5],
-"class_ogre_1_1_d3_d11_staging_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,198,17],
+"class_ogre_1_1_d3_d11_staging_buffer.html#a8047cc93c004c2f6c5700aca44e35b2a":[6,0,0,225,5],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,225,17],
-"class_ogre_1_1_d3_d11_staging_buffer.html#a897e0ef920699d059b273eed1fe71d4d":[7,0,0,198,13],
+"class_ogre_1_1_d3_d11_staging_buffer.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,198,17],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a897e0ef920699d059b273eed1fe71d4d":[6,0,0,225,13],
+"class_ogre_1_1_d3_d11_staging_buffer.html#a897e0ef920699d059b273eed1fe71d4d":[7,0,0,198,13],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,198,20],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,225,20],
-"class_ogre_1_1_d3_d11_staging_buffer.html#a9c8e2853c21a7418218605a0b9cdf461":[7,0,0,198,29],
 "class_ogre_1_1_d3_d11_staging_buffer.html#a9c8e2853c21a7418218605a0b9cdf461":[6,0,0,225,29],
+"class_ogre_1_1_d3_d11_staging_buffer.html#a9c8e2853c21a7418218605a0b9cdf461":[7,0,0,198,29],
 "class_ogre_1_1_d3_d11_staging_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,225,23],
 "class_ogre_1_1_d3_d11_staging_buffer.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,198,23],
-"class_ogre_1_1_d3_d11_staging_buffer.html#ac79f3f3bf9ef8600dfa361f0456db25f":[6,0,0,225,1],
 "class_ogre_1_1_d3_d11_staging_buffer.html#ac79f3f3bf9ef8600dfa361f0456db25f":[7,0,0,198,1],
+"class_ogre_1_1_d3_d11_staging_buffer.html#ac79f3f3bf9ef8600dfa361f0456db25f":[6,0,0,225,1],
 "class_ogre_1_1_d3_d11_staging_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,225,18],
 "class_ogre_1_1_d3_d11_staging_buffer.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,198,18],
-"class_ogre_1_1_d3_d11_staging_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,225,22],
 "class_ogre_1_1_d3_d11_staging_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,198,22],
-"class_ogre_1_1_d3_d11_staging_buffer.html#ad844466b16d039d78fe762a3e32f92c2":[6,0,0,225,7],
+"class_ogre_1_1_d3_d11_staging_buffer.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,225,22],
 "class_ogre_1_1_d3_d11_staging_buffer.html#ad844466b16d039d78fe762a3e32f92c2":[7,0,0,198,7],
-"class_ogre_1_1_d3_d11_staging_buffer.html#ad9db4541715b29e151043a09a24a527a":[7,0,0,198,4],
+"class_ogre_1_1_d3_d11_staging_buffer.html#ad844466b16d039d78fe762a3e32f92c2":[6,0,0,225,7],
 "class_ogre_1_1_d3_d11_staging_buffer.html#ad9db4541715b29e151043a09a24a527a":[6,0,0,225,4],
-"class_ogre_1_1_d3_d11_staging_buffer.html#adce32528577d71b228692df906ecd17c":[6,0,0,225,25],
+"class_ogre_1_1_d3_d11_staging_buffer.html#ad9db4541715b29e151043a09a24a527a":[7,0,0,198,4],
 "class_ogre_1_1_d3_d11_staging_buffer.html#adce32528577d71b228692df906ecd17c":[7,0,0,198,25],
-"class_ogre_1_1_d3_d11_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[6,0,0,225,0],
+"class_ogre_1_1_d3_d11_staging_buffer.html#adce32528577d71b228692df906ecd17c":[6,0,0,225,25],
 "class_ogre_1_1_d3_d11_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[7,0,0,198,0],
-"class_ogre_1_1_d3_d11_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,225,26],
+"class_ogre_1_1_d3_d11_staging_buffer.html#ae90c8303a85284ef6801919bfc4fdfd0":[6,0,0,225,0],
 "class_ogre_1_1_d3_d11_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,198,26],
-"class_ogre_1_1_d3_d11_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[6,0,0,225,30],
+"class_ogre_1_1_d3_d11_staging_buffer.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,225,26],
 "class_ogre_1_1_d3_d11_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[7,0,0,198,30],
-"class_ogre_1_1_d3_d11_staging_texture.html":[6,0,0,226],
+"class_ogre_1_1_d3_d11_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[6,0,0,225,30],
 "class_ogre_1_1_d3_d11_staging_texture.html":[7,0,0,199],
+"class_ogre_1_1_d3_d11_staging_texture.html":[6,0,0,226],
 "class_ogre_1_1_d3_d11_staging_texture.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,226,9],
 "class_ogre_1_1_d3_d11_staging_texture.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,199,9],
 "class_ogre_1_1_d3_d11_staging_texture.html#a2f6d9e9345a93aa1ffe31523f8b9047b":[7,0,0,199,5],
 "class_ogre_1_1_d3_d11_staging_texture.html#a2f6d9e9345a93aa1ffe31523f8b9047b":[6,0,0,226,5],
-"class_ogre_1_1_d3_d11_staging_texture.html#a32b114f0ba5ccc87e1f3d6e18d990e38":[6,0,0,226,18],
 "class_ogre_1_1_d3_d11_staging_texture.html#a32b114f0ba5ccc87e1f3d6e18d990e38":[7,0,0,199,18],
+"class_ogre_1_1_d3_d11_staging_texture.html#a32b114f0ba5ccc87e1f3d6e18d990e38":[6,0,0,226,18],
 "class_ogre_1_1_d3_d11_staging_texture.html#a35fe3320f0e314209e718071ece9de74":[6,0,0,226,0],
 "class_ogre_1_1_d3_d11_staging_texture.html#a35fe3320f0e314209e718071ece9de74":[7,0,0,199,0],
-"class_ogre_1_1_d3_d11_staging_texture.html#a380dff53ad0425e4790b4d181b11126f":[7,0,0,199,19],
 "class_ogre_1_1_d3_d11_staging_texture.html#a380dff53ad0425e4790b4d181b11126f":[6,0,0,226,19],
+"class_ogre_1_1_d3_d11_staging_texture.html#a380dff53ad0425e4790b4d181b11126f":[7,0,0,199,19],
 "class_ogre_1_1_d3_d11_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,199,11],
 "class_ogre_1_1_d3_d11_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,226,11],
 "class_ogre_1_1_d3_d11_staging_texture.html#a63e494e2f4ba1c65ff3ea79e25bfbfc6":[7,0,0,199,3],
 "class_ogre_1_1_d3_d11_staging_texture.html#a63e494e2f4ba1c65ff3ea79e25bfbfc6":[6,0,0,226,3],
-"class_ogre_1_1_d3_d11_staging_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,199,14],
 "class_ogre_1_1_d3_d11_staging_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,226,14],
-"class_ogre_1_1_d3_d11_staging_texture.html#a6ef2e709b1261acf83b75fe831e8065a":[6,0,0,226,1],
+"class_ogre_1_1_d3_d11_staging_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,199,14],
 "class_ogre_1_1_d3_d11_staging_texture.html#a6ef2e709b1261acf83b75fe831e8065a":[7,0,0,199,1],
-"class_ogre_1_1_d3_d11_staging_texture.html#a75ce0eab6f117f78dd45d5d259fedb3c":[7,0,0,199,17],
+"class_ogre_1_1_d3_d11_staging_texture.html#a6ef2e709b1261acf83b75fe831e8065a":[6,0,0,226,1],
 "class_ogre_1_1_d3_d11_staging_texture.html#a75ce0eab6f117f78dd45d5d259fedb3c":[6,0,0,226,17],
-"class_ogre_1_1_d3_d11_staging_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,226,7],
+"class_ogre_1_1_d3_d11_staging_texture.html#a75ce0eab6f117f78dd45d5d259fedb3c":[7,0,0,199,17],
 "class_ogre_1_1_d3_d11_staging_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,199,7],
+"class_ogre_1_1_d3_d11_staging_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,226,7],
 "class_ogre_1_1_d3_d11_staging_texture.html#a8996efde036324ee9c422d11d91a6215":[7,0,0,199,21],
 "class_ogre_1_1_d3_d11_staging_texture.html#a8996efde036324ee9c422d11d91a6215":[6,0,0,226,21],
-"class_ogre_1_1_d3_d11_staging_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,226,10],
 "class_ogre_1_1_d3_d11_staging_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,199,10],
-"class_ogre_1_1_d3_d11_staging_texture.html#aa084e98a2dbab039ea8b025f6d2aedee":[7,0,0,199,2],
+"class_ogre_1_1_d3_d11_staging_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,226,10],
 "class_ogre_1_1_d3_d11_staging_texture.html#aa084e98a2dbab039ea8b025f6d2aedee":[6,0,0,226,2],
+"class_ogre_1_1_d3_d11_staging_texture.html#aa084e98a2dbab039ea8b025f6d2aedee":[7,0,0,199,2],
 "class_ogre_1_1_d3_d11_staging_texture.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,226,13],
 "class_ogre_1_1_d3_d11_staging_texture.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,199,13],
 "class_ogre_1_1_d3_d11_staging_texture.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,199,8],
@@ -223,31 +225,29 @@ var NAVTREEINDEX46 =
 "class_ogre_1_1_d3_d11_staging_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,199,12],
 "class_ogre_1_1_d3_d11_staging_texture.html#adce32528577d71b228692df906ecd17c":[7,0,0,199,15],
 "class_ogre_1_1_d3_d11_staging_texture.html#adce32528577d71b228692df906ecd17c":[6,0,0,226,15],
-"class_ogre_1_1_d3_d11_staging_texture.html#add456455d0c2f094afe75cc60d60f273":[7,0,0,199,20],
 "class_ogre_1_1_d3_d11_staging_texture.html#add456455d0c2f094afe75cc60d60f273":[6,0,0,226,20],
+"class_ogre_1_1_d3_d11_staging_texture.html#add456455d0c2f094afe75cc60d60f273":[7,0,0,199,20],
 "class_ogre_1_1_d3_d11_staging_texture.html#adf5cc3adc54a4ab2ea4e83cde01b3398":[7,0,0,199,6],
 "class_ogre_1_1_d3_d11_staging_texture.html#adf5cc3adc54a4ab2ea4e83cde01b3398":[6,0,0,226,6],
-"class_ogre_1_1_d3_d11_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,226,16],
 "class_ogre_1_1_d3_d11_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,199,16],
-"class_ogre_1_1_d3_d11_staging_texture.html#af880dfa4d3f849a20ffb03a4c248d997":[6,0,0,226,4],
+"class_ogre_1_1_d3_d11_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,226,16],
 "class_ogre_1_1_d3_d11_staging_texture.html#af880dfa4d3f849a20ffb03a4c248d997":[7,0,0,199,4],
-"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html":[7,0,0,200],
+"class_ogre_1_1_d3_d11_staging_texture.html#af880dfa4d3f849a20ffb03a4c248d997":[6,0,0,226,4],
 "class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html":[6,0,0,227],
-"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a0e7cf0d5efd1e52eaa23b31e0e2013a0":[6,0,0,227,1],
+"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html":[7,0,0,200],
 "class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a0e7cf0d5efd1e52eaa23b31e0e2013a0":[7,0,0,200,1],
-"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,200,6],
+"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a0e7cf0d5efd1e52eaa23b31e0e2013a0":[6,0,0,227,1],
 "class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,227,6],
-"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a37e55a92a1d37807f04971ac099e4d01":[6,0,0,227,2],
+"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,200,6],
 "class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a37e55a92a1d37807f04971ac099e4d01":[7,0,0,200,2],
+"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a37e55a92a1d37807f04971ac099e4d01":[6,0,0,227,2],
 "class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,227,8],
 "class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,200,8],
-"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,227,11],
 "class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,200,11],
-"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a743d7ccc8db88583d3adf696217b4657":[6,0,0,227,3],
+"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,227,11],
 "class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a743d7ccc8db88583d3adf696217b4657":[7,0,0,200,3],
-"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,227,4],
+"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a743d7ccc8db88583d3adf696217b4657":[6,0,0,227,3],
 "class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,200,4],
-"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,227,7],
-"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,200,7],
-"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#ab2635c990eb9efe650bbf5f0845538e0":[6,0,0,227,14]
+"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,227,4],
+"class_ogre_1_1_d3_d11_stereo_driver_a_m_d.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,200,7]
 };
