@@ -1,28 +1,30 @@
 var NAVTREEINDEX48 =
 {
+"class_ogre_1_1_d3_d11_texture.html#a0ba4cefce02a7afa769a28c85c892082":[7,0,0,205,102],
+"class_ogre_1_1_d3_d11_texture.html#a104d9db8bfcff1f37b29157bbe070f7a":[6,0,0,232,109],
 "class_ogre_1_1_d3_d11_texture.html#a104d9db8bfcff1f37b29157bbe070f7a":[7,0,0,205,109],
 "class_ogre_1_1_d3_d11_texture.html#a11e0c120ae5cce0f1da28812966aee4a":[7,0,0,205,2],
 "class_ogre_1_1_d3_d11_texture.html#a11e0c120ae5cce0f1da28812966aee4a":[6,0,0,232,2],
-"class_ogre_1_1_d3_d11_texture.html#a13fc432584dd44c2969a8e41bdca569c":[7,0,0,205,8],
 "class_ogre_1_1_d3_d11_texture.html#a13fc432584dd44c2969a8e41bdca569c":[6,0,0,232,8],
+"class_ogre_1_1_d3_d11_texture.html#a13fc432584dd44c2969a8e41bdca569c":[7,0,0,205,8],
 "class_ogre_1_1_d3_d11_texture.html#a167aaa10b49fb6cd486ba0f75b6cdd7a":[7,0,0,205,51],
 "class_ogre_1_1_d3_d11_texture.html#a167aaa10b49fb6cd486ba0f75b6cdd7a":[6,0,0,232,51],
 "class_ogre_1_1_d3_d11_texture.html#a1686b8aef3b2c8d3892ae453086073c4":[7,0,0,205,18],
 "class_ogre_1_1_d3_d11_texture.html#a1686b8aef3b2c8d3892ae453086073c4":[6,0,0,232,18],
 "class_ogre_1_1_d3_d11_texture.html#a1833eb88cf9f2e3cde4f913d6c214a7c":[7,0,0,205,52],
 "class_ogre_1_1_d3_d11_texture.html#a1833eb88cf9f2e3cde4f913d6c214a7c":[6,0,0,232,52],
-"class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94":[6,0,0,232,0],
 "class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94":[7,0,0,205,0],
-"class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94a146041ec2a8b5178e5ad541d129c22eb":[7,0,0,205,0,5],
+"class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94":[6,0,0,232,0],
 "class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94a146041ec2a8b5178e5ad541d129c22eb":[6,0,0,232,0,5],
-"class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[6,0,0,232,0,1],
+"class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94a146041ec2a8b5178e5ad541d129c22eb":[7,0,0,205,0,5],
 "class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[7,0,0,205,0,1],
-"class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[6,0,0,232,0,2],
+"class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[6,0,0,232,0,1],
 "class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[7,0,0,205,0,2],
+"class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[6,0,0,232,0,2],
 "class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c":[7,0,0,205,0,0],
 "class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c":[6,0,0,232,0,0],
-"class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[7,0,0,205,0,4],
 "class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[6,0,0,232,0,4],
+"class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[7,0,0,205,0,4],
 "class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77":[7,0,0,205,0,3],
 "class_ogre_1_1_d3_d11_texture.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77":[6,0,0,232,0,3],
 "class_ogre_1_1_d3_d11_texture.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[6,0,0,232,12],
@@ -33,80 +35,80 @@ var NAVTREEINDEX48 =
 "class_ogre_1_1_d3_d11_texture.html#a1d84784891731ee66945ffbc3b31e35b":[7,0,0,205,73],
 "class_ogre_1_1_d3_d11_texture.html#a1e90ade99935ef70ec5b199243bf995b":[6,0,0,232,33],
 "class_ogre_1_1_d3_d11_texture.html#a1e90ade99935ef70ec5b199243bf995b":[7,0,0,205,33],
-"class_ogre_1_1_d3_d11_texture.html#a2298551707debaf774d577e643ee856a":[7,0,0,205,31],
 "class_ogre_1_1_d3_d11_texture.html#a2298551707debaf774d577e643ee856a":[6,0,0,232,31],
+"class_ogre_1_1_d3_d11_texture.html#a2298551707debaf774d577e643ee856a":[7,0,0,205,31],
 "class_ogre_1_1_d3_d11_texture.html#a297b97d2c7253c1ca8c471b91edd4407":[6,0,0,232,32],
 "class_ogre_1_1_d3_d11_texture.html#a297b97d2c7253c1ca8c471b91edd4407":[7,0,0,205,32],
-"class_ogre_1_1_d3_d11_texture.html#a2ee26937110dfbd80a5419b1e14fe619":[7,0,0,205,92],
 "class_ogre_1_1_d3_d11_texture.html#a2ee26937110dfbd80a5419b1e14fe619":[6,0,0,232,92],
-"class_ogre_1_1_d3_d11_texture.html#a329628051791d3684ec1e4fa3a886d38":[7,0,0,205,53],
+"class_ogre_1_1_d3_d11_texture.html#a2ee26937110dfbd80a5419b1e14fe619":[7,0,0,205,92],
 "class_ogre_1_1_d3_d11_texture.html#a329628051791d3684ec1e4fa3a886d38":[6,0,0,232,53],
-"class_ogre_1_1_d3_d11_texture.html#a350b287fa3e83a389221274f68760008":[6,0,0,232,85],
+"class_ogre_1_1_d3_d11_texture.html#a329628051791d3684ec1e4fa3a886d38":[7,0,0,205,53],
 "class_ogre_1_1_d3_d11_texture.html#a350b287fa3e83a389221274f68760008":[7,0,0,205,85],
-"class_ogre_1_1_d3_d11_texture.html#a367f6fe60bb211cb4c32e3825ca67e4c":[6,0,0,232,16],
+"class_ogre_1_1_d3_d11_texture.html#a350b287fa3e83a389221274f68760008":[6,0,0,232,85],
 "class_ogre_1_1_d3_d11_texture.html#a367f6fe60bb211cb4c32e3825ca67e4c":[7,0,0,205,16],
-"class_ogre_1_1_d3_d11_texture.html#a3af26f716731b64850ea50cfa4d2edef":[6,0,0,232,66],
+"class_ogre_1_1_d3_d11_texture.html#a367f6fe60bb211cb4c32e3825ca67e4c":[6,0,0,232,16],
 "class_ogre_1_1_d3_d11_texture.html#a3af26f716731b64850ea50cfa4d2edef":[7,0,0,205,66],
-"class_ogre_1_1_d3_d11_texture.html#a3c49142f739ba8fb56d6e7b3db235fb7":[6,0,0,232,87],
+"class_ogre_1_1_d3_d11_texture.html#a3af26f716731b64850ea50cfa4d2edef":[6,0,0,232,66],
 "class_ogre_1_1_d3_d11_texture.html#a3c49142f739ba8fb56d6e7b3db235fb7":[7,0,0,205,87],
-"class_ogre_1_1_d3_d11_texture.html#a3c600369ab5d6957524125c93915019f":[6,0,0,232,14],
+"class_ogre_1_1_d3_d11_texture.html#a3c49142f739ba8fb56d6e7b3db235fb7":[6,0,0,232,87],
 "class_ogre_1_1_d3_d11_texture.html#a3c600369ab5d6957524125c93915019f":[7,0,0,205,14],
+"class_ogre_1_1_d3_d11_texture.html#a3c600369ab5d6957524125c93915019f":[6,0,0,232,14],
 "class_ogre_1_1_d3_d11_texture.html#a3d111616339484f39c9456eeec6fd843":[7,0,0,205,9],
 "class_ogre_1_1_d3_d11_texture.html#a3d111616339484f39c9456eeec6fd843":[6,0,0,232,9],
 "class_ogre_1_1_d3_d11_texture.html#a3e314036bfd3198e89bd1d250f5eb6a1":[6,0,0,232,40],
 "class_ogre_1_1_d3_d11_texture.html#a3e314036bfd3198e89bd1d250f5eb6a1":[7,0,0,205,40],
-"class_ogre_1_1_d3_d11_texture.html#a496e18b2a22246735fd08fd83798c4a2":[6,0,0,232,13],
 "class_ogre_1_1_d3_d11_texture.html#a496e18b2a22246735fd08fd83798c4a2":[7,0,0,205,13],
-"class_ogre_1_1_d3_d11_texture.html#a49c64b4abb14f86f1c3108a7647ae3ed":[6,0,0,232,43],
+"class_ogre_1_1_d3_d11_texture.html#a496e18b2a22246735fd08fd83798c4a2":[6,0,0,232,13],
 "class_ogre_1_1_d3_d11_texture.html#a49c64b4abb14f86f1c3108a7647ae3ed":[7,0,0,205,43],
-"class_ogre_1_1_d3_d11_texture.html#a4b5d014a4d078b7893cce480b264c493":[7,0,0,205,7],
+"class_ogre_1_1_d3_d11_texture.html#a49c64b4abb14f86f1c3108a7647ae3ed":[6,0,0,232,43],
 "class_ogre_1_1_d3_d11_texture.html#a4b5d014a4d078b7893cce480b264c493":[6,0,0,232,7],
+"class_ogre_1_1_d3_d11_texture.html#a4b5d014a4d078b7893cce480b264c493":[7,0,0,205,7],
 "class_ogre_1_1_d3_d11_texture.html#a4d0ef43ff1e078b942e017f3dea6471d":[6,0,0,232,55],
 "class_ogre_1_1_d3_d11_texture.html#a4d0ef43ff1e078b942e017f3dea6471d":[7,0,0,205,55],
 "class_ogre_1_1_d3_d11_texture.html#a5016aec1762b026997ddd346775879ef":[7,0,0,205,86],
 "class_ogre_1_1_d3_d11_texture.html#a5016aec1762b026997ddd346775879ef":[6,0,0,232,86],
-"class_ogre_1_1_d3_d11_texture.html#a5513ffce404b14cff72846318b018d32":[6,0,0,232,10],
 "class_ogre_1_1_d3_d11_texture.html#a5513ffce404b14cff72846318b018d32":[7,0,0,205,10],
+"class_ogre_1_1_d3_d11_texture.html#a5513ffce404b14cff72846318b018d32":[6,0,0,232,10],
 "class_ogre_1_1_d3_d11_texture.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,205,79],
 "class_ogre_1_1_d3_d11_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,232,79],
-"class_ogre_1_1_d3_d11_texture.html#a5c9a21a914281a1b6ef5796531ea96e7":[7,0,0,205,64],
 "class_ogre_1_1_d3_d11_texture.html#a5c9a21a914281a1b6ef5796531ea96e7":[6,0,0,232,64],
+"class_ogre_1_1_d3_d11_texture.html#a5c9a21a914281a1b6ef5796531ea96e7":[7,0,0,205,64],
 "class_ogre_1_1_d3_d11_texture.html#a5d3962a2bef3bd77de412c8207975caf":[7,0,0,205,35],
 "class_ogre_1_1_d3_d11_texture.html#a5d3962a2bef3bd77de412c8207975caf":[6,0,0,232,35],
-"class_ogre_1_1_d3_d11_texture.html#a5dcfc70318106dd00902b0fc945d1d0e":[6,0,0,232,60],
 "class_ogre_1_1_d3_d11_texture.html#a5dcfc70318106dd00902b0fc945d1d0e":[7,0,0,205,60],
-"class_ogre_1_1_d3_d11_texture.html#a5decc0244a000c5002935c32ac301f0c":[6,0,0,232,24],
+"class_ogre_1_1_d3_d11_texture.html#a5dcfc70318106dd00902b0fc945d1d0e":[6,0,0,232,60],
 "class_ogre_1_1_d3_d11_texture.html#a5decc0244a000c5002935c32ac301f0c":[7,0,0,205,24],
+"class_ogre_1_1_d3_d11_texture.html#a5decc0244a000c5002935c32ac301f0c":[6,0,0,232,24],
 "class_ogre_1_1_d3_d11_texture.html#a60ce96525ac730a0f7b466ed287beef3":[7,0,0,205,63],
 "class_ogre_1_1_d3_d11_texture.html#a60ce96525ac730a0f7b466ed287beef3":[6,0,0,232,63],
 "class_ogre_1_1_d3_d11_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,205,82],
 "class_ogre_1_1_d3_d11_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,232,82],
-"class_ogre_1_1_d3_d11_texture.html#a65b5bd9531c385e200482c0edafdc1c2":[6,0,0,232,28],
 "class_ogre_1_1_d3_d11_texture.html#a65b5bd9531c385e200482c0edafdc1c2":[7,0,0,205,28],
+"class_ogre_1_1_d3_d11_texture.html#a65b5bd9531c385e200482c0edafdc1c2":[6,0,0,232,28],
 "class_ogre_1_1_d3_d11_texture.html#a699d1c851f494a8d5d23d23b695ceb47":[6,0,0,232,71],
 "class_ogre_1_1_d3_d11_texture.html#a699d1c851f494a8d5d23d23b695ceb47":[7,0,0,205,71],
-"class_ogre_1_1_d3_d11_texture.html#a69fbdff7f241bfd0f7c4c43b267ecbb5":[6,0,0,232,58],
 "class_ogre_1_1_d3_d11_texture.html#a69fbdff7f241bfd0f7c4c43b267ecbb5":[7,0,0,205,58],
-"class_ogre_1_1_d3_d11_texture.html#a6bdd32464ce1df547d34a0739e4c3592":[7,0,0,205,74],
+"class_ogre_1_1_d3_d11_texture.html#a69fbdff7f241bfd0f7c4c43b267ecbb5":[6,0,0,232,58],
 "class_ogre_1_1_d3_d11_texture.html#a6bdd32464ce1df547d34a0739e4c3592":[6,0,0,232,74],
-"class_ogre_1_1_d3_d11_texture.html#a6cfc6014da843369b2619d1d7d807569":[7,0,0,205,30],
+"class_ogre_1_1_d3_d11_texture.html#a6bdd32464ce1df547d34a0739e4c3592":[7,0,0,205,74],
 "class_ogre_1_1_d3_d11_texture.html#a6cfc6014da843369b2619d1d7d807569":[6,0,0,232,30],
-"class_ogre_1_1_d3_d11_texture.html#a6ed49ed8701feb087b04b730ce1d682f":[6,0,0,232,46],
+"class_ogre_1_1_d3_d11_texture.html#a6cfc6014da843369b2619d1d7d807569":[7,0,0,205,30],
 "class_ogre_1_1_d3_d11_texture.html#a6ed49ed8701feb087b04b730ce1d682f":[7,0,0,205,46],
-"class_ogre_1_1_d3_d11_texture.html#a6f186da4d9557d958779eba68bb769a9":[7,0,0,205,34],
+"class_ogre_1_1_d3_d11_texture.html#a6ed49ed8701feb087b04b730ce1d682f":[6,0,0,232,46],
 "class_ogre_1_1_d3_d11_texture.html#a6f186da4d9557d958779eba68bb769a9":[6,0,0,232,34],
-"class_ogre_1_1_d3_d11_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[6,0,0,232,106],
+"class_ogre_1_1_d3_d11_texture.html#a6f186da4d9557d958779eba68bb769a9":[7,0,0,205,34],
 "class_ogre_1_1_d3_d11_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[7,0,0,205,106],
+"class_ogre_1_1_d3_d11_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[6,0,0,232,106],
 "class_ogre_1_1_d3_d11_texture.html#a6fb6a698b152739c2c6a1b405b383e61":[7,0,0,205,20],
 "class_ogre_1_1_d3_d11_texture.html#a6fb6a698b152739c2c6a1b405b383e61":[6,0,0,232,20],
-"class_ogre_1_1_d3_d11_texture.html#a71ef0ea4964cb3c2a716de2b1220be51":[6,0,0,232,72],
 "class_ogre_1_1_d3_d11_texture.html#a71ef0ea4964cb3c2a716de2b1220be51":[7,0,0,205,72],
-"class_ogre_1_1_d3_d11_texture.html#a72833a46b3d9e38a0497e1dfa285f300":[6,0,0,232,49],
+"class_ogre_1_1_d3_d11_texture.html#a71ef0ea4964cb3c2a716de2b1220be51":[6,0,0,232,72],
 "class_ogre_1_1_d3_d11_texture.html#a72833a46b3d9e38a0497e1dfa285f300":[7,0,0,205,49],
+"class_ogre_1_1_d3_d11_texture.html#a72833a46b3d9e38a0497e1dfa285f300":[6,0,0,232,49],
 "class_ogre_1_1_d3_d11_texture.html#a74138c0203835513613af73cdb08890d":[6,0,0,232,65],
 "class_ogre_1_1_d3_d11_texture.html#a74138c0203835513613af73cdb08890d":[7,0,0,205,65],
-"class_ogre_1_1_d3_d11_texture.html#a743e5059501507cd858e90532e8263f9":[7,0,0,205,22],
 "class_ogre_1_1_d3_d11_texture.html#a743e5059501507cd858e90532e8263f9":[6,0,0,232,22],
+"class_ogre_1_1_d3_d11_texture.html#a743e5059501507cd858e90532e8263f9":[7,0,0,205,22],
 "class_ogre_1_1_d3_d11_texture.html#a77987dd9dce1653083f3518fc43da348":[7,0,0,205,37],
 "class_ogre_1_1_d3_d11_texture.html#a77987dd9dce1653083f3518fc43da348":[6,0,0,232,37],
 "class_ogre_1_1_d3_d11_texture.html#a77d5f72e02500f6db6f460bb48eac721":[6,0,0,232,6],
@@ -115,54 +117,54 @@ var NAVTREEINDEX48 =
 "class_ogre_1_1_d3_d11_texture.html#a82174dc4f4a0645332483ced7904c2f6":[6,0,0,232,98],
 "class_ogre_1_1_d3_d11_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,205,75],
 "class_ogre_1_1_d3_d11_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,232,75],
-"class_ogre_1_1_d3_d11_texture.html#a84dc53e8acb6b01bb695f96c048a1990":[7,0,0,205,25],
 "class_ogre_1_1_d3_d11_texture.html#a84dc53e8acb6b01bb695f96c048a1990":[6,0,0,232,25],
+"class_ogre_1_1_d3_d11_texture.html#a84dc53e8acb6b01bb695f96c048a1990":[7,0,0,205,25],
 "class_ogre_1_1_d3_d11_texture.html#a8775d611ddf70bc0ee89a9d62bac69cf":[7,0,0,205,99],
 "class_ogre_1_1_d3_d11_texture.html#a8775d611ddf70bc0ee89a9d62bac69cf":[6,0,0,232,99],
-"class_ogre_1_1_d3_d11_texture.html#a893c7a150edb48a25e5df700cfc194eb":[6,0,0,232,5],
 "class_ogre_1_1_d3_d11_texture.html#a893c7a150edb48a25e5df700cfc194eb":[7,0,0,205,5],
+"class_ogre_1_1_d3_d11_texture.html#a893c7a150edb48a25e5df700cfc194eb":[6,0,0,232,5],
 "class_ogre_1_1_d3_d11_texture.html#a8ab9418311a7b4a116139a7871e57a4b":[6,0,0,232,38],
 "class_ogre_1_1_d3_d11_texture.html#a8ab9418311a7b4a116139a7871e57a4b":[7,0,0,205,38],
 "class_ogre_1_1_d3_d11_texture.html#a8eb34a9034aab62fd537c021a79e3366":[7,0,0,205,69],
 "class_ogre_1_1_d3_d11_texture.html#a8eb34a9034aab62fd537c021a79e3366":[6,0,0,232,69],
-"class_ogre_1_1_d3_d11_texture.html#a8ed6a95810f21f53aa8cbc780b680164":[6,0,0,232,26],
 "class_ogre_1_1_d3_d11_texture.html#a8ed6a95810f21f53aa8cbc780b680164":[7,0,0,205,26],
-"class_ogre_1_1_d3_d11_texture.html#a8f541900f7e1f73f4c313a732199029a":[6,0,0,232,67],
+"class_ogre_1_1_d3_d11_texture.html#a8ed6a95810f21f53aa8cbc780b680164":[6,0,0,232,26],
 "class_ogre_1_1_d3_d11_texture.html#a8f541900f7e1f73f4c313a732199029a":[7,0,0,205,67],
+"class_ogre_1_1_d3_d11_texture.html#a8f541900f7e1f73f4c313a732199029a":[6,0,0,232,67],
 "class_ogre_1_1_d3_d11_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,205,78],
 "class_ogre_1_1_d3_d11_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,232,78],
 "class_ogre_1_1_d3_d11_texture.html#a963dca9c2ab605d51ee75c92d850a96d":[6,0,0,232,56],
 "class_ogre_1_1_d3_d11_texture.html#a963dca9c2ab605d51ee75c92d850a96d":[7,0,0,205,56],
 "class_ogre_1_1_d3_d11_texture.html#a9dffcf1a2d754e63e98770e5cf2cd9ee":[7,0,0,205,39],
 "class_ogre_1_1_d3_d11_texture.html#a9dffcf1a2d754e63e98770e5cf2cd9ee":[6,0,0,232,39],
-"class_ogre_1_1_d3_d11_texture.html#aa31bef1bfaa87731622e56f11b548e27":[6,0,0,232,108],
 "class_ogre_1_1_d3_d11_texture.html#aa31bef1bfaa87731622e56f11b548e27":[7,0,0,205,108],
+"class_ogre_1_1_d3_d11_texture.html#aa31bef1bfaa87731622e56f11b548e27":[6,0,0,232,108],
 "class_ogre_1_1_d3_d11_texture.html#aa38c4f67ab5413135d1830dd164a68e6":[6,0,0,232,91],
 "class_ogre_1_1_d3_d11_texture.html#aa38c4f67ab5413135d1830dd164a68e6":[7,0,0,205,91],
-"class_ogre_1_1_d3_d11_texture.html#aa561d8d03383bb59ecce5c4278ed8da6":[6,0,0,232,104],
 "class_ogre_1_1_d3_d11_texture.html#aa561d8d03383bb59ecce5c4278ed8da6":[7,0,0,205,104],
-"class_ogre_1_1_d3_d11_texture.html#aa5c94ac282eb67a0b8cf6b32af4ccf7e":[6,0,0,232,94],
+"class_ogre_1_1_d3_d11_texture.html#aa561d8d03383bb59ecce5c4278ed8da6":[6,0,0,232,104],
 "class_ogre_1_1_d3_d11_texture.html#aa5c94ac282eb67a0b8cf6b32af4ccf7e":[7,0,0,205,94],
+"class_ogre_1_1_d3_d11_texture.html#aa5c94ac282eb67a0b8cf6b32af4ccf7e":[6,0,0,232,94],
 "class_ogre_1_1_d3_d11_texture.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[7,0,0,205,11],
 "class_ogre_1_1_d3_d11_texture.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[6,0,0,232,11],
-"class_ogre_1_1_d3_d11_texture.html#aa7942df6419c98c2668ffb02de252cc8":[6,0,0,232,23],
 "class_ogre_1_1_d3_d11_texture.html#aa7942df6419c98c2668ffb02de252cc8":[7,0,0,205,23],
+"class_ogre_1_1_d3_d11_texture.html#aa7942df6419c98c2668ffb02de252cc8":[6,0,0,232,23],
 "class_ogre_1_1_d3_d11_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[7,0,0,205,48],
 "class_ogre_1_1_d3_d11_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[6,0,0,232,48],
-"class_ogre_1_1_d3_d11_texture.html#ab3f5c3f62eb8d9e4d7c428c049e62991":[7,0,0,205,15],
 "class_ogre_1_1_d3_d11_texture.html#ab3f5c3f62eb8d9e4d7c428c049e62991":[6,0,0,232,15],
-"class_ogre_1_1_d3_d11_texture.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,232,81],
+"class_ogre_1_1_d3_d11_texture.html#ab3f5c3f62eb8d9e4d7c428c049e62991":[7,0,0,205,15],
 "class_ogre_1_1_d3_d11_texture.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,205,81],
-"class_ogre_1_1_d3_d11_texture.html#aba6375dc3369f7d4a1aaa4e7fedd62aa":[7,0,0,205,36],
+"class_ogre_1_1_d3_d11_texture.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,232,81],
 "class_ogre_1_1_d3_d11_texture.html#aba6375dc3369f7d4a1aaa4e7fedd62aa":[6,0,0,232,36],
-"class_ogre_1_1_d3_d11_texture.html#ac31adbd479f21ddab5ae616cf7fe0e0a":[6,0,0,232,57],
+"class_ogre_1_1_d3_d11_texture.html#aba6375dc3369f7d4a1aaa4e7fedd62aa":[7,0,0,205,36],
 "class_ogre_1_1_d3_d11_texture.html#ac31adbd479f21ddab5ae616cf7fe0e0a":[7,0,0,205,57],
+"class_ogre_1_1_d3_d11_texture.html#ac31adbd479f21ddab5ae616cf7fe0e0a":[6,0,0,232,57],
 "class_ogre_1_1_d3_d11_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[6,0,0,232,45],
 "class_ogre_1_1_d3_d11_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[7,0,0,205,45],
-"class_ogre_1_1_d3_d11_texture.html#ac93f17feff099035542be8b22f890417":[7,0,0,205,29],
 "class_ogre_1_1_d3_d11_texture.html#ac93f17feff099035542be8b22f890417":[6,0,0,232,29],
-"class_ogre_1_1_d3_d11_texture.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,205,76],
+"class_ogre_1_1_d3_d11_texture.html#ac93f17feff099035542be8b22f890417":[7,0,0,205,29],
 "class_ogre_1_1_d3_d11_texture.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,232,76],
+"class_ogre_1_1_d3_d11_texture.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,205,76],
 "class_ogre_1_1_d3_d11_texture.html#acce55ed43f888d8c4c5ed5c5aaf9d1db":[7,0,0,205,42],
 "class_ogre_1_1_d3_d11_texture.html#acce55ed43f888d8c4c5ed5c5aaf9d1db":[6,0,0,232,42],
 "class_ogre_1_1_d3_d11_texture.html#accfa5467ab8ccfc5920ec64101f8f532":[7,0,0,205,19],
@@ -175,8 +177,8 @@ var NAVTREEINDEX48 =
 "class_ogre_1_1_d3_d11_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,205,80],
 "class_ogre_1_1_d3_d11_texture.html#ad8faaf7732b48e059f7d7dc15667f2af":[7,0,0,205,95],
 "class_ogre_1_1_d3_d11_texture.html#ad8faaf7732b48e059f7d7dc15667f2af":[6,0,0,232,95],
-"class_ogre_1_1_d3_d11_texture.html#adb06b3b704674e757a76988f4952004b":[7,0,0,205,62],
 "class_ogre_1_1_d3_d11_texture.html#adb06b3b704674e757a76988f4952004b":[6,0,0,232,62],
+"class_ogre_1_1_d3_d11_texture.html#adb06b3b704674e757a76988f4952004b":[7,0,0,205,62],
 "class_ogre_1_1_d3_d11_texture.html#adce32528577d71b228692df906ecd17c":[7,0,0,205,83],
 "class_ogre_1_1_d3_d11_texture.html#adce32528577d71b228692df906ecd17c":[6,0,0,232,83],
 "class_ogre_1_1_d3_d11_texture.html#ade85e4d5579519e4117a84789c0ae8fd":[6,0,0,232,50],
@@ -187,10 +189,10 @@ var NAVTREEINDEX48 =
 "class_ogre_1_1_d3_d11_texture.html#ae1c886505b803967f91065ae379653dd":[6,0,0,232,21],
 "class_ogre_1_1_d3_d11_texture.html#ae229b1f58092109adef55bfc6f864d79":[6,0,0,232,107],
 "class_ogre_1_1_d3_d11_texture.html#ae229b1f58092109adef55bfc6f864d79":[7,0,0,205,107],
-"class_ogre_1_1_d3_d11_texture.html#ae2386d781b6343fb0697e4e3ce240074":[7,0,0,205,54],
 "class_ogre_1_1_d3_d11_texture.html#ae2386d781b6343fb0697e4e3ce240074":[6,0,0,232,54],
-"class_ogre_1_1_d3_d11_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[7,0,0,205,97],
+"class_ogre_1_1_d3_d11_texture.html#ae2386d781b6343fb0697e4e3ce240074":[7,0,0,205,54],
 "class_ogre_1_1_d3_d11_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[6,0,0,232,97],
+"class_ogre_1_1_d3_d11_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[7,0,0,205,97],
 "class_ogre_1_1_d3_d11_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[6,0,0,232,96],
 "class_ogre_1_1_d3_d11_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[7,0,0,205,96],
 "class_ogre_1_1_d3_d11_texture.html#ae356913ccefbebc4f0119a0599a406fc":[6,0,0,232,101],
@@ -199,55 +201,53 @@ var NAVTREEINDEX48 =
 "class_ogre_1_1_d3_d11_texture.html#ae67e44696cde3c7d4e8fec157ca4f498":[6,0,0,232,90],
 "class_ogre_1_1_d3_d11_texture.html#aec390502f63927ed9470ba423ea66f64":[6,0,0,232,89],
 "class_ogre_1_1_d3_d11_texture.html#aec390502f63927ed9470ba423ea66f64":[7,0,0,205,89],
-"class_ogre_1_1_d3_d11_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,205,84],
 "class_ogre_1_1_d3_d11_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,232,84],
+"class_ogre_1_1_d3_d11_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,205,84],
 "class_ogre_1_1_d3_d11_texture.html#aee3fd3170df592c3cc679cc38d3d9f60":[6,0,0,232,47],
 "class_ogre_1_1_d3_d11_texture.html#aee3fd3170df592c3cc679cc38d3d9f60":[7,0,0,205,47],
-"class_ogre_1_1_d3_d11_texture.html#af2e59ee386bf4ecbda052145ecb1e7f5":[6,0,0,232,17],
 "class_ogre_1_1_d3_d11_texture.html#af2e59ee386bf4ecbda052145ecb1e7f5":[7,0,0,205,17],
-"class_ogre_1_1_d3_d11_texture.html#af745587ede1e8482b1edac167fbf82fd":[6,0,0,232,93],
+"class_ogre_1_1_d3_d11_texture.html#af2e59ee386bf4ecbda052145ecb1e7f5":[6,0,0,232,17],
 "class_ogre_1_1_d3_d11_texture.html#af745587ede1e8482b1edac167fbf82fd":[7,0,0,205,93],
-"class_ogre_1_1_d3_d11_texture.html#afc89f37018b36db6bd839318d38ba434":[7,0,0,205,61],
+"class_ogre_1_1_d3_d11_texture.html#af745587ede1e8482b1edac167fbf82fd":[6,0,0,232,93],
 "class_ogre_1_1_d3_d11_texture.html#afc89f37018b36db6bd839318d38ba434":[6,0,0,232,61],
+"class_ogre_1_1_d3_d11_texture.html#afc89f37018b36db6bd839318d38ba434":[7,0,0,205,61],
 "class_ogre_1_1_d3_d11_texture.html#afcb4a61b965600a67ca2c2f060821db9":[7,0,0,205,4],
 "class_ogre_1_1_d3_d11_texture.html#afcb4a61b965600a67ca2c2f060821db9":[6,0,0,232,4],
 "class_ogre_1_1_d3_d11_texture.html#afefa465095dd97cf22d0a43531171b51":[6,0,0,232,27],
 "class_ogre_1_1_d3_d11_texture.html#afefa465095dd97cf22d0a43531171b51":[7,0,0,205,27],
-"class_ogre_1_1_d3_d11_texture_gpu.html":[7,0,0,206],
 "class_ogre_1_1_d3_d11_texture_gpu.html":[6,0,0,233],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a00ea3e542d7ef9c1e223d12b99d24d0b":[7,0,0,206,23],
+"class_ogre_1_1_d3_d11_texture_gpu.html":[7,0,0,206],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a00ea3e542d7ef9c1e223d12b99d24d0b":[6,0,0,233,23],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a00ea3e542d7ef9c1e223d12b99d24d0b":[7,0,0,206,23],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a03e2b3a27c5827b5f063fa6669f8e161":[6,0,0,233,58],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a03e2b3a27c5827b5f063fa6669f8e161":[7,0,0,206,58],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a06df44c12f039dfb40a60f6aacc94495":[6,0,0,233,36],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a06df44c12f039dfb40a60f6aacc94495":[7,0,0,206,36],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a0729d200bede23e29f5a88f0b9dcb3f6":[6,0,0,233,105],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a0729d200bede23e29f5a88f0b9dcb3f6":[7,0,0,206,105],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a0caa00cccae17c7d5a3d33ff160594bc":[6,0,0,233,48],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a0729d200bede23e29f5a88f0b9dcb3f6":[6,0,0,233,105],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a0caa00cccae17c7d5a3d33ff160594bc":[7,0,0,206,48],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a0ccfb3ab941842233e28a216e337e28e":[7,0,0,206,81],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a0caa00cccae17c7d5a3d33ff160594bc":[6,0,0,233,48],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a0ccfb3ab941842233e28a216e337e28e":[6,0,0,233,81],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a0df37fcb72b47849df985a18828f2e97":[6,0,0,233,10],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a0ccfb3ab941842233e28a216e337e28e":[7,0,0,206,81],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a0df37fcb72b47849df985a18828f2e97":[7,0,0,206,10],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a0df37fcb72b47849df985a18828f2e97":[6,0,0,233,10],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a107372aa3256baf8a80484b7f2412dd6":[6,0,0,233,51],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a107372aa3256baf8a80484b7f2412dd6":[7,0,0,206,51],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a1a1403e76b6775c08d2cb7b0c7d1398d":[6,0,0,233,25],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a1a1403e76b6775c08d2cb7b0c7d1398d":[7,0,0,206,25],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a1a1403e76b6775c08d2cb7b0c7d1398d":[6,0,0,233,25],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a1b6dd0d57c28fe017e8a83877bea0c5f":[7,0,0,206,22],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a1b6dd0d57c28fe017e8a83877bea0c5f":[6,0,0,233,22],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,206,94],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,233,94],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a1df868efdc0e6262a5532f4480448e3a":[7,0,0,206,28],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,206,94],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a1df868efdc0e6262a5532f4480448e3a":[6,0,0,233,28],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a1f897bb3028c54f77c26a153176b5392":[7,0,0,206,31],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a1df868efdc0e6262a5532f4480448e3a":[7,0,0,206,28],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a1f897bb3028c54f77c26a153176b5392":[6,0,0,233,31],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a1f960e2ffea97ad43308c23ce1efb4b1":[7,0,0,206,55],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a1f897bb3028c54f77c26a153176b5392":[7,0,0,206,31],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a1f960e2ffea97ad43308c23ce1efb4b1":[6,0,0,233,55],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a23c32548e36eee7661d2da4c58f09f80":[7,0,0,206,79],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a1f960e2ffea97ad43308c23ce1efb4b1":[7,0,0,206,55],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a23c32548e36eee7661d2da4c58f09f80":[6,0,0,233,79],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a2afd94abec3a7a91c656188fc6d7cdf5":[6,0,0,233,78],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a23c32548e36eee7661d2da4c58f09f80":[7,0,0,206,79],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a2afd94abec3a7a91c656188fc6d7cdf5":[7,0,0,206,78],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a2bc02fb2fe9a6ab56d2a6d206569399c":[6,0,0,233,113],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a2bc02fb2fe9a6ab56d2a6d206569399c":[7,0,0,206,113],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a2e45ab2f1617d1d51c45f687d9ebee8c":[7,0,0,206,62]
+"class_ogre_1_1_d3_d11_texture_gpu.html#a2afd94abec3a7a91c656188fc6d7cdf5":[6,0,0,233,78],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a2bc02fb2fe9a6ab56d2a6d206569399c":[6,0,0,233,113]
 };
