@@ -1,86 +1,88 @@
 var NAVTREEINDEX49 =
 {
+"class_ogre_1_1_d3_d11_texture_gpu.html#a2bc02fb2fe9a6ab56d2a6d206569399c":[7,0,0,206,113],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a2e45ab2f1617d1d51c45f687d9ebee8c":[7,0,0,206,62],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a2e45ab2f1617d1d51c45f687d9ebee8c":[6,0,0,233,62],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a2e6b84b89e2080bb7103d4778641d86e":[7,0,0,206,102],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a2e6b84b89e2080bb7103d4778641d86e":[6,0,0,233,102],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a31a1ba96b03d3bab1a3c5943d03531fc":[6,0,0,233,82],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a31a1ba96b03d3bab1a3c5943d03531fc":[7,0,0,206,82],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a359fd32c4f8c31cdd4db4baf72c1b70c":[6,0,0,233,84],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a31a1ba96b03d3bab1a3c5943d03531fc":[6,0,0,233,82],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a359fd32c4f8c31cdd4db4baf72c1b70c":[7,0,0,206,84],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a359fd32c4f8c31cdd4db4baf72c1b70c":[6,0,0,233,84],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a3660ede23923c71e8bc8621fe732a57d":[6,0,0,233,19],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a3660ede23923c71e8bc8621fe732a57d":[7,0,0,206,19],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a37e063590ddf3677c87852e3107b4e45":[7,0,0,206,47],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a37e063590ddf3677c87852e3107b4e45":[6,0,0,233,47],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a37e063590ddf3677c87852e3107b4e45":[7,0,0,206,47],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a3866a77dfd74f1b70fdd31f42382c544":[6,0,0,233,108],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a3866a77dfd74f1b70fdd31f42382c544":[7,0,0,206,108],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a392c0d59b4956c9a361e82514cba0427":[7,0,0,206,67],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a392c0d59b4956c9a361e82514cba0427":[6,0,0,233,67],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a392c0d59b4956c9a361e82514cba0427":[7,0,0,206,67],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a3bd2fb8a2ce598268c8813f5f230ddd8":[6,0,0,233,114],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a3bd2fb8a2ce598268c8813f5f230ddd8":[7,0,0,206,114],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a3db88cd9e4286f47a56fe7f507cd5c1b":[6,0,0,233,104],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a3db88cd9e4286f47a56fe7f507cd5c1b":[7,0,0,206,104],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a3ed2bdf11740fd262b9311a33e33f935":[6,0,0,233,121],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a3db88cd9e4286f47a56fe7f507cd5c1b":[6,0,0,233,104],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a3ed2bdf11740fd262b9311a33e33f935":[7,0,0,206,121],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a3ed2bdf11740fd262b9311a33e33f935":[6,0,0,233,121],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4044404f7783aea108e986336caaedf6":[6,0,0,233,17],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4044404f7783aea108e986336caaedf6":[7,0,0,206,17],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a43888e98f84f5c9eb9ded14dd0deb34d":[6,0,0,233,122],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a43888e98f84f5c9eb9ded14dd0deb34d":[7,0,0,206,122],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a472f6a92131325af1a8f5ba2b78b86eb":[7,0,0,206,33],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a43888e98f84f5c9eb9ded14dd0deb34d":[6,0,0,233,122],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a472f6a92131325af1a8f5ba2b78b86eb":[6,0,0,233,33],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a4766a70699416dd6dc2a51ad28307a19":[7,0,0,206,41],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a472f6a92131325af1a8f5ba2b78b86eb":[7,0,0,206,33],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4766a70699416dd6dc2a51ad28307a19":[6,0,0,233,41],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a47e1fcc0e8d7a092a55c79ace4564a4a":[7,0,0,206,5],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a4766a70699416dd6dc2a51ad28307a19":[7,0,0,206,41],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a47e1fcc0e8d7a092a55c79ace4564a4a":[6,0,0,233,5],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a47e1fcc0e8d7a092a55c79ace4564a4a":[7,0,0,206,5],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4a10073f63d8fb559374f9e7c6585ae5":[7,0,0,206,50],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4a10073f63d8fb559374f9e7c6585ae5":[6,0,0,233,50],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a4a698f48957f6d466fbddcbf2e80becd":[6,0,0,233,49],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4a698f48957f6d466fbddcbf2e80becd":[7,0,0,206,49],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a4c0edfcf7c6354c686d2ff580e7a5011":[7,0,0,206,85],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a4a698f48957f6d466fbddcbf2e80becd":[6,0,0,233,49],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4c0edfcf7c6354c686d2ff580e7a5011":[6,0,0,233,85],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a4c0edfcf7c6354c686d2ff580e7a5011":[7,0,0,206,85],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4c626ccabbd6c853ee1490358b9ca490":[7,0,0,206,14],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4c626ccabbd6c853ee1490358b9ca490":[6,0,0,233,14],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a4d4ea058e8a05f5d1949fe952ad00063":[6,0,0,233,45],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4d4ea058e8a05f5d1949fe952ad00063":[7,0,0,206,45],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a4d4ea058e8a05f5d1949fe952ad00063":[6,0,0,233,45],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4de8595b73e911c15ce9e8066926380d":[7,0,0,206,73],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a4de8595b73e911c15ce9e8066926380d":[6,0,0,233,73],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a50b8aace07a416886cc0f871b32f078c":[6,0,0,233,24],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a50b8aace07a416886cc0f871b32f078c":[7,0,0,206,24],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a50b8aace07a416886cc0f871b32f078c":[6,0,0,233,24],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a529bc39128cc173557a2742b7278c400":[6,0,0,233,87],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a529bc39128cc173557a2742b7278c400":[7,0,0,206,87],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a52acdc930dff7ae7f455256822d9520d":[7,0,0,206,90],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a52acdc930dff7ae7f455256822d9520d":[6,0,0,233,90],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a52acdc930dff7ae7f455256822d9520d":[7,0,0,206,90],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a54dfe2523d8e5647e79caaf28c296d4e":[7,0,0,206,109],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a54dfe2523d8e5647e79caaf28c296d4e":[6,0,0,233,109],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a56ccef279ef9251c5a4b40bfaf7b9e05":[6,0,0,233,16],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a56ccef279ef9251c5a4b40bfaf7b9e05":[7,0,0,206,16],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a57c6e78baed76ebbde12a2061b35ab16":[6,0,0,233,59],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a57c6e78baed76ebbde12a2061b35ab16":[7,0,0,206,59],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,233,96],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,206,96],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,233,96],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a5dbda8603b2d42d666a9aea7113e290d":[6,0,0,233,52],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a5dbda8603b2d42d666a9aea7113e290d":[7,0,0,206,52],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a5f3949efcab14e16584f66e388137ce8":[6,0,0,233,1],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a5f3949efcab14e16584f66e388137ce8":[7,0,0,206,1],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a6061da5422410802a10d2e97e9ab46f0":[6,0,0,233,7],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a5f3949efcab14e16584f66e388137ce8":[6,0,0,233,1],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a6061da5422410802a10d2e97e9ab46f0":[7,0,0,206,7],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a621cde8bbd49cbb2e6d3c5f9b56b0e5d":[6,0,0,233,40],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a6061da5422410802a10d2e97e9ab46f0":[6,0,0,233,7],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a621cde8bbd49cbb2e6d3c5f9b56b0e5d":[7,0,0,206,40],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a621cde8bbd49cbb2e6d3c5f9b56b0e5d":[6,0,0,233,40],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,206,99],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,233,99],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a65a6949bdace3ca3e22d9cdb8cc77411":[6,0,0,233,56],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a65a6949bdace3ca3e22d9cdb8cc77411":[7,0,0,206,56],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a6740006ae83f39c4aeb83f300b67f6b2":[6,0,0,233,118],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a65a6949bdace3ca3e22d9cdb8cc77411":[6,0,0,233,56],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a6740006ae83f39c4aeb83f300b67f6b2":[7,0,0,206,118],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a6740006ae83f39c4aeb83f300b67f6b2":[6,0,0,233,118],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a6ae40391d39c8feae00acaf25839c6f9":[6,0,0,233,107],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a6ae40391d39c8feae00acaf25839c6f9":[7,0,0,206,107],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a714b2b71f5443736c7c0ac2a97753c02":[7,0,0,206,39],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a714b2b71f5443736c7c0ac2a97753c02":[6,0,0,233,39],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a72fc34cf0b95593aa41df1370f5da312":[6,0,0,233,34],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a72fc34cf0b95593aa41df1370f5da312":[7,0,0,206,34],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a72fc34cf0b95593aa41df1370f5da312":[6,0,0,233,34],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a7345e4a1d69f94657945067273376684":[6,0,0,233,15],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a7345e4a1d69f94657945067273376684":[7,0,0,206,15],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a7556d2e92eb39b9f465d25bd811c5c22":[6,0,0,233,42],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a7556d2e92eb39b9f465d25bd811c5c22":[7,0,0,206,42],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a7556d2e92eb39b9f465d25bd811c5c22":[6,0,0,233,42],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a78663647804665d50f8e0ec251845ff3":[7,0,0,206,69],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a78663647804665d50f8e0ec251845ff3":[6,0,0,233,69],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a78bd23c2116dc08afcaa8dc1b8d2384e":[6,0,0,233,112],
@@ -89,14 +91,14 @@ var NAVTREEINDEX49 =
 "class_ogre_1_1_d3_d11_texture_gpu.html#a78dd6a8c7c23f1dc98a9ec150bdf16e1":[6,0,0,233,53],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a7bb35caa0639bfa59b095295a73ab6c0":[7,0,0,206,46],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a7bb35caa0639bfa59b095295a73ab6c0":[6,0,0,233,46],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a7d040629bd1cd7b1a3ef9c3e77586aef":[7,0,0,206,3],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a7d040629bd1cd7b1a3ef9c3e77586aef":[6,0,0,233,3],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a7d040629bd1cd7b1a3ef9c3e77586aef":[7,0,0,206,3],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,233,92],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,206,92],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a85f9670da9031ec138caf8b3e910b37e":[7,0,0,206,21],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a85f9670da9031ec138caf8b3e910b37e":[6,0,0,233,21],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a88170d5ed9c9d2dc6e886217aaf1f6a5":[6,0,0,233,65],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a88170d5ed9c9d2dc6e886217aaf1f6a5":[7,0,0,206,65],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a88170d5ed9c9d2dc6e886217aaf1f6a5":[6,0,0,233,65],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a8d5974fedfde3ac1d042e7cb14515414":[6,0,0,233,0],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a8d5974fedfde3ac1d042e7cb14515414":[7,0,0,206,0],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a8ec57ce0ef0c682416c3a6b6d13a095a":[7,0,0,206,120],
@@ -109,46 +111,46 @@ var NAVTREEINDEX49 =
 "class_ogre_1_1_d3_d11_texture_gpu.html#a90e16463577b2d4d86293f5953a609c9":[7,0,0,206,29],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,206,95],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,233,95],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a96c0f33134c2401b0e711506c8055623":[7,0,0,206,64],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a96c0f33134c2401b0e711506c8055623":[6,0,0,233,64],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a97ecda8a3b890943e334f365bb32b4b7":[6,0,0,233,66],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a96c0f33134c2401b0e711506c8055623":[7,0,0,206,64],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a97ecda8a3b890943e334f365bb32b4b7":[7,0,0,206,66],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a97ecda8a3b890943e334f365bb32b4b7":[6,0,0,233,66],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a9be2b0daaad98d2140ca22efc6685684":[7,0,0,206,61],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a9be2b0daaad98d2140ca22efc6685684":[6,0,0,233,61],
-"class_ogre_1_1_d3_d11_texture_gpu.html#a9e98f7545f8b2fd4d92dd412fa5ac270":[6,0,0,233,37],
 "class_ogre_1_1_d3_d11_texture_gpu.html#a9e98f7545f8b2fd4d92dd412fa5ac270":[7,0,0,206,37],
+"class_ogre_1_1_d3_d11_texture_gpu.html#a9e98f7545f8b2fd4d92dd412fa5ac270":[6,0,0,233,37],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa0c236009b4074f43621c21db5ff6ef4":[6,0,0,233,86],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa0c236009b4074f43621c21db5ff6ef4":[7,0,0,206,86],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa0ea6521b6c7bc7fdd58dab549d5c26e":[6,0,0,233,91],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa0ea6521b6c7bc7fdd58dab549d5c26e":[7,0,0,206,91],
-"class_ogre_1_1_d3_d11_texture_gpu.html#aa2ee4d088c32b3e9efeb4d2fec5cad3e":[7,0,0,206,111],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa2ee4d088c32b3e9efeb4d2fec5cad3e":[6,0,0,233,111],
+"class_ogre_1_1_d3_d11_texture_gpu.html#aa2ee4d088c32b3e9efeb4d2fec5cad3e":[7,0,0,206,111],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa3c2ce1e86de183dd2e2eff87da180a5":[6,0,0,233,75],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa3c2ce1e86de183dd2e2eff87da180a5":[7,0,0,206,75],
-"class_ogre_1_1_d3_d11_texture_gpu.html#aa3efd161b3ec98e3a405cf3167b7d022":[6,0,0,233,116],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa3efd161b3ec98e3a405cf3167b7d022":[7,0,0,206,116],
+"class_ogre_1_1_d3_d11_texture_gpu.html#aa3efd161b3ec98e3a405cf3167b7d022":[6,0,0,233,116],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa5cba290939fe64d8d12c514d79e9fc4":[7,0,0,206,68],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa5cba290939fe64d8d12c514d79e9fc4":[6,0,0,233,68],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa81e2a8d0caf9096dbab0723bab2b894":[7,0,0,206,20],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa81e2a8d0caf9096dbab0723bab2b894":[6,0,0,233,20],
-"class_ogre_1_1_d3_d11_texture_gpu.html#aa844386b35f2cb71fee2f61304cb0d8d":[6,0,0,233,76],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aa844386b35f2cb71fee2f61304cb0d8d":[7,0,0,206,76],
+"class_ogre_1_1_d3_d11_texture_gpu.html#aa844386b35f2cb71fee2f61304cb0d8d":[6,0,0,233,76],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aad718ff4ec85f52e36ef2772d9b150c2":[6,0,0,233,63],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aad718ff4ec85f52e36ef2772d9b150c2":[7,0,0,206,63],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ab020f76a2cf0e24e13ccb3e3cf49c0f2":[7,0,0,206,8],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ab020f76a2cf0e24e13ccb3e3cf49c0f2":[6,0,0,233,8],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ab038b4f32feeaa739a8cff7397e8809d":[7,0,0,206,72],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ab038b4f32feeaa739a8cff7397e8809d":[6,0,0,233,72],
-"class_ogre_1_1_d3_d11_texture_gpu.html#ab0b3bbbb8ceb6e9e72827a378c3d3627":[6,0,0,233,27],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ab0b3bbbb8ceb6e9e72827a378c3d3627":[7,0,0,206,27],
+"class_ogre_1_1_d3_d11_texture_gpu.html#ab0b3bbbb8ceb6e9e72827a378c3d3627":[6,0,0,233,27],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ab20de005df190c986ae28b25f09fc5a4":[7,0,0,206,38],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ab20de005df190c986ae28b25f09fc5a4":[6,0,0,233,38],
-"class_ogre_1_1_d3_d11_texture_gpu.html#ab292a36bb1fc15ed2a2e4df4f8320faf":[6,0,0,233,32],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ab292a36bb1fc15ed2a2e4df4f8320faf":[7,0,0,206,32],
-"class_ogre_1_1_d3_d11_texture_gpu.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,206,98],
+"class_ogre_1_1_d3_d11_texture_gpu.html#ab292a36bb1fc15ed2a2e4df4f8320faf":[6,0,0,233,32],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,233,98],
-"class_ogre_1_1_d3_d11_texture_gpu.html#ab6906f8bdd2c820cc47b60b7d494d147":[7,0,0,206,70],
+"class_ogre_1_1_d3_d11_texture_gpu.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,206,98],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ab6906f8bdd2c820cc47b60b7d494d147":[6,0,0,233,70],
+"class_ogre_1_1_d3_d11_texture_gpu.html#ab6906f8bdd2c820cc47b60b7d494d147":[7,0,0,206,70],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ac707e8be721a47fb23a628003b1ade1f":[7,0,0,206,115],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ac707e8be721a47fb23a628003b1ade1f":[6,0,0,233,115],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ac7261ed5e880bbe376162a666d0ebea3":[7,0,0,206,44],
@@ -157,30 +159,30 @@ var NAVTREEINDEX49 =
 "class_ogre_1_1_d3_d11_texture_gpu.html#ac965a34686dd8e378e1b614b1211e2c9":[6,0,0,233,26],
 "class_ogre_1_1_d3_d11_texture_gpu.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,206,93],
 "class_ogre_1_1_d3_d11_texture_gpu.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,233,93],
-"class_ogre_1_1_d3_d11_texture_gpu.html#acc59aec11b770b8fc317dea50313d052":[6,0,0,233,30],
 "class_ogre_1_1_d3_d11_texture_gpu.html#acc59aec11b770b8fc317dea50313d052":[7,0,0,206,30],
-"class_ogre_1_1_d3_d11_texture_gpu.html#acdde6ea96205d73550d17a18bf4653a4":[6,0,0,233,89],
+"class_ogre_1_1_d3_d11_texture_gpu.html#acc59aec11b770b8fc317dea50313d052":[6,0,0,233,30],
 "class_ogre_1_1_d3_d11_texture_gpu.html#acdde6ea96205d73550d17a18bf4653a4":[7,0,0,206,89],
+"class_ogre_1_1_d3_d11_texture_gpu.html#acdde6ea96205d73550d17a18bf4653a4":[6,0,0,233,89],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ace88832ef330c2b560127ca2386c87de":[6,0,0,233,77],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ace88832ef330c2b560127ca2386c87de":[7,0,0,206,77],
-"class_ogre_1_1_d3_d11_texture_gpu.html#ad0bb22af342ab460495997988c2a6cf9":[6,0,0,233,80],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ad0bb22af342ab460495997988c2a6cf9":[7,0,0,206,80],
-"class_ogre_1_1_d3_d11_texture_gpu.html#ad1858af3588de15e9da271d22fe9d5c1":[6,0,0,233,71],
+"class_ogre_1_1_d3_d11_texture_gpu.html#ad0bb22af342ab460495997988c2a6cf9":[6,0,0,233,80],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ad1858af3588de15e9da271d22fe9d5c1":[7,0,0,206,71],
-"class_ogre_1_1_d3_d11_texture_gpu.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,233,97],
+"class_ogre_1_1_d3_d11_texture_gpu.html#ad1858af3588de15e9da271d22fe9d5c1":[6,0,0,233,71],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,206,97],
+"class_ogre_1_1_d3_d11_texture_gpu.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,233,97],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ad3b879c519f45ccb57f91bc45a221f3e":[6,0,0,233,9],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ad3b879c519f45ccb57f91bc45a221f3e":[7,0,0,206,9],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ad623ee0c97e95e276074d3cfd64c374c":[7,0,0,206,2],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ad623ee0c97e95e276074d3cfd64c374c":[6,0,0,233,2],
-"class_ogre_1_1_d3_d11_texture_gpu.html#ad9e5b1428a5fc4fdfaca35292509c716":[6,0,0,233,35],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ad9e5b1428a5fc4fdfaca35292509c716":[7,0,0,206,35],
+"class_ogre_1_1_d3_d11_texture_gpu.html#ad9e5b1428a5fc4fdfaca35292509c716":[6,0,0,233,35],
 "class_ogre_1_1_d3_d11_texture_gpu.html#adaef49d04083efa37638502be9ece306":[7,0,0,206,57],
 "class_ogre_1_1_d3_d11_texture_gpu.html#adaef49d04083efa37638502be9ece306":[6,0,0,233,57],
 "class_ogre_1_1_d3_d11_texture_gpu.html#adc608f61167b7b737a4129cd2b85f5f4":[7,0,0,206,117],
 "class_ogre_1_1_d3_d11_texture_gpu.html#adc608f61167b7b737a4129cd2b85f5f4":[6,0,0,233,117],
-"class_ogre_1_1_d3_d11_texture_gpu.html#adce32528577d71b228692df906ecd17c":[7,0,0,206,100],
 "class_ogre_1_1_d3_d11_texture_gpu.html#adce32528577d71b228692df906ecd17c":[6,0,0,233,100],
+"class_ogre_1_1_d3_d11_texture_gpu.html#adce32528577d71b228692df906ecd17c":[7,0,0,206,100],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ae3e0ad601752b91f2851c88f9ed49869":[7,0,0,206,103],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ae3e0ad601752b91f2851c88f9ed49869":[6,0,0,233,103],
 "class_ogre_1_1_d3_d11_texture_gpu.html#ae641939cec4a57193dab3fc88921b7ae":[6,0,0,233,18],
@@ -191,24 +193,24 @@ var NAVTREEINDEX49 =
 "class_ogre_1_1_d3_d11_texture_gpu.html#ae9039d0b1ef9d873aea7440407b37cb2":[7,0,0,206,54],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aeab133cc1245bb5648652e4369d9497b":[6,0,0,233,60],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aeab133cc1245bb5648652e4369d9497b":[7,0,0,206,60],
-"class_ogre_1_1_d3_d11_texture_gpu.html#aeb11dd2fac1160eaa5ae7ea0d8165581":[6,0,0,233,4],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aeb11dd2fac1160eaa5ae7ea0d8165581":[7,0,0,206,4],
+"class_ogre_1_1_d3_d11_texture_gpu.html#aeb11dd2fac1160eaa5ae7ea0d8165581":[6,0,0,233,4],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aecf4a03c2fa6d5dc8db529d2a61e3e9d":[7,0,0,206,11],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aecf4a03c2fa6d5dc8db529d2a61e3e9d":[6,0,0,233,11],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,233,101],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,206,101],
-"class_ogre_1_1_d3_d11_texture_gpu.html#aed4c74e16ccbdaf8bf82c04a0f7ea2d6":[6,0,0,233,12],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aed4c74e16ccbdaf8bf82c04a0f7ea2d6":[7,0,0,206,12],
-"class_ogre_1_1_d3_d11_texture_gpu.html#aeebb419ba824d0128f437bbe20cc81f9":[7,0,0,206,13],
+"class_ogre_1_1_d3_d11_texture_gpu.html#aed4c74e16ccbdaf8bf82c04a0f7ea2d6":[6,0,0,233,12],
 "class_ogre_1_1_d3_d11_texture_gpu.html#aeebb419ba824d0128f437bbe20cc81f9":[6,0,0,233,13],
+"class_ogre_1_1_d3_d11_texture_gpu.html#aeebb419ba824d0128f437bbe20cc81f9":[7,0,0,206,13],
 "class_ogre_1_1_d3_d11_texture_gpu.html#af042e9ab52c07776f154ee077330f592":[7,0,0,206,119],
 "class_ogre_1_1_d3_d11_texture_gpu.html#af042e9ab52c07776f154ee077330f592":[6,0,0,233,119],
-"class_ogre_1_1_d3_d11_texture_gpu.html#af3e85ec353d2f79da71c96ad69b4048a":[7,0,0,206,43],
 "class_ogre_1_1_d3_d11_texture_gpu.html#af3e85ec353d2f79da71c96ad69b4048a":[6,0,0,233,43],
-"class_ogre_1_1_d3_d11_texture_gpu.html#af7046d90f92e6a950d6d803892ee4b09":[7,0,0,206,6],
+"class_ogre_1_1_d3_d11_texture_gpu.html#af3e85ec353d2f79da71c96ad69b4048a":[7,0,0,206,43],
 "class_ogre_1_1_d3_d11_texture_gpu.html#af7046d90f92e6a950d6d803892ee4b09":[6,0,0,233,6],
-"class_ogre_1_1_d3_d11_texture_gpu.html#af79e22c90559d13385d75dc19970806d":[6,0,0,233,110],
+"class_ogre_1_1_d3_d11_texture_gpu.html#af7046d90f92e6a950d6d803892ee4b09":[7,0,0,206,6],
 "class_ogre_1_1_d3_d11_texture_gpu.html#af79e22c90559d13385d75dc19970806d":[7,0,0,206,110],
+"class_ogre_1_1_d3_d11_texture_gpu.html#af79e22c90559d13385d75dc19970806d":[6,0,0,233,110],
 "class_ogre_1_1_d3_d11_texture_gpu.html#af943f8d1fd87f457fb4633058d696470":[6,0,0,233,74],
 "class_ogre_1_1_d3_d11_texture_gpu.html#af943f8d1fd87f457fb4633058d696470":[7,0,0,206,74],
 "class_ogre_1_1_d3_d11_texture_gpu_manager.html":[5,2,11,26],
@@ -247,7 +249,5 @@ var NAVTREEINDEX49 =
 "class_ogre_1_1_d3_d11_texture_gpu_manager.html#a600e78449c3a438ae7cc67b2a156d2fe":[5,2,11,26,47],
 "class_ogre_1_1_d3_d11_texture_gpu_manager.html#a614a8c355b86c01d9f7b847b670c1cd3":[5,2,11,26,69],
 "class_ogre_1_1_d3_d11_texture_gpu_manager.html#a6350878b702f1a483d73ac5e7de8c45f":[5,2,11,26,43],
-"class_ogre_1_1_d3_d11_texture_gpu_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,26,66],
-"class_ogre_1_1_d3_d11_texture_gpu_manager.html#a68dec5d2c3187c3d7be56d9c5cc55fc4":[5,2,11,26,8],
-"class_ogre_1_1_d3_d11_texture_gpu_manager.html#a6de9d156bb0ef5a625f0f8a6f08a9b19":[5,2,11,26,77]
+"class_ogre_1_1_d3_d11_texture_gpu_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,11,26,66]
 };
