@@ -1,40 +1,42 @@
 var NAVTREEINDEX52 =
 {
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,236,94],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#acc159b3ac817e04b1fa9e69431f8e41d":[7,0,0,209,14],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#acc159b3ac817e04b1fa9e69431f8e41d":[6,0,0,236,14],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#acc59aec11b770b8fc317dea50313d052":[6,0,0,236,31],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#acc59aec11b770b8fc317dea50313d052":[7,0,0,209,31],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#acdde6ea96205d73550d17a18bf4653a4":[6,0,0,236,90],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#acc59aec11b770b8fc317dea50313d052":[6,0,0,236,31],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#acdde6ea96205d73550d17a18bf4653a4":[7,0,0,209,90],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#ace88832ef330c2b560127ca2386c87de":[7,0,0,209,78],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#acdde6ea96205d73550d17a18bf4653a4":[6,0,0,236,90],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ace88832ef330c2b560127ca2386c87de":[6,0,0,236,78],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#ad0bb22af342ab460495997988c2a6cf9":[6,0,0,236,81],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#ace88832ef330c2b560127ca2386c87de":[7,0,0,209,78],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ad0bb22af342ab460495997988c2a6cf9":[7,0,0,209,81],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#ad1858af3588de15e9da271d22fe9d5c1":[6,0,0,236,72],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#ad0bb22af342ab460495997988c2a6cf9":[6,0,0,236,81],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ad1858af3588de15e9da271d22fe9d5c1":[7,0,0,209,72],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#ad1858af3588de15e9da271d22fe9d5c1":[6,0,0,236,72],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,236,98],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,209,98],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#ad3b879c519f45ccb57f91bc45a221f3e":[7,0,0,209,9],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ad3b879c519f45ccb57f91bc45a221f3e":[6,0,0,236,9],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#ad3b879c519f45ccb57f91bc45a221f3e":[7,0,0,209,9],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ad623ee0c97e95e276074d3cfd64c374c":[7,0,0,209,2],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ad623ee0c97e95e276074d3cfd64c374c":[6,0,0,236,2],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ad65e6683a50599a911057cc9d774aa27":[7,0,0,209,11],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ad65e6683a50599a911057cc9d774aa27":[6,0,0,236,11],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#adc608f61167b7b737a4129cd2b85f5f4":[6,0,0,236,118],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#adc608f61167b7b737a4129cd2b85f5f4":[7,0,0,209,118],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#adc608f61167b7b737a4129cd2b85f5f4":[6,0,0,236,118],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,236,101],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,209,101],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ae3e0ad601752b91f2851c88f9ed49869":[7,0,0,209,104],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ae3e0ad601752b91f2851c88f9ed49869":[6,0,0,236,104],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ae5f9574abd474e92f8f20da4145e157f":[6,0,0,236,109],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ae5f9574abd474e92f8f20da4145e157f":[7,0,0,209,109],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#ae641939cec4a57193dab3fc88921b7ae":[7,0,0,209,19],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ae641939cec4a57193dab3fc88921b7ae":[6,0,0,236,19],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#ae6576323b0cf05a3efbf46f9ab5d6e1e":[6,0,0,236,84],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#ae641939cec4a57193dab3fc88921b7ae":[7,0,0,209,19],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#ae6576323b0cf05a3efbf46f9ab5d6e1e":[7,0,0,209,84],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#ae6576323b0cf05a3efbf46f9ab5d6e1e":[6,0,0,236,84],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#aeab133cc1245bb5648652e4369d9497b":[6,0,0,236,61],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#aeab133cc1245bb5648652e4369d9497b":[7,0,0,209,61],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#aeb11dd2fac1160eaa5ae7ea0d8165581":[6,0,0,236,4],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#aeb11dd2fac1160eaa5ae7ea0d8165581":[7,0,0,209,4],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#aeb11dd2fac1160eaa5ae7ea0d8165581":[6,0,0,236,4],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#aec257f859827c5e53670e262211e505e":[7,0,0,209,8],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#aec257f859827c5e53670e262211e505e":[6,0,0,236,8],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,209,102],
@@ -43,38 +45,38 @@ var NAVTREEINDEX52 =
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#aed4c74e16ccbdaf8bf82c04a0f7ea2d6":[6,0,0,236,12],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#aeebb419ba824d0128f437bbe20cc81f9":[7,0,0,209,13],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#aeebb419ba824d0128f437bbe20cc81f9":[6,0,0,236,13],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#af042e9ab52c07776f154ee077330f592":[7,0,0,209,120],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#af042e9ab52c07776f154ee077330f592":[6,0,0,236,120],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#af042e9ab52c07776f154ee077330f592":[7,0,0,209,120],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#af3e85ec353d2f79da71c96ad69b4048a":[6,0,0,236,44],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#af3e85ec353d2f79da71c96ad69b4048a":[7,0,0,209,44],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#af7046d90f92e6a950d6d803892ee4b09":[7,0,0,209,6],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#af7046d90f92e6a950d6d803892ee4b09":[6,0,0,236,6],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#af79e22c90559d13385d75dc19970806d":[7,0,0,209,111],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#af79e22c90559d13385d75dc19970806d":[6,0,0,236,111],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#af943f8d1fd87f457fb4633058d696470":[6,0,0,236,75],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#af943f8d1fd87f457fb4633058d696470":[7,0,0,209,75],
-"class_ogre_1_1_d3_d11_texture_gpu_window.html#afe886084dabc338b0705ce3d792fe0d6":[6,0,0,236,58],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#af943f8d1fd87f457fb4633058d696470":[6,0,0,236,75],
 "class_ogre_1_1_d3_d11_texture_gpu_window.html#afe886084dabc338b0705ce3d792fe0d6":[7,0,0,209,58],
-"class_ogre_1_1_d3_d11_texture_manager.html":[6,0,0,237],
+"class_ogre_1_1_d3_d11_texture_gpu_window.html#afe886084dabc338b0705ce3d792fe0d6":[6,0,0,236,58],
 "class_ogre_1_1_d3_d11_texture_manager.html":[7,0,0,210],
+"class_ogre_1_1_d3_d11_texture_manager.html":[6,0,0,237],
 "class_ogre_1_1_d3_d11_texture_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[7,0,0,210,17],
 "class_ogre_1_1_d3_d11_texture_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[6,0,0,237,17],
-"class_ogre_1_1_d3_d11_texture_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[6,0,0,237,32],
 "class_ogre_1_1_d3_d11_texture_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[7,0,0,210,32],
-"class_ogre_1_1_d3_d11_texture_manager.html#a09b135c03fcee0a9ebfa441e96260a4f":[7,0,0,210,25],
+"class_ogre_1_1_d3_d11_texture_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[6,0,0,237,32],
 "class_ogre_1_1_d3_d11_texture_manager.html#a09b135c03fcee0a9ebfa441e96260a4f":[6,0,0,237,25],
+"class_ogre_1_1_d3_d11_texture_manager.html#a09b135c03fcee0a9ebfa441e96260a4f":[7,0,0,210,25],
 "class_ogre_1_1_d3_d11_texture_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[7,0,0,210,30],
 "class_ogre_1_1_d3_d11_texture_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[6,0,0,237,30],
-"class_ogre_1_1_d3_d11_texture_manager.html#a117a3887bbf9e83e0585777beb0501dc":[6,0,0,237,4],
 "class_ogre_1_1_d3_d11_texture_manager.html#a117a3887bbf9e83e0585777beb0501dc":[7,0,0,210,4],
+"class_ogre_1_1_d3_d11_texture_manager.html#a117a3887bbf9e83e0585777beb0501dc":[6,0,0,237,4],
 "class_ogre_1_1_d3_d11_texture_manager.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,237,45],
 "class_ogre_1_1_d3_d11_texture_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,210,45],
-"class_ogre_1_1_d3_d11_texture_manager.html#a1db642a9eef36b32dbdea28d19e8ea0d":[7,0,0,210,40],
 "class_ogre_1_1_d3_d11_texture_manager.html#a1db642a9eef36b32dbdea28d19e8ea0d":[6,0,0,237,40],
+"class_ogre_1_1_d3_d11_texture_manager.html#a1db642a9eef36b32dbdea28d19e8ea0d":[7,0,0,210,40],
 "class_ogre_1_1_d3_d11_texture_manager.html#a1f3ce30531f94b25d95f5009d410b8a2":[7,0,0,210,6],
 "class_ogre_1_1_d3_d11_texture_manager.html#a1f3ce30531f94b25d95f5009d410b8a2":[6,0,0,237,6],
-"class_ogre_1_1_d3_d11_texture_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[6,0,0,237,74],
 "class_ogre_1_1_d3_d11_texture_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[7,0,0,210,74],
+"class_ogre_1_1_d3_d11_texture_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[6,0,0,237,74],
 "class_ogre_1_1_d3_d11_texture_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[7,0,0,210,2],
 "class_ogre_1_1_d3_d11_texture_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[6,0,0,237,2],
 "class_ogre_1_1_d3_d11_texture_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[7,0,0,210,1],
@@ -91,80 +93,80 @@ var NAVTREEINDEX52 =
 "class_ogre_1_1_d3_d11_texture_manager.html#a3cc7b930d37bc9fc156f7a2cadb572a3":[6,0,0,237,21],
 "class_ogre_1_1_d3_d11_texture_manager.html#a3f92489910e40e3756606a35618d7b06":[7,0,0,210,59],
 "class_ogre_1_1_d3_d11_texture_manager.html#a3f92489910e40e3756606a35618d7b06":[6,0,0,237,59],
-"class_ogre_1_1_d3_d11_texture_manager.html#a40769092850d5b296e1d1a9190631700":[6,0,0,237,8],
 "class_ogre_1_1_d3_d11_texture_manager.html#a40769092850d5b296e1d1a9190631700":[7,0,0,210,8],
+"class_ogre_1_1_d3_d11_texture_manager.html#a40769092850d5b296e1d1a9190631700":[6,0,0,237,8],
 "class_ogre_1_1_d3_d11_texture_manager.html#a42ae3de59dd5ccfd449645ec4af1143c":[7,0,0,210,34],
 "class_ogre_1_1_d3_d11_texture_manager.html#a42ae3de59dd5ccfd449645ec4af1143c":[6,0,0,237,34],
-"class_ogre_1_1_d3_d11_texture_manager.html#a42f172a8ed1625011d510b081eee66dd":[7,0,0,210,22],
 "class_ogre_1_1_d3_d11_texture_manager.html#a42f172a8ed1625011d510b081eee66dd":[6,0,0,237,22],
-"class_ogre_1_1_d3_d11_texture_manager.html#a45d8b138d17f258816383140ca765aa3":[7,0,0,210,55],
+"class_ogre_1_1_d3_d11_texture_manager.html#a42f172a8ed1625011d510b081eee66dd":[7,0,0,210,22],
 "class_ogre_1_1_d3_d11_texture_manager.html#a45d8b138d17f258816383140ca765aa3":[6,0,0,237,55],
-"class_ogre_1_1_d3_d11_texture_manager.html#a48c565d0e63b286c6388439ae73417df":[7,0,0,210,13],
+"class_ogre_1_1_d3_d11_texture_manager.html#a45d8b138d17f258816383140ca765aa3":[7,0,0,210,55],
 "class_ogre_1_1_d3_d11_texture_manager.html#a48c565d0e63b286c6388439ae73417df":[6,0,0,237,13],
-"class_ogre_1_1_d3_d11_texture_manager.html#a49a47b8919269342243265df3bd1e1fc":[6,0,0,237,27],
+"class_ogre_1_1_d3_d11_texture_manager.html#a48c565d0e63b286c6388439ae73417df":[7,0,0,210,13],
 "class_ogre_1_1_d3_d11_texture_manager.html#a49a47b8919269342243265df3bd1e1fc":[7,0,0,210,27],
-"class_ogre_1_1_d3_d11_texture_manager.html#a4d3289d4636168230da11c1c9794db59":[6,0,0,237,29],
+"class_ogre_1_1_d3_d11_texture_manager.html#a49a47b8919269342243265df3bd1e1fc":[6,0,0,237,27],
 "class_ogre_1_1_d3_d11_texture_manager.html#a4d3289d4636168230da11c1c9794db59":[7,0,0,210,29],
+"class_ogre_1_1_d3_d11_texture_manager.html#a4d3289d4636168230da11c1c9794db59":[6,0,0,237,29],
 "class_ogre_1_1_d3_d11_texture_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[7,0,0,210,58],
 "class_ogre_1_1_d3_d11_texture_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[6,0,0,237,58],
 "class_ogre_1_1_d3_d11_texture_manager.html#a4f00d9cf3ea35b9804e5ce10d45d2fff":[7,0,0,210,12],
 "class_ogre_1_1_d3_d11_texture_manager.html#a4f00d9cf3ea35b9804e5ce10d45d2fff":[6,0,0,237,12],
-"class_ogre_1_1_d3_d11_texture_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[6,0,0,237,3],
 "class_ogre_1_1_d3_d11_texture_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[7,0,0,210,3],
+"class_ogre_1_1_d3_d11_texture_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[6,0,0,237,3],
 "class_ogre_1_1_d3_d11_texture_manager.html#a515b0fd5ae01a4d07254d44e81d45274":[7,0,0,210,5],
 "class_ogre_1_1_d3_d11_texture_manager.html#a515b0fd5ae01a4d07254d44e81d45274":[6,0,0,237,5],
-"class_ogre_1_1_d3_d11_texture_manager.html#a54d1843a43aebb13542312cd17134e6a":[6,0,0,237,9],
 "class_ogre_1_1_d3_d11_texture_manager.html#a54d1843a43aebb13542312cd17134e6a":[7,0,0,210,9],
-"class_ogre_1_1_d3_d11_texture_manager.html#a57e22b305d763f9ede5bda93f31051ca":[6,0,0,237,31],
+"class_ogre_1_1_d3_d11_texture_manager.html#a54d1843a43aebb13542312cd17134e6a":[6,0,0,237,9],
 "class_ogre_1_1_d3_d11_texture_manager.html#a57e22b305d763f9ede5bda93f31051ca":[7,0,0,210,31],
-"class_ogre_1_1_d3_d11_texture_manager.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,210,47],
+"class_ogre_1_1_d3_d11_texture_manager.html#a57e22b305d763f9ede5bda93f31051ca":[6,0,0,237,31],
 "class_ogre_1_1_d3_d11_texture_manager.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,237,47],
-"class_ogre_1_1_d3_d11_texture_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,210,50],
+"class_ogre_1_1_d3_d11_texture_manager.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,210,47],
 "class_ogre_1_1_d3_d11_texture_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,237,50],
-"class_ogre_1_1_d3_d11_texture_manager.html#a65730ea50a81401518b4cbf6bb6a0a73":[7,0,0,210,37],
+"class_ogre_1_1_d3_d11_texture_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,210,50],
 "class_ogre_1_1_d3_d11_texture_manager.html#a65730ea50a81401518b4cbf6bb6a0a73":[6,0,0,237,37],
+"class_ogre_1_1_d3_d11_texture_manager.html#a65730ea50a81401518b4cbf6bb6a0a73":[7,0,0,210,37],
 "class_ogre_1_1_d3_d11_texture_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[7,0,0,210,28],
 "class_ogre_1_1_d3_d11_texture_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[6,0,0,237,28],
-"class_ogre_1_1_d3_d11_texture_manager.html#a69555b9ae434b8dbf2783395fa59191e":[6,0,0,237,38],
 "class_ogre_1_1_d3_d11_texture_manager.html#a69555b9ae434b8dbf2783395fa59191e":[7,0,0,210,38],
+"class_ogre_1_1_d3_d11_texture_manager.html#a69555b9ae434b8dbf2783395fa59191e":[6,0,0,237,38],
 "class_ogre_1_1_d3_d11_texture_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[6,0,0,237,63],
 "class_ogre_1_1_d3_d11_texture_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[7,0,0,210,63],
-"class_ogre_1_1_d3_d11_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[7,0,0,210,62],
 "class_ogre_1_1_d3_d11_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[6,0,0,237,62],
-"class_ogre_1_1_d3_d11_texture_manager.html#a77d097944def071bd10e1c2a03fc5b2c":[7,0,0,210,69],
+"class_ogre_1_1_d3_d11_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[7,0,0,210,62],
 "class_ogre_1_1_d3_d11_texture_manager.html#a77d097944def071bd10e1c2a03fc5b2c":[6,0,0,237,69],
+"class_ogre_1_1_d3_d11_texture_manager.html#a77d097944def071bd10e1c2a03fc5b2c":[7,0,0,210,69],
 "class_ogre_1_1_d3_d11_texture_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[7,0,0,210,16],
 "class_ogre_1_1_d3_d11_texture_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[6,0,0,237,16],
 "class_ogre_1_1_d3_d11_texture_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[7,0,0,210,53],
 "class_ogre_1_1_d3_d11_texture_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[6,0,0,237,53],
 "class_ogre_1_1_d3_d11_texture_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,210,43],
 "class_ogre_1_1_d3_d11_texture_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,237,43],
-"class_ogre_1_1_d3_d11_texture_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[6,0,0,237,57],
 "class_ogre_1_1_d3_d11_texture_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[7,0,0,210,57],
-"class_ogre_1_1_d3_d11_texture_manager.html#a8faa10c9150687d1bf229ccff16a8960":[6,0,0,237,33],
+"class_ogre_1_1_d3_d11_texture_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[6,0,0,237,57],
 "class_ogre_1_1_d3_d11_texture_manager.html#a8faa10c9150687d1bf229ccff16a8960":[7,0,0,210,33],
-"class_ogre_1_1_d3_d11_texture_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[6,0,0,237,75],
+"class_ogre_1_1_d3_d11_texture_manager.html#a8faa10c9150687d1bf229ccff16a8960":[6,0,0,237,33],
 "class_ogre_1_1_d3_d11_texture_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[7,0,0,210,75],
+"class_ogre_1_1_d3_d11_texture_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[6,0,0,237,75],
 "class_ogre_1_1_d3_d11_texture_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,237,46],
 "class_ogre_1_1_d3_d11_texture_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,210,46],
-"class_ogre_1_1_d3_d11_texture_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[6,0,0,237,73],
 "class_ogre_1_1_d3_d11_texture_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[7,0,0,210,73],
+"class_ogre_1_1_d3_d11_texture_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[6,0,0,237,73],
 "class_ogre_1_1_d3_d11_texture_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[6,0,0,237,64],
 "class_ogre_1_1_d3_d11_texture_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[7,0,0,210,64],
-"class_ogre_1_1_d3_d11_texture_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[7,0,0,210,24],
 "class_ogre_1_1_d3_d11_texture_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[6,0,0,237,24],
-"class_ogre_1_1_d3_d11_texture_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[6,0,0,237,71],
+"class_ogre_1_1_d3_d11_texture_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[7,0,0,210,24],
 "class_ogre_1_1_d3_d11_texture_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[7,0,0,210,71],
+"class_ogre_1_1_d3_d11_texture_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[6,0,0,237,71],
 "class_ogre_1_1_d3_d11_texture_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[7,0,0,210,67],
 "class_ogre_1_1_d3_d11_texture_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[6,0,0,237,67],
 "class_ogre_1_1_d3_d11_texture_manager.html#aa8b761abb06d74347e9636550307ccd9":[6,0,0,237,18],
 "class_ogre_1_1_d3_d11_texture_manager.html#aa8b761abb06d74347e9636550307ccd9":[7,0,0,210,18],
-"class_ogre_1_1_d3_d11_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[6,0,0,237,56],
 "class_ogre_1_1_d3_d11_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[7,0,0,210,56],
+"class_ogre_1_1_d3_d11_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[6,0,0,237,56],
 "class_ogre_1_1_d3_d11_texture_manager.html#aaaa53651124f3773fbcf6ae2b4a6fbe5":[7,0,0,210,70],
 "class_ogre_1_1_d3_d11_texture_manager.html#aaaa53651124f3773fbcf6ae2b4a6fbe5":[6,0,0,237,70],
-"class_ogre_1_1_d3_d11_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[6,0,0,237,41],
 "class_ogre_1_1_d3_d11_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[7,0,0,210,41],
+"class_ogre_1_1_d3_d11_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[6,0,0,237,41],
 "class_ogre_1_1_d3_d11_texture_manager.html#ab194cb5e332fc3eb35591e468f5dbcd3":[7,0,0,210,66],
 "class_ogre_1_1_d3_d11_texture_manager.html#ab194cb5e332fc3eb35591e468f5dbcd3":[6,0,0,237,66],
 "class_ogre_1_1_d3_d11_texture_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[6,0,0,237,19],
@@ -177,32 +179,32 @@ var NAVTREEINDEX52 =
 "class_ogre_1_1_d3_d11_texture_manager.html#abbbab1db9a334e39c2114ee3a21b013f":[7,0,0,210,36],
 "class_ogre_1_1_d3_d11_texture_manager.html#abfb0022b18d022a7605f0d19a966f00f":[7,0,0,210,60],
 "class_ogre_1_1_d3_d11_texture_manager.html#abfb0022b18d022a7605f0d19a966f00f":[6,0,0,237,60],
-"class_ogre_1_1_d3_d11_texture_manager.html#ac22655af03ecea85d863a1d1d561778c":[7,0,0,210,61],
 "class_ogre_1_1_d3_d11_texture_manager.html#ac22655af03ecea85d863a1d1d561778c":[6,0,0,237,61],
-"class_ogre_1_1_d3_d11_texture_manager.html#ac8f7ee61606730572a8590060d8896a0":[6,0,0,237,23],
+"class_ogre_1_1_d3_d11_texture_manager.html#ac22655af03ecea85d863a1d1d561778c":[7,0,0,210,61],
 "class_ogre_1_1_d3_d11_texture_manager.html#ac8f7ee61606730572a8590060d8896a0":[7,0,0,210,23],
-"class_ogre_1_1_d3_d11_texture_manager.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,237,44],
+"class_ogre_1_1_d3_d11_texture_manager.html#ac8f7ee61606730572a8590060d8896a0":[6,0,0,237,23],
 "class_ogre_1_1_d3_d11_texture_manager.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,210,44],
+"class_ogre_1_1_d3_d11_texture_manager.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,237,44],
 "class_ogre_1_1_d3_d11_texture_manager.html#acd4223279e97a7687e2f9994f05e2491":[7,0,0,210,15],
 "class_ogre_1_1_d3_d11_texture_manager.html#acd4223279e97a7687e2f9994f05e2491":[6,0,0,237,15],
 "class_ogre_1_1_d3_d11_texture_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,237,48],
 "class_ogre_1_1_d3_d11_texture_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,210,48],
 "class_ogre_1_1_d3_d11_texture_manager.html#ad6d63fe7126510bf10fd337705cb0b29":[6,0,0,237,39],
 "class_ogre_1_1_d3_d11_texture_manager.html#ad6d63fe7126510bf10fd337705cb0b29":[7,0,0,210,39],
-"class_ogre_1_1_d3_d11_texture_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[6,0,0,237,65],
 "class_ogre_1_1_d3_d11_texture_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[7,0,0,210,65],
-"class_ogre_1_1_d3_d11_texture_manager.html#adce32528577d71b228692df906ecd17c":[6,0,0,237,51],
+"class_ogre_1_1_d3_d11_texture_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[6,0,0,237,65],
 "class_ogre_1_1_d3_d11_texture_manager.html#adce32528577d71b228692df906ecd17c":[7,0,0,210,51],
-"class_ogre_1_1_d3_d11_texture_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[7,0,0,210,54],
+"class_ogre_1_1_d3_d11_texture_manager.html#adce32528577d71b228692df906ecd17c":[6,0,0,237,51],
 "class_ogre_1_1_d3_d11_texture_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[6,0,0,237,54],
+"class_ogre_1_1_d3_d11_texture_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[7,0,0,210,54],
 "class_ogre_1_1_d3_d11_texture_manager.html#ae63b06c1fd6d1266b4c5dacc35e521b4":[6,0,0,237,10],
 "class_ogre_1_1_d3_d11_texture_manager.html#ae63b06c1fd6d1266b4c5dacc35e521b4":[7,0,0,210,10],
 "class_ogre_1_1_d3_d11_texture_manager.html#aeaa1410333b7bcea14b00c360112a528":[6,0,0,237,76],
 "class_ogre_1_1_d3_d11_texture_manager.html#aeaa1410333b7bcea14b00c360112a528":[7,0,0,210,76],
 "class_ogre_1_1_d3_d11_texture_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,210,52],
 "class_ogre_1_1_d3_d11_texture_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,237,52],
-"class_ogre_1_1_d3_d11_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[6,0,0,237,7],
 "class_ogre_1_1_d3_d11_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[7,0,0,210,7],
+"class_ogre_1_1_d3_d11_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[6,0,0,237,7],
 "class_ogre_1_1_d3_d11_texture_manager.html#af2cae9ecc99635a541df72ae7cdd337a":[6,0,0,237,68],
 "class_ogre_1_1_d3_d11_texture_manager.html#af2cae9ecc99635a541df72ae7cdd337a":[7,0,0,210,68],
 "class_ogre_1_1_d3_d11_texture_manager.html#af33a91a3a918df919de56635b13a532e":[7,0,0,210,11],
@@ -211,28 +213,28 @@ var NAVTREEINDEX52 =
 "class_ogre_1_1_d3_d11_texture_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[6,0,0,237,0],
 "class_ogre_1_1_d3_d11_texture_manager.html#af4b66fba75a4c341bd1c1dd16decfec8":[6,0,0,237,20],
 "class_ogre_1_1_d3_d11_texture_manager.html#af4b66fba75a4c341bd1c1dd16decfec8":[7,0,0,210,20],
-"class_ogre_1_1_d3_d11_texture_manager.html#af96b58b31c152a8ae3c6152ee3ea12e7":[7,0,0,210,35],
 "class_ogre_1_1_d3_d11_texture_manager.html#af96b58b31c152a8ae3c6152ee3ea12e7":[6,0,0,237,35],
+"class_ogre_1_1_d3_d11_texture_manager.html#af96b58b31c152a8ae3c6152ee3ea12e7":[7,0,0,210,35],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html":[7,0,0,211],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html":[6,0,0,238],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a0409f331e3df0a784b3067f6a23fefe0":[7,0,0,211,10],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a0409f331e3df0a784b3067f6a23fefe0":[6,0,0,238,10],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a08b7bfb98310a65e4bdac7bd1f59be23":[6,0,0,238,17],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a08b7bfb98310a65e4bdac7bd1f59be23":[7,0,0,211,17],
-"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[6,0,0,238,43],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[7,0,0,211,43],
+"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[6,0,0,238,43],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[6,0,0,238,26],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[7,0,0,211,26],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[7,0,0,211,11],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[6,0,0,238,11],
-"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,238,32],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,211,32],
+"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,238,32],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[6,0,0,238,9],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[7,0,0,211,9],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[6,0,0,238,29],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[7,0,0,211,29],
-"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[7,0,0,211,18],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[6,0,0,238,18],
+"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[7,0,0,211,18],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[6,0,0,238,25],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[7,0,0,211,25],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a3d389b0aae18bb6dcb82af84c93b77de":[7,0,0,211,28],
@@ -245,9 +247,7 @@ var NAVTREEINDEX52 =
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a4eebb429f8f6905c692f0543d3390c4c":[6,0,0,238,12],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a4f4a89f5f9d89f1dbb5b605dbc1cbddb":[6,0,0,238,14],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a4f4a89f5f9d89f1dbb5b605dbc1cbddb":[7,0,0,211,14],
-"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a50080eb729acd0c995606d512d5633c9":[7,0,0,211,20],
 "class_ogre_1_1_d3_d11_uav_buffer_packed.html#a50080eb729acd0c995606d512d5633c9":[6,0,0,238,20],
-"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a542b46fc7a7cf5fe524cfc7b4b389ba9":[7,0,0,211,22],
-"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a542b46fc7a7cf5fe524cfc7b4b389ba9":[6,0,0,238,22],
-"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a564935579f2252627f46dff29142e7ff":[7,0,0,211,8]
+"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a50080eb729acd0c995606d512d5633c9":[7,0,0,211,20],
+"class_ogre_1_1_d3_d11_uav_buffer_packed.html#a542b46fc7a7cf5fe524cfc7b4b389ba9":[7,0,0,211,22]
 };
