@@ -1,174 +1,176 @@
 var NAVTREEINDEX54 =
 {
+"class_ogre_1_1_d3_d11_video_mode.html#aed2d01b995a1b9cbb438fe44e42f4e92":[7,0,0,216,3],
 "class_ogre_1_1_d3_d11_video_mode_list.html":[6,0,0,244],
-"class_ogre_1_1_d3_d11_video_mode_list.html#a159cf065f3de2af60f04d57dd7690d05":[6,0,0,244,2],
+"class_ogre_1_1_d3_d11_video_mode_list.html":[7,0,0,217],
 "class_ogre_1_1_d3_d11_video_mode_list.html#a159cf065f3de2af60f04d57dd7690d05":[7,0,0,217,2],
+"class_ogre_1_1_d3_d11_video_mode_list.html#a159cf065f3de2af60f04d57dd7690d05":[6,0,0,244,2],
 "class_ogre_1_1_d3_d11_video_mode_list.html#a75ec75aa7fc68122461aad21269045be":[7,0,0,217,3],
 "class_ogre_1_1_d3_d11_video_mode_list.html#a75ec75aa7fc68122461aad21269045be":[6,0,0,244,3],
-"class_ogre_1_1_d3_d11_video_mode_list.html#a9bc61e9b1d5327a7687e548c621292f7":[7,0,0,217,0],
 "class_ogre_1_1_d3_d11_video_mode_list.html#a9bc61e9b1d5327a7687e548c621292f7":[6,0,0,244,0],
+"class_ogre_1_1_d3_d11_video_mode_list.html#a9bc61e9b1d5327a7687e548c621292f7":[7,0,0,217,0],
 "class_ogre_1_1_d3_d11_video_mode_list.html#ac9bc902a956c2cc7fb4948f5066720c3":[7,0,0,217,1],
 "class_ogre_1_1_d3_d11_video_mode_list.html#ac9bc902a956c2cc7fb4948f5066720c3":[6,0,0,244,1],
-"class_ogre_1_1_d3_d11_window.html":[6,0,0,245],
 "class_ogre_1_1_d3_d11_window.html":[7,0,0,218],
+"class_ogre_1_1_d3_d11_window.html":[6,0,0,245],
 "class_ogre_1_1_d3_d11_window.html#a09d75f1c1eec5dd8cd06297b76245de6":[7,0,0,218,24],
 "class_ogre_1_1_d3_d11_window.html#a09d75f1c1eec5dd8cd06297b76245de6":[6,0,0,245,24],
 "class_ogre_1_1_d3_d11_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,245,46],
 "class_ogre_1_1_d3_d11_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[7,0,0,218,46],
 "class_ogre_1_1_d3_d11_window.html#a12411d378aa0623e29287964eeb261c4":[7,0,0,218,20],
 "class_ogre_1_1_d3_d11_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,245,20],
-"class_ogre_1_1_d3_d11_window.html#a1284a6c13adf9c244e4dcc2f973d7749":[6,0,0,245,43],
 "class_ogre_1_1_d3_d11_window.html#a1284a6c13adf9c244e4dcc2f973d7749":[7,0,0,218,43],
-"class_ogre_1_1_d3_d11_window.html#a14c0ef3312945158ad042463bef69e74":[7,0,0,218,30],
+"class_ogre_1_1_d3_d11_window.html#a1284a6c13adf9c244e4dcc2f973d7749":[6,0,0,245,43],
 "class_ogre_1_1_d3_d11_window.html#a14c0ef3312945158ad042463bef69e74":[6,0,0,245,30],
-"class_ogre_1_1_d3_d11_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,218,33],
+"class_ogre_1_1_d3_d11_window.html#a14c0ef3312945158ad042463bef69e74":[7,0,0,218,30],
 "class_ogre_1_1_d3_d11_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,245,33],
-"class_ogre_1_1_d3_d11_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,218,28],
+"class_ogre_1_1_d3_d11_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,218,33],
 "class_ogre_1_1_d3_d11_window.html#a22779bbfb123c76e922942ba876e330a":[6,0,0,245,28],
-"class_ogre_1_1_d3_d11_window.html#a2d5423c38fb53d7346a00c0e7e582347":[6,0,0,245,42],
+"class_ogre_1_1_d3_d11_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,218,28],
 "class_ogre_1_1_d3_d11_window.html#a2d5423c38fb53d7346a00c0e7e582347":[7,0,0,218,42],
-"class_ogre_1_1_d3_d11_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,218,19],
+"class_ogre_1_1_d3_d11_window.html#a2d5423c38fb53d7346a00c0e7e582347":[6,0,0,245,42],
 "class_ogre_1_1_d3_d11_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[6,0,0,245,19],
-"class_ogre_1_1_d3_d11_window.html#a462859aeb6b4db7290622623dae2a6a4":[7,0,0,218,25],
+"class_ogre_1_1_d3_d11_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,218,19],
 "class_ogre_1_1_d3_d11_window.html#a462859aeb6b4db7290622623dae2a6a4":[6,0,0,245,25],
+"class_ogre_1_1_d3_d11_window.html#a462859aeb6b4db7290622623dae2a6a4":[7,0,0,218,25],
 "class_ogre_1_1_d3_d11_window.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,245,35],
 "class_ogre_1_1_d3_d11_window.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,218,35],
-"class_ogre_1_1_d3_d11_window.html#a5a97866f3f7ce86466fbe8ef775d7301":[7,0,0,218,7],
 "class_ogre_1_1_d3_d11_window.html#a5a97866f3f7ce86466fbe8ef775d7301":[6,0,0,245,7],
-"class_ogre_1_1_d3_d11_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,218,38],
+"class_ogre_1_1_d3_d11_window.html#a5a97866f3f7ce86466fbe8ef775d7301":[7,0,0,218,7],
 "class_ogre_1_1_d3_d11_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,245,38],
-"class_ogre_1_1_d3_d11_window.html#a6649ad876d350f201b59b45b20b57108":[7,0,0,218,4],
+"class_ogre_1_1_d3_d11_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,218,38],
 "class_ogre_1_1_d3_d11_window.html#a6649ad876d350f201b59b45b20b57108":[6,0,0,245,4],
-"class_ogre_1_1_d3_d11_window.html#a67ba7307754a41632bb41c383191bba7":[7,0,0,218,6],
+"class_ogre_1_1_d3_d11_window.html#a6649ad876d350f201b59b45b20b57108":[7,0,0,218,4],
 "class_ogre_1_1_d3_d11_window.html#a67ba7307754a41632bb41c383191bba7":[6,0,0,245,6],
+"class_ogre_1_1_d3_d11_window.html#a67ba7307754a41632bb41c383191bba7":[7,0,0,218,6],
 "class_ogre_1_1_d3_d11_window.html#a67e3922f9cdc6d2b8bfaa2e4ccfed206":[7,0,0,218,41],
 "class_ogre_1_1_d3_d11_window.html#a67e3922f9cdc6d2b8bfaa2e4ccfed206":[6,0,0,245,41],
-"class_ogre_1_1_d3_d11_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[7,0,0,218,22],
 "class_ogre_1_1_d3_d11_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[6,0,0,245,22],
+"class_ogre_1_1_d3_d11_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[7,0,0,218,22],
 "class_ogre_1_1_d3_d11_window.html#a70cfe4412cfa68a9423854fc1b19872e":[7,0,0,218,9],
 "class_ogre_1_1_d3_d11_window.html#a70cfe4412cfa68a9423854fc1b19872e":[6,0,0,245,9],
 "class_ogre_1_1_d3_d11_window.html#a75261d46e5f123e31ab4f889b8788e5f":[7,0,0,218,18],
 "class_ogre_1_1_d3_d11_window.html#a75261d46e5f123e31ab4f889b8788e5f":[6,0,0,245,18],
-"class_ogre_1_1_d3_d11_window.html#a766fc30be7bb699389532945f13dc2d3":[6,0,0,245,0],
 "class_ogre_1_1_d3_d11_window.html#a766fc30be7bb699389532945f13dc2d3":[7,0,0,218,0],
+"class_ogre_1_1_d3_d11_window.html#a766fc30be7bb699389532945f13dc2d3":[6,0,0,245,0],
 "class_ogre_1_1_d3_d11_window.html#a76b56f475ba7474c83760b557c34c6a5":[6,0,0,245,49],
 "class_ogre_1_1_d3_d11_window.html#a76b56f475ba7474c83760b557c34c6a5":[7,0,0,218,49],
 "class_ogre_1_1_d3_d11_window.html#a7c9f7111539b0d1e859caa947f9e8220":[7,0,0,218,47],
 "class_ogre_1_1_d3_d11_window.html#a7c9f7111539b0d1e859caa947f9e8220":[6,0,0,245,47],
-"class_ogre_1_1_d3_d11_window.html#a7cab14f9a69e0b87d42e72f4ab237640":[6,0,0,245,1],
 "class_ogre_1_1_d3_d11_window.html#a7cab14f9a69e0b87d42e72f4ab237640":[7,0,0,218,1],
+"class_ogre_1_1_d3_d11_window.html#a7cab14f9a69e0b87d42e72f4ab237640":[6,0,0,245,1],
 "class_ogre_1_1_d3_d11_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[6,0,0,245,45],
 "class_ogre_1_1_d3_d11_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[7,0,0,218,45],
 "class_ogre_1_1_d3_d11_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[7,0,0,218,23],
 "class_ogre_1_1_d3_d11_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[6,0,0,245,23],
-"class_ogre_1_1_d3_d11_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,218,31],
 "class_ogre_1_1_d3_d11_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,245,31],
+"class_ogre_1_1_d3_d11_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,218,31],
 "class_ogre_1_1_d3_d11_window.html#a84739cd779700fa8d7991c9cf11c289d":[6,0,0,245,21],
 "class_ogre_1_1_d3_d11_window.html#a84739cd779700fa8d7991c9cf11c289d":[7,0,0,218,21],
 "class_ogre_1_1_d3_d11_window.html#a8a464e98db9c09042b866bdb95b210f4":[6,0,0,245,12],
 "class_ogre_1_1_d3_d11_window.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,218,12],
-"class_ogre_1_1_d3_d11_window.html#a8b05fabc7b8b6cf3129279629562476d":[6,0,0,245,14],
 "class_ogre_1_1_d3_d11_window.html#a8b05fabc7b8b6cf3129279629562476d":[7,0,0,218,14],
+"class_ogre_1_1_d3_d11_window.html#a8b05fabc7b8b6cf3129279629562476d":[6,0,0,245,14],
 "class_ogre_1_1_d3_d11_window.html#a8c1bb2ab75cacd7d2b470406d33f427d":[6,0,0,245,27],
 "class_ogre_1_1_d3_d11_window.html#a8c1bb2ab75cacd7d2b470406d33f427d":[7,0,0,218,27],
-"class_ogre_1_1_d3_d11_window.html#a8d7e786602979fc29169555056834c65":[6,0,0,245,10],
 "class_ogre_1_1_d3_d11_window.html#a8d7e786602979fc29169555056834c65":[7,0,0,218,10],
+"class_ogre_1_1_d3_d11_window.html#a8d7e786602979fc29169555056834c65":[6,0,0,245,10],
 "class_ogre_1_1_d3_d11_window.html#a92d426a5762a35639ab102cfcbcaedf5":[6,0,0,245,29],
 "class_ogre_1_1_d3_d11_window.html#a92d426a5762a35639ab102cfcbcaedf5":[7,0,0,218,29],
-"class_ogre_1_1_d3_d11_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,245,34],
 "class_ogre_1_1_d3_d11_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,218,34],
-"class_ogre_1_1_d3_d11_window.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,218,13],
+"class_ogre_1_1_d3_d11_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,245,34],
 "class_ogre_1_1_d3_d11_window.html#a9439f12db8a964f79f4b743493a0fd75":[6,0,0,245,13],
-"class_ogre_1_1_d3_d11_window.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,245,15],
+"class_ogre_1_1_d3_d11_window.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,218,13],
 "class_ogre_1_1_d3_d11_window.html#a98f49dbefa207210a2f4c0025848b93c":[7,0,0,218,15],
+"class_ogre_1_1_d3_d11_window.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,245,15],
 "class_ogre_1_1_d3_d11_window.html#a9a3958eb8e9dbcd44ad87f480f3bd40d":[7,0,0,218,2],
 "class_ogre_1_1_d3_d11_window.html#a9a3958eb8e9dbcd44ad87f480f3bd40d":[6,0,0,245,2],
-"class_ogre_1_1_d3_d11_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[7,0,0,218,44],
 "class_ogre_1_1_d3_d11_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[6,0,0,245,44],
+"class_ogre_1_1_d3_d11_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[7,0,0,218,44],
 "class_ogre_1_1_d3_d11_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[7,0,0,218,52],
 "class_ogre_1_1_d3_d11_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[6,0,0,245,52],
 "class_ogre_1_1_d3_d11_window.html#aae6dcff474c7222cd2cb047540a50852":[7,0,0,218,50],
 "class_ogre_1_1_d3_d11_window.html#aae6dcff474c7222cd2cb047540a50852":[6,0,0,245,50],
-"class_ogre_1_1_d3_d11_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,245,37],
 "class_ogre_1_1_d3_d11_window.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,218,37],
-"class_ogre_1_1_d3_d11_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,245,3],
+"class_ogre_1_1_d3_d11_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,245,37],
 "class_ogre_1_1_d3_d11_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[7,0,0,218,3],
-"class_ogre_1_1_d3_d11_window.html#abffec246be83d1df9c7a8c6ecb0249ea":[6,0,0,245,53],
+"class_ogre_1_1_d3_d11_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,245,3],
 "class_ogre_1_1_d3_d11_window.html#abffec246be83d1df9c7a8c6ecb0249ea":[7,0,0,218,53],
+"class_ogre_1_1_d3_d11_window.html#abffec246be83d1df9c7a8c6ecb0249ea":[6,0,0,245,53],
 "class_ogre_1_1_d3_d11_window.html#ac344214fa2a1ead13bb78f73712f69a3":[7,0,0,218,51],
 "class_ogre_1_1_d3_d11_window.html#ac344214fa2a1ead13bb78f73712f69a3":[6,0,0,245,51],
-"class_ogre_1_1_d3_d11_window.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,245,8],
 "class_ogre_1_1_d3_d11_window.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,218,8],
+"class_ogre_1_1_d3_d11_window.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,245,8],
 "class_ogre_1_1_d3_d11_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,218,32],
 "class_ogre_1_1_d3_d11_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,245,32],
-"class_ogre_1_1_d3_d11_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,245,16],
 "class_ogre_1_1_d3_d11_window.html#ad15462609bf45808fb04668cc1c28c78":[7,0,0,218,16],
+"class_ogre_1_1_d3_d11_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,245,16],
 "class_ogre_1_1_d3_d11_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,218,36],
 "class_ogre_1_1_d3_d11_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,245,36],
-"class_ogre_1_1_d3_d11_window.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,245,48],
 "class_ogre_1_1_d3_d11_window.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,218,48],
-"class_ogre_1_1_d3_d11_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[6,0,0,245,26],
+"class_ogre_1_1_d3_d11_window.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,245,48],
 "class_ogre_1_1_d3_d11_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[7,0,0,218,26],
+"class_ogre_1_1_d3_d11_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[6,0,0,245,26],
 "class_ogre_1_1_d3_d11_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,245,17],
 "class_ogre_1_1_d3_d11_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[7,0,0,218,17],
-"class_ogre_1_1_d3_d11_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,218,39],
 "class_ogre_1_1_d3_d11_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,245,39],
+"class_ogre_1_1_d3_d11_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,218,39],
 "class_ogre_1_1_d3_d11_window.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,245,11],
 "class_ogre_1_1_d3_d11_window.html#add8e20491fc0e054c9cab3c75297c6ec":[7,0,0,218,11],
-"class_ogre_1_1_d3_d11_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,245,40],
 "class_ogre_1_1_d3_d11_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,218,40],
+"class_ogre_1_1_d3_d11_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,245,40],
 "class_ogre_1_1_d3_d11_window.html#af422e9aa4ffd140769b406ad2f7f5551":[7,0,0,218,5],
 "class_ogre_1_1_d3_d11_window.html#af422e9aa4ffd140769b406ad2f7f5551":[6,0,0,245,5],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html":[7,0,0,219],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html":[6,0,0,246],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a09d75f1c1eec5dd8cd06297b76245de6":[6,0,0,246,24],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a09d75f1c1eec5dd8cd06297b76245de6":[7,0,0,219,24],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,246,20],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a09d75f1c1eec5dd8cd06297b76245de6":[6,0,0,246,24],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a12411d378aa0623e29287964eeb261c4":[7,0,0,219,20],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,246,20],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a1284a6c13adf9c244e4dcc2f973d7749":[7,0,0,219,43],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a1284a6c13adf9c244e4dcc2f973d7749":[6,0,0,246,43],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a14c0ef3312945158ad042463bef69e74":[6,0,0,246,30],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a14c0ef3312945158ad042463bef69e74":[7,0,0,219,30],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a14c0ef3312945158ad042463bef69e74":[6,0,0,246,30],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,246,33],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,219,33],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a22779bbfb123c76e922942ba876e330a":[6,0,0,246,28],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,219,28],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a22d178982a14ecf322a07eaaca7f5923":[6,0,0,246,5],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a22d178982a14ecf322a07eaaca7f5923":[7,0,0,219,5],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a2d5423c38fb53d7346a00c0e7e582347":[6,0,0,246,42],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a2d5423c38fb53d7346a00c0e7e582347":[7,0,0,219,42],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a2d5423c38fb53d7346a00c0e7e582347":[6,0,0,246,42],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[6,0,0,246,19],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,219,19],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a4030f129ece0a05d1a787cb5154703bb":[6,0,0,246,50],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a4030f129ece0a05d1a787cb5154703bb":[7,0,0,219,50],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a4157fed83bc06a39bcad50d83f34d442":[6,0,0,246,46],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a4157fed83bc06a39bcad50d83f34d442":[7,0,0,219,46],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a4157fed83bc06a39bcad50d83f34d442":[6,0,0,246,46],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a462859aeb6b4db7290622623dae2a6a4":[7,0,0,219,25],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a462859aeb6b4db7290622623dae2a6a4":[6,0,0,246,25],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a590987fd3f74fddf304212001fb2665b":[6,0,0,246,2],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a590987fd3f74fddf304212001fb2665b":[7,0,0,219,2],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,246,35],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a590987fd3f74fddf304212001fb2665b":[6,0,0,246,2],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,219,35],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,246,35],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a5a97866f3f7ce86466fbe8ef775d7301":[6,0,0,246,7],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a5a97866f3f7ce86466fbe8ef775d7301":[7,0,0,219,7],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,219,38],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,246,38],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a6649ad876d350f201b59b45b20b57108":[7,0,0,219,4],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a6649ad876d350f201b59b45b20b57108":[6,0,0,246,4],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a6649ad876d350f201b59b45b20b57108":[7,0,0,219,4],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a67ba7307754a41632bb41c383191bba7":[7,0,0,219,6],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a67ba7307754a41632bb41c383191bba7":[6,0,0,246,6],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a67e3922f9cdc6d2b8bfaa2e4ccfed206":[7,0,0,219,41],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a67e3922f9cdc6d2b8bfaa2e4ccfed206":[6,0,0,246,41],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a6acbc757e5f5b091aa51022e4cb382a4":[7,0,0,219,22],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a6acbc757e5f5b091aa51022e4cb382a4":[6,0,0,246,22],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a6acbc757e5f5b091aa51022e4cb382a4":[7,0,0,219,22],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a70cfe4412cfa68a9423854fc1b19872e":[6,0,0,246,9],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a70cfe4412cfa68a9423854fc1b19872e":[7,0,0,219,9],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a75261d46e5f123e31ab4f889b8788e5f":[6,0,0,246,18],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a75261d46e5f123e31ab4f889b8788e5f":[7,0,0,219,18],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a76b56f475ba7474c83760b557c34c6a5":[6,0,0,246,49],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a76b56f475ba7474c83760b557c34c6a5":[7,0,0,219,49],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a7c9f7111539b0d1e859caa947f9e8220":[7,0,0,219,47],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a7c9f7111539b0d1e859caa947f9e8220":[6,0,0,246,47],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a7c9f7111539b0d1e859caa947f9e8220":[7,0,0,219,47],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[7,0,0,219,45],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[6,0,0,246,45],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a814de6b1529bba5f7aa80ea3ac537ae1":[7,0,0,219,23],
@@ -177,22 +179,22 @@ var NAVTREEINDEX54 =
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,219,31],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a84739cd779700fa8d7991c9cf11c289d":[7,0,0,219,21],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a84739cd779700fa8d7991c9cf11c289d":[6,0,0,246,21],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8a464e98db9c09042b866bdb95b210f4":[6,0,0,246,12],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,219,12],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8a464e98db9c09042b866bdb95b210f4":[6,0,0,246,12],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8b05fabc7b8b6cf3129279629562476d":[7,0,0,219,14],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8b05fabc7b8b6cf3129279629562476d":[6,0,0,246,14],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8c1bb2ab75cacd7d2b470406d33f427d":[7,0,0,219,27],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8c1bb2ab75cacd7d2b470406d33f427d":[6,0,0,246,27],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8c1bb2ab75cacd7d2b470406d33f427d":[7,0,0,219,27],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8d7e786602979fc29169555056834c65":[6,0,0,246,10],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a8d7e786602979fc29169555056834c65":[7,0,0,219,10],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a92d426a5762a35639ab102cfcbcaedf5":[7,0,0,219,29],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a92d426a5762a35639ab102cfcbcaedf5":[6,0,0,246,29],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,219,34],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,246,34],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a9439f12db8a964f79f4b743493a0fd75":[6,0,0,246,13],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,219,34],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,219,13],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,246,15],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a9439f12db8a964f79f4b743493a0fd75":[6,0,0,246,13],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a98f49dbefa207210a2f4c0025848b93c":[7,0,0,219,15],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,246,15],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a9ec1d985ef5286ca5c069373705e4187":[6,0,0,246,0],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#a9ec1d985ef5286ca5c069373705e4187":[7,0,0,219,0],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#aa6ee76edb7111f8feefbb1f73aae50be":[7,0,0,219,44],
@@ -203,51 +205,49 @@ var NAVTREEINDEX54 =
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,219,37],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[7,0,0,219,3],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,246,3],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#abffec246be83d1df9c7a8c6ecb0249ea":[7,0,0,219,53],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#abffec246be83d1df9c7a8c6ecb0249ea":[6,0,0,246,53],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ac344214fa2a1ead13bb78f73712f69a3":[6,0,0,246,51],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#abffec246be83d1df9c7a8c6ecb0249ea":[7,0,0,219,53],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#ac344214fa2a1ead13bb78f73712f69a3":[7,0,0,219,51],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,219,8],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ac344214fa2a1ead13bb78f73712f69a3":[6,0,0,246,51],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,246,8],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,246,32],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,219,8],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,219,32],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,246,16],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,246,32],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad15462609bf45808fb04668cc1c28c78":[7,0,0,219,16],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,219,36],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,246,16],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,246,36],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,246,48],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,219,36],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,219,48],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad923d33063acb2a613fa243d4b1fbc78":[7,0,0,219,1],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,246,48],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad923d33063acb2a613fa243d4b1fbc78":[6,0,0,246,1],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[7,0,0,219,26],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#ad923d33063acb2a613fa243d4b1fbc78":[7,0,0,219,1],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[6,0,0,246,26],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,246,17],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[7,0,0,219,26],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#adb9f92d4da00b9e48328a1c3e19151c4":[7,0,0,219,17],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#adce32528577d71b228692df906ecd17c":[6,0,0,246,39],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,246,17],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#adce32528577d71b228692df906ecd17c":[7,0,0,219,39],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#adce32528577d71b228692df906ecd17c":[6,0,0,246,39],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,246,11],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#add8e20491fc0e054c9cab3c75297c6ec":[7,0,0,219,11],
-"class_ogre_1_1_d3_d11_window_swap_chain_based.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,246,40],
 "class_ogre_1_1_d3_d11_window_swap_chain_based.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,219,40],
-"class_ogre_1_1_d3_d9_depth_buffer.html":[6,0,0,247],
+"class_ogre_1_1_d3_d11_window_swap_chain_based.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,246,40],
 "class_ogre_1_1_d3_d9_depth_buffer.html":[7,0,0,220],
-"class_ogre_1_1_d3_d9_depth_buffer.html#a0ad586d8d280dd4b81b35321c0dbdca0":[6,0,0,247,33],
+"class_ogre_1_1_d3_d9_depth_buffer.html":[6,0,0,247],
 "class_ogre_1_1_d3_d9_depth_buffer.html#a0ad586d8d280dd4b81b35321c0dbdca0":[7,0,0,220,33],
+"class_ogre_1_1_d3_d9_depth_buffer.html#a0ad586d8d280dd4b81b35321c0dbdca0":[6,0,0,247,33],
 "class_ogre_1_1_d3_d9_depth_buffer.html#a0da54b20b25ac5313fc8c142e8b35168":[7,0,0,220,9],
 "class_ogre_1_1_d3_d9_depth_buffer.html#a0da54b20b25ac5313fc8c142e8b35168":[6,0,0,247,9],
 "class_ogre_1_1_d3_d9_depth_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,220,24],
 "class_ogre_1_1_d3_d9_depth_buffer.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,247,24],
-"class_ogre_1_1_d3_d9_depth_buffer.html#a1e43ad38a4e82b5bfb65e96fd7ce7e95":[6,0,0,247,14],
 "class_ogre_1_1_d3_d9_depth_buffer.html#a1e43ad38a4e82b5bfb65e96fd7ce7e95":[7,0,0,220,14],
-"class_ogre_1_1_d3_d9_depth_buffer.html#a227b541ef2ae3de53334c10397a08f99":[6,0,0,247,6],
+"class_ogre_1_1_d3_d9_depth_buffer.html#a1e43ad38a4e82b5bfb65e96fd7ce7e95":[6,0,0,247,14],
 "class_ogre_1_1_d3_d9_depth_buffer.html#a227b541ef2ae3de53334c10397a08f99":[7,0,0,220,6],
-"class_ogre_1_1_d3_d9_depth_buffer.html#a26c4ce1003ddab1ed7e3befecb0888a1":[6,0,0,247,5],
+"class_ogre_1_1_d3_d9_depth_buffer.html#a227b541ef2ae3de53334c10397a08f99":[6,0,0,247,6],
 "class_ogre_1_1_d3_d9_depth_buffer.html#a26c4ce1003ddab1ed7e3befecb0888a1":[7,0,0,220,5],
-"class_ogre_1_1_d3_d9_depth_buffer.html#a2bfd06803e6627d29b6eef9fd6bc6319":[6,0,0,247,3],
+"class_ogre_1_1_d3_d9_depth_buffer.html#a26c4ce1003ddab1ed7e3befecb0888a1":[6,0,0,247,5],
 "class_ogre_1_1_d3_d9_depth_buffer.html#a2bfd06803e6627d29b6eef9fd6bc6319":[7,0,0,220,3],
-"class_ogre_1_1_d3_d9_depth_buffer.html#a2c0b3bd4598e7e95aa1d20ddf5bfc055":[6,0,0,247,8],
+"class_ogre_1_1_d3_d9_depth_buffer.html#a2bfd06803e6627d29b6eef9fd6bc6319":[6,0,0,247,3],
 "class_ogre_1_1_d3_d9_depth_buffer.html#a2c0b3bd4598e7e95aa1d20ddf5bfc055":[7,0,0,220,8],
-"class_ogre_1_1_d3_d9_depth_buffer.html#a4a3de78684016598642ad2d00e5caa86":[7,0,0,220,21],
-"class_ogre_1_1_d3_d9_depth_buffer.html#a4a3de78684016598642ad2d00e5caa86":[6,0,0,247,21],
-"class_ogre_1_1_d3_d9_depth_buffer.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,247,26]
+"class_ogre_1_1_d3_d9_depth_buffer.html#a2c0b3bd4598e7e95aa1d20ddf5bfc055":[6,0,0,247,8],
+"class_ogre_1_1_d3_d9_depth_buffer.html#a4a3de78684016598642ad2d00e5caa86":[6,0,0,247,21]
 };
