@@ -1,120 +1,122 @@
 var NAVTREEINDEX68 =
 {
+"class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,248,10],
+"class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#ac0bdd94939814460b0b654fd704e88ab":[7,0,0,248,14],
 "class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#ac0bdd94939814460b0b654fd704e88ab":[6,0,0,275,14],
-"class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,248,5],
 "class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,275,5],
+"class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,248,5],
 "class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,275,9],
 "class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,248,9],
-"class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#adce32528577d71b228692df906ecd17c":[6,0,0,275,12],
 "class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#adce32528577d71b228692df906ecd17c":[7,0,0,248,12],
-"class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,248,13],
+"class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#adce32528577d71b228692df906ecd17c":[6,0,0,275,12],
 "class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,275,13],
-"class_ogre_1_1_d3_d9_texture.html":[6,0,0,276],
+"class_ogre_1_1_d3_d9_stereo_driver_n_v_i_d_i_a.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,248,13],
 "class_ogre_1_1_d3_d9_texture.html":[7,0,0,249],
+"class_ogre_1_1_d3_d9_texture.html":[6,0,0,276],
 "class_ogre_1_1_d3_d9_texture.html#a01a6e571941916969316ab23c5ee4739":[6,0,0,276,42],
 "class_ogre_1_1_d3_d9_texture.html#a01a6e571941916969316ab23c5ee4739":[7,0,0,249,42],
 "class_ogre_1_1_d3_d9_texture.html#a0389e214a82832a0c11d91babbc0d65f":[7,0,0,249,102],
 "class_ogre_1_1_d3_d9_texture.html#a0389e214a82832a0c11d91babbc0d65f":[6,0,0,276,102],
 "class_ogre_1_1_d3_d9_texture.html#a04969ca1d25bf40e71e907f2cdb7443b":[6,0,0,276,104],
 "class_ogre_1_1_d3_d9_texture.html#a04969ca1d25bf40e71e907f2cdb7443b":[7,0,0,249,104],
-"class_ogre_1_1_d3_d9_texture.html#a0617d9f04ca03bd25f4bde201e6ac13b":[7,0,0,249,44],
 "class_ogre_1_1_d3_d9_texture.html#a0617d9f04ca03bd25f4bde201e6ac13b":[6,0,0,276,44],
-"class_ogre_1_1_d3_d9_texture.html#a0779c46df96234b6619a5f57fbb36078":[6,0,0,276,62],
+"class_ogre_1_1_d3_d9_texture.html#a0617d9f04ca03bd25f4bde201e6ac13b":[7,0,0,249,44],
 "class_ogre_1_1_d3_d9_texture.html#a0779c46df96234b6619a5f57fbb36078":[7,0,0,249,62],
+"class_ogre_1_1_d3_d9_texture.html#a0779c46df96234b6619a5f57fbb36078":[6,0,0,276,62],
 "class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572c":[6,0,0,276,1],
 "class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572c":[7,0,0,249,1],
-"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca0c7b0873cacd42dec59d948b9bd28062":[7,0,0,249,1,6],
 "class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca0c7b0873cacd42dec59d948b9bd28062":[6,0,0,276,1,6],
-"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1":[7,0,0,249,1,4],
+"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca0c7b0873cacd42dec59d948b9bd28062":[7,0,0,249,1,6],
 "class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1":[6,0,0,276,1,4],
-"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca28d463296cacdfc115dbc3fb02d00e94":[7,0,0,249,1,0],
+"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1":[7,0,0,249,1,4],
 "class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca28d463296cacdfc115dbc3fb02d00e94":[6,0,0,276,1,0],
+"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca28d463296cacdfc115dbc3fb02d00e94":[7,0,0,249,1,0],
 "class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca4228d390b3a9ed614001db177d1f441e":[7,0,0,249,1,3],
 "class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca4228d390b3a9ed614001db177d1f441e":[6,0,0,276,1,3],
-"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572caa38cbef7605fc4bff6da2f34599ace8f":[6,0,0,276,1,2],
 "class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572caa38cbef7605fc4bff6da2f34599ace8f":[7,0,0,249,1,2],
-"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb":[6,0,0,276,1,5],
+"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572caa38cbef7605fc4bff6da2f34599ace8f":[6,0,0,276,1,2],
 "class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb":[7,0,0,249,1,5],
-"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572caf138fc9087e0dc755bff08a83720cbb5":[6,0,0,276,1,1],
+"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb":[6,0,0,276,1,5],
 "class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572caf138fc9087e0dc755bff08a83720cbb5":[7,0,0,249,1,1],
+"class_ogre_1_1_d3_d9_texture.html#a07e619aa09d3bc6789a6667cb4fc572caf138fc9087e0dc755bff08a83720cbb5":[6,0,0,276,1,1],
 "class_ogre_1_1_d3_d9_texture.html#a0883c51e283830144741fe47a7f3ef00":[7,0,0,249,64],
 "class_ogre_1_1_d3_d9_texture.html#a0883c51e283830144741fe47a7f3ef00":[6,0,0,276,64],
-"class_ogre_1_1_d3_d9_texture.html#a0ba4cefce02a7afa769a28c85c892082":[7,0,0,249,101],
 "class_ogre_1_1_d3_d9_texture.html#a0ba4cefce02a7afa769a28c85c892082":[6,0,0,276,101],
+"class_ogre_1_1_d3_d9_texture.html#a0ba4cefce02a7afa769a28c85c892082":[7,0,0,249,101],
 "class_ogre_1_1_d3_d9_texture.html#a104d9db8bfcff1f37b29157bbe070f7a":[7,0,0,249,111],
 "class_ogre_1_1_d3_d9_texture.html#a104d9db8bfcff1f37b29157bbe070f7a":[6,0,0,276,111],
-"class_ogre_1_1_d3_d9_texture.html#a13fc432584dd44c2969a8e41bdca569c":[6,0,0,276,9],
 "class_ogre_1_1_d3_d9_texture.html#a13fc432584dd44c2969a8e41bdca569c":[7,0,0,249,9],
+"class_ogre_1_1_d3_d9_texture.html#a13fc432584dd44c2969a8e41bdca569c":[6,0,0,276,9],
 "class_ogre_1_1_d3_d9_texture.html#a1686b8aef3b2c8d3892ae453086073c4":[6,0,0,276,19],
 "class_ogre_1_1_d3_d9_texture.html#a1686b8aef3b2c8d3892ae453086073c4":[7,0,0,249,19],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94":[7,0,0,249,0],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94":[6,0,0,276,0],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94a146041ec2a8b5178e5ad541d129c22eb":[6,0,0,276,0,5],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94a146041ec2a8b5178e5ad541d129c22eb":[7,0,0,249,0,5],
-"class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[6,0,0,276,0,1],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[7,0,0,249,0,1],
+"class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[6,0,0,276,0,1],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[6,0,0,276,0,2],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[7,0,0,249,0,2],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c":[7,0,0,249,0,0],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c":[6,0,0,276,0,0],
-"class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[6,0,0,276,0,4],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[7,0,0,249,0,4],
-"class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77":[6,0,0,276,0,3],
+"class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[6,0,0,276,0,4],
 "class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77":[7,0,0,249,0,3],
-"class_ogre_1_1_d3_d9_texture.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[6,0,0,276,13],
+"class_ogre_1_1_d3_d9_texture.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77":[6,0,0,276,0,3],
 "class_ogre_1_1_d3_d9_texture.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[7,0,0,249,13],
-"class_ogre_1_1_d3_d9_texture.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,276,76],
+"class_ogre_1_1_d3_d9_texture.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[6,0,0,276,13],
 "class_ogre_1_1_d3_d9_texture.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,249,76],
+"class_ogre_1_1_d3_d9_texture.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,276,76],
 "class_ogre_1_1_d3_d9_texture.html#a1d84784891731ee66945ffbc3b31e35b":[6,0,0,276,67],
 "class_ogre_1_1_d3_d9_texture.html#a1d84784891731ee66945ffbc3b31e35b":[7,0,0,249,67],
 "class_ogre_1_1_d3_d9_texture.html#a1e90ade99935ef70ec5b199243bf995b":[6,0,0,276,33],
 "class_ogre_1_1_d3_d9_texture.html#a1e90ade99935ef70ec5b199243bf995b":[7,0,0,249,33],
-"class_ogre_1_1_d3_d9_texture.html#a2149a95b9fd7be7959497233273fce29":[7,0,0,249,109],
 "class_ogre_1_1_d3_d9_texture.html#a2149a95b9fd7be7959497233273fce29":[6,0,0,276,109],
-"class_ogre_1_1_d3_d9_texture.html#a226649efcfea4e395fae458465213dc6":[6,0,0,276,4],
+"class_ogre_1_1_d3_d9_texture.html#a2149a95b9fd7be7959497233273fce29":[7,0,0,249,109],
 "class_ogre_1_1_d3_d9_texture.html#a226649efcfea4e395fae458465213dc6":[7,0,0,249,4],
-"class_ogre_1_1_d3_d9_texture.html#a2298551707debaf774d577e643ee856a":[7,0,0,249,31],
+"class_ogre_1_1_d3_d9_texture.html#a226649efcfea4e395fae458465213dc6":[6,0,0,276,4],
 "class_ogre_1_1_d3_d9_texture.html#a2298551707debaf774d577e643ee856a":[6,0,0,276,31],
-"class_ogre_1_1_d3_d9_texture.html#a297b97d2c7253c1ca8c471b91edd4407":[6,0,0,276,32],
+"class_ogre_1_1_d3_d9_texture.html#a2298551707debaf774d577e643ee856a":[7,0,0,249,31],
 "class_ogre_1_1_d3_d9_texture.html#a297b97d2c7253c1ca8c471b91edd4407":[7,0,0,249,32],
-"class_ogre_1_1_d3_d9_texture.html#a2ee26937110dfbd80a5419b1e14fe619":[6,0,0,276,91],
+"class_ogre_1_1_d3_d9_texture.html#a297b97d2c7253c1ca8c471b91edd4407":[6,0,0,276,32],
 "class_ogre_1_1_d3_d9_texture.html#a2ee26937110dfbd80a5419b1e14fe619":[7,0,0,249,91],
+"class_ogre_1_1_d3_d9_texture.html#a2ee26937110dfbd80a5419b1e14fe619":[6,0,0,276,91],
 "class_ogre_1_1_d3_d9_texture.html#a31a756c7827434953aa06a3a63c4b96e":[6,0,0,276,18],
 "class_ogre_1_1_d3_d9_texture.html#a31a756c7827434953aa06a3a63c4b96e":[7,0,0,249,18],
-"class_ogre_1_1_d3_d9_texture.html#a32ce5899ef0c534de28ec4c1f3a601f0":[7,0,0,249,2],
 "class_ogre_1_1_d3_d9_texture.html#a32ce5899ef0c534de28ec4c1f3a601f0":[6,0,0,276,2],
+"class_ogre_1_1_d3_d9_texture.html#a32ce5899ef0c534de28ec4c1f3a601f0":[7,0,0,249,2],
 "class_ogre_1_1_d3_d9_texture.html#a350b287fa3e83a389221274f68760008":[6,0,0,276,84],
 "class_ogre_1_1_d3_d9_texture.html#a350b287fa3e83a389221274f68760008":[7,0,0,249,84],
 "class_ogre_1_1_d3_d9_texture.html#a367f6fe60bb211cb4c32e3825ca67e4c":[7,0,0,249,17],
 "class_ogre_1_1_d3_d9_texture.html#a367f6fe60bb211cb4c32e3825ca67e4c":[6,0,0,276,17],
-"class_ogre_1_1_d3_d9_texture.html#a3af26f716731b64850ea50cfa4d2edef":[7,0,0,249,60],
 "class_ogre_1_1_d3_d9_texture.html#a3af26f716731b64850ea50cfa4d2edef":[6,0,0,276,60],
+"class_ogre_1_1_d3_d9_texture.html#a3af26f716731b64850ea50cfa4d2edef":[7,0,0,249,60],
 "class_ogre_1_1_d3_d9_texture.html#a3c49142f739ba8fb56d6e7b3db235fb7":[6,0,0,276,86],
 "class_ogre_1_1_d3_d9_texture.html#a3c49142f739ba8fb56d6e7b3db235fb7":[7,0,0,249,86],
-"class_ogre_1_1_d3_d9_texture.html#a3c600369ab5d6957524125c93915019f":[6,0,0,276,15],
 "class_ogre_1_1_d3_d9_texture.html#a3c600369ab5d6957524125c93915019f":[7,0,0,249,15],
+"class_ogre_1_1_d3_d9_texture.html#a3c600369ab5d6957524125c93915019f":[6,0,0,276,15],
 "class_ogre_1_1_d3_d9_texture.html#a3d111616339484f39c9456eeec6fd843":[7,0,0,249,10],
 "class_ogre_1_1_d3_d9_texture.html#a3d111616339484f39c9456eeec6fd843":[6,0,0,276,10],
 "class_ogre_1_1_d3_d9_texture.html#a3e314036bfd3198e89bd1d250f5eb6a1":[6,0,0,276,41],
 "class_ogre_1_1_d3_d9_texture.html#a3e314036bfd3198e89bd1d250f5eb6a1":[7,0,0,249,41],
-"class_ogre_1_1_d3_d9_texture.html#a496e18b2a22246735fd08fd83798c4a2":[7,0,0,249,14],
 "class_ogre_1_1_d3_d9_texture.html#a496e18b2a22246735fd08fd83798c4a2":[6,0,0,276,14],
-"class_ogre_1_1_d3_d9_texture.html#a4b5d014a4d078b7893cce480b264c493":[7,0,0,249,8],
+"class_ogre_1_1_d3_d9_texture.html#a496e18b2a22246735fd08fd83798c4a2":[7,0,0,249,14],
 "class_ogre_1_1_d3_d9_texture.html#a4b5d014a4d078b7893cce480b264c493":[6,0,0,276,8],
+"class_ogre_1_1_d3_d9_texture.html#a4b5d014a4d078b7893cce480b264c493":[7,0,0,249,8],
 "class_ogre_1_1_d3_d9_texture.html#a4d0ef43ff1e078b942e017f3dea6471d":[6,0,0,276,51],
 "class_ogre_1_1_d3_d9_texture.html#a4d0ef43ff1e078b942e017f3dea6471d":[7,0,0,249,51],
 "class_ogre_1_1_d3_d9_texture.html#a5016aec1762b026997ddd346775879ef":[6,0,0,276,85],
 "class_ogre_1_1_d3_d9_texture.html#a5016aec1762b026997ddd346775879ef":[7,0,0,249,85],
 "class_ogre_1_1_d3_d9_texture.html#a5513ffce404b14cff72846318b018d32":[6,0,0,276,11],
 "class_ogre_1_1_d3_d9_texture.html#a5513ffce404b14cff72846318b018d32":[7,0,0,249,11],
-"class_ogre_1_1_d3_d9_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,276,78],
 "class_ogre_1_1_d3_d9_texture.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,249,78],
-"class_ogre_1_1_d3_d9_texture.html#a5c6c0349c15cc698f016fa4fe9e0846b":[7,0,0,249,71],
+"class_ogre_1_1_d3_d9_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,276,78],
 "class_ogre_1_1_d3_d9_texture.html#a5c6c0349c15cc698f016fa4fe9e0846b":[6,0,0,276,71],
-"class_ogre_1_1_d3_d9_texture.html#a5c9a21a914281a1b6ef5796531ea96e7":[7,0,0,249,57],
+"class_ogre_1_1_d3_d9_texture.html#a5c6c0349c15cc698f016fa4fe9e0846b":[7,0,0,249,71],
 "class_ogre_1_1_d3_d9_texture.html#a5c9a21a914281a1b6ef5796531ea96e7":[6,0,0,276,57],
-"class_ogre_1_1_d3_d9_texture.html#a5d3962a2bef3bd77de412c8207975caf":[7,0,0,249,35],
+"class_ogre_1_1_d3_d9_texture.html#a5c9a21a914281a1b6ef5796531ea96e7":[7,0,0,249,57],
 "class_ogre_1_1_d3_d9_texture.html#a5d3962a2bef3bd77de412c8207975caf":[6,0,0,276,35],
+"class_ogre_1_1_d3_d9_texture.html#a5d3962a2bef3bd77de412c8207975caf":[7,0,0,249,35],
 "class_ogre_1_1_d3_d9_texture.html#a5dcfc70318106dd00902b0fc945d1d0e":[6,0,0,276,55],
 "class_ogre_1_1_d3_d9_texture.html#a5dcfc70318106dd00902b0fc945d1d0e":[7,0,0,249,55],
 "class_ogre_1_1_d3_d9_texture.html#a5decc0244a000c5002935c32ac301f0c":[6,0,0,276,24],
@@ -123,44 +125,44 @@ var NAVTREEINDEX68 =
 "class_ogre_1_1_d3_d9_texture.html#a6066bcdcb0bfe3a0d4ab47fbcee00281":[6,0,0,276,110],
 "class_ogre_1_1_d3_d9_texture.html#a60ce96525ac730a0f7b466ed287beef3":[6,0,0,276,56],
 "class_ogre_1_1_d3_d9_texture.html#a60ce96525ac730a0f7b466ed287beef3":[7,0,0,249,56],
-"class_ogre_1_1_d3_d9_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,276,81],
 "class_ogre_1_1_d3_d9_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,249,81],
-"class_ogre_1_1_d3_d9_texture.html#a65b5bd9531c385e200482c0edafdc1c2":[7,0,0,249,28],
+"class_ogre_1_1_d3_d9_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,276,81],
 "class_ogre_1_1_d3_d9_texture.html#a65b5bd9531c385e200482c0edafdc1c2":[6,0,0,276,28],
-"class_ogre_1_1_d3_d9_texture.html#a699d1c851f494a8d5d23d23b695ceb47":[6,0,0,276,65],
+"class_ogre_1_1_d3_d9_texture.html#a65b5bd9531c385e200482c0edafdc1c2":[7,0,0,249,28],
 "class_ogre_1_1_d3_d9_texture.html#a699d1c851f494a8d5d23d23b695ceb47":[7,0,0,249,65],
-"class_ogre_1_1_d3_d9_texture.html#a69fbdff7f241bfd0f7c4c43b267ecbb5":[6,0,0,276,53],
+"class_ogre_1_1_d3_d9_texture.html#a699d1c851f494a8d5d23d23b695ceb47":[6,0,0,276,65],
 "class_ogre_1_1_d3_d9_texture.html#a69fbdff7f241bfd0f7c4c43b267ecbb5":[7,0,0,249,53],
-"class_ogre_1_1_d3_d9_texture.html#a6bdd32464ce1df547d34a0739e4c3592":[6,0,0,276,69],
+"class_ogre_1_1_d3_d9_texture.html#a69fbdff7f241bfd0f7c4c43b267ecbb5":[6,0,0,276,53],
 "class_ogre_1_1_d3_d9_texture.html#a6bdd32464ce1df547d34a0739e4c3592":[7,0,0,249,69],
+"class_ogre_1_1_d3_d9_texture.html#a6bdd32464ce1df547d34a0739e4c3592":[6,0,0,276,69],
 "class_ogre_1_1_d3_d9_texture.html#a6cfc6014da843369b2619d1d7d807569":[7,0,0,249,30],
 "class_ogre_1_1_d3_d9_texture.html#a6cfc6014da843369b2619d1d7d807569":[6,0,0,276,30],
 "class_ogre_1_1_d3_d9_texture.html#a6ed49ed8701feb087b04b730ce1d682f":[6,0,0,276,46],
 "class_ogre_1_1_d3_d9_texture.html#a6ed49ed8701feb087b04b730ce1d682f":[7,0,0,249,46],
 "class_ogre_1_1_d3_d9_texture.html#a6f186da4d9557d958779eba68bb769a9":[6,0,0,276,34],
 "class_ogre_1_1_d3_d9_texture.html#a6f186da4d9557d958779eba68bb769a9":[7,0,0,249,34],
-"class_ogre_1_1_d3_d9_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[6,0,0,276,105],
 "class_ogre_1_1_d3_d9_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[7,0,0,249,105],
+"class_ogre_1_1_d3_d9_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[6,0,0,276,105],
 "class_ogre_1_1_d3_d9_texture.html#a6fc9c0ebe4a4c559b172f25f3b5dc9d8":[7,0,0,249,108],
 "class_ogre_1_1_d3_d9_texture.html#a6fc9c0ebe4a4c559b172f25f3b5dc9d8":[6,0,0,276,108],
-"class_ogre_1_1_d3_d9_texture.html#a74138c0203835513613af73cdb08890d":[7,0,0,249,59],
 "class_ogre_1_1_d3_d9_texture.html#a74138c0203835513613af73cdb08890d":[6,0,0,276,59],
+"class_ogre_1_1_d3_d9_texture.html#a74138c0203835513613af73cdb08890d":[7,0,0,249,59],
 "class_ogre_1_1_d3_d9_texture.html#a743e5059501507cd858e90532e8263f9":[7,0,0,249,22],
 "class_ogre_1_1_d3_d9_texture.html#a743e5059501507cd858e90532e8263f9":[6,0,0,276,22],
-"class_ogre_1_1_d3_d9_texture.html#a77987dd9dce1653083f3518fc43da348":[6,0,0,276,38],
 "class_ogre_1_1_d3_d9_texture.html#a77987dd9dce1653083f3518fc43da348":[7,0,0,249,38],
+"class_ogre_1_1_d3_d9_texture.html#a77987dd9dce1653083f3518fc43da348":[6,0,0,276,38],
 "class_ogre_1_1_d3_d9_texture.html#a77d5f72e02500f6db6f460bb48eac721":[6,0,0,276,7],
 "class_ogre_1_1_d3_d9_texture.html#a77d5f72e02500f6db6f460bb48eac721":[7,0,0,249,7],
-"class_ogre_1_1_d3_d9_texture.html#a82174dc4f4a0645332483ced7904c2f6":[7,0,0,249,97],
 "class_ogre_1_1_d3_d9_texture.html#a82174dc4f4a0645332483ced7904c2f6":[6,0,0,276,97],
+"class_ogre_1_1_d3_d9_texture.html#a82174dc4f4a0645332483ced7904c2f6":[7,0,0,249,97],
 "class_ogre_1_1_d3_d9_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,276,74],
 "class_ogre_1_1_d3_d9_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,249,74],
-"class_ogre_1_1_d3_d9_texture.html#a84dc53e8acb6b01bb695f96c048a1990":[7,0,0,249,25],
 "class_ogre_1_1_d3_d9_texture.html#a84dc53e8acb6b01bb695f96c048a1990":[6,0,0,276,25],
-"class_ogre_1_1_d3_d9_texture.html#a8775d611ddf70bc0ee89a9d62bac69cf":[7,0,0,249,98],
+"class_ogre_1_1_d3_d9_texture.html#a84dc53e8acb6b01bb695f96c048a1990":[7,0,0,249,25],
 "class_ogre_1_1_d3_d9_texture.html#a8775d611ddf70bc0ee89a9d62bac69cf":[6,0,0,276,98],
-"class_ogre_1_1_d3_d9_texture.html#a87c0bc1fea93de0e2cd65fa2dc374fd8":[6,0,0,276,72],
+"class_ogre_1_1_d3_d9_texture.html#a8775d611ddf70bc0ee89a9d62bac69cf":[7,0,0,249,98],
 "class_ogre_1_1_d3_d9_texture.html#a87c0bc1fea93de0e2cd65fa2dc374fd8":[7,0,0,249,72],
+"class_ogre_1_1_d3_d9_texture.html#a87c0bc1fea93de0e2cd65fa2dc374fd8":[6,0,0,276,72],
 "class_ogre_1_1_d3_d9_texture.html#a893c7a150edb48a25e5df700cfc194eb":[7,0,0,249,6],
 "class_ogre_1_1_d3_d9_texture.html#a893c7a150edb48a25e5df700cfc194eb":[6,0,0,276,6],
 "class_ogre_1_1_d3_d9_texture.html#a8ab9418311a7b4a116139a7871e57a4b":[7,0,0,249,39],
@@ -169,54 +171,54 @@ var NAVTREEINDEX68 =
 "class_ogre_1_1_d3_d9_texture.html#a8eb34a9034aab62fd537c021a79e3366":[6,0,0,276,63],
 "class_ogre_1_1_d3_d9_texture.html#a8ed6a95810f21f53aa8cbc780b680164":[6,0,0,276,26],
 "class_ogre_1_1_d3_d9_texture.html#a8ed6a95810f21f53aa8cbc780b680164":[7,0,0,249,26],
-"class_ogre_1_1_d3_d9_texture.html#a8f541900f7e1f73f4c313a732199029a":[6,0,0,276,61],
 "class_ogre_1_1_d3_d9_texture.html#a8f541900f7e1f73f4c313a732199029a":[7,0,0,249,61],
+"class_ogre_1_1_d3_d9_texture.html#a8f541900f7e1f73f4c313a732199029a":[6,0,0,276,61],
 "class_ogre_1_1_d3_d9_texture.html#a8fa804706ce91a40535efe38056d6356":[6,0,0,276,36],
 "class_ogre_1_1_d3_d9_texture.html#a8fa804706ce91a40535efe38056d6356":[7,0,0,249,36],
 "class_ogre_1_1_d3_d9_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,249,77],
 "class_ogre_1_1_d3_d9_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,276,77],
 "class_ogre_1_1_d3_d9_texture.html#a963dca9c2ab605d51ee75c92d850a96d":[7,0,0,249,52],
 "class_ogre_1_1_d3_d9_texture.html#a963dca9c2ab605d51ee75c92d850a96d":[6,0,0,276,52],
-"class_ogre_1_1_d3_d9_texture.html#a9877df680d0756fa081a3a558ac94b2a":[7,0,0,249,16],
 "class_ogre_1_1_d3_d9_texture.html#a9877df680d0756fa081a3a558ac94b2a":[6,0,0,276,16],
+"class_ogre_1_1_d3_d9_texture.html#a9877df680d0756fa081a3a558ac94b2a":[7,0,0,249,16],
 "class_ogre_1_1_d3_d9_texture.html#a9dffcf1a2d754e63e98770e5cf2cd9ee":[6,0,0,276,40],
 "class_ogre_1_1_d3_d9_texture.html#a9dffcf1a2d754e63e98770e5cf2cd9ee":[7,0,0,249,40],
 "class_ogre_1_1_d3_d9_texture.html#aa31bef1bfaa87731622e56f11b548e27":[6,0,0,276,107],
 "class_ogre_1_1_d3_d9_texture.html#aa31bef1bfaa87731622e56f11b548e27":[7,0,0,249,107],
-"class_ogre_1_1_d3_d9_texture.html#aa38c4f67ab5413135d1830dd164a68e6":[6,0,0,276,90],
 "class_ogre_1_1_d3_d9_texture.html#aa38c4f67ab5413135d1830dd164a68e6":[7,0,0,249,90],
+"class_ogre_1_1_d3_d9_texture.html#aa38c4f67ab5413135d1830dd164a68e6":[6,0,0,276,90],
 "class_ogre_1_1_d3_d9_texture.html#aa561d8d03383bb59ecce5c4278ed8da6":[7,0,0,249,103],
 "class_ogre_1_1_d3_d9_texture.html#aa561d8d03383bb59ecce5c4278ed8da6":[6,0,0,276,103],
 "class_ogre_1_1_d3_d9_texture.html#aa5c94ac282eb67a0b8cf6b32af4ccf7e":[7,0,0,249,93],
 "class_ogre_1_1_d3_d9_texture.html#aa5c94ac282eb67a0b8cf6b32af4ccf7e":[6,0,0,276,93],
-"class_ogre_1_1_d3_d9_texture.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[6,0,0,276,12],
 "class_ogre_1_1_d3_d9_texture.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[7,0,0,249,12],
-"class_ogre_1_1_d3_d9_texture.html#aa7942df6419c98c2668ffb02de252cc8":[6,0,0,276,23],
+"class_ogre_1_1_d3_d9_texture.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[6,0,0,276,12],
 "class_ogre_1_1_d3_d9_texture.html#aa7942df6419c98c2668ffb02de252cc8":[7,0,0,249,23],
+"class_ogre_1_1_d3_d9_texture.html#aa7942df6419c98c2668ffb02de252cc8":[6,0,0,276,23],
 "class_ogre_1_1_d3_d9_texture.html#aa97afae987b0c0f16c3e232a7317fad5":[6,0,0,276,68],
 "class_ogre_1_1_d3_d9_texture.html#aa97afae987b0c0f16c3e232a7317fad5":[7,0,0,249,68],
-"class_ogre_1_1_d3_d9_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[7,0,0,249,48],
 "class_ogre_1_1_d3_d9_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[6,0,0,276,48],
-"class_ogre_1_1_d3_d9_texture.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,249,80],
+"class_ogre_1_1_d3_d9_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[7,0,0,249,48],
 "class_ogre_1_1_d3_d9_texture.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,276,80],
+"class_ogre_1_1_d3_d9_texture.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,249,80],
 "class_ogre_1_1_d3_d9_texture.html#aba6375dc3369f7d4a1aaa4e7fedd62aa":[6,0,0,276,37],
 "class_ogre_1_1_d3_d9_texture.html#aba6375dc3369f7d4a1aaa4e7fedd62aa":[7,0,0,249,37],
-"class_ogre_1_1_d3_d9_texture.html#ac129cc0a773f0d9d0eb4c3c1a1b65618":[7,0,0,249,66],
 "class_ogre_1_1_d3_d9_texture.html#ac129cc0a773f0d9d0eb4c3c1a1b65618":[6,0,0,276,66],
+"class_ogre_1_1_d3_d9_texture.html#ac129cc0a773f0d9d0eb4c3c1a1b65618":[7,0,0,249,66],
 "class_ogre_1_1_d3_d9_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[6,0,0,276,45],
 "class_ogre_1_1_d3_d9_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[7,0,0,249,45],
 "class_ogre_1_1_d3_d9_texture.html#ac93f17feff099035542be8b22f890417":[6,0,0,276,29],
 "class_ogre_1_1_d3_d9_texture.html#ac93f17feff099035542be8b22f890417":[7,0,0,249,29],
-"class_ogre_1_1_d3_d9_texture.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,276,75],
 "class_ogre_1_1_d3_d9_texture.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,249,75],
+"class_ogre_1_1_d3_d9_texture.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,276,75],
 "class_ogre_1_1_d3_d9_texture.html#acce55ed43f888d8c4c5ed5c5aaf9d1db":[6,0,0,276,43],
 "class_ogre_1_1_d3_d9_texture.html#acce55ed43f888d8c4c5ed5c5aaf9d1db":[7,0,0,249,43],
-"class_ogre_1_1_d3_d9_texture.html#accfa5467ab8ccfc5920ec64101f8f532":[7,0,0,249,21],
 "class_ogre_1_1_d3_d9_texture.html#accfa5467ab8ccfc5920ec64101f8f532":[6,0,0,276,21],
+"class_ogre_1_1_d3_d9_texture.html#accfa5467ab8ccfc5920ec64101f8f532":[7,0,0,249,21],
 "class_ogre_1_1_d3_d9_texture.html#ace884b65b722ead9b920b9abf27bf815":[6,0,0,276,99],
 "class_ogre_1_1_d3_d9_texture.html#ace884b65b722ead9b920b9abf27bf815":[7,0,0,249,99],
-"class_ogre_1_1_d3_d9_texture.html#ad1c33ba2014eeb134c8ce932f2a43418":[6,0,0,276,54],
 "class_ogre_1_1_d3_d9_texture.html#ad1c33ba2014eeb134c8ce932f2a43418":[7,0,0,249,54],
+"class_ogre_1_1_d3_d9_texture.html#ad1c33ba2014eeb134c8ce932f2a43418":[6,0,0,276,54],
 "class_ogre_1_1_d3_d9_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,276,79],
 "class_ogre_1_1_d3_d9_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,249,79],
 "class_ogre_1_1_d3_d9_texture.html#ad8faaf7732b48e059f7d7dc15667f2af":[7,0,0,249,94],
@@ -231,23 +233,21 @@ var NAVTREEINDEX68 =
 "class_ogre_1_1_d3_d9_texture.html#ae0a0007de944eb3c2f933a372a752b35":[7,0,0,249,87],
 "class_ogre_1_1_d3_d9_texture.html#ae229b1f58092109adef55bfc6f864d79":[6,0,0,276,106],
 "class_ogre_1_1_d3_d9_texture.html#ae229b1f58092109adef55bfc6f864d79":[7,0,0,249,106],
-"class_ogre_1_1_d3_d9_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[7,0,0,249,96],
 "class_ogre_1_1_d3_d9_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[6,0,0,276,96],
-"class_ogre_1_1_d3_d9_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[7,0,0,249,95],
+"class_ogre_1_1_d3_d9_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[7,0,0,249,96],
 "class_ogre_1_1_d3_d9_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[6,0,0,276,95],
-"class_ogre_1_1_d3_d9_texture.html#ae356913ccefbebc4f0119a0599a406fc":[6,0,0,276,100],
+"class_ogre_1_1_d3_d9_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[7,0,0,249,95],
 "class_ogre_1_1_d3_d9_texture.html#ae356913ccefbebc4f0119a0599a406fc":[7,0,0,249,100],
-"class_ogre_1_1_d3_d9_texture.html#ae440722e537a413cd1dfaef1837883b0":[7,0,0,249,50],
+"class_ogre_1_1_d3_d9_texture.html#ae356913ccefbebc4f0119a0599a406fc":[6,0,0,276,100],
 "class_ogre_1_1_d3_d9_texture.html#ae440722e537a413cd1dfaef1837883b0":[6,0,0,276,50],
-"class_ogre_1_1_d3_d9_texture.html#ae67e44696cde3c7d4e8fec157ca4f498":[6,0,0,276,89],
+"class_ogre_1_1_d3_d9_texture.html#ae440722e537a413cd1dfaef1837883b0":[7,0,0,249,50],
 "class_ogre_1_1_d3_d9_texture.html#ae67e44696cde3c7d4e8fec157ca4f498":[7,0,0,249,89],
-"class_ogre_1_1_d3_d9_texture.html#ae72275dc12039548b1e774151854f3aa":[6,0,0,276,20],
+"class_ogre_1_1_d3_d9_texture.html#ae67e44696cde3c7d4e8fec157ca4f498":[6,0,0,276,89],
 "class_ogre_1_1_d3_d9_texture.html#ae72275dc12039548b1e774151854f3aa":[7,0,0,249,20],
-"class_ogre_1_1_d3_d9_texture.html#aec390502f63927ed9470ba423ea66f64":[7,0,0,249,88],
+"class_ogre_1_1_d3_d9_texture.html#ae72275dc12039548b1e774151854f3aa":[6,0,0,276,20],
 "class_ogre_1_1_d3_d9_texture.html#aec390502f63927ed9470ba423ea66f64":[6,0,0,276,88],
+"class_ogre_1_1_d3_d9_texture.html#aec390502f63927ed9470ba423ea66f64":[7,0,0,249,88],
 "class_ogre_1_1_d3_d9_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,276,83],
 "class_ogre_1_1_d3_d9_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,249,83],
-"class_ogre_1_1_d3_d9_texture.html#aedec7c3a2b04b5c8046782ebf8a05fc8":[7,0,0,249,3],
-"class_ogre_1_1_d3_d9_texture.html#aedec7c3a2b04b5c8046782ebf8a05fc8":[6,0,0,276,3],
-"class_ogre_1_1_d3_d9_texture.html#aee3fd3170df592c3cc679cc38d3d9f60":[6,0,0,276,47]
+"class_ogre_1_1_d3_d9_texture.html#aedec7c3a2b04b5c8046782ebf8a05fc8":[7,0,0,249,3]
 };
