@@ -1,12 +1,14 @@
 var NAVTREEINDEX69 =
 {
+"class_ogre_1_1_d3_d9_texture.html#aedec7c3a2b04b5c8046782ebf8a05fc8":[6,0,0,276,3],
 "class_ogre_1_1_d3_d9_texture.html#aee3fd3170df592c3cc679cc38d3d9f60":[7,0,0,249,47],
+"class_ogre_1_1_d3_d9_texture.html#aee3fd3170df592c3cc679cc38d3d9f60":[6,0,0,276,47],
 "class_ogre_1_1_d3_d9_texture.html#af745587ede1e8482b1edac167fbf82fd":[6,0,0,276,92],
 "class_ogre_1_1_d3_d9_texture.html#af745587ede1e8482b1edac167fbf82fd":[7,0,0,249,92],
 "class_ogre_1_1_d3_d9_texture.html#afb69d75b785af9cb8698f310bd0907cc":[6,0,0,276,70],
 "class_ogre_1_1_d3_d9_texture.html#afb69d75b785af9cb8698f310bd0907cc":[7,0,0,249,70],
-"class_ogre_1_1_d3_d9_texture.html#afc6a04837b2999d85f59f04e33e743ee":[7,0,0,249,58],
 "class_ogre_1_1_d3_d9_texture.html#afc6a04837b2999d85f59f04e33e743ee":[6,0,0,276,58],
+"class_ogre_1_1_d3_d9_texture.html#afc6a04837b2999d85f59f04e33e743ee":[7,0,0,249,58],
 "class_ogre_1_1_d3_d9_texture.html#afcb4a61b965600a67ca2c2f060821db9":[7,0,0,249,5],
 "class_ogre_1_1_d3_d9_texture.html#afcb4a61b965600a67ca2c2f060821db9":[6,0,0,276,5],
 "class_ogre_1_1_d3_d9_texture.html#afefa465095dd97cf22d0a43531171b51":[6,0,0,276,27],
@@ -15,42 +17,42 @@ var NAVTREEINDEX69 =
 "class_ogre_1_1_d3_d9_texture_manager.html":[7,0,0,250],
 "class_ogre_1_1_d3_d9_texture_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[6,0,0,277,17],
 "class_ogre_1_1_d3_d9_texture_manager.html#a00a7fe59aaaa4acdfda07edc704516ee":[7,0,0,250,17],
-"class_ogre_1_1_d3_d9_texture_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[7,0,0,250,32],
 "class_ogre_1_1_d3_d9_texture_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[6,0,0,277,32],
-"class_ogre_1_1_d3_d9_texture_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[7,0,0,250,30],
+"class_ogre_1_1_d3_d9_texture_manager.html#a00de71bdbcfe019fb7d743d3f8c92432":[7,0,0,250,32],
 "class_ogre_1_1_d3_d9_texture_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[6,0,0,277,30],
-"class_ogre_1_1_d3_d9_texture_manager.html#a117a3887bbf9e83e0585777beb0501dc":[7,0,0,250,4],
+"class_ogre_1_1_d3_d9_texture_manager.html#a0e655f4afb2eb68bbcf280f2879e20b6":[7,0,0,250,30],
 "class_ogre_1_1_d3_d9_texture_manager.html#a117a3887bbf9e83e0585777beb0501dc":[6,0,0,277,4],
+"class_ogre_1_1_d3_d9_texture_manager.html#a117a3887bbf9e83e0585777beb0501dc":[7,0,0,250,4],
 "class_ogre_1_1_d3_d9_texture_manager.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,277,45],
 "class_ogre_1_1_d3_d9_texture_manager.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,250,45],
 "class_ogre_1_1_d3_d9_texture_manager.html#a1db642a9eef36b32dbdea28d19e8ea0d":[7,0,0,250,40],
 "class_ogre_1_1_d3_d9_texture_manager.html#a1db642a9eef36b32dbdea28d19e8ea0d":[6,0,0,277,40],
-"class_ogre_1_1_d3_d9_texture_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[7,0,0,250,74],
 "class_ogre_1_1_d3_d9_texture_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[6,0,0,277,74],
+"class_ogre_1_1_d3_d9_texture_manager.html#a1fe343406d15d5367cfc4f86ba589b55":[7,0,0,250,74],
 "class_ogre_1_1_d3_d9_texture_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[6,0,0,277,2],
 "class_ogre_1_1_d3_d9_texture_manager.html#a2883e5999ded4031bd421fc5d045aaf7":[7,0,0,250,2],
 "class_ogre_1_1_d3_d9_texture_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[6,0,0,277,1],
 "class_ogre_1_1_d3_d9_texture_manager.html#a2a3ef36f60dc007920eb9bba20ef9125":[7,0,0,250,1],
-"class_ogre_1_1_d3_d9_texture_manager.html#a2a5f6c92d4f91eb1eaa0ccf9b73f8c83":[6,0,0,277,26],
 "class_ogre_1_1_d3_d9_texture_manager.html#a2a5f6c92d4f91eb1eaa0ccf9b73f8c83":[7,0,0,250,26],
-"class_ogre_1_1_d3_d9_texture_manager.html#a2cf457c70ea86892b1bec52028c96237":[7,0,0,250,72],
+"class_ogre_1_1_d3_d9_texture_manager.html#a2a5f6c92d4f91eb1eaa0ccf9b73f8c83":[6,0,0,277,26],
 "class_ogre_1_1_d3_d9_texture_manager.html#a2cf457c70ea86892b1bec52028c96237":[6,0,0,277,72],
-"class_ogre_1_1_d3_d9_texture_manager.html#a3083fb17ce51843aecdc0382d2d717f6":[7,0,0,250,42],
+"class_ogre_1_1_d3_d9_texture_manager.html#a2cf457c70ea86892b1bec52028c96237":[7,0,0,250,72],
 "class_ogre_1_1_d3_d9_texture_manager.html#a3083fb17ce51843aecdc0382d2d717f6":[6,0,0,277,42],
+"class_ogre_1_1_d3_d9_texture_manager.html#a3083fb17ce51843aecdc0382d2d717f6":[7,0,0,250,42],
 "class_ogre_1_1_d3_d9_texture_manager.html#a3b27a21f192919d78c14bccea5184736":[6,0,0,277,14],
 "class_ogre_1_1_d3_d9_texture_manager.html#a3b27a21f192919d78c14bccea5184736":[7,0,0,250,14],
-"class_ogre_1_1_d3_d9_texture_manager.html#a3cc7b930d37bc9fc156f7a2cadb572a3":[6,0,0,277,21],
 "class_ogre_1_1_d3_d9_texture_manager.html#a3cc7b930d37bc9fc156f7a2cadb572a3":[7,0,0,250,21],
+"class_ogre_1_1_d3_d9_texture_manager.html#a3cc7b930d37bc9fc156f7a2cadb572a3":[6,0,0,277,21],
 "class_ogre_1_1_d3_d9_texture_manager.html#a3f92489910e40e3756606a35618d7b06":[6,0,0,277,59],
 "class_ogre_1_1_d3_d9_texture_manager.html#a3f92489910e40e3756606a35618d7b06":[7,0,0,250,59],
-"class_ogre_1_1_d3_d9_texture_manager.html#a40769092850d5b296e1d1a9190631700":[7,0,0,250,8],
 "class_ogre_1_1_d3_d9_texture_manager.html#a40769092850d5b296e1d1a9190631700":[6,0,0,277,8],
+"class_ogre_1_1_d3_d9_texture_manager.html#a40769092850d5b296e1d1a9190631700":[7,0,0,250,8],
 "class_ogre_1_1_d3_d9_texture_manager.html#a4173c940f4c67e8a2dc1a5c4b6de62f6":[7,0,0,250,38],
 "class_ogre_1_1_d3_d9_texture_manager.html#a4173c940f4c67e8a2dc1a5c4b6de62f6":[6,0,0,277,38],
 "class_ogre_1_1_d3_d9_texture_manager.html#a42ae3de59dd5ccfd449645ec4af1143c":[7,0,0,250,34],
 "class_ogre_1_1_d3_d9_texture_manager.html#a42ae3de59dd5ccfd449645ec4af1143c":[6,0,0,277,34],
-"class_ogre_1_1_d3_d9_texture_manager.html#a42f172a8ed1625011d510b081eee66dd":[7,0,0,250,22],
 "class_ogre_1_1_d3_d9_texture_manager.html#a42f172a8ed1625011d510b081eee66dd":[6,0,0,277,22],
+"class_ogre_1_1_d3_d9_texture_manager.html#a42f172a8ed1625011d510b081eee66dd":[7,0,0,250,22],
 "class_ogre_1_1_d3_d9_texture_manager.html#a45d8b138d17f258816383140ca765aa3":[6,0,0,277,55],
 "class_ogre_1_1_d3_d9_texture_manager.html#a45d8b138d17f258816383140ca765aa3":[7,0,0,250,55],
 "class_ogre_1_1_d3_d9_texture_manager.html#a48c565d0e63b286c6388439ae73417df":[7,0,0,250,13],
@@ -63,12 +65,12 @@ var NAVTREEINDEX69 =
 "class_ogre_1_1_d3_d9_texture_manager.html#a4dda8323b265a00638dd29a4fa6510bc":[6,0,0,277,58],
 "class_ogre_1_1_d3_d9_texture_manager.html#a4f00d9cf3ea35b9804e5ce10d45d2fff":[6,0,0,277,12],
 "class_ogre_1_1_d3_d9_texture_manager.html#a4f00d9cf3ea35b9804e5ce10d45d2fff":[7,0,0,250,12],
-"class_ogre_1_1_d3_d9_texture_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[7,0,0,250,3],
 "class_ogre_1_1_d3_d9_texture_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[6,0,0,277,3],
-"class_ogre_1_1_d3_d9_texture_manager.html#a54d1843a43aebb13542312cd17134e6a":[7,0,0,250,9],
+"class_ogre_1_1_d3_d9_texture_manager.html#a4f7da59507a5a8550ea97615ff9afff0":[7,0,0,250,3],
 "class_ogre_1_1_d3_d9_texture_manager.html#a54d1843a43aebb13542312cd17134e6a":[6,0,0,277,9],
-"class_ogre_1_1_d3_d9_texture_manager.html#a57e22b305d763f9ede5bda93f31051ca":[7,0,0,250,31],
+"class_ogre_1_1_d3_d9_texture_manager.html#a54d1843a43aebb13542312cd17134e6a":[7,0,0,250,9],
 "class_ogre_1_1_d3_d9_texture_manager.html#a57e22b305d763f9ede5bda93f31051ca":[6,0,0,277,31],
+"class_ogre_1_1_d3_d9_texture_manager.html#a57e22b305d763f9ede5bda93f31051ca":[7,0,0,250,31],
 "class_ogre_1_1_d3_d9_texture_manager.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,277,47],
 "class_ogre_1_1_d3_d9_texture_manager.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,250,47],
 "class_ogre_1_1_d3_d9_texture_manager.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,277,50],
@@ -77,74 +79,74 @@ var NAVTREEINDEX69 =
 "class_ogre_1_1_d3_d9_texture_manager.html#a65730ea50a81401518b4cbf6bb6a0a73":[7,0,0,250,37],
 "class_ogre_1_1_d3_d9_texture_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[6,0,0,277,28],
 "class_ogre_1_1_d3_d9_texture_manager.html#a6870dfdab954bc10c92d60c10ea86b3c":[7,0,0,250,28],
-"class_ogre_1_1_d3_d9_texture_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[6,0,0,277,63],
 "class_ogre_1_1_d3_d9_texture_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[7,0,0,250,63],
-"class_ogre_1_1_d3_d9_texture_manager.html#a6f62363053ac50af65f3762c4f1cc498":[6,0,0,277,25],
+"class_ogre_1_1_d3_d9_texture_manager.html#a6ce966e769770ce9f90d77eddc2c30a3":[6,0,0,277,63],
 "class_ogre_1_1_d3_d9_texture_manager.html#a6f62363053ac50af65f3762c4f1cc498":[7,0,0,250,25],
-"class_ogre_1_1_d3_d9_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[6,0,0,277,62],
+"class_ogre_1_1_d3_d9_texture_manager.html#a6f62363053ac50af65f3762c4f1cc498":[6,0,0,277,25],
 "class_ogre_1_1_d3_d9_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[7,0,0,250,62],
+"class_ogre_1_1_d3_d9_texture_manager.html#a6ff50fee06a678837cbeeea75e4372a5":[6,0,0,277,62],
 "class_ogre_1_1_d3_d9_texture_manager.html#a77d097944def071bd10e1c2a03fc5b2c":[7,0,0,250,69],
 "class_ogre_1_1_d3_d9_texture_manager.html#a77d097944def071bd10e1c2a03fc5b2c":[6,0,0,277,69],
 "class_ogre_1_1_d3_d9_texture_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[6,0,0,277,16],
 "class_ogre_1_1_d3_d9_texture_manager.html#a7913c36c02ef03007ff1a1c76ddf7710":[7,0,0,250,16],
-"class_ogre_1_1_d3_d9_texture_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[6,0,0,277,53],
 "class_ogre_1_1_d3_d9_texture_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[7,0,0,250,53],
-"class_ogre_1_1_d3_d9_texture_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,277,43],
+"class_ogre_1_1_d3_d9_texture_manager.html#a8240f6bbf3449b1f2acdd476efbde821":[6,0,0,277,53],
 "class_ogre_1_1_d3_d9_texture_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,250,43],
+"class_ogre_1_1_d3_d9_texture_manager.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,277,43],
 "class_ogre_1_1_d3_d9_texture_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[6,0,0,277,57],
 "class_ogre_1_1_d3_d9_texture_manager.html#a84e25cc5ad09ff7567d1fed7429433a3":[7,0,0,250,57],
-"class_ogre_1_1_d3_d9_texture_manager.html#a8faa10c9150687d1bf229ccff16a8960":[7,0,0,250,33],
 "class_ogre_1_1_d3_d9_texture_manager.html#a8faa10c9150687d1bf229ccff16a8960":[6,0,0,277,33],
+"class_ogre_1_1_d3_d9_texture_manager.html#a8faa10c9150687d1bf229ccff16a8960":[7,0,0,250,33],
 "class_ogre_1_1_d3_d9_texture_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[6,0,0,277,75],
 "class_ogre_1_1_d3_d9_texture_manager.html#a93b40c858020f2bbbcebcd4dc72a6321":[7,0,0,250,75],
-"class_ogre_1_1_d3_d9_texture_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,250,46],
 "class_ogre_1_1_d3_d9_texture_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,277,46],
+"class_ogre_1_1_d3_d9_texture_manager.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,250,46],
 "class_ogre_1_1_d3_d9_texture_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[7,0,0,250,73],
 "class_ogre_1_1_d3_d9_texture_manager.html#a94962d0929fdc88c25d35672ff2c1ff0":[6,0,0,277,73],
-"class_ogre_1_1_d3_d9_texture_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[7,0,0,250,64],
 "class_ogre_1_1_d3_d9_texture_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[6,0,0,277,64],
-"class_ogre_1_1_d3_d9_texture_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[6,0,0,277,24],
+"class_ogre_1_1_d3_d9_texture_manager.html#a9dcc9da5760fcd3b39b4566fe308ad6b":[7,0,0,250,64],
 "class_ogre_1_1_d3_d9_texture_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[7,0,0,250,24],
+"class_ogre_1_1_d3_d9_texture_manager.html#aa273e1a7543272d0d9b21de7a55c1b7a":[6,0,0,277,24],
 "class_ogre_1_1_d3_d9_texture_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[7,0,0,250,71],
 "class_ogre_1_1_d3_d9_texture_manager.html#aa3ff9558e8fa8187f510472a58093b6f":[6,0,0,277,71],
-"class_ogre_1_1_d3_d9_texture_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[6,0,0,277,67],
 "class_ogre_1_1_d3_d9_texture_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[7,0,0,250,67],
+"class_ogre_1_1_d3_d9_texture_manager.html#aa7bd4f02b31fba693d3bea6492fe20a8":[6,0,0,277,67],
 "class_ogre_1_1_d3_d9_texture_manager.html#aa8b761abb06d74347e9636550307ccd9":[6,0,0,277,18],
 "class_ogre_1_1_d3_d9_texture_manager.html#aa8b761abb06d74347e9636550307ccd9":[7,0,0,250,18],
-"class_ogre_1_1_d3_d9_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[6,0,0,277,56],
 "class_ogre_1_1_d3_d9_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[7,0,0,250,56],
-"class_ogre_1_1_d3_d9_texture_manager.html#aaaa53651124f3773fbcf6ae2b4a6fbe5":[6,0,0,277,70],
+"class_ogre_1_1_d3_d9_texture_manager.html#aa9608544a7beb1b0e43835877ab62788":[6,0,0,277,56],
 "class_ogre_1_1_d3_d9_texture_manager.html#aaaa53651124f3773fbcf6ae2b4a6fbe5":[7,0,0,250,70],
-"class_ogre_1_1_d3_d9_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[7,0,0,250,41],
+"class_ogre_1_1_d3_d9_texture_manager.html#aaaa53651124f3773fbcf6ae2b4a6fbe5":[6,0,0,277,70],
 "class_ogre_1_1_d3_d9_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[6,0,0,277,41],
+"class_ogre_1_1_d3_d9_texture_manager.html#aae5cce977c3523af14bb17b3a954effd":[7,0,0,250,41],
 "class_ogre_1_1_d3_d9_texture_manager.html#ab194cb5e332fc3eb35591e468f5dbcd3":[6,0,0,277,66],
 "class_ogre_1_1_d3_d9_texture_manager.html#ab194cb5e332fc3eb35591e468f5dbcd3":[7,0,0,250,66],
-"class_ogre_1_1_d3_d9_texture_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[7,0,0,250,19],
 "class_ogre_1_1_d3_d9_texture_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[6,0,0,277,19],
-"class_ogre_1_1_d3_d9_texture_manager.html#ab3d834cb2b240988c4fa8663763e444c":[7,0,0,250,6],
+"class_ogre_1_1_d3_d9_texture_manager.html#ab1c354fd2294c7c50b3f3e9ce42543f7":[7,0,0,250,19],
 "class_ogre_1_1_d3_d9_texture_manager.html#ab3d834cb2b240988c4fa8663763e444c":[6,0,0,277,6],
-"class_ogre_1_1_d3_d9_texture_manager.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,250,49],
+"class_ogre_1_1_d3_d9_texture_manager.html#ab3d834cb2b240988c4fa8663763e444c":[7,0,0,250,6],
 "class_ogre_1_1_d3_d9_texture_manager.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,277,49],
+"class_ogre_1_1_d3_d9_texture_manager.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,250,49],
 "class_ogre_1_1_d3_d9_texture_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[6,0,0,277,77],
 "class_ogre_1_1_d3_d9_texture_manager.html#abbb523a827bc6ea90d3b5ec80f0cf770":[7,0,0,250,77],
-"class_ogre_1_1_d3_d9_texture_manager.html#abbbab1db9a334e39c2114ee3a21b013f":[7,0,0,250,36],
 "class_ogre_1_1_d3_d9_texture_manager.html#abbbab1db9a334e39c2114ee3a21b013f":[6,0,0,277,36],
+"class_ogre_1_1_d3_d9_texture_manager.html#abbbab1db9a334e39c2114ee3a21b013f":[7,0,0,250,36],
 "class_ogre_1_1_d3_d9_texture_manager.html#abfb0022b18d022a7605f0d19a966f00f":[7,0,0,250,60],
 "class_ogre_1_1_d3_d9_texture_manager.html#abfb0022b18d022a7605f0d19a966f00f":[6,0,0,277,60],
-"class_ogre_1_1_d3_d9_texture_manager.html#ac22655af03ecea85d863a1d1d561778c":[6,0,0,277,61],
 "class_ogre_1_1_d3_d9_texture_manager.html#ac22655af03ecea85d863a1d1d561778c":[7,0,0,250,61],
+"class_ogre_1_1_d3_d9_texture_manager.html#ac22655af03ecea85d863a1d1d561778c":[6,0,0,277,61],
 "class_ogre_1_1_d3_d9_texture_manager.html#ac380e4c615bcd2546bf961354f4ebda2":[7,0,0,250,5],
 "class_ogre_1_1_d3_d9_texture_manager.html#ac380e4c615bcd2546bf961354f4ebda2":[6,0,0,277,5],
 "class_ogre_1_1_d3_d9_texture_manager.html#ac8f7ee61606730572a8590060d8896a0":[7,0,0,250,23],
 "class_ogre_1_1_d3_d9_texture_manager.html#ac8f7ee61606730572a8590060d8896a0":[6,0,0,277,23],
 "class_ogre_1_1_d3_d9_texture_manager.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,250,44],
 "class_ogre_1_1_d3_d9_texture_manager.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,277,44],
-"class_ogre_1_1_d3_d9_texture_manager.html#acd4223279e97a7687e2f9994f05e2491":[6,0,0,277,15],
 "class_ogre_1_1_d3_d9_texture_manager.html#acd4223279e97a7687e2f9994f05e2491":[7,0,0,250,15],
+"class_ogre_1_1_d3_d9_texture_manager.html#acd4223279e97a7687e2f9994f05e2491":[6,0,0,277,15],
 "class_ogre_1_1_d3_d9_texture_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,250,48],
 "class_ogre_1_1_d3_d9_texture_manager.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,277,48],
-"class_ogre_1_1_d3_d9_texture_manager.html#ad6d63fe7126510bf10fd337705cb0b29":[6,0,0,277,39],
 "class_ogre_1_1_d3_d9_texture_manager.html#ad6d63fe7126510bf10fd337705cb0b29":[7,0,0,250,39],
+"class_ogre_1_1_d3_d9_texture_manager.html#ad6d63fe7126510bf10fd337705cb0b29":[6,0,0,277,39],
 "class_ogre_1_1_d3_d9_texture_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[6,0,0,277,65],
 "class_ogre_1_1_d3_d9_texture_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[7,0,0,250,65],
 "class_ogre_1_1_d3_d9_texture_manager.html#adce32528577d71b228692df906ecd17c":[6,0,0,277,51],
@@ -155,36 +157,36 @@ var NAVTREEINDEX69 =
 "class_ogre_1_1_d3_d9_texture_manager.html#ae63b06c1fd6d1266b4c5dacc35e521b4":[6,0,0,277,10],
 "class_ogre_1_1_d3_d9_texture_manager.html#aeaa1410333b7bcea14b00c360112a528":[6,0,0,277,76],
 "class_ogre_1_1_d3_d9_texture_manager.html#aeaa1410333b7bcea14b00c360112a528":[7,0,0,250,76],
-"class_ogre_1_1_d3_d9_texture_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,250,52],
 "class_ogre_1_1_d3_d9_texture_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,277,52],
-"class_ogre_1_1_d3_d9_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[7,0,0,250,7],
+"class_ogre_1_1_d3_d9_texture_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,250,52],
 "class_ogre_1_1_d3_d9_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[6,0,0,277,7],
-"class_ogre_1_1_d3_d9_texture_manager.html#af2cae9ecc99635a541df72ae7cdd337a":[7,0,0,250,68],
+"class_ogre_1_1_d3_d9_texture_manager.html#af1a871ac005af0be0b8c1857a4f8eea9":[7,0,0,250,7],
 "class_ogre_1_1_d3_d9_texture_manager.html#af2cae9ecc99635a541df72ae7cdd337a":[6,0,0,277,68],
+"class_ogre_1_1_d3_d9_texture_manager.html#af2cae9ecc99635a541df72ae7cdd337a":[7,0,0,250,68],
 "class_ogre_1_1_d3_d9_texture_manager.html#af33a91a3a918df919de56635b13a532e":[6,0,0,277,11],
 "class_ogre_1_1_d3_d9_texture_manager.html#af33a91a3a918df919de56635b13a532e":[7,0,0,250,11],
 "class_ogre_1_1_d3_d9_texture_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[7,0,0,250,0],
 "class_ogre_1_1_d3_d9_texture_manager.html#af484f2b60c8d9bc87f37fa8af8e630c5":[6,0,0,277,0],
-"class_ogre_1_1_d3_d9_texture_manager.html#af4b66fba75a4c341bd1c1dd16decfec8":[6,0,0,277,20],
 "class_ogre_1_1_d3_d9_texture_manager.html#af4b66fba75a4c341bd1c1dd16decfec8":[7,0,0,250,20],
-"class_ogre_1_1_d3_d9_texture_manager.html#af96b58b31c152a8ae3c6152ee3ea12e7":[6,0,0,277,35],
+"class_ogre_1_1_d3_d9_texture_manager.html#af4b66fba75a4c341bd1c1dd16decfec8":[6,0,0,277,20],
 "class_ogre_1_1_d3_d9_texture_manager.html#af96b58b31c152a8ae3c6152ee3ea12e7":[7,0,0,250,35],
+"class_ogre_1_1_d3_d9_texture_manager.html#af96b58b31c152a8ae3c6152ee3ea12e7":[6,0,0,277,35],
 "class_ogre_1_1_d3_d9_vertex_declaration.html":[7,0,0,251],
 "class_ogre_1_1_d3_d9_vertex_declaration.html":[6,0,0,278],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a266542b0e2a78904d671f615b03b8080":[6,0,0,278,11],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a266542b0e2a78904d671f615b03b8080":[7,0,0,251,11],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a5a91d9a841eca45392494b2444968029":[6,0,0,278,8],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a5a91d9a841eca45392494b2444968029":[7,0,0,251,8],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a604bc46f07db7b70e10855b5c94b0109":[7,0,0,251,2],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a5a91d9a841eca45392494b2444968029":[6,0,0,278,8],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a604bc46f07db7b70e10855b5c94b0109":[6,0,0,278,2],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a6554d69f9dc3f80b6eca71d4cba69989":[7,0,0,251,3],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a604bc46f07db7b70e10855b5c94b0109":[7,0,0,251,2],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a6554d69f9dc3f80b6eca71d4cba69989":[6,0,0,278,3],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a6e35239737da934f62f69fad4c3bd290":[7,0,0,251,1],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a6554d69f9dc3f80b6eca71d4cba69989":[7,0,0,251,3],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a6e35239737da934f62f69fad4c3bd290":[6,0,0,278,1],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a6e35239737da934f62f69fad4c3bd290":[7,0,0,251,1],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a6fc9c0ebe4a4c559b172f25f3b5dc9d8":[7,0,0,251,14],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a6fc9c0ebe4a4c559b172f25f3b5dc9d8":[6,0,0,278,14],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#a842f42e52d16d44819abb342fc182cad":[6,0,0,278,0],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a842f42e52d16d44819abb342fc182cad":[7,0,0,251,0],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#a842f42e52d16d44819abb342fc182cad":[6,0,0,278,0],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a8cb01902db67a5d34ccc02a5ff733fd1":[6,0,0,278,12],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a8cb01902db67a5d34ccc02a5ff733fd1":[7,0,0,251,12],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a8d55f1d5ce61a1b796d8d86dd3c69fdb":[7,0,0,251,9],
@@ -193,61 +195,59 @@ var NAVTREEINDEX69 =
 "class_ogre_1_1_d3_d9_vertex_declaration.html#a9008da922e8b8762ac284cc1f08a0749":[7,0,0,251,10],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#aa97afae987b0c0f16c3e232a7317fad5":[7,0,0,251,5],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#aa97afae987b0c0f16c3e232a7317fad5":[6,0,0,278,5],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#aaf846d91970816cbbe04bb3def85e2b6":[7,0,0,251,13],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#aaf846d91970816cbbe04bb3def85e2b6":[6,0,0,278,13],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#aaf846d91970816cbbe04bb3def85e2b6":[7,0,0,251,13],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#aaf8a19f49875ccc73d2df582b9dba4f3":[7,0,0,251,4],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#aaf8a19f49875ccc73d2df582b9dba4f3":[6,0,0,278,4],
-"class_ogre_1_1_d3_d9_vertex_declaration.html#aeb5a689761d0ee05e79015a4ee26917b":[7,0,0,251,6],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#aeb5a689761d0ee05e79015a4ee26917b":[6,0,0,278,6],
+"class_ogre_1_1_d3_d9_vertex_declaration.html#aeb5a689761d0ee05e79015a4ee26917b":[7,0,0,251,6],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#afe9b5394456063cae5b95d512cc54cc0":[7,0,0,251,7],
 "class_ogre_1_1_d3_d9_vertex_declaration.html#afe9b5394456063cae5b95d512cc54cc0":[6,0,0,278,7],
-"class_ogre_1_1_d3_d9_video_mode.html":[7,0,0,252],
 "class_ogre_1_1_d3_d9_video_mode.html":[6,0,0,279],
+"class_ogre_1_1_d3_d9_video_mode.html":[7,0,0,252],
 "class_ogre_1_1_d3_d9_video_mode.html#a055a751c6ab62e8f68f55d34d074f4b9":[7,0,0,252,5],
 "class_ogre_1_1_d3_d9_video_mode.html#a055a751c6ab62e8f68f55d34d074f4b9":[6,0,0,279,5],
 "class_ogre_1_1_d3_d9_video_mode.html#a2993d0fefdcad771e9649e5283d85270":[7,0,0,252,8],
 "class_ogre_1_1_d3_d9_video_mode.html#a2993d0fefdcad771e9649e5283d85270":[6,0,0,279,8],
-"class_ogre_1_1_d3_d9_video_mode.html#a3092cd96e44807a629e3ac45f05c683c":[6,0,0,279,1],
 "class_ogre_1_1_d3_d9_video_mode.html#a3092cd96e44807a629e3ac45f05c683c":[7,0,0,252,1],
+"class_ogre_1_1_d3_d9_video_mode.html#a3092cd96e44807a629e3ac45f05c683c":[6,0,0,279,1],
 "class_ogre_1_1_d3_d9_video_mode.html#a327c0921f5f515d59b9f01de46e08b88":[7,0,0,252,4],
 "class_ogre_1_1_d3_d9_video_mode.html#a327c0921f5f515d59b9f01de46e08b88":[6,0,0,279,4],
 "class_ogre_1_1_d3_d9_video_mode.html#a349726fc8e0cf1e82dba2c831dc8bc0c":[7,0,0,252,7],
 "class_ogre_1_1_d3_d9_video_mode.html#a349726fc8e0cf1e82dba2c831dc8bc0c":[6,0,0,279,7],
-"class_ogre_1_1_d3_d9_video_mode.html#a34a77a0c52fb29311ec6181ac8bee754":[6,0,0,279,0],
 "class_ogre_1_1_d3_d9_video_mode.html#a34a77a0c52fb29311ec6181ac8bee754":[7,0,0,252,0],
-"class_ogre_1_1_d3_d9_video_mode.html#a3f7dd41242c7c00188aad2e8489f41b8":[7,0,0,252,9],
+"class_ogre_1_1_d3_d9_video_mode.html#a34a77a0c52fb29311ec6181ac8bee754":[6,0,0,279,0],
 "class_ogre_1_1_d3_d9_video_mode.html#a3f7dd41242c7c00188aad2e8489f41b8":[6,0,0,279,9],
-"class_ogre_1_1_d3_d9_video_mode.html#a4024d30689e34f0c9022cef516405028":[6,0,0,279,6],
+"class_ogre_1_1_d3_d9_video_mode.html#a3f7dd41242c7c00188aad2e8489f41b8":[7,0,0,252,9],
 "class_ogre_1_1_d3_d9_video_mode.html#a4024d30689e34f0c9022cef516405028":[7,0,0,252,6],
-"class_ogre_1_1_d3_d9_video_mode.html#a70e53fa440e95ed17b85015a1e5643a6":[6,0,0,279,10],
+"class_ogre_1_1_d3_d9_video_mode.html#a4024d30689e34f0c9022cef516405028":[6,0,0,279,6],
 "class_ogre_1_1_d3_d9_video_mode.html#a70e53fa440e95ed17b85015a1e5643a6":[7,0,0,252,10],
+"class_ogre_1_1_d3_d9_video_mode.html#a70e53fa440e95ed17b85015a1e5643a6":[6,0,0,279,10],
 "class_ogre_1_1_d3_d9_video_mode.html#a84bc6e2cc34253b99afc560176038b4c":[7,0,0,252,11],
 "class_ogre_1_1_d3_d9_video_mode.html#a84bc6e2cc34253b99afc560176038b4c":[6,0,0,279,11],
 "class_ogre_1_1_d3_d9_video_mode.html#ac4d2913efac422ca4a93ab0771373431":[7,0,0,252,2],
 "class_ogre_1_1_d3_d9_video_mode.html#ac4d2913efac422ca4a93ab0771373431":[6,0,0,279,2],
-"class_ogre_1_1_d3_d9_video_mode.html#af819f89d3ecd9236d1c0f9f91a71d0ba":[7,0,0,252,3],
 "class_ogre_1_1_d3_d9_video_mode.html#af819f89d3ecd9236d1c0f9f91a71d0ba":[6,0,0,279,3],
+"class_ogre_1_1_d3_d9_video_mode.html#af819f89d3ecd9236d1c0f9f91a71d0ba":[7,0,0,252,3],
 "class_ogre_1_1_d3_d9_video_mode_list.html":[7,0,0,253],
 "class_ogre_1_1_d3_d9_video_mode_list.html":[6,0,0,280],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,280,8],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,253,8],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a2cd7b9abf98533d646fcbe3c74b370e4":[6,0,0,280,3],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a2cd7b9abf98533d646fcbe3c74b370e4":[7,0,0,253,3],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a413ec33c53b844739d33dadc357d45b0":[6,0,0,280,2],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a2cd7b9abf98533d646fcbe3c74b370e4":[6,0,0,280,3],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a413ec33c53b844739d33dadc357d45b0":[7,0,0,253,2],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a537516c036db7310614aa3011325f8db":[6,0,0,280,1],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a413ec33c53b844739d33dadc357d45b0":[6,0,0,280,2],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a537516c036db7310614aa3011325f8db":[7,0,0,253,1],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a537516c036db7310614aa3011325f8db":[6,0,0,280,1],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,280,10],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,253,10],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,253,13],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,280,13],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a80ca3ca66b3445380b26aa3bb35ff990":[7,0,0,253,0],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,253,13],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a80ca3ca66b3445380b26aa3bb35ff990":[6,0,0,280,0],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,280,6],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a80ca3ca66b3445380b26aa3bb35ff990":[7,0,0,253,0],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,253,6],
-"class_ogre_1_1_d3_d9_video_mode_list.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,280,9],
+"class_ogre_1_1_d3_d9_video_mode_list.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,280,6],
 "class_ogre_1_1_d3_d9_video_mode_list.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,253,9],
-"class_ogre_1_1_d3_d9_video_mode_list.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,253,12],
-"class_ogre_1_1_d3_d9_video_mode_list.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,280,12],
-"class_ogre_1_1_d3_d9_video_mode_list.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,280,7]
+"class_ogre_1_1_d3_d9_video_mode_list.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,280,9],
+"class_ogre_1_1_d3_d9_video_mode_list.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,253,12]
 };
