@@ -1,16 +1,18 @@
 var NAVTREEINDEX70 =
 {
+"class_ogre_1_1_d3_d9_video_mode_list.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,280,12],
 "class_ogre_1_1_d3_d9_video_mode_list.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,253,7],
+"class_ogre_1_1_d3_d9_video_mode_list.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,280,7],
 "class_ogre_1_1_d3_d9_video_mode_list.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,280,11],
 "class_ogre_1_1_d3_d9_video_mode_list.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,253,11],
-"class_ogre_1_1_d3_d9_video_mode_list.html#adce32528577d71b228692df906ecd17c":[7,0,0,253,14],
 "class_ogre_1_1_d3_d9_video_mode_list.html#adce32528577d71b228692df906ecd17c":[6,0,0,280,14],
-"class_ogre_1_1_d3_d9_video_mode_list.html#ae5e59d08fcdd4ac62d62353490ae84dd":[7,0,0,253,4],
+"class_ogre_1_1_d3_d9_video_mode_list.html#adce32528577d71b228692df906ecd17c":[7,0,0,253,14],
 "class_ogre_1_1_d3_d9_video_mode_list.html#ae5e59d08fcdd4ac62d62353490ae84dd":[6,0,0,280,4],
-"class_ogre_1_1_d3_d9_video_mode_list.html#ae6b57890a3961b5a8e4aa90e2515cc6f":[7,0,0,253,5],
+"class_ogre_1_1_d3_d9_video_mode_list.html#ae5e59d08fcdd4ac62d62353490ae84dd":[7,0,0,253,4],
 "class_ogre_1_1_d3_d9_video_mode_list.html#ae6b57890a3961b5a8e4aa90e2515cc6f":[6,0,0,280,5],
-"class_ogre_1_1_d3_d9_video_mode_list.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,253,15],
+"class_ogre_1_1_d3_d9_video_mode_list.html#ae6b57890a3961b5a8e4aa90e2515cc6f":[7,0,0,253,5],
 "class_ogre_1_1_d3_d9_video_mode_list.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,280,15],
+"class_ogre_1_1_d3_d9_video_mode_list.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,253,15],
 "class_ogre_1_1_d_d_s_codec.html":[5,2,3,1],
 "class_ogre_1_1_d_d_s_codec.html#a033bc39aab1445bb54e509bcc0ce5408":[5,2,3,1,4],
 "class_ogre_1_1_d_d_s_codec.html#a168c221edd167155da2047b2e1c96cd4":[5,2,3,1,5],
@@ -111,18 +113,18 @@ var NAVTREEINDEX70 =
 "class_ogre_1_1_data_stream.html#aff0243c8ad8f5de00bf8e0887d0f034f":[5,2,11,27,11],
 "class_ogre_1_1_decal.html":[7,0,0,257],
 "class_ogre_1_1_decal.html":[6,0,0,284],
-"class_ogre_1_1_decal.html#a015c3801632c98bca5dbb5aa3da1aa24":[7,0,0,257,27],
 "class_ogre_1_1_decal.html#a015c3801632c98bca5dbb5aa3da1aa24":[6,0,0,284,27],
-"class_ogre_1_1_decal.html#a01f48775e48b672d7796311f3ffe2930":[7,0,0,257,30],
+"class_ogre_1_1_decal.html#a015c3801632c98bca5dbb5aa3da1aa24":[7,0,0,257,27],
 "class_ogre_1_1_decal.html#a01f48775e48b672d7796311f3ffe2930":[6,0,0,284,30],
-"class_ogre_1_1_decal.html#a090ed9460fa373f8f76fd21c2c744039":[7,0,0,257,65],
+"class_ogre_1_1_decal.html#a01f48775e48b672d7796311f3ffe2930":[7,0,0,257,30],
 "class_ogre_1_1_decal.html#a090ed9460fa373f8f76fd21c2c744039":[6,0,0,284,65],
+"class_ogre_1_1_decal.html#a090ed9460fa373f8f76fd21c2c744039":[7,0,0,257,65],
 "class_ogre_1_1_decal.html#a0a7a49cc2dc55581e05baca116972b52":[6,0,0,284,33],
 "class_ogre_1_1_decal.html#a0a7a49cc2dc55581e05baca116972b52":[7,0,0,257,33],
 "class_ogre_1_1_decal.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[6,0,0,284,77],
 "class_ogre_1_1_decal.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[7,0,0,257,77],
-"class_ogre_1_1_decal.html#a10f80a56f3fc23e48d5ca438d37b2295":[7,0,0,257,101],
 "class_ogre_1_1_decal.html#a10f80a56f3fc23e48d5ca438d37b2295":[6,0,0,284,101],
+"class_ogre_1_1_decal.html#a10f80a56f3fc23e48d5ca438d37b2295":[7,0,0,257,101],
 "class_ogre_1_1_decal.html#a13629b96b4a6b0b34f652234f037d8d9":[7,0,0,257,59],
 "class_ogre_1_1_decal.html#a13629b96b4a6b0b34f652234f037d8d9":[6,0,0,284,59],
 "class_ogre_1_1_decal.html#a1427f0b635a4186cd6083a9bab879fa2":[7,0,0,257,107],
@@ -135,60 +137,60 @@ var NAVTREEINDEX70 =
 "class_ogre_1_1_decal.html#a19bf2951b97744064509c13068143f3d":[6,0,0,284,55],
 "class_ogre_1_1_decal.html#a1a048b8ace0a21cd2ed2c3008941ce3d":[7,0,0,257,29],
 "class_ogre_1_1_decal.html#a1a048b8ace0a21cd2ed2c3008941ce3d":[6,0,0,284,29],
-"class_ogre_1_1_decal.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,284,68],
 "class_ogre_1_1_decal.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,257,68],
+"class_ogre_1_1_decal.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,284,68],
 "class_ogre_1_1_decal.html#a1ce521035e5c57bf8db060d48710702a":[6,0,0,284,87],
 "class_ogre_1_1_decal.html#a1ce521035e5c57bf8db060d48710702a":[7,0,0,257,87],
-"class_ogre_1_1_decal.html#a27eb8980ee187b42ea619c582eaebf73":[7,0,0,257,54],
 "class_ogre_1_1_decal.html#a27eb8980ee187b42ea619c582eaebf73":[6,0,0,284,54],
+"class_ogre_1_1_decal.html#a27eb8980ee187b42ea619c582eaebf73":[7,0,0,257,54],
 "class_ogre_1_1_decal.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[6,0,0,284,105],
 "class_ogre_1_1_decal.html#a28b12f8d0fd7c9da7fcd1e9806dd8064":[7,0,0,257,105],
-"class_ogre_1_1_decal.html#a2d62d2c3d09910210c948fc660468c46":[6,0,0,284,61],
 "class_ogre_1_1_decal.html#a2d62d2c3d09910210c948fc660468c46":[7,0,0,257,61],
-"class_ogre_1_1_decal.html#a2e3e690195e9d7e14c6ad4e1fe7ba9e5":[7,0,0,257,63],
+"class_ogre_1_1_decal.html#a2d62d2c3d09910210c948fc660468c46":[6,0,0,284,61],
 "class_ogre_1_1_decal.html#a2e3e690195e9d7e14c6ad4e1fe7ba9e5":[6,0,0,284,63],
+"class_ogre_1_1_decal.html#a2e3e690195e9d7e14c6ad4e1fe7ba9e5":[7,0,0,257,63],
 "class_ogre_1_1_decal.html#a2eb94fea5944cf0d33702a75cfa14a74":[6,0,0,284,31],
 "class_ogre_1_1_decal.html#a2eb94fea5944cf0d33702a75cfa14a74":[7,0,0,257,31],
 "class_ogre_1_1_decal.html#a30acf249cd312d9eed03a0f3ad618067":[6,0,0,284,38],
 "class_ogre_1_1_decal.html#a30acf249cd312d9eed03a0f3ad618067":[7,0,0,257,38],
-"class_ogre_1_1_decal.html#a346fc3cc74be861a12e7d9a541468ab2":[7,0,0,257,93],
 "class_ogre_1_1_decal.html#a346fc3cc74be861a12e7d9a541468ab2":[6,0,0,284,93],
-"class_ogre_1_1_decal.html#a35b519fd7cbbee4b8dc8ef7c1e526ba3":[7,0,0,257,39],
+"class_ogre_1_1_decal.html#a346fc3cc74be861a12e7d9a541468ab2":[7,0,0,257,93],
 "class_ogre_1_1_decal.html#a35b519fd7cbbee4b8dc8ef7c1e526ba3":[6,0,0,284,39],
+"class_ogre_1_1_decal.html#a35b519fd7cbbee4b8dc8ef7c1e526ba3":[7,0,0,257,39],
 "class_ogre_1_1_decal.html#a35d4fa19a2750732ceef42ec5f9aabd1":[6,0,0,284,118],
 "class_ogre_1_1_decal.html#a35d4fa19a2750732ceef42ec5f9aabd1":[7,0,0,257,118],
-"class_ogre_1_1_decal.html#a38f8241458458e4f1235eae7d8f850c3":[7,0,0,257,104],
 "class_ogre_1_1_decal.html#a38f8241458458e4f1235eae7d8f850c3":[6,0,0,284,104],
-"class_ogre_1_1_decal.html#a3aaa7460cb807314ec6538fd90f3c5ea":[7,0,0,257,35],
+"class_ogre_1_1_decal.html#a38f8241458458e4f1235eae7d8f850c3":[7,0,0,257,104],
 "class_ogre_1_1_decal.html#a3aaa7460cb807314ec6538fd90f3c5ea":[6,0,0,284,35],
-"class_ogre_1_1_decal.html#a40c16510f922349564850218d20f54cb":[7,0,0,257,115],
+"class_ogre_1_1_decal.html#a3aaa7460cb807314ec6538fd90f3c5ea":[7,0,0,257,35],
 "class_ogre_1_1_decal.html#a40c16510f922349564850218d20f54cb":[6,0,0,284,115],
+"class_ogre_1_1_decal.html#a40c16510f922349564850218d20f54cb":[7,0,0,257,115],
 "class_ogre_1_1_decal.html#a4569b91ce5341ab892f74ab4555cac7d":[6,0,0,284,49],
 "class_ogre_1_1_decal.html#a4569b91ce5341ab892f74ab4555cac7d":[7,0,0,257,49],
-"class_ogre_1_1_decal.html#a4a40a12d7cd0f7fa4c4c0fc31bbf9a40":[6,0,0,284,78],
 "class_ogre_1_1_decal.html#a4a40a12d7cd0f7fa4c4c0fc31bbf9a40":[7,0,0,257,78],
-"class_ogre_1_1_decal.html#a4c29a048d9254c17c43a9fa313df0a6b":[6,0,0,284,8],
+"class_ogre_1_1_decal.html#a4a40a12d7cd0f7fa4c4c0fc31bbf9a40":[6,0,0,284,78],
 "class_ogre_1_1_decal.html#a4c29a048d9254c17c43a9fa313df0a6b":[7,0,0,257,8],
-"class_ogre_1_1_decal.html#a4d43f57e9abcc21d4bc50e6e6d1b5cc7":[7,0,0,257,100],
+"class_ogre_1_1_decal.html#a4c29a048d9254c17c43a9fa313df0a6b":[6,0,0,284,8],
 "class_ogre_1_1_decal.html#a4d43f57e9abcc21d4bc50e6e6d1b5cc7":[6,0,0,284,100],
+"class_ogre_1_1_decal.html#a4d43f57e9abcc21d4bc50e6e6d1b5cc7":[7,0,0,257,100],
 "class_ogre_1_1_decal.html#a504e2192036f75007c51e157315e1548":[7,0,0,257,80],
 "class_ogre_1_1_decal.html#a504e2192036f75007c51e157315e1548":[6,0,0,284,80],
 "class_ogre_1_1_decal.html#a5456ecd630d55c91b2fd1b19969d29f5":[6,0,0,284,90],
 "class_ogre_1_1_decal.html#a5456ecd630d55c91b2fd1b19969d29f5":[7,0,0,257,90],
 "class_ogre_1_1_decal.html#a54fc365f16014359d23cecf859da5510":[7,0,0,257,36],
 "class_ogre_1_1_decal.html#a54fc365f16014359d23cecf859da5510":[6,0,0,284,36],
-"class_ogre_1_1_decal.html#a55237a2e03c449e5c3c62858e61d5494":[7,0,0,257,5],
 "class_ogre_1_1_decal.html#a55237a2e03c449e5c3c62858e61d5494":[6,0,0,284,5],
-"class_ogre_1_1_decal.html#a56f68c0f66ff12a7e9f9d18945a13c0c":[6,0,0,284,102],
+"class_ogre_1_1_decal.html#a55237a2e03c449e5c3c62858e61d5494":[7,0,0,257,5],
 "class_ogre_1_1_decal.html#a56f68c0f66ff12a7e9f9d18945a13c0c":[7,0,0,257,102],
+"class_ogre_1_1_decal.html#a56f68c0f66ff12a7e9f9d18945a13c0c":[6,0,0,284,102],
 "class_ogre_1_1_decal.html#a56f9a81669101f7ed60e7fd3fb587378":[6,0,0,284,3],
 "class_ogre_1_1_decal.html#a56f9a81669101f7ed60e7fd3fb587378":[7,0,0,257,3],
 "class_ogre_1_1_decal.html#a57123ae4fec1b472f25270c1dd6abe59":[7,0,0,257,12],
 "class_ogre_1_1_decal.html#a57123ae4fec1b472f25270c1dd6abe59":[6,0,0,284,12],
 "class_ogre_1_1_decal.html#a57e0523432c6e5133ff4fc251111a60e":[6,0,0,284,76],
 "class_ogre_1_1_decal.html#a57e0523432c6e5133ff4fc251111a60e":[7,0,0,257,76],
-"class_ogre_1_1_decal.html#a581bf216b2102978ac08f9801c26cc30":[7,0,0,257,41],
 "class_ogre_1_1_decal.html#a581bf216b2102978ac08f9801c26cc30":[6,0,0,284,41],
+"class_ogre_1_1_decal.html#a581bf216b2102978ac08f9801c26cc30":[7,0,0,257,41],
 "class_ogre_1_1_decal.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,257,70],
 "class_ogre_1_1_decal.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,284,70],
 "class_ogre_1_1_decal.html#a5f7b365da61eba227c468681e0fb1cde":[7,0,0,257,24],
@@ -199,55 +201,53 @@ var NAVTREEINDEX70 =
 "class_ogre_1_1_decal.html#a61b39d44e60020d43033a6957895aa5f":[6,0,0,284,23],
 "class_ogre_1_1_decal.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,257,73],
 "class_ogre_1_1_decal.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,284,73],
-"class_ogre_1_1_decal.html#a64bd61f33ae8a2d4e824ce7e23308d98":[6,0,0,284,18],
 "class_ogre_1_1_decal.html#a64bd61f33ae8a2d4e824ce7e23308d98":[7,0,0,257,18],
-"class_ogre_1_1_decal.html#a6944af26e8944b13756ade50cd1092d8":[7,0,0,257,37],
+"class_ogre_1_1_decal.html#a64bd61f33ae8a2d4e824ce7e23308d98":[6,0,0,284,18],
 "class_ogre_1_1_decal.html#a6944af26e8944b13756ade50cd1092d8":[6,0,0,284,37],
-"class_ogre_1_1_decal.html#a6b823b52684730302908ecfd1a8e6d54":[6,0,0,284,16],
+"class_ogre_1_1_decal.html#a6944af26e8944b13756ade50cd1092d8":[7,0,0,257,37],
 "class_ogre_1_1_decal.html#a6b823b52684730302908ecfd1a8e6d54":[7,0,0,257,16],
+"class_ogre_1_1_decal.html#a6b823b52684730302908ecfd1a8e6d54":[6,0,0,284,16],
 "class_ogre_1_1_decal.html#a6c4003f6b67540727844dc33c20714f7":[6,0,0,284,64],
 "class_ogre_1_1_decal.html#a6c4003f6b67540727844dc33c20714f7":[7,0,0,257,64],
-"class_ogre_1_1_decal.html#a6fb94e1627676c7d7517e13944bd0580":[7,0,0,257,79],
 "class_ogre_1_1_decal.html#a6fb94e1627676c7d7517e13944bd0580":[6,0,0,284,79],
-"class_ogre_1_1_decal.html#a7241fd29a548973d1d2fa56bcc9f13a4":[6,0,0,284,7],
+"class_ogre_1_1_decal.html#a6fb94e1627676c7d7517e13944bd0580":[7,0,0,257,79],
 "class_ogre_1_1_decal.html#a7241fd29a548973d1d2fa56bcc9f13a4":[7,0,0,257,7],
+"class_ogre_1_1_decal.html#a7241fd29a548973d1d2fa56bcc9f13a4":[6,0,0,284,7],
 "class_ogre_1_1_decal.html#a77198e02dd65dd368ea4e6af88a93fda":[7,0,0,257,97],
 "class_ogre_1_1_decal.html#a77198e02dd65dd368ea4e6af88a93fda":[6,0,0,284,97],
-"class_ogre_1_1_decal.html#a7bba2e8114704b6e682df9d9b090415c":[7,0,0,257,96],
 "class_ogre_1_1_decal.html#a7bba2e8114704b6e682df9d9b090415c":[6,0,0,284,96],
+"class_ogre_1_1_decal.html#a7bba2e8114704b6e682df9d9b090415c":[7,0,0,257,96],
 "class_ogre_1_1_decal.html#a7c3bff2a6922bbc098c789e9386140e3":[7,0,0,257,109],
 "class_ogre_1_1_decal.html#a7c3bff2a6922bbc098c789e9386140e3":[6,0,0,284,109],
 "class_ogre_1_1_decal.html#a7c633da32362e05bd24871c7a612fdac":[6,0,0,284,26],
 "class_ogre_1_1_decal.html#a7c633da32362e05bd24871c7a612fdac":[7,0,0,257,26],
-"class_ogre_1_1_decal.html#a7cd15e3a5caae8ae786bd752c6b27f26":[6,0,0,284,103],
 "class_ogre_1_1_decal.html#a7cd15e3a5caae8ae786bd752c6b27f26":[7,0,0,257,103],
-"class_ogre_1_1_decal.html#a7d491859c987cf03cd2b62121e9bfea0":[6,0,0,284,21],
+"class_ogre_1_1_decal.html#a7cd15e3a5caae8ae786bd752c6b27f26":[6,0,0,284,103],
 "class_ogre_1_1_decal.html#a7d491859c987cf03cd2b62121e9bfea0":[7,0,0,257,21],
-"class_ogre_1_1_decal.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,257,66],
+"class_ogre_1_1_decal.html#a7d491859c987cf03cd2b62121e9bfea0":[6,0,0,284,21],
 "class_ogre_1_1_decal.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,284,66],
+"class_ogre_1_1_decal.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,257,66],
 "class_ogre_1_1_decal.html#a8561b8de767cf64740c37eb1aeddd529":[6,0,0,284,14],
 "class_ogre_1_1_decal.html#a8561b8de767cf64740c37eb1aeddd529":[7,0,0,257,14],
-"class_ogre_1_1_decal.html#a862e7d3af40ee31de2f95a626207f96d":[6,0,0,284,4],
 "class_ogre_1_1_decal.html#a862e7d3af40ee31de2f95a626207f96d":[7,0,0,257,4],
-"class_ogre_1_1_decal.html#a863bac56e5c968767e811816376d3ce5":[7,0,0,257,25],
+"class_ogre_1_1_decal.html#a862e7d3af40ee31de2f95a626207f96d":[6,0,0,284,4],
 "class_ogre_1_1_decal.html#a863bac56e5c968767e811816376d3ce5":[6,0,0,284,25],
-"class_ogre_1_1_decal.html#a865cb46cc09cbb8bd560abeca1d0d31e":[7,0,0,257,9],
+"class_ogre_1_1_decal.html#a863bac56e5c968767e811816376d3ce5":[7,0,0,257,25],
 "class_ogre_1_1_decal.html#a865cb46cc09cbb8bd560abeca1d0d31e":[6,0,0,284,9],
+"class_ogre_1_1_decal.html#a865cb46cc09cbb8bd560abeca1d0d31e":[7,0,0,257,9],
 "class_ogre_1_1_decal.html#a87b5691e56e3879d8a6986bd27f8f61c":[7,0,0,257,111],
 "class_ogre_1_1_decal.html#a87b5691e56e3879d8a6986bd27f8f61c":[6,0,0,284,111],
-"class_ogre_1_1_decal.html#a9117a6346875a501daf2f425fde5abe7":[6,0,0,284,89],
 "class_ogre_1_1_decal.html#a9117a6346875a501daf2f425fde5abe7":[7,0,0,257,89],
+"class_ogre_1_1_decal.html#a9117a6346875a501daf2f425fde5abe7":[6,0,0,284,89],
 "class_ogre_1_1_decal.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,284,69],
 "class_ogre_1_1_decal.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,257,69],
-"class_ogre_1_1_decal.html#a93efcc6b9a3052535463db26b6d62cf7":[7,0,0,257,95],
 "class_ogre_1_1_decal.html#a93efcc6b9a3052535463db26b6d62cf7":[6,0,0,284,95],
-"class_ogre_1_1_decal.html#a946fe853888c890294ae407f47f404a0":[6,0,0,284,114],
+"class_ogre_1_1_decal.html#a93efcc6b9a3052535463db26b6d62cf7":[7,0,0,257,95],
 "class_ogre_1_1_decal.html#a946fe853888c890294ae407f47f404a0":[7,0,0,257,114],
-"class_ogre_1_1_decal.html#a94b6027a7a2a0b5b36850eaff922c888":[6,0,0,284,113],
+"class_ogre_1_1_decal.html#a946fe853888c890294ae407f47f404a0":[6,0,0,284,114],
 "class_ogre_1_1_decal.html#a94b6027a7a2a0b5b36850eaff922c888":[7,0,0,257,113],
+"class_ogre_1_1_decal.html#a94b6027a7a2a0b5b36850eaff922c888":[6,0,0,284,113],
 "class_ogre_1_1_decal.html#a98fe88f82f86eafa19308074495db809":[6,0,0,284,15],
 "class_ogre_1_1_decal.html#a98fe88f82f86eafa19308074495db809":[7,0,0,257,15],
-"class_ogre_1_1_decal.html#a9a62a4a12787812f012691af0c3493f1":[7,0,0,257,82],
-"class_ogre_1_1_decal.html#a9a62a4a12787812f012691af0c3493f1":[6,0,0,284,82],
-"class_ogre_1_1_decal.html#a9a72ade896561e23c32cf8659f1640e4":[7,0,0,257,57]
+"class_ogre_1_1_decal.html#a9a62a4a12787812f012691af0c3493f1":[6,0,0,284,82]
 };
