@@ -1,82 +1,84 @@
 var NAVTREEINDEX72 =
 {
+"class_ogre_1_1_default_intersection_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,2,12,12,25],
 "class_ogre_1_1_default_intersection_scene_query.html#a467a4c2459e8bad4fb14eba9f9d8f567":[5,0,1,12,2],
-"class_ogre_1_1_default_intersection_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,12,14],
+"class_ogre_1_1_default_intersection_scene_query.html#a467a4c2459e8bad4fb14eba9f9d8f567":[5,2,12,12,2],
 "class_ogre_1_1_default_intersection_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,12,14],
-"class_ogre_1_1_default_intersection_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,12,17],
+"class_ogre_1_1_default_intersection_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,12,14],
 "class_ogre_1_1_default_intersection_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,12,17],
+"class_ogre_1_1_default_intersection_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,12,17],
 "class_ogre_1_1_default_intersection_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,2,12,12,8],
 "class_ogre_1_1_default_intersection_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,0,1,12,8],
 "class_ogre_1_1_default_intersection_scene_query.html#a7df8386f937c104aeb4f6cf50eb3bd8f":[5,2,12,12,6],
 "class_ogre_1_1_default_intersection_scene_query.html#a7df8386f937c104aeb4f6cf50eb3bd8f":[5,0,1,12,6],
 "class_ogre_1_1_default_intersection_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,12,10],
 "class_ogre_1_1_default_intersection_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,12,10],
-"class_ogre_1_1_default_intersection_scene_query.html#a8bb5ee8db3442cd4515ae683e437d9f3":[5,2,12,12,3],
 "class_ogre_1_1_default_intersection_scene_query.html#a8bb5ee8db3442cd4515ae683e437d9f3":[5,0,1,12,3],
-"class_ogre_1_1_default_intersection_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,12,13],
+"class_ogre_1_1_default_intersection_scene_query.html#a8bb5ee8db3442cd4515ae683e437d9f3":[5,2,12,12,3],
 "class_ogre_1_1_default_intersection_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,12,13],
-"class_ogre_1_1_default_intersection_scene_query.html#a9518286cb7bd045924f2337f88bbcca2":[5,2,12,12,1],
+"class_ogre_1_1_default_intersection_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,12,13],
 "class_ogre_1_1_default_intersection_scene_query.html#a9518286cb7bd045924f2337f88bbcca2":[5,0,1,12,1],
+"class_ogre_1_1_default_intersection_scene_query.html#a9518286cb7bd045924f2337f88bbcca2":[5,2,12,12,1],
 "class_ogre_1_1_default_intersection_scene_query.html#ab1b25001401cf9026c9aa58e490f978f":[5,2,12,12,21],
 "class_ogre_1_1_default_intersection_scene_query.html#ab1b25001401cf9026c9aa58e490f978f":[5,0,1,12,21],
-"class_ogre_1_1_default_intersection_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,12,16],
 "class_ogre_1_1_default_intersection_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,12,16],
-"class_ogre_1_1_default_intersection_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,12,11],
+"class_ogre_1_1_default_intersection_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,12,16],
 "class_ogre_1_1_default_intersection_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,12,11],
-"class_ogre_1_1_default_intersection_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,0,1,12,9],
+"class_ogre_1_1_default_intersection_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,12,11],
 "class_ogre_1_1_default_intersection_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,2,12,12,9],
+"class_ogre_1_1_default_intersection_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,0,1,12,9],
 "class_ogre_1_1_default_intersection_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,12,15],
 "class_ogre_1_1_default_intersection_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,12,15],
 "class_ogre_1_1_default_intersection_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,12,12,22],
 "class_ogre_1_1_default_intersection_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,0,1,12,22],
-"class_ogre_1_1_default_intersection_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,12,18],
 "class_ogre_1_1_default_intersection_scene_query.html#adce32528577d71b228692df906ecd17c":[5,2,12,12,18],
-"class_ogre_1_1_default_intersection_scene_query.html#adfd70f00b13654735336f4360af84995":[5,0,1,12,24],
+"class_ogre_1_1_default_intersection_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,12,18],
 "class_ogre_1_1_default_intersection_scene_query.html#adfd70f00b13654735336f4360af84995":[5,2,12,12,24],
-"class_ogre_1_1_default_intersection_scene_query.html#ae14c15e1a2630b4a45dd3a9ee8eb2d45":[5,2,12,12,4],
+"class_ogre_1_1_default_intersection_scene_query.html#adfd70f00b13654735336f4360af84995":[5,0,1,12,24],
 "class_ogre_1_1_default_intersection_scene_query.html#ae14c15e1a2630b4a45dd3a9ee8eb2d45":[5,0,1,12,4],
+"class_ogre_1_1_default_intersection_scene_query.html#ae14c15e1a2630b4a45dd3a9ee8eb2d45":[5,2,12,12,4],
 "class_ogre_1_1_default_intersection_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,1,12,23],
 "class_ogre_1_1_default_intersection_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,2,12,12,23],
-"class_ogre_1_1_default_intersection_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,12,19],
 "class_ogre_1_1_default_intersection_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,12,19],
+"class_ogre_1_1_default_intersection_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,12,19],
 "class_ogre_1_1_default_intersection_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,12,12,7],
 "class_ogre_1_1_default_intersection_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,0,1,12,7],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html":[5,0,1,13],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html":[5,2,12,13],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,2,12,13,0],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,0,1,13,0],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,2,12,13,0],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,0,1,13,0,2],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,13,0,2],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,2,12,13,0,1],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,0,1,13,0,1],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,2,12,13,0,1],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,0,1,13,0,0],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,2,12,13,0,0],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,0,1,13,0,4],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,2,12,13,0,4],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,2,12,13,0,3],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,0,1,13,0,3],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,13,14],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,2,12,13,0,3],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,13,14],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,13,14],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,2,12,13,3],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,0,1,13,3],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a2d902fd16b0ca8e206797bc0bc7b0fbc":[5,2,12,13,4],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a2d902fd16b0ca8e206797bc0bc7b0fbc":[5,0,1,13,4],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a3aa0ae83ca7021ea278a5f152053c48a":[5,2,12,13,1],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a3aa0ae83ca7021ea278a5f152053c48a":[5,0,1,13,1],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a3aa0ae83ca7021ea278a5f152053c48a":[5,2,12,13,1],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,2,12,13,28],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,0,1,13,28],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,2,12,13,22],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,0,1,13,22],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a530f7cf03ff0240f2ce9806e09707364":[5,0,1,13,2],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,2,12,13,22],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a530f7cf03ff0240f2ce9806e09707364":[5,2,12,13,2],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,13,16],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a530f7cf03ff0240f2ce9806e09707364":[5,0,1,13,2],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,13,16],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,13,19],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,13,16],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,13,19],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,0,1,13,9],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,13,19],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,2,12,13,9],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,13,12],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,0,1,13,9],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,13,12],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,13,12],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,0,1,13,7],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,2,12,13,7],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,13,15],
@@ -87,136 +89,136 @@ var NAVTREEINDEX72 =
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,0,1,13,6],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,13,18],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,13,18],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,13,13],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,13,13],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,13,13],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,0,1,13,11],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,2,12,13,11],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,13,17],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,13,17],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,12,13,24],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,0,1,13,24],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,12,13,24],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,13,20],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#adce32528577d71b228692df906ecd17c":[5,2,12,13,20],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#adfd70f00b13654735336f4360af84995":[5,0,1,13,27],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#adfd70f00b13654735336f4360af84995":[5,2,12,13,27],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#adfd70f00b13654735336f4360af84995":[5,0,1,13,27],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,0,1,13,23],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,2,12,13,23],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,1,13,26],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,2,12,13,26],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,13,21],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,1,13,26],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,13,21],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,12,13,8],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,13,21],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,0,1,13,8],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#af82e119f79b5e4e91e599c27623977df":[5,0,1,13,25],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,12,13,8],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#af82e119f79b5e4e91e599c27623977df":[5,2,12,13,25],
-"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#af9f6f42dc4cd2b5368e380ff4297fdbf":[5,0,1,13,10],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#af82e119f79b5e4e91e599c27623977df":[5,0,1,13,25],
 "class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#af9f6f42dc4cd2b5368e380ff4297fdbf":[5,2,12,13,10],
+"class_ogre_1_1_default_plane_bounded_volume_list_scene_query.html#af9f6f42dc4cd2b5368e380ff4297fdbf":[5,0,1,13,10],
 "class_ogre_1_1_default_ray_scene_query.html":[5,0,1,14],
 "class_ogre_1_1_default_ray_scene_query.html":[5,2,12,14],
 "class_ogre_1_1_default_ray_scene_query.html#a07bab17df4892cfcd7a7b73edc2dee2d":[5,2,12,14,1],
 "class_ogre_1_1_default_ray_scene_query.html#a07bab17df4892cfcd7a7b73edc2dee2d":[5,0,1,14,1],
-"class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,2,12,14,0],
 "class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,0,1,14,0],
+"class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,2,12,14,0],
 "class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,14,0,2],
 "class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,0,1,14,0,2],
 "class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,2,12,14,0,1],
 "class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa667bbec7031e58ab244f9efc32056f38":[5,0,1,14,0,1],
-"class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,2,12,14,0,0],
 "class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,0,1,14,0,0],
-"class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,0,1,14,0,4],
+"class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa6ed287fab168d451beb369009f0fd03b":[5,2,12,14,0,0],
 "class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,2,12,14,0,4],
-"class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,2,12,14,0,3],
+"class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,0,1,14,0,4],
 "class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,0,1,14,0,3],
+"class_ogre_1_1_default_ray_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,2,12,14,0,3],
 "class_ogre_1_1_default_ray_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,14,15],
 "class_ogre_1_1_default_ray_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,14,15],
-"class_ogre_1_1_default_ray_scene_query.html#a32f960cc88fd644922bfc4c58643f993":[5,0,1,14,27],
 "class_ogre_1_1_default_ray_scene_query.html#a32f960cc88fd644922bfc4c58643f993":[5,2,12,14,27],
-"class_ogre_1_1_default_ray_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,0,1,14,30],
+"class_ogre_1_1_default_ray_scene_query.html#a32f960cc88fd644922bfc4c58643f993":[5,0,1,14,27],
 "class_ogre_1_1_default_ray_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,2,12,14,30],
-"class_ogre_1_1_default_ray_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,14,17],
+"class_ogre_1_1_default_ray_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,0,1,14,30],
 "class_ogre_1_1_default_ray_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,14,17],
-"class_ogre_1_1_default_ray_scene_query.html#a5a96085659aec2c0df9c271f4372a74a":[5,2,12,14,26],
+"class_ogre_1_1_default_ray_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,14,17],
 "class_ogre_1_1_default_ray_scene_query.html#a5a96085659aec2c0df9c271f4372a74a":[5,0,1,14,26],
+"class_ogre_1_1_default_ray_scene_query.html#a5a96085659aec2c0df9c271f4372a74a":[5,2,12,14,26],
 "class_ogre_1_1_default_ray_scene_query.html#a61b4f1fb6ff472bba5e89a516956dcb9":[5,0,1,14,4],
 "class_ogre_1_1_default_ray_scene_query.html#a61b4f1fb6ff472bba5e89a516956dcb9":[5,2,12,14,4],
-"class_ogre_1_1_default_ray_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,14,20],
 "class_ogre_1_1_default_ray_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,14,20],
+"class_ogre_1_1_default_ray_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,14,20],
 "class_ogre_1_1_default_ray_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,2,12,14,11],
 "class_ogre_1_1_default_ray_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,0,1,14,11],
-"class_ogre_1_1_default_ray_scene_query.html#a77a386c0c29bb49f1138c447d13489ea":[5,2,12,14,10],
 "class_ogre_1_1_default_ray_scene_query.html#a77a386c0c29bb49f1138c447d13489ea":[5,0,1,14,10],
-"class_ogre_1_1_default_ray_scene_query.html#a82be4a74a790ba20482858c9fa4a7feb":[5,0,1,14,5],
+"class_ogre_1_1_default_ray_scene_query.html#a77a386c0c29bb49f1138c447d13489ea":[5,2,12,14,10],
 "class_ogre_1_1_default_ray_scene_query.html#a82be4a74a790ba20482858c9fa4a7feb":[5,2,12,14,5],
+"class_ogre_1_1_default_ray_scene_query.html#a82be4a74a790ba20482858c9fa4a7feb":[5,0,1,14,5],
 "class_ogre_1_1_default_ray_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,14,13],
 "class_ogre_1_1_default_ray_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,14,13],
-"class_ogre_1_1_default_ray_scene_query.html#a88c9810df53d94b893bc5aef885d14a1":[5,2,12,14,23],
 "class_ogre_1_1_default_ray_scene_query.html#a88c9810df53d94b893bc5aef885d14a1":[5,0,1,14,23],
-"class_ogre_1_1_default_ray_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,14,16],
+"class_ogre_1_1_default_ray_scene_query.html#a88c9810df53d94b893bc5aef885d14a1":[5,2,12,14,23],
 "class_ogre_1_1_default_ray_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,14,16],
-"class_ogre_1_1_default_ray_scene_query.html#a9d92470691482f1d57b31b5a23deca62":[5,2,12,14,9],
+"class_ogre_1_1_default_ray_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,14,16],
 "class_ogre_1_1_default_ray_scene_query.html#a9d92470691482f1d57b31b5a23deca62":[5,0,1,14,9],
-"class_ogre_1_1_default_ray_scene_query.html#ab04fa682c37d4a7d3d981a1513015120":[5,2,12,14,6],
+"class_ogre_1_1_default_ray_scene_query.html#a9d92470691482f1d57b31b5a23deca62":[5,2,12,14,9],
 "class_ogre_1_1_default_ray_scene_query.html#ab04fa682c37d4a7d3d981a1513015120":[5,0,1,14,6],
+"class_ogre_1_1_default_ray_scene_query.html#ab04fa682c37d4a7d3d981a1513015120":[5,2,12,14,6],
 "class_ogre_1_1_default_ray_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,14,19],
 "class_ogre_1_1_default_ray_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,14,19],
-"class_ogre_1_1_default_ray_scene_query.html#abd5211784dd04e0e0705fe21d43cb900":[5,2,12,14,24],
 "class_ogre_1_1_default_ray_scene_query.html#abd5211784dd04e0e0705fe21d43cb900":[5,0,1,14,24],
+"class_ogre_1_1_default_ray_scene_query.html#abd5211784dd04e0e0705fe21d43cb900":[5,2,12,14,24],
 "class_ogre_1_1_default_ray_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,14,14],
 "class_ogre_1_1_default_ray_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,14,14],
-"class_ogre_1_1_default_ray_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,2,12,14,12],
 "class_ogre_1_1_default_ray_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,0,1,14,12],
-"class_ogre_1_1_default_ray_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,14,18],
+"class_ogre_1_1_default_ray_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,2,12,14,12],
 "class_ogre_1_1_default_ray_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,14,18],
-"class_ogre_1_1_default_ray_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,12,14,25],
+"class_ogre_1_1_default_ray_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,14,18],
 "class_ogre_1_1_default_ray_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,0,1,14,25],
-"class_ogre_1_1_default_ray_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,14,21],
+"class_ogre_1_1_default_ray_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,12,14,25],
 "class_ogre_1_1_default_ray_scene_query.html#adce32528577d71b228692df906ecd17c":[5,2,12,14,21],
+"class_ogre_1_1_default_ray_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,14,21],
 "class_ogre_1_1_default_ray_scene_query.html#adfd70f00b13654735336f4360af84995":[5,0,1,14,29],
 "class_ogre_1_1_default_ray_scene_query.html#adfd70f00b13654735336f4360af84995":[5,2,12,14,29],
 "class_ogre_1_1_default_ray_scene_query.html#ae36fdbcb7dd13085b245f7a565a3ef54":[5,0,1,14,7],
 "class_ogre_1_1_default_ray_scene_query.html#ae36fdbcb7dd13085b245f7a565a3ef54":[5,2,12,14,7],
 "class_ogre_1_1_default_ray_scene_query.html#ae93bb5dafd039eb08c44cd42215c34c4":[5,0,1,14,3],
 "class_ogre_1_1_default_ray_scene_query.html#ae93bb5dafd039eb08c44cd42215c34c4":[5,2,12,14,3],
-"class_ogre_1_1_default_ray_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,2,12,14,28],
 "class_ogre_1_1_default_ray_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,1,14,28],
+"class_ogre_1_1_default_ray_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,2,12,14,28],
 "class_ogre_1_1_default_ray_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,14,22],
 "class_ogre_1_1_default_ray_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,14,22],
 "class_ogre_1_1_default_ray_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,0,1,14,8],
 "class_ogre_1_1_default_ray_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,12,14,8],
-"class_ogre_1_1_default_ray_scene_query.html#aee26bdd5505fbcad6a077124810738af":[5,0,1,14,2],
 "class_ogre_1_1_default_ray_scene_query.html#aee26bdd5505fbcad6a077124810738af":[5,2,12,14,2],
+"class_ogre_1_1_default_ray_scene_query.html#aee26bdd5505fbcad6a077124810738af":[5,0,1,14,2],
 "class_ogre_1_1_default_scene_format_listener.html":[5,2,12,15],
 "class_ogre_1_1_default_scene_format_listener.html":[5,0,1,15],
-"class_ogre_1_1_default_scene_format_listener.html#a17bb4d20d25d4ece80a72d28bdc016ac":[5,0,1,15,5],
 "class_ogre_1_1_default_scene_format_listener.html#a17bb4d20d25d4ece80a72d28bdc016ac":[5,2,12,15,5],
-"class_ogre_1_1_default_scene_format_listener.html#a26a4e68160fcc7c36bfcd938ca5c38a0":[5,0,1,15,4],
+"class_ogre_1_1_default_scene_format_listener.html#a17bb4d20d25d4ece80a72d28bdc016ac":[5,0,1,15,5],
 "class_ogre_1_1_default_scene_format_listener.html#a26a4e68160fcc7c36bfcd938ca5c38a0":[5,2,12,15,4],
-"class_ogre_1_1_default_scene_format_listener.html#a2e0c85f8de336de4cb83b18962a5d852":[5,2,12,15,8],
+"class_ogre_1_1_default_scene_format_listener.html#a26a4e68160fcc7c36bfcd938ca5c38a0":[5,0,1,15,4],
 "class_ogre_1_1_default_scene_format_listener.html#a2e0c85f8de336de4cb83b18962a5d852":[5,0,1,15,8],
-"class_ogre_1_1_default_scene_format_listener.html#a3f7ab493cf90b1db58b87c4d1e43d6ab":[5,0,1,15,0],
+"class_ogre_1_1_default_scene_format_listener.html#a2e0c85f8de336de4cb83b18962a5d852":[5,2,12,15,8],
 "class_ogre_1_1_default_scene_format_listener.html#a3f7ab493cf90b1db58b87c4d1e43d6ab":[5,2,12,15,0],
+"class_ogre_1_1_default_scene_format_listener.html#a3f7ab493cf90b1db58b87c4d1e43d6ab":[5,0,1,15,0],
 "class_ogre_1_1_default_scene_format_listener.html#a41c9cc88fa90d3073646c2814a45d07e":[5,2,12,15,2],
 "class_ogre_1_1_default_scene_format_listener.html#a41c9cc88fa90d3073646c2814a45d07e":[5,0,1,15,2],
-"class_ogre_1_1_default_scene_format_listener.html#a5c7bab9449f5610535e2a56a1013418c":[5,0,1,15,7],
 "class_ogre_1_1_default_scene_format_listener.html#a5c7bab9449f5610535e2a56a1013418c":[5,2,12,15,7],
+"class_ogre_1_1_default_scene_format_listener.html#a5c7bab9449f5610535e2a56a1013418c":[5,0,1,15,7],
 "class_ogre_1_1_default_scene_format_listener.html#a6c123c76133ae614dd071a031044fbf0":[5,2,12,15,9],
 "class_ogre_1_1_default_scene_format_listener.html#a6c123c76133ae614dd071a031044fbf0":[5,0,1,15,9],
 "class_ogre_1_1_default_scene_format_listener.html#a7091dd9d227b3bc2256694c9f3458dbd":[5,2,12,15,3],
 "class_ogre_1_1_default_scene_format_listener.html#a7091dd9d227b3bc2256694c9f3458dbd":[5,0,1,15,3],
-"class_ogre_1_1_default_scene_format_listener.html#aa7611935807a1b85f8c061185244d975":[5,2,12,15,11],
 "class_ogre_1_1_default_scene_format_listener.html#aa7611935807a1b85f8c061185244d975":[5,0,1,15,11],
+"class_ogre_1_1_default_scene_format_listener.html#aa7611935807a1b85f8c061185244d975":[5,2,12,15,11],
 "class_ogre_1_1_default_scene_format_listener.html#addab83d9039190c1769f465f86f85085":[5,2,12,15,10],
 "class_ogre_1_1_default_scene_format_listener.html#addab83d9039190c1769f465f86f85085":[5,0,1,15,10],
 "class_ogre_1_1_default_scene_format_listener.html#ae6db42ab9429dfe14beb1f5b83b4c85c":[5,0,1,15,1],
 "class_ogre_1_1_default_scene_format_listener.html#ae6db42ab9429dfe14beb1f5b83b4c85c":[5,2,12,15,1],
-"class_ogre_1_1_default_scene_format_listener.html#af44a8e42054c4ff5174ee07bdf75c115":[5,2,12,15,6],
 "class_ogre_1_1_default_scene_format_listener.html#af44a8e42054c4ff5174ee07bdf75c115":[5,0,1,15,6],
+"class_ogre_1_1_default_scene_format_listener.html#af44a8e42054c4ff5174ee07bdf75c115":[5,2,12,15,6],
 "class_ogre_1_1_default_scene_manager.html":[5,0,1,16],
 "class_ogre_1_1_default_scene_manager.html":[5,2,12,16],
-"class_ogre_1_1_default_scene_manager.html#a019a31618f2285f79be2b414488c04c3":[5,0,1,16,96],
 "class_ogre_1_1_default_scene_manager.html#a019a31618f2285f79be2b414488c04c3":[5,2,12,16,96],
-"class_ogre_1_1_default_scene_manager.html#a01ba0aad5090ed0a8ff5e9c3d24fa924":[5,2,12,16,65],
+"class_ogre_1_1_default_scene_manager.html#a019a31618f2285f79be2b414488c04c3":[5,0,1,16,96],
 "class_ogre_1_1_default_scene_manager.html#a01ba0aad5090ed0a8ff5e9c3d24fa924":[5,0,1,16,65],
+"class_ogre_1_1_default_scene_manager.html#a01ba0aad5090ed0a8ff5e9c3d24fa924":[5,2,12,16,65],
 "class_ogre_1_1_default_scene_manager.html#a02d7d29cc4bc8ee4cbe40d16a984291c":[5,0,1,16,151],
 "class_ogre_1_1_default_scene_manager.html#a02d7d29cc4bc8ee4cbe40d16a984291c":[5,2,12,16,151],
 "class_ogre_1_1_default_scene_manager.html#a040241bad11b74f5ba8971fb146f8c6d":[5,2,12,16,136],
@@ -231,8 +233,8 @@ var NAVTREEINDEX72 =
 "class_ogre_1_1_default_scene_manager.html#a081573273b7994313aa328e5641a5189":[5,0,1,16,10],
 "class_ogre_1_1_default_scene_manager.html#a08f7adf5f342c6808481fa922c8c62a0":[5,0,1,16,126],
 "class_ogre_1_1_default_scene_manager.html#a08f7adf5f342c6808481fa922c8c62a0":[5,2,12,16,126],
-"class_ogre_1_1_default_scene_manager.html#a096a0b8744464d12eecc7c8bf5059684":[5,2,12,16,78],
 "class_ogre_1_1_default_scene_manager.html#a096a0b8744464d12eecc7c8bf5059684":[5,0,1,16,78],
+"class_ogre_1_1_default_scene_manager.html#a096a0b8744464d12eecc7c8bf5059684":[5,2,12,16,78],
 "class_ogre_1_1_default_scene_manager.html#a09844d40f3b7404e591224b814067e63":[5,0,1,16,290],
 "class_ogre_1_1_default_scene_manager.html#a09844d40f3b7404e591224b814067e63":[5,2,12,16,290],
 "class_ogre_1_1_default_scene_manager.html#a09cefefe52f0a24f5df51d8edc36df25":[5,0,1,16,224],
@@ -241,13 +243,11 @@ var NAVTREEINDEX72 =
 "class_ogre_1_1_default_scene_manager.html#a0ae22596b5bd2a3faf2958ab3d109d1f":[5,2,12,16,238],
 "class_ogre_1_1_default_scene_manager.html#a0cf942914f681a54cce83bad04906798":[5,2,12,16,146],
 "class_ogre_1_1_default_scene_manager.html#a0cf942914f681a54cce83bad04906798":[5,0,1,16,146],
-"class_ogre_1_1_default_scene_manager.html#a0d2c3ee352d2bb94df5cec30856aeba2":[5,2,12,16,161],
 "class_ogre_1_1_default_scene_manager.html#a0d2c3ee352d2bb94df5cec30856aeba2":[5,0,1,16,161],
+"class_ogre_1_1_default_scene_manager.html#a0d2c3ee352d2bb94df5cec30856aeba2":[5,2,12,16,161],
 "class_ogre_1_1_default_scene_manager.html#a0da39851ae801a1a561a2dc8a269532b":[5,2,12,16,212],
 "class_ogre_1_1_default_scene_manager.html#a0da39851ae801a1a561a2dc8a269532b":[5,0,1,16,212],
-"class_ogre_1_1_default_scene_manager.html#a0dfe820c569ee6b74419af8ee43deda0":[5,2,12,16,223],
 "class_ogre_1_1_default_scene_manager.html#a0dfe820c569ee6b74419af8ee43deda0":[5,0,1,16,223],
-"class_ogre_1_1_default_scene_manager.html#a0e593d05e2f892b8fc3bfca917a75fef":[5,0,1,16,266],
-"class_ogre_1_1_default_scene_manager.html#a0e593d05e2f892b8fc3bfca917a75fef":[5,2,12,16,266],
-"class_ogre_1_1_default_scene_manager.html#a0fec5de5b1af8423dbdae70fa1d18954":[5,0,1,16,169]
+"class_ogre_1_1_default_scene_manager.html#a0dfe820c569ee6b74419af8ee43deda0":[5,2,12,16,223],
+"class_ogre_1_1_default_scene_manager.html#a0e593d05e2f892b8fc3bfca917a75fef":[5,2,12,16,266]
 };
