@@ -1,30 +1,32 @@
 var NAVTREEINDEX75 =
 {
+"class_ogre_1_1_default_scene_manager.html#adcfa98c914fe6e6f67a21fe144bd281d":[5,2,12,16,178],
 "class_ogre_1_1_default_scene_manager.html#add6fe27d7a9500aafbe9325c21985801":[5,2,12,16,210],
-"class_ogre_1_1_default_scene_manager.html#ae291393bc0c5bd48a8c6e79742180c93":[5,2,12,16,192],
+"class_ogre_1_1_default_scene_manager.html#add6fe27d7a9500aafbe9325c21985801":[5,0,1,16,210],
 "class_ogre_1_1_default_scene_manager.html#ae291393bc0c5bd48a8c6e79742180c93":[5,0,1,16,192],
+"class_ogre_1_1_default_scene_manager.html#ae291393bc0c5bd48a8c6e79742180c93":[5,2,12,16,192],
 "class_ogre_1_1_default_scene_manager.html#ae32663cfb04485c2643a24a1240240c2":[5,0,1,16,46],
 "class_ogre_1_1_default_scene_manager.html#ae32663cfb04485c2643a24a1240240c2":[5,2,12,16,46],
-"class_ogre_1_1_default_scene_manager.html#ae333535bc17cb63a4500d4301b7270a0":[5,2,12,16,52],
 "class_ogre_1_1_default_scene_manager.html#ae333535bc17cb63a4500d4301b7270a0":[5,0,1,16,52],
-"class_ogre_1_1_default_scene_manager.html#ae3ac7fea64e00ce827e90b178c6223a9":[5,2,12,16,197],
+"class_ogre_1_1_default_scene_manager.html#ae333535bc17cb63a4500d4301b7270a0":[5,2,12,16,52],
 "class_ogre_1_1_default_scene_manager.html#ae3ac7fea64e00ce827e90b178c6223a9":[5,0,1,16,197],
+"class_ogre_1_1_default_scene_manager.html#ae3ac7fea64e00ce827e90b178c6223a9":[5,2,12,16,197],
 "class_ogre_1_1_default_scene_manager.html#ae4b6a7748dc4273fd6c160fb162c544f":[5,2,12,16,38],
 "class_ogre_1_1_default_scene_manager.html#ae4b6a7748dc4273fd6c160fb162c544f":[5,0,1,16,38],
 "class_ogre_1_1_default_scene_manager.html#ae4f180b40f4bf55669f9842fe922a003":[5,2,12,16,131],
 "class_ogre_1_1_default_scene_manager.html#ae4f180b40f4bf55669f9842fe922a003":[5,0,1,16,131],
-"class_ogre_1_1_default_scene_manager.html#ae51472468ae83562f0a70e0bc8ca3add":[5,0,1,16,220],
 "class_ogre_1_1_default_scene_manager.html#ae51472468ae83562f0a70e0bc8ca3add":[5,2,12,16,220],
-"class_ogre_1_1_default_scene_manager.html#ae60242c5d130f884cd605d3393186df6":[5,0,1,16,63],
+"class_ogre_1_1_default_scene_manager.html#ae51472468ae83562f0a70e0bc8ca3add":[5,0,1,16,220],
 "class_ogre_1_1_default_scene_manager.html#ae60242c5d130f884cd605d3393186df6":[5,2,12,16,63],
-"class_ogre_1_1_default_scene_manager.html#ae809ab7de35a8947b1d196006a17720e":[5,0,1,16,21],
+"class_ogre_1_1_default_scene_manager.html#ae60242c5d130f884cd605d3393186df6":[5,0,1,16,63],
 "class_ogre_1_1_default_scene_manager.html#ae809ab7de35a8947b1d196006a17720e":[5,2,12,16,21],
+"class_ogre_1_1_default_scene_manager.html#ae809ab7de35a8947b1d196006a17720e":[5,0,1,16,21],
 "class_ogre_1_1_default_scene_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,16,236],
 "class_ogre_1_1_default_scene_manager.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,16,236],
-"class_ogre_1_1_default_scene_manager.html#aed6fa4bfde15ddcc956bf8d69082064b":[5,2,12,16,184],
 "class_ogre_1_1_default_scene_manager.html#aed6fa4bfde15ddcc956bf8d69082064b":[5,0,1,16,184],
-"class_ogre_1_1_default_scene_manager.html#aefc67b4b417b9d5ade6d6188235bdf8f":[5,2,12,16,180],
+"class_ogre_1_1_default_scene_manager.html#aed6fa4bfde15ddcc956bf8d69082064b":[5,2,12,16,184],
 "class_ogre_1_1_default_scene_manager.html#aefc67b4b417b9d5ade6d6188235bdf8f":[5,0,1,16,180],
+"class_ogre_1_1_default_scene_manager.html#aefc67b4b417b9d5ade6d6188235bdf8f":[5,2,12,16,180],
 "class_ogre_1_1_default_scene_manager.html#af13eb691a7bdd67e17a402dee98c4b5f":[5,2,12,16,218],
 "class_ogre_1_1_default_scene_manager.html#af13eb691a7bdd67e17a402dee98c4b5f":[5,0,1,16,218],
 "class_ogre_1_1_default_scene_manager.html#af19c32fbc0adc0fa28d8e6c26d9800cb":[5,0,1,16,186],
@@ -39,26 +41,26 @@ var NAVTREEINDEX75 =
 "class_ogre_1_1_default_scene_manager.html#af46af31e3f0a9a4c88eb755b9af885d4":[5,2,12,16,116],
 "class_ogre_1_1_default_scene_manager.html#af4a61278b3ac74c9e16a7ba9cb45815b":[5,0,1,16,40],
 "class_ogre_1_1_default_scene_manager.html#af4a61278b3ac74c9e16a7ba9cb45815b":[5,2,12,16,40],
-"class_ogre_1_1_default_scene_manager.html#af5348867645ff727d1ca25dd89795376":[5,0,1,16,2],
 "class_ogre_1_1_default_scene_manager.html#af5348867645ff727d1ca25dd89795376":[5,2,12,16,2],
+"class_ogre_1_1_default_scene_manager.html#af5348867645ff727d1ca25dd89795376":[5,0,1,16,2],
 "class_ogre_1_1_default_scene_manager.html#af5714312a90c6f699d901ca41933ee6a":[5,2,12,16,73],
 "class_ogre_1_1_default_scene_manager.html#af5714312a90c6f699d901ca41933ee6a":[5,0,1,16,73],
-"class_ogre_1_1_default_scene_manager.html#af7806fd7b6e943c67d80f23de0b3b518":[5,2,12,16,15],
 "class_ogre_1_1_default_scene_manager.html#af7806fd7b6e943c67d80f23de0b3b518":[5,0,1,16,15],
-"class_ogre_1_1_default_scene_manager.html#af7bc9d19d31025a52fd76389066ab418":[5,2,12,16,18],
+"class_ogre_1_1_default_scene_manager.html#af7806fd7b6e943c67d80f23de0b3b518":[5,2,12,16,15],
 "class_ogre_1_1_default_scene_manager.html#af7bc9d19d31025a52fd76389066ab418":[5,0,1,16,18],
+"class_ogre_1_1_default_scene_manager.html#af7bc9d19d31025a52fd76389066ab418":[5,2,12,16,18],
 "class_ogre_1_1_default_scene_manager.html#af8b9ac37458ce1911947e1c077187fec":[5,0,1,16,188],
 "class_ogre_1_1_default_scene_manager.html#af8b9ac37458ce1911947e1c077187fec":[5,2,12,16,188],
 "class_ogre_1_1_default_scene_manager.html#af985062a80dbc20d8fe523be166ecca6":[5,2,12,16,106],
 "class_ogre_1_1_default_scene_manager.html#af985062a80dbc20d8fe523be166ecca6":[5,0,1,16,106],
-"class_ogre_1_1_default_scene_manager.html#afb4874ff4b526ccbc83a6dd8acd6dcdd":[5,2,12,16,209],
 "class_ogre_1_1_default_scene_manager.html#afb4874ff4b526ccbc83a6dd8acd6dcdd":[5,0,1,16,209],
+"class_ogre_1_1_default_scene_manager.html#afb4874ff4b526ccbc83a6dd8acd6dcdd":[5,2,12,16,209],
 "class_ogre_1_1_default_scene_manager.html#afbbf975d14a09242a72e002109360fb2":[5,0,1,16,83],
 "class_ogre_1_1_default_scene_manager.html#afbbf975d14a09242a72e002109360fb2":[5,2,12,16,83],
-"class_ogre_1_1_default_scene_manager.html#afc2f8c3290cbb504699c165100a4619a":[5,2,12,16,145],
 "class_ogre_1_1_default_scene_manager.html#afc2f8c3290cbb504699c165100a4619a":[5,0,1,16,145],
-"class_ogre_1_1_default_scene_manager.html#afe2b19a98bc975b8810cdb531e912da3":[5,2,12,16,25],
+"class_ogre_1_1_default_scene_manager.html#afc2f8c3290cbb504699c165100a4619a":[5,2,12,16,145],
 "class_ogre_1_1_default_scene_manager.html#afe2b19a98bc975b8810cdb531e912da3":[5,0,1,16,25],
+"class_ogre_1_1_default_scene_manager.html#afe2b19a98bc975b8810cdb531e912da3":[5,2,12,16,25],
 "class_ogre_1_1_default_scene_manager.html#affa968418639b742f299cf6cb553aa73":[5,0,1,16,214],
 "class_ogre_1_1_default_scene_manager.html#affa968418639b742f299cf6cb553aa73":[5,2,12,16,214],
 "class_ogre_1_1_default_scene_manager_factory.html":[5,2,12,17],
@@ -69,46 +71,46 @@ var NAVTREEINDEX75 =
 "class_ogre_1_1_default_scene_manager_factory.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,17,9],
 "class_ogre_1_1_default_scene_manager_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,17,12],
 "class_ogre_1_1_default_scene_manager_factory.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,17,12],
-"class_ogre_1_1_default_scene_manager_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,17,5],
 "class_ogre_1_1_default_scene_manager_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,17,5],
+"class_ogre_1_1_default_scene_manager_factory.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,17,5],
 "class_ogre_1_1_default_scene_manager_factory.html#a87932aa032f993f51292da737f5e83f3":[5,0,1,17,1],
 "class_ogre_1_1_default_scene_manager_factory.html#a87932aa032f993f51292da737f5e83f3":[5,2,12,17,1],
-"class_ogre_1_1_default_scene_manager_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,17,8],
 "class_ogre_1_1_default_scene_manager_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,17,8],
+"class_ogre_1_1_default_scene_manager_factory.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,17,8],
 "class_ogre_1_1_default_scene_manager_factory.html#aa940efe05e1639f24ec2f5358bde932d":[5,2,12,17,2],
 "class_ogre_1_1_default_scene_manager_factory.html#aa940efe05e1639f24ec2f5358bde932d":[5,0,1,17,2],
 "class_ogre_1_1_default_scene_manager_factory.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,17,11],
 "class_ogre_1_1_default_scene_manager_factory.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,17,11],
-"class_ogre_1_1_default_scene_manager_factory.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,17,6],
 "class_ogre_1_1_default_scene_manager_factory.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,17,6],
-"class_ogre_1_1_default_scene_manager_factory.html#ace5330179b707c67b7d9705b61d051d3":[5,0,1,17,4],
+"class_ogre_1_1_default_scene_manager_factory.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,17,6],
 "class_ogre_1_1_default_scene_manager_factory.html#ace5330179b707c67b7d9705b61d051d3":[5,2,12,17,4],
+"class_ogre_1_1_default_scene_manager_factory.html#ace5330179b707c67b7d9705b61d051d3":[5,0,1,17,4],
 "class_ogre_1_1_default_scene_manager_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,17,10],
 "class_ogre_1_1_default_scene_manager_factory.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,17,10],
 "class_ogre_1_1_default_scene_manager_factory.html#adce32528577d71b228692df906ecd17c":[5,2,12,17,13],
 "class_ogre_1_1_default_scene_manager_factory.html#adce32528577d71b228692df906ecd17c":[5,0,1,17,13],
-"class_ogre_1_1_default_scene_manager_factory.html#ae107524e7e876629bfa92037abaf5b08":[5,0,1,17,3],
 "class_ogre_1_1_default_scene_manager_factory.html#ae107524e7e876629bfa92037abaf5b08":[5,2,12,17,3],
-"class_ogre_1_1_default_scene_manager_factory.html#aecb930d0603388f00979d9822a24d7bf":[5,0,1,17,15],
+"class_ogre_1_1_default_scene_manager_factory.html#ae107524e7e876629bfa92037abaf5b08":[5,0,1,17,3],
 "class_ogre_1_1_default_scene_manager_factory.html#aecb930d0603388f00979d9822a24d7bf":[5,2,12,17,15],
-"class_ogre_1_1_default_scene_manager_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,17,14],
+"class_ogre_1_1_default_scene_manager_factory.html#aecb930d0603388f00979d9822a24d7bf":[5,0,1,17,15],
 "class_ogre_1_1_default_scene_manager_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,17,14],
+"class_ogre_1_1_default_scene_manager_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,17,14],
 "class_ogre_1_1_default_scene_manager_factory.html#affd69f67c70d61231b323b1de67af92f":[5,2,12,17,0],
 "class_ogre_1_1_default_scene_manager_factory.html#affd69f67c70d61231b323b1de67af92f":[5,0,1,17,0],
 "class_ogre_1_1_default_shadow_camera_setup.html":[5,0,1,18],
 "class_ogre_1_1_default_shadow_camera_setup.html":[5,2,12,18],
-"class_ogre_1_1_default_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,18,7],
 "class_ogre_1_1_default_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,18,7],
-"class_ogre_1_1_default_shadow_camera_setup.html#a33706dc2e3d61f4f0b2419d9cc259c76":[5,0,1,18,0],
+"class_ogre_1_1_default_shadow_camera_setup.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,18,7],
 "class_ogre_1_1_default_shadow_camera_setup.html#a33706dc2e3d61f4f0b2419d9cc259c76":[5,2,12,18,0],
-"class_ogre_1_1_default_shadow_camera_setup.html#a4663dca3e570aa2e7f0134c9221ad6ea":[5,0,1,18,1],
+"class_ogre_1_1_default_shadow_camera_setup.html#a33706dc2e3d61f4f0b2419d9cc259c76":[5,0,1,18,0],
 "class_ogre_1_1_default_shadow_camera_setup.html#a4663dca3e570aa2e7f0134c9221ad6ea":[5,2,12,18,1],
+"class_ogre_1_1_default_shadow_camera_setup.html#a4663dca3e570aa2e7f0134c9221ad6ea":[5,0,1,18,1],
 "class_ogre_1_1_default_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,18,9],
 "class_ogre_1_1_default_shadow_camera_setup.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,18,9],
 "class_ogre_1_1_default_shadow_camera_setup.html#a5e701a58a1dbd0a22810faec87e9a59a":[5,2,12,18,4],
 "class_ogre_1_1_default_shadow_camera_setup.html#a5e701a58a1dbd0a22810faec87e9a59a":[5,0,1,18,4],
-"class_ogre_1_1_default_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,2,12,18,2],
 "class_ogre_1_1_default_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,0,1,18,2],
+"class_ogre_1_1_default_shadow_camera_setup.html#a5fca5ac3db0ec963d468a050a597e81b":[5,2,12,18,2],
 "class_ogre_1_1_default_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,18,12],
 "class_ogre_1_1_default_shadow_camera_setup.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,18,12],
 "class_ogre_1_1_default_shadow_camera_setup.html#a64ec2cc49a15be1446603390cf2d5536":[5,2,12,18,15],
@@ -117,20 +119,20 @@ var NAVTREEINDEX75 =
 "class_ogre_1_1_default_shadow_camera_setup.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,18,5],
 "class_ogre_1_1_default_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,18,8],
 "class_ogre_1_1_default_shadow_camera_setup.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,18,8],
-"class_ogre_1_1_default_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,18,11],
 "class_ogre_1_1_default_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,18,11],
+"class_ogre_1_1_default_shadow_camera_setup.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,18,11],
 "class_ogre_1_1_default_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,18,6],
 "class_ogre_1_1_default_shadow_camera_setup.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,18,6],
-"class_ogre_1_1_default_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,18,10],
 "class_ogre_1_1_default_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,18,10],
+"class_ogre_1_1_default_shadow_camera_setup.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,18,10],
 "class_ogre_1_1_default_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,0,1,18,3],
 "class_ogre_1_1_default_shadow_camera_setup.html#ada64716374ef5839054ebb8b9d5ecd19":[5,2,12,18,3],
 "class_ogre_1_1_default_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,0,1,18,13],
 "class_ogre_1_1_default_shadow_camera_setup.html#adce32528577d71b228692df906ecd17c":[5,2,12,18,13],
 "class_ogre_1_1_default_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,18,14],
 "class_ogre_1_1_default_shadow_camera_setup.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,18,14],
-"class_ogre_1_1_default_sphere_scene_query.html":[5,0,1,19],
 "class_ogre_1_1_default_sphere_scene_query.html":[5,2,12,19],
+"class_ogre_1_1_default_sphere_scene_query.html":[5,0,1,19],
 "class_ogre_1_1_default_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,0,1,19,0],
 "class_ogre_1_1_default_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3a":[5,2,12,19,0],
 "class_ogre_1_1_default_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aa018493b6c87271e0c8ba014f058cffd3":[5,2,12,19,0,2],
@@ -143,62 +145,62 @@ var NAVTREEINDEX75 =
 "class_ogre_1_1_default_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aad498944c8c6b81d737c3ceee86881e8d":[5,0,1,19,0,4],
 "class_ogre_1_1_default_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,2,12,19,0,3],
 "class_ogre_1_1_default_sphere_scene_query.html#a0a75b5ed976da2f9023382f4c4514b3aadeefa0cc2dfd1ec783c2a266ea61f925":[5,0,1,19,0,3],
-"class_ogre_1_1_default_sphere_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,19,14],
 "class_ogre_1_1_default_sphere_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,2,12,19,14],
-"class_ogre_1_1_default_sphere_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,0,1,19,3],
+"class_ogre_1_1_default_sphere_scene_query.html#a1c727e879a260c37b00ce5505fe8e144":[5,0,1,19,14],
 "class_ogre_1_1_default_sphere_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,2,12,19,3],
+"class_ogre_1_1_default_sphere_scene_query.html#a1f8750081b57a70381bc6dd9fe663955":[5,0,1,19,3],
 "class_ogre_1_1_default_sphere_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,2,12,19,28],
 "class_ogre_1_1_default_sphere_scene_query.html#a3eadff3663a1c862a6de073041157bc0":[5,0,1,19,28],
-"class_ogre_1_1_default_sphere_scene_query.html#a45782a80dd5916bbf4a0934243cf7d96":[5,0,1,19,9],
 "class_ogre_1_1_default_sphere_scene_query.html#a45782a80dd5916bbf4a0934243cf7d96":[5,2,12,19,9],
+"class_ogre_1_1_default_sphere_scene_query.html#a45782a80dd5916bbf4a0934243cf7d96":[5,0,1,19,9],
 "class_ogre_1_1_default_sphere_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,2,12,19,22],
 "class_ogre_1_1_default_sphere_scene_query.html#a49641297f4affe82b8e9f8b9ab3ff9f4":[5,0,1,19,22],
-"class_ogre_1_1_default_sphere_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,19,16],
 "class_ogre_1_1_default_sphere_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,0,1,19,16],
+"class_ogre_1_1_default_sphere_scene_query.html#a595ea4c05da8aa987d3800e65d23355d":[5,2,12,19,16],
 "class_ogre_1_1_default_sphere_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,2,12,19,19],
 "class_ogre_1_1_default_sphere_scene_query.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[5,0,1,19,19],
-"class_ogre_1_1_default_sphere_scene_query.html#a6b8ac84df4b61cdd0abba7fcd43ae956":[5,2,12,19,25],
 "class_ogre_1_1_default_sphere_scene_query.html#a6b8ac84df4b61cdd0abba7fcd43ae956":[5,0,1,19,25],
-"class_ogre_1_1_default_sphere_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,2,12,19,10],
+"class_ogre_1_1_default_sphere_scene_query.html#a6b8ac84df4b61cdd0abba7fcd43ae956":[5,2,12,19,25],
 "class_ogre_1_1_default_sphere_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,0,1,19,10],
+"class_ogre_1_1_default_sphere_scene_query.html#a6c520c277bf2db7d9fe0c6ef89153876":[5,2,12,19,10],
 "class_ogre_1_1_default_sphere_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,0,1,19,12],
 "class_ogre_1_1_default_sphere_scene_query.html#a8357fe4fb4849772b94baa4bf47c7ded":[5,2,12,19,12],
 "class_ogre_1_1_default_sphere_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,0,1,19,7],
 "class_ogre_1_1_default_sphere_scene_query.html#a8be0cafc960c53f65cb7972ced8f5b83":[5,2,12,19,7],
-"class_ogre_1_1_default_sphere_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,19,15],
 "class_ogre_1_1_default_sphere_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,0,1,19,15],
+"class_ogre_1_1_default_sphere_scene_query.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[5,2,12,19,15],
 "class_ogre_1_1_default_sphere_scene_query.html#a9a851da02c7d6677649aca5fc0d06ddd":[5,0,1,19,1],
 "class_ogre_1_1_default_sphere_scene_query.html#a9a851da02c7d6677649aca5fc0d06ddd":[5,2,12,19,1],
 "class_ogre_1_1_default_sphere_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,0,1,19,6],
 "class_ogre_1_1_default_sphere_scene_query.html#aacf8e0e589c0573719d213c5f826247a":[5,2,12,19,6],
 "class_ogre_1_1_default_sphere_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,0,1,19,18],
 "class_ogre_1_1_default_sphere_scene_query.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,12,19,18],
-"class_ogre_1_1_default_sphere_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,19,13],
 "class_ogre_1_1_default_sphere_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,0,1,19,13],
-"class_ogre_1_1_default_sphere_scene_query.html#acfc259778f393e9fea0d02976c0ce338":[5,0,1,19,5],
+"class_ogre_1_1_default_sphere_scene_query.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,12,19,13],
 "class_ogre_1_1_default_sphere_scene_query.html#acfc259778f393e9fea0d02976c0ce338":[5,2,12,19,5],
+"class_ogre_1_1_default_sphere_scene_query.html#acfc259778f393e9fea0d02976c0ce338":[5,0,1,19,5],
 "class_ogre_1_1_default_sphere_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,2,12,19,11],
 "class_ogre_1_1_default_sphere_scene_query.html#acffb9330fc3de7109f8274822e362b00":[5,0,1,19,11],
 "class_ogre_1_1_default_sphere_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,12,19,17],
 "class_ogre_1_1_default_sphere_scene_query.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,0,1,19,17],
-"class_ogre_1_1_default_sphere_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,12,19,24],
 "class_ogre_1_1_default_sphere_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,0,1,19,24],
+"class_ogre_1_1_default_sphere_scene_query.html#ad392a7fc0b338e5507540d3183f82cfb":[5,2,12,19,24],
 "class_ogre_1_1_default_sphere_scene_query.html#adce32528577d71b228692df906ecd17c":[5,2,12,19,20],
 "class_ogre_1_1_default_sphere_scene_query.html#adce32528577d71b228692df906ecd17c":[5,0,1,19,20],
-"class_ogre_1_1_default_sphere_scene_query.html#adfd70f00b13654735336f4360af84995":[5,2,12,19,27],
 "class_ogre_1_1_default_sphere_scene_query.html#adfd70f00b13654735336f4360af84995":[5,0,1,19,27],
-"class_ogre_1_1_default_sphere_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,0,1,19,23],
+"class_ogre_1_1_default_sphere_scene_query.html#adfd70f00b13654735336f4360af84995":[5,2,12,19,27],
 "class_ogre_1_1_default_sphere_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,2,12,19,23],
+"class_ogre_1_1_default_sphere_scene_query.html#ae52b991bb3e6ecdb688c3d06d245c468":[5,0,1,19,23],
 "class_ogre_1_1_default_sphere_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,2,12,19,26],
 "class_ogre_1_1_default_sphere_scene_query.html#aec3aa0b8b16c41fae990ee78150f8d2a":[5,0,1,19,26],
-"class_ogre_1_1_default_sphere_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,19,21],
 "class_ogre_1_1_default_sphere_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,0,1,19,21],
+"class_ogre_1_1_default_sphere_scene_query.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,12,19,21],
 "class_ogre_1_1_default_sphere_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,0,1,19,8],
 "class_ogre_1_1_default_sphere_scene_query.html#aed7b296e80ea3acebc493842727e8db3":[5,2,12,19,8],
-"class_ogre_1_1_default_sphere_scene_query.html#aee3c881aad0e146950d8fd5cf3791469":[5,0,1,19,2],
 "class_ogre_1_1_default_sphere_scene_query.html#aee3c881aad0e146950d8fd5cf3791469":[5,2,12,19,2],
-"class_ogre_1_1_default_sphere_scene_query.html#af3abfea7c8d18bfb4b3783699e084068":[5,0,1,19,4],
+"class_ogre_1_1_default_sphere_scene_query.html#aee3c881aad0e146950d8fd5cf3791469":[5,0,1,19,2],
 "class_ogre_1_1_default_sphere_scene_query.html#af3abfea7c8d18bfb4b3783699e084068":[5,2,12,19,4],
+"class_ogre_1_1_default_sphere_scene_query.html#af3abfea7c8d18bfb4b3783699e084068":[5,0,1,19,4],
 "class_ogre_1_1_default_texture_gpu_manager_listener.html":[5,2,11,28],
 "class_ogre_1_1_default_texture_gpu_manager_listener.html#a1427f0b635a4186cd6083a9bab879fa2":[5,2,11,28,4],
 "class_ogre_1_1_default_texture_gpu_manager_listener.html#a1481a146fb95328ef24c37360113b7a9":[5,2,11,28,2],
@@ -224,30 +226,28 @@ var NAVTREEINDEX75 =
 "class_ogre_1_1_default_work_queue.html":[7,0,0,269],
 "class_ogre_1_1_default_work_queue.html#a087a56b1cd59c19193e8012a8dbcd3b3":[6,0,0,296,8],
 "class_ogre_1_1_default_work_queue.html#a087a56b1cd59c19193e8012a8dbcd3b3":[6,0,0,296,7],
-"class_ogre_1_1_default_work_queue.html#a087a56b1cd59c19193e8012a8dbcd3b3":[7,0,0,269,7],
 "class_ogre_1_1_default_work_queue.html#a087a56b1cd59c19193e8012a8dbcd3b3":[7,0,0,269,8],
+"class_ogre_1_1_default_work_queue.html#a087a56b1cd59c19193e8012a8dbcd3b3":[7,0,0,269,7],
 "class_ogre_1_1_default_work_queue.html#a09a2d91f22689b5aad7967cfb799c63e":[6,0,0,296,34],
 "class_ogre_1_1_default_work_queue.html#a09a2d91f22689b5aad7967cfb799c63e":[7,0,0,269,34],
-"class_ogre_1_1_default_work_queue.html#a0c50d7ab19de75a3e378ba46aa8fbf9c":[6,0,0,296,9],
 "class_ogre_1_1_default_work_queue.html#a0c50d7ab19de75a3e378ba46aa8fbf9c":[7,0,0,269,9],
+"class_ogre_1_1_default_work_queue.html#a0c50d7ab19de75a3e378ba46aa8fbf9c":[6,0,0,296,9],
 "class_ogre_1_1_default_work_queue.html#a1654469715e0e622018a07bb7d82e998":[7,0,0,269,23],
 "class_ogre_1_1_default_work_queue.html#a1654469715e0e622018a07bb7d82e998":[6,0,0,296,23],
-"class_ogre_1_1_default_work_queue.html#a1908257e726af6caa80f1a6cd5682d76":[7,0,0,269,0],
 "class_ogre_1_1_default_work_queue.html#a1908257e726af6caa80f1a6cd5682d76":[6,0,0,296,0],
+"class_ogre_1_1_default_work_queue.html#a1908257e726af6caa80f1a6cd5682d76":[7,0,0,269,0],
 "class_ogre_1_1_default_work_queue.html#a1a0f33724027da3501c0c8b8182480cf":[6,0,0,296,45],
 "class_ogre_1_1_default_work_queue.html#a1a0f33724027da3501c0c8b8182480cf":[6,0,0,296,44],
 "class_ogre_1_1_default_work_queue.html#a1a0f33724027da3501c0c8b8182480cf":[7,0,0,269,44],
 "class_ogre_1_1_default_work_queue.html#a1a0f33724027da3501c0c8b8182480cf":[7,0,0,269,45],
-"class_ogre_1_1_default_work_queue.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,269,26],
 "class_ogre_1_1_default_work_queue.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,296,26],
+"class_ogre_1_1_default_work_queue.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,269,26],
 "class_ogre_1_1_default_work_queue.html#a1f0847f5d8a4f9e4703a390acacfaa84":[7,0,0,269,35],
 "class_ogre_1_1_default_work_queue.html#a1f0847f5d8a4f9e4703a390acacfaa84":[6,0,0,296,35],
 "class_ogre_1_1_default_work_queue.html#a291e7c92efb374ec208c680375edd2ce":[7,0,0,269,38],
 "class_ogre_1_1_default_work_queue.html#a291e7c92efb374ec208c680375edd2ce":[6,0,0,296,38],
-"class_ogre_1_1_default_work_queue.html#a3b38abc5e3d472c3282b0f1a3b6b8809":[6,0,0,296,17],
 "class_ogre_1_1_default_work_queue.html#a3b38abc5e3d472c3282b0f1a3b6b8809":[7,0,0,269,17],
+"class_ogre_1_1_default_work_queue.html#a3b38abc5e3d472c3282b0f1a3b6b8809":[6,0,0,296,17],
 "class_ogre_1_1_default_work_queue.html#a4cb3250578088b0d6d05092cde9a38e2":[7,0,0,269,1],
-"class_ogre_1_1_default_work_queue.html#a4cb3250578088b0d6d05092cde9a38e2":[6,0,0,296,3],
-"class_ogre_1_1_default_work_queue.html#a4cb3250578088b0d6d05092cde9a38e2":[6,0,0,296,1],
 "class_ogre_1_1_default_work_queue.html#a4cb3250578088b0d6d05092cde9a38e2":[7,0,0,269,3]
 };
