@@ -1,110 +1,112 @@
 var NAVTREEINDEX79 =
 {
+"class_ogre_1_1_e_g_l_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,292,92],
 "class_ogre_1_1_e_g_l_window.html#a9439f12db8a964f79f4b743493a0fd75":[6,0,0,319,47],
+"class_ogre_1_1_e_g_l_window.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,292,47],
 "class_ogre_1_1_e_g_l_window.html#a95768aeda225df73c3636f228f9f770b":[7,0,0,292,73],
 "class_ogre_1_1_e_g_l_window.html#a95768aeda225df73c3636f228f9f770b":[6,0,0,319,73],
 "class_ogre_1_1_e_g_l_window.html#a96ec12856ec5384456c9d0a86bd76568":[7,0,0,292,118],
 "class_ogre_1_1_e_g_l_window.html#a96ec12856ec5384456c9d0a86bd76568":[6,0,0,319,118],
-"class_ogre_1_1_e_g_l_window.html#a97b2d63554ec8e515789ac65c6200a33":[6,0,0,319,75],
 "class_ogre_1_1_e_g_l_window.html#a97b2d63554ec8e515789ac65c6200a33":[7,0,0,292,75],
+"class_ogre_1_1_e_g_l_window.html#a97b2d63554ec8e515789ac65c6200a33":[6,0,0,319,75],
 "class_ogre_1_1_e_g_l_window.html#a98f49dbefa207210a2f4c0025848b93c":[7,0,0,292,50],
 "class_ogre_1_1_e_g_l_window.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,319,50],
 "class_ogre_1_1_e_g_l_window.html#aa1d5570996e2e5ccf219257ec48d8d7f":[6,0,0,319,17],
 "class_ogre_1_1_e_g_l_window.html#aa1d5570996e2e5ccf219257ec48d8d7f":[7,0,0,292,17],
 "class_ogre_1_1_e_g_l_window.html#aa3acdf7203060614ba2a234a2e70d235":[7,0,0,292,23],
 "class_ogre_1_1_e_g_l_window.html#aa3acdf7203060614ba2a234a2e70d235":[6,0,0,319,23],
-"class_ogre_1_1_e_g_l_window.html#aa4700a4cfb9e67af07602d9917c92831":[7,0,0,292,38],
 "class_ogre_1_1_e_g_l_window.html#aa4700a4cfb9e67af07602d9917c92831":[6,0,0,319,38],
-"class_ogre_1_1_e_g_l_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[6,0,0,319,117],
+"class_ogre_1_1_e_g_l_window.html#aa4700a4cfb9e67af07602d9917c92831":[7,0,0,292,38],
 "class_ogre_1_1_e_g_l_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[7,0,0,292,117],
+"class_ogre_1_1_e_g_l_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[6,0,0,319,117],
 "class_ogre_1_1_e_g_l_window.html#aa73246df694f79ef700ca3c50bdd252d":[7,0,0,292,2],
 "class_ogre_1_1_e_g_l_window.html#aa73246df694f79ef700ca3c50bdd252d":[6,0,0,319,2],
 "class_ogre_1_1_e_g_l_window.html#aa971d5061a29b749442914de05813682":[7,0,0,292,142],
 "class_ogre_1_1_e_g_l_window.html#aa971d5061a29b749442914de05813682":[6,0,0,319,142],
 "class_ogre_1_1_e_g_l_window.html#aabb50104a367aa91fd7c5a6d2a21b0e3":[6,0,0,319,29],
 "class_ogre_1_1_e_g_l_window.html#aabb50104a367aa91fd7c5a6d2a21b0e3":[7,0,0,292,29],
-"class_ogre_1_1_e_g_l_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[6,0,0,319,139],
 "class_ogre_1_1_e_g_l_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[7,0,0,292,139],
+"class_ogre_1_1_e_g_l_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[6,0,0,319,139],
 "class_ogre_1_1_e_g_l_window.html#aaf42ce91cddbebe097c168dba749159b":[6,0,0,319,84],
 "class_ogre_1_1_e_g_l_window.html#aaf42ce91cddbebe097c168dba749159b":[7,0,0,292,84],
 "class_ogre_1_1_e_g_l_window.html#ab02f58cb99451d6c34235a3e78bb9417":[6,0,0,319,20],
 "class_ogre_1_1_e_g_l_window.html#ab02f58cb99451d6c34235a3e78bb9417":[7,0,0,292,20],
 "class_ogre_1_1_e_g_l_window.html#ab16d079db49b93e915e9386b4e27880b":[6,0,0,319,11],
 "class_ogre_1_1_e_g_l_window.html#ab16d079db49b93e915e9386b4e27880b":[7,0,0,292,11],
+"class_ogre_1_1_e_g_l_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,319,97],
+"class_ogre_1_1_e_g_l_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,319,98],
 "class_ogre_1_1_e_g_l_window.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,292,98],
 "class_ogre_1_1_e_g_l_window.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,292,97],
-"class_ogre_1_1_e_g_l_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,319,98],
-"class_ogre_1_1_e_g_l_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,319,97],
-"class_ogre_1_1_e_g_l_window.html#ab5074c9166d5444b59f75d4f1300ae0a":[6,0,0,319,67],
 "class_ogre_1_1_e_g_l_window.html#ab5074c9166d5444b59f75d4f1300ae0a":[7,0,0,292,67],
+"class_ogre_1_1_e_g_l_window.html#ab5074c9166d5444b59f75d4f1300ae0a":[6,0,0,319,67],
 "class_ogre_1_1_e_g_l_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[7,0,0,292,12],
 "class_ogre_1_1_e_g_l_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,319,12],
-"class_ogre_1_1_e_g_l_window.html#ab757d8a24dead55af8e773a036ee141d":[7,0,0,292,135],
 "class_ogre_1_1_e_g_l_window.html#ab757d8a24dead55af8e773a036ee141d":[6,0,0,319,135],
-"class_ogre_1_1_e_g_l_window.html#ab82d2cf13a93ae6406cee9d2d044aa06":[6,0,0,319,46],
+"class_ogre_1_1_e_g_l_window.html#ab757d8a24dead55af8e773a036ee141d":[7,0,0,292,135],
 "class_ogre_1_1_e_g_l_window.html#ab82d2cf13a93ae6406cee9d2d044aa06":[7,0,0,292,46],
-"class_ogre_1_1_e_g_l_window.html#abb4fa5e6970515a4d6cb9a16501557b5":[6,0,0,319,63],
+"class_ogre_1_1_e_g_l_window.html#ab82d2cf13a93ae6406cee9d2d044aa06":[6,0,0,319,46],
 "class_ogre_1_1_e_g_l_window.html#abb4fa5e6970515a4d6cb9a16501557b5":[7,0,0,292,63],
+"class_ogre_1_1_e_g_l_window.html#abb4fa5e6970515a4d6cb9a16501557b5":[6,0,0,319,63],
+"class_ogre_1_1_e_g_l_window.html#abb8787baa99c92944f4fddac7c53cc6d":[6,0,0,319,5],
 "class_ogre_1_1_e_g_l_window.html#abb8787baa99c92944f4fddac7c53cc6d":[7,0,0,292,5],
 "class_ogre_1_1_e_g_l_window.html#abb8787baa99c92944f4fddac7c53cc6d":[7,0,0,292,3],
-"class_ogre_1_1_e_g_l_window.html#abb8787baa99c92944f4fddac7c53cc6d":[6,0,0,319,5],
 "class_ogre_1_1_e_g_l_window.html#abb8787baa99c92944f4fddac7c53cc6d":[6,0,0,319,3],
 "class_ogre_1_1_e_g_l_window.html#ac344214fa2a1ead13bb78f73712f69a3":[6,0,0,319,138],
 "class_ogre_1_1_e_g_l_window.html#ac344214fa2a1ead13bb78f73712f69a3":[7,0,0,292,138],
-"class_ogre_1_1_e_g_l_window.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,292,30],
 "class_ogre_1_1_e_g_l_window.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,319,30],
-"class_ogre_1_1_e_g_l_window.html#aca21c0cb66c690e35847a1cf30aef357":[6,0,0,319,56],
+"class_ogre_1_1_e_g_l_window.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,292,30],
 "class_ogre_1_1_e_g_l_window.html#aca21c0cb66c690e35847a1cf30aef357":[7,0,0,292,56],
+"class_ogre_1_1_e_g_l_window.html#aca21c0cb66c690e35847a1cf30aef357":[6,0,0,319,56],
+"class_ogre_1_1_e_g_l_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,292,87],
 "class_ogre_1_1_e_g_l_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,319,88],
 "class_ogre_1_1_e_g_l_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,319,87],
-"class_ogre_1_1_e_g_l_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,292,87],
 "class_ogre_1_1_e_g_l_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,292,88],
-"class_ogre_1_1_e_g_l_window.html#acdd2df1d7b419b61d1abd82b72e0d0a5":[7,0,0,292,70],
 "class_ogre_1_1_e_g_l_window.html#acdd2df1d7b419b61d1abd82b72e0d0a5":[6,0,0,319,70],
-"class_ogre_1_1_e_g_l_window.html#acfb338c927b445144253ce6893bbbb55":[7,0,0,292,15],
+"class_ogre_1_1_e_g_l_window.html#acdd2df1d7b419b61d1abd82b72e0d0a5":[7,0,0,292,70],
 "class_ogre_1_1_e_g_l_window.html#acfb338c927b445144253ce6893bbbb55":[6,0,0,319,15],
-"class_ogre_1_1_e_g_l_window.html#ad0b724596d2b9e278293aee6e55a5273":[6,0,0,319,6],
+"class_ogre_1_1_e_g_l_window.html#acfb338c927b445144253ce6893bbbb55":[7,0,0,292,15],
 "class_ogre_1_1_e_g_l_window.html#ad0b724596d2b9e278293aee6e55a5273":[7,0,0,292,6],
-"class_ogre_1_1_e_g_l_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,319,51],
+"class_ogre_1_1_e_g_l_window.html#ad0b724596d2b9e278293aee6e55a5273":[6,0,0,319,6],
 "class_ogre_1_1_e_g_l_window.html#ad15462609bf45808fb04668cc1c28c78":[7,0,0,292,51],
+"class_ogre_1_1_e_g_l_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,319,51],
 "class_ogre_1_1_e_g_l_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,292,96],
-"class_ogre_1_1_e_g_l_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,319,96],
-"class_ogre_1_1_e_g_l_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,319,95],
 "class_ogre_1_1_e_g_l_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,292,95],
-"class_ogre_1_1_e_g_l_window.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,292,130],
+"class_ogre_1_1_e_g_l_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,319,95],
+"class_ogre_1_1_e_g_l_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,319,96],
 "class_ogre_1_1_e_g_l_window.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,319,130],
-"class_ogre_1_1_e_g_l_window.html#ad4e95b76827cb41d936ccb4a8c308c6e":[6,0,0,319,43],
+"class_ogre_1_1_e_g_l_window.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,292,130],
 "class_ogre_1_1_e_g_l_window.html#ad4e95b76827cb41d936ccb4a8c308c6e":[7,0,0,292,43],
+"class_ogre_1_1_e_g_l_window.html#ad4e95b76827cb41d936ccb4a8c308c6e":[6,0,0,319,43],
 "class_ogre_1_1_e_g_l_window.html#ad6a737624f18ad142c9a710aa1cd59a3":[6,0,0,319,45],
 "class_ogre_1_1_e_g_l_window.html#ad6a737624f18ad142c9a710aa1cd59a3":[7,0,0,292,45],
-"class_ogre_1_1_e_g_l_window.html#ad850ea808459d7839604eb4e8dfb93a3":[7,0,0,292,132],
 "class_ogre_1_1_e_g_l_window.html#ad850ea808459d7839604eb4e8dfb93a3":[6,0,0,319,132],
-"class_ogre_1_1_e_g_l_window.html#ad8558b8eb75dfa61abfcd1b8d8f0ee31":[7,0,0,292,65],
+"class_ogre_1_1_e_g_l_window.html#ad850ea808459d7839604eb4e8dfb93a3":[7,0,0,292,132],
 "class_ogre_1_1_e_g_l_window.html#ad8558b8eb75dfa61abfcd1b8d8f0ee31":[6,0,0,319,65],
+"class_ogre_1_1_e_g_l_window.html#ad8558b8eb75dfa61abfcd1b8d8f0ee31":[7,0,0,292,65],
 "class_ogre_1_1_e_g_l_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[7,0,0,292,72],
 "class_ogre_1_1_e_g_l_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[6,0,0,319,72],
 "class_ogre_1_1_e_g_l_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,319,53],
 "class_ogre_1_1_e_g_l_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[7,0,0,292,53],
-"class_ogre_1_1_e_g_l_window.html#adc15081bc322c19aefc8ac499f8af28c":[6,0,0,319,82],
-"class_ogre_1_1_e_g_l_window.html#adc15081bc322c19aefc8ac499f8af28c":[6,0,0,319,83],
 "class_ogre_1_1_e_g_l_window.html#adc15081bc322c19aefc8ac499f8af28c":[7,0,0,292,83],
+"class_ogre_1_1_e_g_l_window.html#adc15081bc322c19aefc8ac499f8af28c":[6,0,0,319,83],
+"class_ogre_1_1_e_g_l_window.html#adc15081bc322c19aefc8ac499f8af28c":[6,0,0,319,82],
 "class_ogre_1_1_e_g_l_window.html#adc15081bc322c19aefc8ac499f8af28c":[7,0,0,292,82],
-"class_ogre_1_1_e_g_l_window.html#adc5ae8e1b69ca1a62df88d52471910db":[6,0,0,319,120],
 "class_ogre_1_1_e_g_l_window.html#adc5ae8e1b69ca1a62df88d52471910db":[7,0,0,292,120],
-"class_ogre_1_1_e_g_l_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,292,101],
-"class_ogre_1_1_e_g_l_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,319,101],
-"class_ogre_1_1_e_g_l_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,292,102],
+"class_ogre_1_1_e_g_l_window.html#adc5ae8e1b69ca1a62df88d52471910db":[6,0,0,319,120],
 "class_ogre_1_1_e_g_l_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,319,102],
-"class_ogre_1_1_e_g_l_window.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,319,41],
+"class_ogre_1_1_e_g_l_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,319,101],
+"class_ogre_1_1_e_g_l_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,292,101],
+"class_ogre_1_1_e_g_l_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,292,102],
 "class_ogre_1_1_e_g_l_window.html#add8e20491fc0e054c9cab3c75297c6ec":[7,0,0,292,41],
-"class_ogre_1_1_e_g_l_window.html#ade23b0e64aea68657b81833b99868802":[6,0,0,319,34],
+"class_ogre_1_1_e_g_l_window.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,319,41],
 "class_ogre_1_1_e_g_l_window.html#ade23b0e64aea68657b81833b99868802":[7,0,0,292,34],
-"class_ogre_1_1_e_g_l_window.html#adfad418204ed0a3e78adadee9e6c2648":[7,0,0,292,19],
+"class_ogre_1_1_e_g_l_window.html#ade23b0e64aea68657b81833b99868802":[6,0,0,319,34],
 "class_ogre_1_1_e_g_l_window.html#adfad418204ed0a3e78adadee9e6c2648":[6,0,0,319,19],
+"class_ogre_1_1_e_g_l_window.html#adfad418204ed0a3e78adadee9e6c2648":[7,0,0,292,19],
 "class_ogre_1_1_e_g_l_window.html#ae1603d5b0e983523ea1c1ba3401f6506":[6,0,0,319,61],
 "class_ogre_1_1_e_g_l_window.html#ae1603d5b0e983523ea1c1ba3401f6506":[7,0,0,292,61],
-"class_ogre_1_1_e_g_l_window.html#ae2bd3003533d24447f883d9035b7aed0":[7,0,0,292,115],
 "class_ogre_1_1_e_g_l_window.html#ae2bd3003533d24447f883d9035b7aed0":[6,0,0,319,115],
+"class_ogre_1_1_e_g_l_window.html#ae2bd3003533d24447f883d9035b7aed0":[7,0,0,292,115],
 "class_ogre_1_1_e_g_l_window.html#ae68eb2ce228a55811c058de85e369a29":[6,0,0,319,7],
 "class_ogre_1_1_e_g_l_window.html#ae68eb2ce228a55811c058de85e369a29":[7,0,0,292,7],
 "class_ogre_1_1_e_g_l_window.html#ae78e25805a045b8834c831d452ab6e07":[6,0,0,319,141],
@@ -113,20 +115,20 @@ var NAVTREEINDEX79 =
 "class_ogre_1_1_e_g_l_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,292,104],
 "class_ogre_1_1_e_g_l_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,319,104],
 "class_ogre_1_1_e_g_l_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,319,103],
-"class_ogre_1_1_e_g_l_window.html#aef01aef07c52dd58fe07e68e602931a1":[6,0,0,319,71],
 "class_ogre_1_1_e_g_l_window.html#aef01aef07c52dd58fe07e68e602931a1":[7,0,0,292,71],
+"class_ogre_1_1_e_g_l_window.html#aef01aef07c52dd58fe07e68e602931a1":[6,0,0,319,71],
 "class_ogre_1_1_e_g_l_window.html#af31a02e64d08c411b8873f9f7b006b55":[6,0,0,319,18],
 "class_ogre_1_1_e_g_l_window.html#af31a02e64d08c411b8873f9f7b006b55":[7,0,0,292,18],
 "class_ogre_1_1_e_g_l_window.html#af72cb6156c72e9d9568591dadcc54217":[7,0,0,292,44],
 "class_ogre_1_1_e_g_l_window.html#af72cb6156c72e9d9568591dadcc54217":[6,0,0,319,44],
 "class_ogre_1_1_e_g_l_window.html#af77a2b45550db00c0ca364d762a5ca36":[6,0,0,319,31],
 "class_ogre_1_1_e_g_l_window.html#af77a2b45550db00c0ca364d762a5ca36":[7,0,0,292,31],
-"class_ogre_1_1_e_g_l_window.html#af8615122f9bc57a80ffc8c73a75d2852":[7,0,0,292,134],
 "class_ogre_1_1_e_g_l_window.html#af8615122f9bc57a80ffc8c73a75d2852":[6,0,0,319,134],
-"class_ogre_1_1_e_g_l_window.html#af8854efa9b905e9becd10e062a53ae3a":[6,0,0,319,79],
+"class_ogre_1_1_e_g_l_window.html#af8615122f9bc57a80ffc8c73a75d2852":[7,0,0,292,134],
 "class_ogre_1_1_e_g_l_window.html#af8854efa9b905e9becd10e062a53ae3a":[7,0,0,292,79],
-"class_ogre_1_1_e_g_l_window.html#af8ca9d240bd48662c37dbdf8fa881bad":[7,0,0,292,119],
+"class_ogre_1_1_e_g_l_window.html#af8854efa9b905e9becd10e062a53ae3a":[6,0,0,319,79],
 "class_ogre_1_1_e_g_l_window.html#af8ca9d240bd48662c37dbdf8fa881bad":[6,0,0,319,119],
+"class_ogre_1_1_e_g_l_window.html#af8ca9d240bd48662c37dbdf8fa881bad":[7,0,0,292,119],
 "class_ogre_1_1_e_g_l_window.html#afd829eb1b4b17d7881a49adbd9206edb":[7,0,0,292,110],
 "class_ogre_1_1_e_g_l_window.html#afd829eb1b4b17d7881a49adbd9206edb":[6,0,0,319,110],
 "class_ogre_1_1_e_t_c_codec.html":[5,2,3,3],
@@ -167,14 +169,14 @@ var NAVTREEINDEX79 =
 "class_ogre_1_1_egl_p_buffer_context.html#a1adbc39dc51e3c5dd91795544c2fa352":[6,0,0,315,6],
 "class_ogre_1_1_egl_p_buffer_context.html#a27fda5b9f2d30956691788fb643fdb84":[7,0,0,288,7],
 "class_ogre_1_1_egl_p_buffer_context.html#a27fda5b9f2d30956691788fb643fdb84":[6,0,0,315,7],
-"class_ogre_1_1_egl_p_buffer_context.html#a291525177116254970385db2fab2536d":[6,0,0,315,8],
 "class_ogre_1_1_egl_p_buffer_context.html#a291525177116254970385db2fab2536d":[7,0,0,288,8],
+"class_ogre_1_1_egl_p_buffer_context.html#a291525177116254970385db2fab2536d":[6,0,0,315,8],
 "class_ogre_1_1_egl_p_buffer_context.html#a385571885f435261eeb4fa5092965b5e":[6,0,0,315,3],
 "class_ogre_1_1_egl_p_buffer_context.html#a385571885f435261eeb4fa5092965b5e":[7,0,0,288,3],
-"class_ogre_1_1_egl_p_buffer_context.html#a55ff470f470368ebc9e26dfa693f2d91":[6,0,0,315,2],
 "class_ogre_1_1_egl_p_buffer_context.html#a55ff470f470368ebc9e26dfa693f2d91":[7,0,0,288,2],
-"class_ogre_1_1_egl_p_buffer_context.html#a5fb4a93dd5fc6c08a3d9b5a9417fc7c2":[7,0,0,288,0],
+"class_ogre_1_1_egl_p_buffer_context.html#a55ff470f470368ebc9e26dfa693f2d91":[6,0,0,315,2],
 "class_ogre_1_1_egl_p_buffer_context.html#a5fb4a93dd5fc6c08a3d9b5a9417fc7c2":[6,0,0,315,0],
+"class_ogre_1_1_egl_p_buffer_context.html#a5fb4a93dd5fc6c08a3d9b5a9417fc7c2":[7,0,0,288,0],
 "class_ogre_1_1_egl_p_buffer_context.html#a6977ed979951b1fb503d438652af37e1":[7,0,0,288,1],
 "class_ogre_1_1_egl_p_buffer_context.html#a6977ed979951b1fb503d438652af37e1":[6,0,0,315,1],
 "class_ogre_1_1_egl_p_buffer_context.html#a8dcd8f61a534e96e0c1c35cb8b37f337":[7,0,0,288,4],
@@ -185,69 +187,67 @@ var NAVTREEINDEX79 =
 "class_ogre_1_1_egl_p_buffer_support.html":[6,0,0,316],
 "class_ogre_1_1_egl_p_buffer_support.html#a00f443e800891f54ac1176072e99e3a5":[6,0,0,316,8],
 "class_ogre_1_1_egl_p_buffer_support.html#a00f443e800891f54ac1176072e99e3a5":[7,0,0,289,8],
-"class_ogre_1_1_egl_p_buffer_support.html#a0696cf54790b3178a765c4554fe29888":[6,0,0,316,13],
 "class_ogre_1_1_egl_p_buffer_support.html#a0696cf54790b3178a765c4554fe29888":[7,0,0,289,13],
+"class_ogre_1_1_egl_p_buffer_support.html#a0696cf54790b3178a765c4554fe29888":[6,0,0,316,13],
 "class_ogre_1_1_egl_p_buffer_support.html#a0786a0dd2feecb480940bc568e4c66d0":[7,0,0,289,15],
 "class_ogre_1_1_egl_p_buffer_support.html#a0786a0dd2feecb480940bc568e4c66d0":[6,0,0,316,15],
-"class_ogre_1_1_egl_p_buffer_support.html#a1967867822fc80e81590ac9be066440b":[7,0,0,289,18],
 "class_ogre_1_1_egl_p_buffer_support.html#a1967867822fc80e81590ac9be066440b":[6,0,0,316,18],
-"class_ogre_1_1_egl_p_buffer_support.html#a1d8351d5b2f05fd0608d9850d38d5787":[7,0,0,289,14],
+"class_ogre_1_1_egl_p_buffer_support.html#a1967867822fc80e81590ac9be066440b":[7,0,0,289,18],
 "class_ogre_1_1_egl_p_buffer_support.html#a1d8351d5b2f05fd0608d9850d38d5787":[6,0,0,316,14],
-"class_ogre_1_1_egl_p_buffer_support.html#a22d2839b5816a96da40df621110a367c":[7,0,0,289,25],
+"class_ogre_1_1_egl_p_buffer_support.html#a1d8351d5b2f05fd0608d9850d38d5787":[7,0,0,289,14],
 "class_ogre_1_1_egl_p_buffer_support.html#a22d2839b5816a96da40df621110a367c":[6,0,0,316,25],
+"class_ogre_1_1_egl_p_buffer_support.html#a22d2839b5816a96da40df621110a367c":[7,0,0,289,25],
 "class_ogre_1_1_egl_p_buffer_support.html#a29895b78058f78044f1259375366d20f":[7,0,0,289,7],
 "class_ogre_1_1_egl_p_buffer_support.html#a29895b78058f78044f1259375366d20f":[6,0,0,316,7],
-"class_ogre_1_1_egl_p_buffer_support.html#a3a065dfae10c8617edb53aba19e75fe0":[6,0,0,316,5],
 "class_ogre_1_1_egl_p_buffer_support.html#a3a065dfae10c8617edb53aba19e75fe0":[7,0,0,289,5],
-"class_ogre_1_1_egl_p_buffer_support.html#a412221584c7c370d65551d2e162cc8b6":[7,0,0,289,11],
+"class_ogre_1_1_egl_p_buffer_support.html#a3a065dfae10c8617edb53aba19e75fe0":[6,0,0,316,5],
 "class_ogre_1_1_egl_p_buffer_support.html#a412221584c7c370d65551d2e162cc8b6":[6,0,0,316,11],
-"class_ogre_1_1_egl_p_buffer_support.html#a484f8497139f7ec284b75a01bf6eb18a":[6,0,0,316,3],
+"class_ogre_1_1_egl_p_buffer_support.html#a412221584c7c370d65551d2e162cc8b6":[7,0,0,289,11],
 "class_ogre_1_1_egl_p_buffer_support.html#a484f8497139f7ec284b75a01bf6eb18a":[7,0,0,289,3],
+"class_ogre_1_1_egl_p_buffer_support.html#a484f8497139f7ec284b75a01bf6eb18a":[6,0,0,316,3],
 "class_ogre_1_1_egl_p_buffer_support.html#a4f53bfb02b1f21018d2902d466c1208c":[7,0,0,289,4],
 "class_ogre_1_1_egl_p_buffer_support.html#a4f53bfb02b1f21018d2902d466c1208c":[6,0,0,316,4],
 "class_ogre_1_1_egl_p_buffer_support.html#a5a9d93fc7bd29b59b6ecbe4c591a61aa":[7,0,0,289,26],
 "class_ogre_1_1_egl_p_buffer_support.html#a5a9d93fc7bd29b59b6ecbe4c591a61aa":[6,0,0,316,26],
-"class_ogre_1_1_egl_p_buffer_support.html#a8954a5a970c650fa6fd97e73f3428ef6":[7,0,0,289,19],
 "class_ogre_1_1_egl_p_buffer_support.html#a8954a5a970c650fa6fd97e73f3428ef6":[6,0,0,316,19],
-"class_ogre_1_1_egl_p_buffer_support.html#a8bd62abfa24666b8110de75e4a24a46f":[7,0,0,289,12],
+"class_ogre_1_1_egl_p_buffer_support.html#a8954a5a970c650fa6fd97e73f3428ef6":[7,0,0,289,19],
 "class_ogre_1_1_egl_p_buffer_support.html#a8bd62abfa24666b8110de75e4a24a46f":[6,0,0,316,12],
+"class_ogre_1_1_egl_p_buffer_support.html#a8bd62abfa24666b8110de75e4a24a46f":[7,0,0,289,12],
 "class_ogre_1_1_egl_p_buffer_support.html#a8ea937e17888a28c251d85dd198f63e6":[6,0,0,316,2],
 "class_ogre_1_1_egl_p_buffer_support.html#a8ea937e17888a28c251d85dd198f63e6":[7,0,0,289,2],
 "class_ogre_1_1_egl_p_buffer_support.html#a929673c956ff6e75a8f701898eca511c":[7,0,0,289,9],
 "class_ogre_1_1_egl_p_buffer_support.html#a929673c956ff6e75a8f701898eca511c":[6,0,0,316,9],
-"class_ogre_1_1_egl_p_buffer_support.html#a93b42683ff274d8cb6663b7fb2064901":[7,0,0,289,24],
 "class_ogre_1_1_egl_p_buffer_support.html#a93b42683ff274d8cb6663b7fb2064901":[6,0,0,316,24],
-"class_ogre_1_1_egl_p_buffer_support.html#a99adef70272ec72c1d44943c43a27ab3":[6,0,0,316,10],
+"class_ogre_1_1_egl_p_buffer_support.html#a93b42683ff274d8cb6663b7fb2064901":[7,0,0,289,24],
 "class_ogre_1_1_egl_p_buffer_support.html#a99adef70272ec72c1d44943c43a27ab3":[7,0,0,289,10],
-"class_ogre_1_1_egl_p_buffer_support.html#aa59e93bc2da16cb9b03d48c1cc90b444":[6,0,0,316,23],
+"class_ogre_1_1_egl_p_buffer_support.html#a99adef70272ec72c1d44943c43a27ab3":[6,0,0,316,10],
 "class_ogre_1_1_egl_p_buffer_support.html#aa59e93bc2da16cb9b03d48c1cc90b444":[7,0,0,289,23],
+"class_ogre_1_1_egl_p_buffer_support.html#aa59e93bc2da16cb9b03d48c1cc90b444":[6,0,0,316,23],
 "class_ogre_1_1_egl_p_buffer_support.html#aa81f4a5318f16df14c2cb4193f2a5982":[7,0,0,289,1],
 "class_ogre_1_1_egl_p_buffer_support.html#aa81f4a5318f16df14c2cb4193f2a5982":[6,0,0,316,1],
-"class_ogre_1_1_egl_p_buffer_support.html#ab0f1e560e37dc452aa5b6c169323d5e5":[7,0,0,289,21],
 "class_ogre_1_1_egl_p_buffer_support.html#ab0f1e560e37dc452aa5b6c169323d5e5":[6,0,0,316,21],
-"class_ogre_1_1_egl_p_buffer_support.html#ab4bd3f3ed2d900304219ccff511b45d1":[7,0,0,289,16],
+"class_ogre_1_1_egl_p_buffer_support.html#ab0f1e560e37dc452aa5b6c169323d5e5":[7,0,0,289,21],
 "class_ogre_1_1_egl_p_buffer_support.html#ab4bd3f3ed2d900304219ccff511b45d1":[6,0,0,316,16],
+"class_ogre_1_1_egl_p_buffer_support.html#ab4bd3f3ed2d900304219ccff511b45d1":[7,0,0,289,16],
 "class_ogre_1_1_egl_p_buffer_support.html#abf5d077e3e006563d98c8e48ec773770":[7,0,0,289,6],
 "class_ogre_1_1_egl_p_buffer_support.html#abf5d077e3e006563d98c8e48ec773770":[6,0,0,316,6],
-"class_ogre_1_1_egl_p_buffer_support.html#ae5eebd1e301e98a051389601418bb7ad":[7,0,0,289,17],
 "class_ogre_1_1_egl_p_buffer_support.html#ae5eebd1e301e98a051389601418bb7ad":[6,0,0,316,17],
+"class_ogre_1_1_egl_p_buffer_support.html#ae5eebd1e301e98a051389601418bb7ad":[7,0,0,289,17],
 "class_ogre_1_1_egl_p_buffer_support.html#aeb3f9d47949328053ba5d856a95a56cd":[7,0,0,289,20],
 "class_ogre_1_1_egl_p_buffer_support.html#aeb3f9d47949328053ba5d856a95a56cd":[6,0,0,316,20],
-"class_ogre_1_1_egl_p_buffer_support.html#afc5a8ba353c6479ec2fab128cf736c90":[7,0,0,289,22],
 "class_ogre_1_1_egl_p_buffer_support.html#afc5a8ba353c6479ec2fab128cf736c90":[6,0,0,316,22],
+"class_ogre_1_1_egl_p_buffer_support.html#afc5a8ba353c6479ec2fab128cf736c90":[7,0,0,289,22],
 "class_ogre_1_1_egl_p_buffer_window.html":[7,0,0,290],
 "class_ogre_1_1_egl_p_buffer_window.html":[6,0,0,317],
-"class_ogre_1_1_egl_p_buffer_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,317,47],
 "class_ogre_1_1_egl_p_buffer_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[7,0,0,290,47],
+"class_ogre_1_1_egl_p_buffer_window.html#a0f7e59347f6a688da34e9a759e92aa1a":[6,0,0,317,47],
 "class_ogre_1_1_egl_p_buffer_window.html#a12411d378aa0623e29287964eeb261c4":[7,0,0,290,20],
 "class_ogre_1_1_egl_p_buffer_window.html#a12411d378aa0623e29287964eeb261c4":[6,0,0,317,20],
-"class_ogre_1_1_egl_p_buffer_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,317,33],
 "class_ogre_1_1_egl_p_buffer_window.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,290,33],
+"class_ogre_1_1_egl_p_buffer_window.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,317,33],
 "class_ogre_1_1_egl_p_buffer_window.html#a1dd206963ccd3147463e4e0a33baa422":[7,0,0,290,51],
 "class_ogre_1_1_egl_p_buffer_window.html#a1dd206963ccd3147463e4e0a33baa422":[6,0,0,317,51],
-"class_ogre_1_1_egl_p_buffer_window.html#a1de45573360bcfdc0f100111902be88a":[7,0,0,290,1],
 "class_ogre_1_1_egl_p_buffer_window.html#a1de45573360bcfdc0f100111902be88a":[6,0,0,317,1],
-"class_ogre_1_1_egl_p_buffer_window.html#a2226f9abed46d6988c8f0b520ce2a894":[6,0,0,317,27],
-"class_ogre_1_1_egl_p_buffer_window.html#a2226f9abed46d6988c8f0b520ce2a894":[7,0,0,290,27],
-"class_ogre_1_1_egl_p_buffer_window.html#a22779bbfb123c76e922942ba876e330a":[6,0,0,317,28]
+"class_ogre_1_1_egl_p_buffer_window.html#a1de45573360bcfdc0f100111902be88a":[7,0,0,290,1],
+"class_ogre_1_1_egl_p_buffer_window.html#a2226f9abed46d6988c8f0b520ce2a894":[6,0,0,317,27]
 };
