@@ -1,6 +1,8 @@
 var NAVTREEINDEX80 =
 {
+"class_ogre_1_1_egl_p_buffer_window.html#a2226f9abed46d6988c8f0b520ce2a894":[7,0,0,290,27],
 "class_ogre_1_1_egl_p_buffer_window.html#a22779bbfb123c76e922942ba876e330a":[7,0,0,290,28],
+"class_ogre_1_1_egl_p_buffer_window.html#a22779bbfb123c76e922942ba876e330a":[6,0,0,317,28],
 "class_ogre_1_1_egl_p_buffer_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[6,0,0,317,19],
 "class_ogre_1_1_egl_p_buffer_window.html#a3b1af2a3ccebacfad34e1c5c2eb99d49":[7,0,0,290,19],
 "class_ogre_1_1_egl_p_buffer_window.html#a3ff24dc15ec59e058aadea1e1381b8ed":[7,0,0,290,42],
@@ -9,10 +11,10 @@ var NAVTREEINDEX80 =
 "class_ogre_1_1_egl_p_buffer_window.html#a462859aeb6b4db7290622623dae2a6a4":[7,0,0,290,25],
 "class_ogre_1_1_egl_p_buffer_window.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,317,35],
 "class_ogre_1_1_egl_p_buffer_window.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,290,35],
-"class_ogre_1_1_egl_p_buffer_window.html#a63c597775e7ce471f3b4c54763fdba4e":[6,0,0,317,43],
 "class_ogre_1_1_egl_p_buffer_window.html#a63c597775e7ce471f3b4c54763fdba4e":[7,0,0,290,43],
-"class_ogre_1_1_egl_p_buffer_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,290,38],
+"class_ogre_1_1_egl_p_buffer_window.html#a63c597775e7ce471f3b4c54763fdba4e":[6,0,0,317,43],
 "class_ogre_1_1_egl_p_buffer_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,317,38],
+"class_ogre_1_1_egl_p_buffer_window.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,290,38],
 "class_ogre_1_1_egl_p_buffer_window.html#a67ba7307754a41632bb41c383191bba7":[6,0,0,317,6],
 "class_ogre_1_1_egl_p_buffer_window.html#a67ba7307754a41632bb41c383191bba7":[7,0,0,290,6],
 "class_ogre_1_1_egl_p_buffer_window.html#a6acbc757e5f5b091aa51022e4cb382a4":[6,0,0,317,22],
@@ -23,78 +25,78 @@ var NAVTREEINDEX80 =
 "class_ogre_1_1_egl_p_buffer_window.html#a75261d46e5f123e31ab4f889b8788e5f":[7,0,0,290,18],
 "class_ogre_1_1_egl_p_buffer_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[6,0,0,317,46],
 "class_ogre_1_1_egl_p_buffer_window.html#a7df3603f7918dcb9af4e6c031d0b7fb9":[7,0,0,290,46],
-"class_ogre_1_1_egl_p_buffer_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[7,0,0,290,23],
 "class_ogre_1_1_egl_p_buffer_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[6,0,0,317,23],
-"class_ogre_1_1_egl_p_buffer_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,290,31],
+"class_ogre_1_1_egl_p_buffer_window.html#a814de6b1529bba5f7aa80ea3ac537ae1":[7,0,0,290,23],
 "class_ogre_1_1_egl_p_buffer_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,317,31],
+"class_ogre_1_1_egl_p_buffer_window.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,290,31],
 "class_ogre_1_1_egl_p_buffer_window.html#a84739cd779700fa8d7991c9cf11c289d":[6,0,0,317,21],
 "class_ogre_1_1_egl_p_buffer_window.html#a84739cd779700fa8d7991c9cf11c289d":[7,0,0,290,21],
 "class_ogre_1_1_egl_p_buffer_window.html#a88a4164162cf67ca28f4cda6e40d4455":[7,0,0,290,2],
 "class_ogre_1_1_egl_p_buffer_window.html#a88a4164162cf67ca28f4cda6e40d4455":[6,0,0,317,2],
-"class_ogre_1_1_egl_p_buffer_window.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,290,12],
 "class_ogre_1_1_egl_p_buffer_window.html#a8a464e98db9c09042b866bdb95b210f4":[6,0,0,317,12],
-"class_ogre_1_1_egl_p_buffer_window.html#a8b05fabc7b8b6cf3129279629562476d":[7,0,0,290,14],
+"class_ogre_1_1_egl_p_buffer_window.html#a8a464e98db9c09042b866bdb95b210f4":[7,0,0,290,12],
 "class_ogre_1_1_egl_p_buffer_window.html#a8b05fabc7b8b6cf3129279629562476d":[6,0,0,317,14],
+"class_ogre_1_1_egl_p_buffer_window.html#a8b05fabc7b8b6cf3129279629562476d":[7,0,0,290,14],
 "class_ogre_1_1_egl_p_buffer_window.html#a8d7e786602979fc29169555056834c65":[7,0,0,290,10],
 "class_ogre_1_1_egl_p_buffer_window.html#a8d7e786602979fc29169555056834c65":[6,0,0,317,10],
-"class_ogre_1_1_egl_p_buffer_window.html#a92d426a5762a35639ab102cfcbcaedf5":[6,0,0,317,29],
 "class_ogre_1_1_egl_p_buffer_window.html#a92d426a5762a35639ab102cfcbcaedf5":[7,0,0,290,29],
-"class_ogre_1_1_egl_p_buffer_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,317,34],
+"class_ogre_1_1_egl_p_buffer_window.html#a92d426a5762a35639ab102cfcbcaedf5":[6,0,0,317,29],
 "class_ogre_1_1_egl_p_buffer_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,290,34],
+"class_ogre_1_1_egl_p_buffer_window.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,317,34],
 "class_ogre_1_1_egl_p_buffer_window.html#a9439f12db8a964f79f4b743493a0fd75":[7,0,0,290,13],
 "class_ogre_1_1_egl_p_buffer_window.html#a9439f12db8a964f79f4b743493a0fd75":[6,0,0,317,13],
-"class_ogre_1_1_egl_p_buffer_window.html#a944ec2ce91e3431655eded15fbdf9e76":[7,0,0,290,44],
 "class_ogre_1_1_egl_p_buffer_window.html#a944ec2ce91e3431655eded15fbdf9e76":[6,0,0,317,44],
+"class_ogre_1_1_egl_p_buffer_window.html#a944ec2ce91e3431655eded15fbdf9e76":[7,0,0,290,44],
 "class_ogre_1_1_egl_p_buffer_window.html#a98e469177049ea5be91a095748b344e6":[6,0,0,317,48],
 "class_ogre_1_1_egl_p_buffer_window.html#a98e469177049ea5be91a095748b344e6":[7,0,0,290,48],
-"class_ogre_1_1_egl_p_buffer_window.html#a98f49dbefa207210a2f4c0025848b93c":[7,0,0,290,15],
 "class_ogre_1_1_egl_p_buffer_window.html#a98f49dbefa207210a2f4c0025848b93c":[6,0,0,317,15],
+"class_ogre_1_1_egl_p_buffer_window.html#a98f49dbefa207210a2f4c0025848b93c":[7,0,0,290,15],
 "class_ogre_1_1_egl_p_buffer_window.html#aa5e2f5fa5648f21e83818873ef4c2e86":[6,0,0,317,0],
 "class_ogre_1_1_egl_p_buffer_window.html#aa5e2f5fa5648f21e83818873ef4c2e86":[7,0,0,290,0],
-"class_ogre_1_1_egl_p_buffer_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[6,0,0,317,45],
 "class_ogre_1_1_egl_p_buffer_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[7,0,0,290,45],
-"class_ogre_1_1_egl_p_buffer_window.html#aa8c616e4ad1eb3976c9fab8233945a09":[7,0,0,290,7],
+"class_ogre_1_1_egl_p_buffer_window.html#aa6ee76edb7111f8feefbb1f73aae50be":[6,0,0,317,45],
 "class_ogre_1_1_egl_p_buffer_window.html#aa8c616e4ad1eb3976c9fab8233945a09":[6,0,0,317,7],
+"class_ogre_1_1_egl_p_buffer_window.html#aa8c616e4ad1eb3976c9fab8233945a09":[7,0,0,290,7],
 "class_ogre_1_1_egl_p_buffer_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[6,0,0,317,53],
 "class_ogre_1_1_egl_p_buffer_window.html#aabfaa3d20b4ad5f0ad0b30ccaf6f2ef7":[7,0,0,290,53],
-"class_ogre_1_1_egl_p_buffer_window.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,290,37],
 "class_ogre_1_1_egl_p_buffer_window.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,317,37],
-"class_ogre_1_1_egl_p_buffer_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[7,0,0,290,3],
+"class_ogre_1_1_egl_p_buffer_window.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,290,37],
 "class_ogre_1_1_egl_p_buffer_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[6,0,0,317,3],
-"class_ogre_1_1_egl_p_buffer_window.html#ab871683cdc01c7fcaab957f2a09641d5":[7,0,0,290,30],
+"class_ogre_1_1_egl_p_buffer_window.html#ab6a57b4b121d4f1af4e98bcc4f86e161":[7,0,0,290,3],
 "class_ogre_1_1_egl_p_buffer_window.html#ab871683cdc01c7fcaab957f2a09641d5":[6,0,0,317,30],
-"class_ogre_1_1_egl_p_buffer_window.html#abc2f3a9544249455de8e94c501aaa04f":[7,0,0,290,5],
+"class_ogre_1_1_egl_p_buffer_window.html#ab871683cdc01c7fcaab957f2a09641d5":[7,0,0,290,30],
 "class_ogre_1_1_egl_p_buffer_window.html#abc2f3a9544249455de8e94c501aaa04f":[6,0,0,317,5],
+"class_ogre_1_1_egl_p_buffer_window.html#abc2f3a9544249455de8e94c501aaa04f":[7,0,0,290,5],
 "class_ogre_1_1_egl_p_buffer_window.html#abcff58b0641f5540f159d8ce080bb05e":[7,0,0,290,41],
 "class_ogre_1_1_egl_p_buffer_window.html#abcff58b0641f5540f159d8ce080bb05e":[6,0,0,317,41],
 "class_ogre_1_1_egl_p_buffer_window.html#abffec246be83d1df9c7a8c6ecb0249ea":[7,0,0,290,54],
 "class_ogre_1_1_egl_p_buffer_window.html#abffec246be83d1df9c7a8c6ecb0249ea":[6,0,0,317,54],
-"class_ogre_1_1_egl_p_buffer_window.html#ac344214fa2a1ead13bb78f73712f69a3":[7,0,0,290,52],
 "class_ogre_1_1_egl_p_buffer_window.html#ac344214fa2a1ead13bb78f73712f69a3":[6,0,0,317,52],
+"class_ogre_1_1_egl_p_buffer_window.html#ac344214fa2a1ead13bb78f73712f69a3":[7,0,0,290,52],
 "class_ogre_1_1_egl_p_buffer_window.html#ac77d3326bdf2833b952bded3277d5ca1":[6,0,0,317,24],
 "class_ogre_1_1_egl_p_buffer_window.html#ac77d3326bdf2833b952bded3277d5ca1":[7,0,0,290,24],
 "class_ogre_1_1_egl_p_buffer_window.html#ac863907feaf796e7b8073a7a5b8cc24b":[6,0,0,317,4],
 "class_ogre_1_1_egl_p_buffer_window.html#ac863907feaf796e7b8073a7a5b8cc24b":[7,0,0,290,4],
-"class_ogre_1_1_egl_p_buffer_window.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,317,8],
 "class_ogre_1_1_egl_p_buffer_window.html#ac97a3175013569f96d6109f9f159ed0c":[7,0,0,290,8],
-"class_ogre_1_1_egl_p_buffer_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,290,32],
+"class_ogre_1_1_egl_p_buffer_window.html#ac97a3175013569f96d6109f9f159ed0c":[6,0,0,317,8],
 "class_ogre_1_1_egl_p_buffer_window.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,317,32],
-"class_ogre_1_1_egl_p_buffer_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,317,16],
+"class_ogre_1_1_egl_p_buffer_window.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,290,32],
 "class_ogre_1_1_egl_p_buffer_window.html#ad15462609bf45808fb04668cc1c28c78":[7,0,0,290,16],
-"class_ogre_1_1_egl_p_buffer_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,290,36],
+"class_ogre_1_1_egl_p_buffer_window.html#ad15462609bf45808fb04668cc1c28c78":[6,0,0,317,16],
 "class_ogre_1_1_egl_p_buffer_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,317,36],
+"class_ogre_1_1_egl_p_buffer_window.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,290,36],
 "class_ogre_1_1_egl_p_buffer_window.html#ad31d3601f5dcd10458a0cfc530fff042":[7,0,0,290,49],
 "class_ogre_1_1_egl_p_buffer_window.html#ad31d3601f5dcd10458a0cfc530fff042":[6,0,0,317,49],
 "class_ogre_1_1_egl_p_buffer_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[6,0,0,317,26],
 "class_ogre_1_1_egl_p_buffer_window.html#adb2bd9cd226f8e00ea1cd7d70c2e38e4":[7,0,0,290,26],
-"class_ogre_1_1_egl_p_buffer_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,317,17],
 "class_ogre_1_1_egl_p_buffer_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[7,0,0,290,17],
-"class_ogre_1_1_egl_p_buffer_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,317,39],
+"class_ogre_1_1_egl_p_buffer_window.html#adb9f92d4da00b9e48328a1c3e19151c4":[6,0,0,317,17],
 "class_ogre_1_1_egl_p_buffer_window.html#adce32528577d71b228692df906ecd17c":[7,0,0,290,39],
-"class_ogre_1_1_egl_p_buffer_window.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,317,11],
+"class_ogre_1_1_egl_p_buffer_window.html#adce32528577d71b228692df906ecd17c":[6,0,0,317,39],
 "class_ogre_1_1_egl_p_buffer_window.html#add8e20491fc0e054c9cab3c75297c6ec":[7,0,0,290,11],
-"class_ogre_1_1_egl_p_buffer_window.html#aec66e97b5ca37c165bbaa9e8a08bc031":[6,0,0,317,50],
+"class_ogre_1_1_egl_p_buffer_window.html#add8e20491fc0e054c9cab3c75297c6ec":[6,0,0,317,11],
 "class_ogre_1_1_egl_p_buffer_window.html#aec66e97b5ca37c165bbaa9e8a08bc031":[7,0,0,290,50],
+"class_ogre_1_1_egl_p_buffer_window.html#aec66e97b5ca37c165bbaa9e8a08bc031":[6,0,0,317,50],
 "class_ogre_1_1_egl_p_buffer_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,290,40],
 "class_ogre_1_1_egl_p_buffer_window.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,317,40],
 "class_ogre_1_1_embedded_zip_archive_factory.html":[5,2,11,33],
@@ -118,84 +120,84 @@ var NAVTREEINDEX80 =
 "class_ogre_1_1_embedded_zip_archive_factory.html#ad730fc7214af02a0f1a348428e197366":[5,2,11,33,4],
 "class_ogre_1_1_embedded_zip_archive_factory.html#adce32528577d71b228692df906ecd17c":[5,2,11,33,17],
 "class_ogre_1_1_embedded_zip_archive_factory.html#aed1464ac3de21ff20db8f9f1f8608dc7":[5,2,11,33,18],
-"class_ogre_1_1_emitter_commands_1_1_cmd_angle.html":[6,0,0,7,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_angle.html":[7,0,0,0,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_angle.html":[6,0,0,7,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_angle.html#a87c9723b9e1981abea32845e4d557141":[7,0,0,0,0,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_angle.html#a87c9723b9e1981abea32845e4d557141":[6,0,0,7,0,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_angle.html#aae800df784bd4e920cd0ac3e3dceb5c9":[7,0,0,0,0,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_angle.html#aae800df784bd4e920cd0ac3e3dceb5c9":[6,0,0,7,0,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_colour.html":[6,0,0,7,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour.html":[7,0,0,0,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_colour.html":[6,0,0,7,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour.html#a62f39d1188ce10397993cd79d3e5b85c":[7,0,0,0,1,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour.html#a62f39d1188ce10397993cd79d3e5b85c":[6,0,0,7,1,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour.html#a75a8b5b22d60976de5fda44e3e56dc77":[7,0,0,0,1,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour.html#a75a8b5b22d60976de5fda44e3e56dc77":[6,0,0,7,1,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_end.html":[7,0,0,0,2],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_end.html":[6,0,0,7,2],
-"class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_end.html#a0afdc4c39933dab9727b742dff91328b":[6,0,0,7,2,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_end.html":[7,0,0,0,2],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_end.html#a0afdc4c39933dab9727b742dff91328b":[7,0,0,0,2,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_end.html#a0afdc4c39933dab9727b742dff91328b":[6,0,0,7,2,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_end.html#a4f4724fa269071c6dea19e30cc4d5e31":[6,0,0,7,2,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_end.html#a4f4724fa269071c6dea19e30cc4d5e31":[7,0,0,0,2,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_start.html":[7,0,0,0,3],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_start.html":[6,0,0,7,3],
+"class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_start.html":[7,0,0,0,3],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_start.html#acd432f965389d608f8bd5e37cfd2e6e7":[6,0,0,7,3,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_start.html#acd432f965389d608f8bd5e37cfd2e6e7":[7,0,0,0,3,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_start.html#af30f01379314258929d695bc5e39a792":[6,0,0,7,3,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_colour_range_start.html#af30f01379314258929d695bc5e39a792":[7,0,0,0,3,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_dir_position_ref.html":[6,0,0,7,5],
 "class_ogre_1_1_emitter_commands_1_1_cmd_dir_position_ref.html":[7,0,0,0,5],
-"class_ogre_1_1_emitter_commands_1_1_cmd_dir_position_ref.html#a3ea3d34b777cfa3d87b6981df953d455":[6,0,0,7,5,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_dir_position_ref.html":[6,0,0,7,5],
 "class_ogre_1_1_emitter_commands_1_1_cmd_dir_position_ref.html#a3ea3d34b777cfa3d87b6981df953d455":[7,0,0,0,5,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_dir_position_ref.html#aab83d7bcb64f33928ec9b4e4d473f8b0":[6,0,0,7,5,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_dir_position_ref.html#a3ea3d34b777cfa3d87b6981df953d455":[6,0,0,7,5,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_dir_position_ref.html#aab83d7bcb64f33928ec9b4e4d473f8b0":[7,0,0,0,5,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_direction.html":[7,0,0,0,4],
+"class_ogre_1_1_emitter_commands_1_1_cmd_dir_position_ref.html#aab83d7bcb64f33928ec9b4e4d473f8b0":[6,0,0,7,5,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_direction.html":[6,0,0,7,4],
-"class_ogre_1_1_emitter_commands_1_1_cmd_direction.html#a183ca16a0bb97772c0f6836761bcd168":[6,0,0,7,4,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_direction.html":[7,0,0,0,4],
 "class_ogre_1_1_emitter_commands_1_1_cmd_direction.html#a183ca16a0bb97772c0f6836761bcd168":[7,0,0,0,4,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_direction.html#a183ca16a0bb97772c0f6836761bcd168":[6,0,0,7,4,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_direction.html#a25b4703949e8e50ef65783c8218e4922":[6,0,0,7,4,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_direction.html#a25b4703949e8e50ef65783c8218e4922":[7,0,0,0,4,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_duration.html":[7,0,0,0,6],
 "class_ogre_1_1_emitter_commands_1_1_cmd_duration.html":[6,0,0,7,6],
-"class_ogre_1_1_emitter_commands_1_1_cmd_duration.html#a1e94d5a0af5739b057b7e6728db6b8f5":[7,0,0,0,6,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_duration.html#a1e94d5a0af5739b057b7e6728db6b8f5":[6,0,0,7,6,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_duration.html#a6d1700b8b3e41fbdb5726ed4a00a6a52":[7,0,0,0,6,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_duration.html#a1e94d5a0af5739b057b7e6728db6b8f5":[7,0,0,0,6,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_duration.html#a6d1700b8b3e41fbdb5726ed4a00a6a52":[6,0,0,7,6,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_duration.html#a6d1700b8b3e41fbdb5726ed4a00a6a52":[7,0,0,0,6,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_emission_rate.html":[7,0,0,0,7],
 "class_ogre_1_1_emitter_commands_1_1_cmd_emission_rate.html":[6,0,0,7,7],
-"class_ogre_1_1_emitter_commands_1_1_cmd_emission_rate.html#a5e4beef3fd633d05186db80f6e935724":[7,0,0,0,7,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_emission_rate.html#a5e4beef3fd633d05186db80f6e935724":[6,0,0,7,7,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_emission_rate.html#aefd94cbc0ca5f06b4e59bf53c61149e7":[7,0,0,0,7,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_emission_rate.html#a5e4beef3fd633d05186db80f6e935724":[7,0,0,0,7,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_emission_rate.html#aefd94cbc0ca5f06b4e59bf53c61149e7":[6,0,0,7,7,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_emitted_emitter.html":[6,0,0,7,8],
+"class_ogre_1_1_emitter_commands_1_1_cmd_emission_rate.html#aefd94cbc0ca5f06b4e59bf53c61149e7":[7,0,0,0,7,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_emitted_emitter.html":[7,0,0,0,8],
+"class_ogre_1_1_emitter_commands_1_1_cmd_emitted_emitter.html":[6,0,0,7,8],
 "class_ogre_1_1_emitter_commands_1_1_cmd_emitted_emitter.html#af1882a2c738949716241f03cfc61f0a2":[7,0,0,0,8,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_emitted_emitter.html#af1882a2c738949716241f03cfc61f0a2":[6,0,0,7,8,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_emitted_emitter.html#af680b2cb9887d99316dab0e1ce6e24e7":[7,0,0,0,8,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_emitted_emitter.html#af680b2cb9887d99316dab0e1ce6e24e7":[6,0,0,7,8,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_emitted_emitter.html#af680b2cb9887d99316dab0e1ce6e24e7":[7,0,0,0,8,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_duration.html":[7,0,0,0,9],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_duration.html":[6,0,0,7,9],
-"class_ogre_1_1_emitter_commands_1_1_cmd_max_duration.html#a0adc725dccef84af7591f8692fc4d90f":[6,0,0,7,9,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_duration.html#a0adc725dccef84af7591f8692fc4d90f":[7,0,0,0,9,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_max_duration.html#a0adc725dccef84af7591f8692fc4d90f":[6,0,0,7,9,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_duration.html#ae738fd01077a481a06bb54e6a35133f7":[7,0,0,0,9,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_duration.html#ae738fd01077a481a06bb54e6a35133f7":[6,0,0,7,9,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_max_repeat_delay.html":[7,0,0,0,10],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_repeat_delay.html":[6,0,0,7,10],
-"class_ogre_1_1_emitter_commands_1_1_cmd_max_repeat_delay.html#a33810edfaeeccb3ff2d8354d96df312e":[6,0,0,7,10,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_max_repeat_delay.html":[7,0,0,0,10],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_repeat_delay.html#a33810edfaeeccb3ff2d8354d96df312e":[7,0,0,0,10,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_max_repeat_delay.html#a67fe0ff0ecbbc1020271e77b81871085":[6,0,0,7,10,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_max_repeat_delay.html#a33810edfaeeccb3ff2d8354d96df312e":[6,0,0,7,10,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_repeat_delay.html#a67fe0ff0ecbbc1020271e77b81871085":[7,0,0,0,10,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_max_t_t_l.html":[7,0,0,0,11],
+"class_ogre_1_1_emitter_commands_1_1_cmd_max_repeat_delay.html#a67fe0ff0ecbbc1020271e77b81871085":[6,0,0,7,10,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_t_t_l.html":[6,0,0,7,11],
-"class_ogre_1_1_emitter_commands_1_1_cmd_max_t_t_l.html#a3a9fb9438dacba74f9ad7165318df4a4":[6,0,0,7,11,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_max_t_t_l.html":[7,0,0,0,11],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_t_t_l.html#a3a9fb9438dacba74f9ad7165318df4a4":[7,0,0,0,11,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_max_t_t_l.html#a721b4bc9ac1c1be4acc90c181ca30a06":[6,0,0,7,11,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_max_t_t_l.html#a3a9fb9438dacba74f9ad7165318df4a4":[6,0,0,7,11,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_t_t_l.html#a721b4bc9ac1c1be4acc90c181ca30a06":[7,0,0,0,11,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_max_t_t_l.html#a721b4bc9ac1c1be4acc90c181ca30a06":[6,0,0,7,11,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_velocity.html":[6,0,0,7,12],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_velocity.html":[7,0,0,0,12],
-"class_ogre_1_1_emitter_commands_1_1_cmd_max_velocity.html#a1dcde3e9da6c012afa9e34ea6bcee082":[6,0,0,7,12,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_velocity.html#a1dcde3e9da6c012afa9e34ea6bcee082":[7,0,0,0,12,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_max_velocity.html#af37a9ceb9e09e2035c34fc38bfe4fd3e":[6,0,0,7,12,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_max_velocity.html#a1dcde3e9da6c012afa9e34ea6bcee082":[6,0,0,7,12,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_max_velocity.html#af37a9ceb9e09e2035c34fc38bfe4fd3e":[7,0,0,0,12,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_max_velocity.html#af37a9ceb9e09e2035c34fc38bfe4fd3e":[6,0,0,7,12,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_duration.html":[7,0,0,0,13],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_duration.html":[6,0,0,7,13],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_duration.html#aa17a214cecf5d3030864a85c816e67ff":[6,0,0,7,13,1],
@@ -206,48 +208,46 @@ var NAVTREEINDEX80 =
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_repeat_delay.html":[6,0,0,7,14],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_repeat_delay.html#a37ffe1864f7d5655cda17e1ee1bcd4bb":[7,0,0,0,14,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_repeat_delay.html#a37ffe1864f7d5655cda17e1ee1bcd4bb":[6,0,0,7,14,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_min_repeat_delay.html#ad48aae845cf71a48e7064824eec20c61":[7,0,0,0,14,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_repeat_delay.html#ad48aae845cf71a48e7064824eec20c61":[6,0,0,7,14,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_min_t_t_l.html":[7,0,0,0,15],
+"class_ogre_1_1_emitter_commands_1_1_cmd_min_repeat_delay.html#ad48aae845cf71a48e7064824eec20c61":[7,0,0,0,14,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_t_t_l.html":[6,0,0,7,15],
-"class_ogre_1_1_emitter_commands_1_1_cmd_min_t_t_l.html#a6744ef1b0a754650fe0b74eb91efc19a":[6,0,0,7,15,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_min_t_t_l.html":[7,0,0,0,15],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_t_t_l.html#a6744ef1b0a754650fe0b74eb91efc19a":[7,0,0,0,15,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_min_t_t_l.html#a73edf98f969e2d7ff3849c0c52e04572":[6,0,0,7,15,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_min_t_t_l.html#a6744ef1b0a754650fe0b74eb91efc19a":[6,0,0,7,15,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_t_t_l.html#a73edf98f969e2d7ff3849c0c52e04572":[7,0,0,0,15,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_min_velocity.html":[7,0,0,0,16],
+"class_ogre_1_1_emitter_commands_1_1_cmd_min_t_t_l.html#a73edf98f969e2d7ff3849c0c52e04572":[6,0,0,7,15,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_velocity.html":[6,0,0,7,16],
+"class_ogre_1_1_emitter_commands_1_1_cmd_min_velocity.html":[7,0,0,0,16],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_velocity.html#a2842042188b1892b2ccd0073bc08a640":[6,0,0,7,16,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_velocity.html#a2842042188b1892b2ccd0073bc08a640":[7,0,0,0,16,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_min_velocity.html#a66674767ec0d6e5c2be307066ec55431":[6,0,0,7,16,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_min_velocity.html#a66674767ec0d6e5c2be307066ec55431":[7,0,0,0,16,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_name.html":[7,0,0,0,17],
+"class_ogre_1_1_emitter_commands_1_1_cmd_min_velocity.html#a66674767ec0d6e5c2be307066ec55431":[6,0,0,7,16,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_name.html":[6,0,0,7,17],
+"class_ogre_1_1_emitter_commands_1_1_cmd_name.html":[7,0,0,0,17],
 "class_ogre_1_1_emitter_commands_1_1_cmd_name.html#a5e68b04d17f4e029daae8bb58ed2ddc9":[7,0,0,0,17,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_name.html#a5e68b04d17f4e029daae8bb58ed2ddc9":[6,0,0,7,17,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_name.html#ac7533d60514ad91d1fd8f3d391c90eb7":[7,0,0,0,17,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_name.html#ac7533d60514ad91d1fd8f3d391c90eb7":[6,0,0,7,17,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_position.html":[6,0,0,7,18],
 "class_ogre_1_1_emitter_commands_1_1_cmd_position.html":[7,0,0,0,18],
-"class_ogre_1_1_emitter_commands_1_1_cmd_position.html#ab241cc533c9085a3c360c6c1deb9e381":[6,0,0,7,18,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_position.html#ab241cc533c9085a3c360c6c1deb9e381":[7,0,0,0,18,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_position.html#af673ed7707415d9fda8998715fbbaab4":[6,0,0,7,18,1],
+"class_ogre_1_1_emitter_commands_1_1_cmd_position.html#ab241cc533c9085a3c360c6c1deb9e381":[6,0,0,7,18,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_position.html#af673ed7707415d9fda8998715fbbaab4":[7,0,0,0,18,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_repeat_delay.html":[6,0,0,7,19],
+"class_ogre_1_1_emitter_commands_1_1_cmd_position.html#af673ed7707415d9fda8998715fbbaab4":[6,0,0,7,18,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_repeat_delay.html":[7,0,0,0,19],
+"class_ogre_1_1_emitter_commands_1_1_cmd_repeat_delay.html":[6,0,0,7,19],
 "class_ogre_1_1_emitter_commands_1_1_cmd_repeat_delay.html#a034e5bda1f3c5b85fcaa965fdd6ee65d":[7,0,0,0,19,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_repeat_delay.html#a034e5bda1f3c5b85fcaa965fdd6ee65d":[6,0,0,7,19,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_repeat_delay.html#ade9f2e216c0452f7444115440f659455":[6,0,0,7,19,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_repeat_delay.html#ade9f2e216c0452f7444115440f659455":[7,0,0,0,19,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_repeat_delay.html#ade9f2e216c0452f7444115440f659455":[6,0,0,7,19,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_t_t_l.html":[6,0,0,7,20],
 "class_ogre_1_1_emitter_commands_1_1_cmd_t_t_l.html":[7,0,0,0,20],
 "class_ogre_1_1_emitter_commands_1_1_cmd_t_t_l.html#ad198b8248164985291386bb4be276f92":[6,0,0,7,20,1],
 "class_ogre_1_1_emitter_commands_1_1_cmd_t_t_l.html#ad198b8248164985291386bb4be276f92":[7,0,0,0,20,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_t_t_l.html#ae8bde3fe13fc794b1ff2a5ec38a01491":[7,0,0,0,20,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_t_t_l.html#ae8bde3fe13fc794b1ff2a5ec38a01491":[6,0,0,7,20,0],
+"class_ogre_1_1_emitter_commands_1_1_cmd_t_t_l.html#ae8bde3fe13fc794b1ff2a5ec38a01491":[7,0,0,0,20,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_up.html":[6,0,0,7,21],
 "class_ogre_1_1_emitter_commands_1_1_cmd_up.html":[7,0,0,0,21],
-"class_ogre_1_1_emitter_commands_1_1_cmd_up.html#a3cfdb7c09528078d63d1e69878fbc56c":[6,0,0,7,21,0],
 "class_ogre_1_1_emitter_commands_1_1_cmd_up.html#a3cfdb7c09528078d63d1e69878fbc56c":[7,0,0,0,21,0],
-"class_ogre_1_1_emitter_commands_1_1_cmd_up.html#ae6b325fab9cc33797f2b38aba8e35a27":[7,0,0,0,21,1],
-"class_ogre_1_1_emitter_commands_1_1_cmd_up.html#ae6b325fab9cc33797f2b38aba8e35a27":[6,0,0,7,21,1]
+"class_ogre_1_1_emitter_commands_1_1_cmd_up.html#a3cfdb7c09528078d63d1e69878fbc56c":[6,0,0,7,21,0]
 };
