@@ -1,5 +1,7 @@
 var NAVTREEINDEX85 =
 {
+"class_ogre_1_1_font_manager.html#ad9b4efbeacb17f07710c30bd5048e42f":[5,2,11,40,51],
+"class_ogre_1_1_font_manager.html#ada6af0d588fd5c17f0f8f7904fa657a8":[5,2,11,40,40],
 "class_ogre_1_1_font_manager.html#adce32528577d71b228692df906ecd17c":[5,2,11,40,38],
 "class_ogre_1_1_font_manager.html#ae26b6ecd722f3e24b52de8b4ac9bba0d":[5,2,11,40,41],
 "class_ogre_1_1_font_manager.html#aeaa1410333b7bcea14b00c360112a528":[5,2,11,40,58],
@@ -247,7 +249,5 @@ var NAVTREEINDEX85 =
 "class_ogre_1_1_free_image_codec2.html#ab422c67a2c8844f410fe822a357cba3b":[5,2,3,7,24],
 "class_ogre_1_1_free_image_codec2.html#ac63514f56fd78eba2480c9c689745280":[5,2,3,7,29],
 "class_ogre_1_1_free_image_codec2.html#acb46d4b0a597156d9ba5abc39d127792":[5,2,3,7,19],
-"class_ogre_1_1_free_image_codec2.html#ad10f9cea1938e7a50c78414ed8b2edc5":[5,2,3,7,17],
-"class_ogre_1_1_free_image_codec2.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[5,2,3,7,23],
-"class_ogre_1_1_free_image_codec2.html#adce32528577d71b228692df906ecd17c":[5,2,3,7,26]
+"class_ogre_1_1_free_image_codec2.html#ad10f9cea1938e7a50c78414ed8b2edc5":[5,2,3,7,17]
 };
