@@ -1,25 +1,27 @@
 var NAVTREEINDEX92 =
 {
+"class_ogre_1_1_g_l3_plus_null_texture.html#a0389e214a82832a0c11d91babbc0d65f":[6,0,0,381,97],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a0389e214a82832a0c11d91babbc0d65f":[7,0,0,354,97],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a04969ca1d25bf40e71e907f2cdb7443b":[6,0,0,381,99],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a04969ca1d25bf40e71e907f2cdb7443b":[7,0,0,354,99],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a0617d9f04ca03bd25f4bde201e6ac13b":[7,0,0,354,46],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a0617d9f04ca03bd25f4bde201e6ac13b":[6,0,0,381,46],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a0779c46df96234b6619a5f57fbb36078":[7,0,0,354,62],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a0617d9f04ca03bd25f4bde201e6ac13b":[7,0,0,354,46],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a0779c46df96234b6619a5f57fbb36078":[6,0,0,381,62],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572c":[6,0,0,381,1],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a0779c46df96234b6619a5f57fbb36078":[7,0,0,354,62],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572c":[7,0,0,354,1],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572c":[6,0,0,381,1],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca0c7b0873cacd42dec59d948b9bd28062":[6,0,0,381,1,6],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca0c7b0873cacd42dec59d948b9bd28062":[7,0,0,354,1,6],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1":[7,0,0,354,1,4],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1":[6,0,0,381,1,4],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca133a073b86c346096237063f99870fc1":[7,0,0,354,1,4],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca28d463296cacdfc115dbc3fb02d00e94":[7,0,0,354,1,0],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca28d463296cacdfc115dbc3fb02d00e94":[6,0,0,381,1,0],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca4228d390b3a9ed614001db177d1f441e":[6,0,0,381,1,3],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca4228d390b3a9ed614001db177d1f441e":[7,0,0,354,1,3],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572ca4228d390b3a9ed614001db177d1f441e":[6,0,0,381,1,3],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572caa38cbef7605fc4bff6da2f34599ace8f":[7,0,0,354,1,2],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572caa38cbef7605fc4bff6da2f34599ace8f":[6,0,0,381,1,2],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb":[7,0,0,354,1,5],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb":[6,0,0,381,1,5],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572cab43c913411f4a96722902f17b88f10fb":[7,0,0,354,1,5],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572caf138fc9087e0dc755bff08a83720cbb5":[7,0,0,354,1,1],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a07e619aa09d3bc6789a6667cb4fc572caf138fc9087e0dc755bff08a83720cbb5":[6,0,0,381,1,1],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a0883c51e283830144741fe47a7f3ef00":[7,0,0,354,64],
@@ -28,66 +30,66 @@ var NAVTREEINDEX92 =
 "class_ogre_1_1_g_l3_plus_null_texture.html#a0ba4cefce02a7afa769a28c85c892082":[7,0,0,354,96],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a104d9db8bfcff1f37b29157bbe070f7a":[7,0,0,354,103],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a104d9db8bfcff1f37b29157bbe070f7a":[6,0,0,381,103],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a13fc432584dd44c2969a8e41bdca569c":[6,0,0,381,8],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a13fc432584dd44c2969a8e41bdca569c":[7,0,0,354,8],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a1686b8aef3b2c8d3892ae453086073c4":[6,0,0,381,21],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a13fc432584dd44c2969a8e41bdca569c":[6,0,0,381,8],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1686b8aef3b2c8d3892ae453086073c4":[7,0,0,354,21],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a1686b8aef3b2c8d3892ae453086073c4":[6,0,0,381,21],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94":[7,0,0,354,0],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94":[6,0,0,381,0],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94a146041ec2a8b5178e5ad541d129c22eb":[7,0,0,354,0,5],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94a146041ec2a8b5178e5ad541d129c22eb":[6,0,0,381,0,5],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[6,0,0,381,0,1],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[7,0,0,354,0,1],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[6,0,0,381,0,2],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94a6ee542226e1cf18df28ab88426be6809":[6,0,0,381,0,1],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[7,0,0,354,0,2],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94a70589e0b87b09b0a4fd98ce490dc9782":[6,0,0,381,0,2],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c":[7,0,0,354,0,0],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94ab49695ac949df3a7d2e2f9a03267097c":[6,0,0,381,0,0],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[6,0,0,381,0,4],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[7,0,0,354,0,4],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94ad83abf165de5cfa1a4c8e0cd5471ad2c":[6,0,0,381,0,4],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77":[7,0,0,354,0,3],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1aa750a4b994f2b1066220936cdfdb94ae5f2eca654bd810da4c774570a5b4b77":[6,0,0,381,0,3],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[7,0,0,354,12],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1bea65fa2b3c2ac5a9f3be59b46a80e8":[6,0,0,381,12],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,354,71],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,381,71],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a1d84784891731ee66945ffbc3b31e35b":[7,0,0,354,67],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,354,71],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1d84784891731ee66945ffbc3b31e35b":[6,0,0,381,67],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a1e90ade99935ef70ec5b199243bf995b":[6,0,0,381,36],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a1d84784891731ee66945ffbc3b31e35b":[7,0,0,354,67],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a1e90ade99935ef70ec5b199243bf995b":[7,0,0,354,36],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a2298551707debaf774d577e643ee856a":[7,0,0,354,34],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a1e90ade99935ef70ec5b199243bf995b":[6,0,0,381,36],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a2298551707debaf774d577e643ee856a":[6,0,0,381,34],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a2298551707debaf774d577e643ee856a":[7,0,0,354,34],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a297b97d2c7253c1ca8c471b91edd4407":[6,0,0,381,35],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a297b97d2c7253c1ca8c471b91edd4407":[7,0,0,354,35],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a2ee26937110dfbd80a5419b1e14fe619":[6,0,0,381,86],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a2ee26937110dfbd80a5419b1e14fe619":[7,0,0,354,86],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a350b287fa3e83a389221274f68760008":[6,0,0,381,79],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a350b287fa3e83a389221274f68760008":[7,0,0,354,79],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a367f6fe60bb211cb4c32e3825ca67e4c":[7,0,0,354,18],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a350b287fa3e83a389221274f68760008":[6,0,0,381,79],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a367f6fe60bb211cb4c32e3825ca67e4c":[6,0,0,381,18],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a367f6fe60bb211cb4c32e3825ca67e4c":[7,0,0,354,18],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a3af26f716731b64850ea50cfa4d2edef":[7,0,0,354,60],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a3af26f716731b64850ea50cfa4d2edef":[6,0,0,381,60],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a3c49142f739ba8fb56d6e7b3db235fb7":[6,0,0,381,81],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a3c49142f739ba8fb56d6e7b3db235fb7":[7,0,0,354,81],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a3c600369ab5d6957524125c93915019f":[7,0,0,354,14],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a3c600369ab5d6957524125c93915019f":[6,0,0,381,14],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a3c600369ab5d6957524125c93915019f":[7,0,0,354,14],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a3d111616339484f39c9456eeec6fd843":[6,0,0,381,9],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a3d111616339484f39c9456eeec6fd843":[7,0,0,354,9],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a3e314036bfd3198e89bd1d250f5eb6a1":[6,0,0,381,43],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a3e314036bfd3198e89bd1d250f5eb6a1":[7,0,0,354,43],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a43fa847c09ec75de76555dd648e95420":[7,0,0,354,19],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a43fa847c09ec75de76555dd648e95420":[6,0,0,381,19],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a496e18b2a22246735fd08fd83798c4a2":[7,0,0,354,13],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a43fa847c09ec75de76555dd648e95420":[7,0,0,354,19],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a496e18b2a22246735fd08fd83798c4a2":[6,0,0,381,13],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a4b5d014a4d078b7893cce480b264c493":[7,0,0,354,7],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a496e18b2a22246735fd08fd83798c4a2":[7,0,0,354,13],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a4b5d014a4d078b7893cce480b264c493":[6,0,0,381,7],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a4d0ef43ff1e078b942e017f3dea6471d":[6,0,0,381,52],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a4b5d014a4d078b7893cce480b264c493":[7,0,0,354,7],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a4d0ef43ff1e078b942e017f3dea6471d":[7,0,0,354,52],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a5016aec1762b026997ddd346775879ef":[7,0,0,354,80],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a4d0ef43ff1e078b942e017f3dea6471d":[6,0,0,381,52],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a5016aec1762b026997ddd346775879ef":[6,0,0,381,80],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a5016aec1762b026997ddd346775879ef":[7,0,0,354,80],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a5513ffce404b14cff72846318b018d32":[7,0,0,354,10],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a5513ffce404b14cff72846318b018d32":[6,0,0,381,10],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,354,73],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,381,73],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,354,73],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a5b35a8bf205a7fb382c448522c0f3fc8":[7,0,0,354,22],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a5b35a8bf205a7fb382c448522c0f3fc8":[6,0,0,381,22],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a5c9a21a914281a1b6ef5796531ea96e7":[7,0,0,354,58],
@@ -96,8 +98,8 @@ var NAVTREEINDEX92 =
 "class_ogre_1_1_g_l3_plus_null_texture.html#a5d3962a2bef3bd77de412c8207975caf":[7,0,0,354,38],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a5dcfc70318106dd00902b0fc945d1d0e":[6,0,0,381,56],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a5dcfc70318106dd00902b0fc945d1d0e":[7,0,0,354,56],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a5decc0244a000c5002935c32ac301f0c":[6,0,0,381,25],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a5decc0244a000c5002935c32ac301f0c":[7,0,0,354,25],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a5decc0244a000c5002935c32ac301f0c":[6,0,0,381,25],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a60ce96525ac730a0f7b466ed287beef3":[6,0,0,381,57],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a60ce96525ac730a0f7b466ed287beef3":[7,0,0,354,57],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,381,76],
@@ -106,42 +108,42 @@ var NAVTREEINDEX92 =
 "class_ogre_1_1_g_l3_plus_null_texture.html#a65b5bd9531c385e200482c0edafdc1c2":[7,0,0,354,29],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a699d1c851f494a8d5d23d23b695ceb47":[6,0,0,381,65],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a699d1c851f494a8d5d23d23b695ceb47":[7,0,0,354,65],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a69fbdff7f241bfd0f7c4c43b267ecbb5":[6,0,0,381,54],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a69fbdff7f241bfd0f7c4c43b267ecbb5":[7,0,0,354,54],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a69fbdff7f241bfd0f7c4c43b267ecbb5":[6,0,0,381,54],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a6bdd32464ce1df547d34a0739e4c3592":[6,0,0,381,68],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a6bdd32464ce1df547d34a0739e4c3592":[7,0,0,354,68],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a6cfc6014da843369b2619d1d7d807569":[6,0,0,381,33],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a6cfc6014da843369b2619d1d7d807569":[7,0,0,354,33],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a6cfc6014da843369b2619d1d7d807569":[6,0,0,381,33],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a6ed49ed8701feb087b04b730ce1d682f":[6,0,0,381,48],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a6ed49ed8701feb087b04b730ce1d682f":[7,0,0,354,48],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a6f186da4d9557d958779eba68bb769a9":[7,0,0,354,37],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a6f186da4d9557d958779eba68bb769a9":[6,0,0,381,37],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[6,0,0,381,100],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a6f186da4d9557d958779eba68bb769a9":[7,0,0,354,37],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[7,0,0,354,100],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a74138c0203835513613af73cdb08890d":[7,0,0,354,59],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a6f1a52798479255a174b3c0ecba6a10c":[6,0,0,381,100],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a74138c0203835513613af73cdb08890d":[6,0,0,381,59],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a743e5059501507cd858e90532e8263f9":[7,0,0,354,23],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a74138c0203835513613af73cdb08890d":[7,0,0,354,59],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a743e5059501507cd858e90532e8263f9":[6,0,0,381,23],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a77987dd9dce1653083f3518fc43da348":[7,0,0,354,40],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a743e5059501507cd858e90532e8263f9":[7,0,0,354,23],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a77987dd9dce1653083f3518fc43da348":[6,0,0,381,40],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a77d5f72e02500f6db6f460bb48eac721":[7,0,0,354,6],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a77987dd9dce1653083f3518fc43da348":[7,0,0,354,40],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a77d5f72e02500f6db6f460bb48eac721":[6,0,0,381,6],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a77d5f72e02500f6db6f460bb48eac721":[7,0,0,354,6],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a79ef841657ae82e68116314688c87539":[7,0,0,354,17],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a79ef841657ae82e68116314688c87539":[6,0,0,381,17],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a82174dc4f4a0645332483ced7904c2f6":[7,0,0,354,92],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a82174dc4f4a0645332483ced7904c2f6":[6,0,0,381,92],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a82174dc4f4a0645332483ced7904c2f6":[7,0,0,354,92],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,381,69],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,354,69],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a84dc53e8acb6b01bb695f96c048a1990":[6,0,0,381,26],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a84dc53e8acb6b01bb695f96c048a1990":[7,0,0,354,26],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a8775d611ddf70bc0ee89a9d62bac69cf":[7,0,0,354,93],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a84dc53e8acb6b01bb695f96c048a1990":[6,0,0,381,26],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a8775d611ddf70bc0ee89a9d62bac69cf":[6,0,0,381,93],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a893c7a150edb48a25e5df700cfc194eb":[6,0,0,381,5],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a8775d611ddf70bc0ee89a9d62bac69cf":[7,0,0,354,93],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a893c7a150edb48a25e5df700cfc194eb":[7,0,0,354,5],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a8ab9418311a7b4a116139a7871e57a4b":[7,0,0,354,41],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a893c7a150edb48a25e5df700cfc194eb":[6,0,0,381,5],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a8ab9418311a7b4a116139a7871e57a4b":[6,0,0,381,41],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a8eb34a9034aab62fd537c021a79e3366":[6,0,0,381,63],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a8ab9418311a7b4a116139a7871e57a4b":[7,0,0,354,41],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a8eb34a9034aab62fd537c021a79e3366":[7,0,0,354,63],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a8eb34a9034aab62fd537c021a79e3366":[6,0,0,381,63],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a8ed6a95810f21f53aa8cbc780b680164":[6,0,0,381,27],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a8ed6a95810f21f53aa8cbc780b680164":[7,0,0,354,27],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a8f541900f7e1f73f4c313a732199029a":[7,0,0,354,61],
@@ -150,8 +152,8 @@ var NAVTREEINDEX92 =
 "class_ogre_1_1_g_l3_plus_null_texture.html#a906f16bb83aecba3b1204d62308e419d":[6,0,0,381,16],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,354,72],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,381,72],
-"class_ogre_1_1_g_l3_plus_null_texture.html#a963dca9c2ab605d51ee75c92d850a96d":[7,0,0,354,53],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a963dca9c2ab605d51ee75c92d850a96d":[6,0,0,381,53],
+"class_ogre_1_1_g_l3_plus_null_texture.html#a963dca9c2ab605d51ee75c92d850a96d":[7,0,0,354,53],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a9dffcf1a2d754e63e98770e5cf2cd9ee":[7,0,0,354,42],
 "class_ogre_1_1_g_l3_plus_null_texture.html#a9dffcf1a2d754e63e98770e5cf2cd9ee":[6,0,0,381,42],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aa2f69f436608ba1fef23b49b845ef14f":[6,0,0,381,31],
@@ -160,28 +162,28 @@ var NAVTREEINDEX92 =
 "class_ogre_1_1_g_l3_plus_null_texture.html#aa31bef1bfaa87731622e56f11b548e27":[7,0,0,354,102],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aa38c4f67ab5413135d1830dd164a68e6":[6,0,0,381,85],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aa38c4f67ab5413135d1830dd164a68e6":[7,0,0,354,85],
-"class_ogre_1_1_g_l3_plus_null_texture.html#aa561d8d03383bb59ecce5c4278ed8da6":[7,0,0,354,98],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aa561d8d03383bb59ecce5c4278ed8da6":[6,0,0,381,98],
+"class_ogre_1_1_g_l3_plus_null_texture.html#aa561d8d03383bb59ecce5c4278ed8da6":[7,0,0,354,98],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aa5c94ac282eb67a0b8cf6b32af4ccf7e":[6,0,0,381,88],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aa5c94ac282eb67a0b8cf6b32af4ccf7e":[7,0,0,354,88],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[7,0,0,354,11],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aa5d6f3f7e73b77b233fc62b11f270e4d":[6,0,0,381,11],
-"class_ogre_1_1_g_l3_plus_null_texture.html#aa7942df6419c98c2668ffb02de252cc8":[7,0,0,354,24],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aa7942df6419c98c2668ffb02de252cc8":[6,0,0,381,24],
-"class_ogre_1_1_g_l3_plus_null_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[7,0,0,354,50],
+"class_ogre_1_1_g_l3_plus_null_texture.html#aa7942df6419c98c2668ffb02de252cc8":[7,0,0,354,24],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[6,0,0,381,50],
+"class_ogre_1_1_g_l3_plus_null_texture.html#aadcef30707e8e10fbac61d65e1e73e52":[7,0,0,354,50],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,354,75],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,381,75],
-"class_ogre_1_1_g_l3_plus_null_texture.html#aba6375dc3369f7d4a1aaa4e7fedd62aa":[7,0,0,354,39],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aba6375dc3369f7d4a1aaa4e7fedd62aa":[6,0,0,381,39],
+"class_ogre_1_1_g_l3_plus_null_texture.html#aba6375dc3369f7d4a1aaa4e7fedd62aa":[7,0,0,354,39],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ac129cc0a773f0d9d0eb4c3c1a1b65618":[6,0,0,381,66],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ac129cc0a773f0d9d0eb4c3c1a1b65618":[7,0,0,354,66],
-"class_ogre_1_1_g_l3_plus_null_texture.html#ac37480f24162a75a4ecc54846563766e":[6,0,0,381,2],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ac37480f24162a75a4ecc54846563766e":[7,0,0,354,2],
+"class_ogre_1_1_g_l3_plus_null_texture.html#ac37480f24162a75a4ecc54846563766e":[6,0,0,381,2],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ac7abec2125f4070a290e4528f1f89f85":[6,0,0,381,32],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ac7abec2125f4070a290e4528f1f89f85":[7,0,0,354,32],
-"class_ogre_1_1_g_l3_plus_null_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[7,0,0,354,47],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[6,0,0,381,47],
+"class_ogre_1_1_g_l3_plus_null_texture.html#ac7eab6fa3b2133384bf2d92b4f5a2a99":[7,0,0,354,47],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ac93f17feff099035542be8b22f890417":[6,0,0,381,30],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ac93f17feff099035542be8b22f890417":[7,0,0,354,30],
 "class_ogre_1_1_g_l3_plus_null_texture.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,354,70],
@@ -190,28 +192,28 @@ var NAVTREEINDEX92 =
 "class_ogre_1_1_g_l3_plus_null_texture.html#acce55ed43f888d8c4c5ed5c5aaf9d1db":[6,0,0,381,45],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ace884b65b722ead9b920b9abf27bf815":[7,0,0,354,94],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ace884b65b722ead9b920b9abf27bf815":[6,0,0,381,94],
-"class_ogre_1_1_g_l3_plus_null_texture.html#ad1c33ba2014eeb134c8ce932f2a43418":[7,0,0,354,55],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ad1c33ba2014eeb134c8ce932f2a43418":[6,0,0,381,55],
-"class_ogre_1_1_g_l3_plus_null_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,381,74],
+"class_ogre_1_1_g_l3_plus_null_texture.html#ad1c33ba2014eeb134c8ce932f2a43418":[7,0,0,354,55],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,354,74],
-"class_ogre_1_1_g_l3_plus_null_texture.html#ad7674a0019ec63edf97d0d24378f3792":[7,0,0,354,3],
+"class_ogre_1_1_g_l3_plus_null_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,381,74],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ad7674a0019ec63edf97d0d24378f3792":[6,0,0,381,3],
+"class_ogre_1_1_g_l3_plus_null_texture.html#ad7674a0019ec63edf97d0d24378f3792":[7,0,0,354,3],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ad8faaf7732b48e059f7d7dc15667f2af":[6,0,0,381,89],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ad8faaf7732b48e059f7d7dc15667f2af":[7,0,0,354,89],
-"class_ogre_1_1_g_l3_plus_null_texture.html#adce32528577d71b228692df906ecd17c":[7,0,0,354,77],
 "class_ogre_1_1_g_l3_plus_null_texture.html#adce32528577d71b228692df906ecd17c":[6,0,0,381,77],
+"class_ogre_1_1_g_l3_plus_null_texture.html#adce32528577d71b228692df906ecd17c":[7,0,0,354,77],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ade85e4d5579519e4117a84789c0ae8fd":[6,0,0,381,51],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ade85e4d5579519e4117a84789c0ae8fd":[7,0,0,354,51],
-"class_ogre_1_1_g_l3_plus_null_texture.html#ae0a0007de944eb3c2f933a372a752b35":[6,0,0,381,82],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ae0a0007de944eb3c2f933a372a752b35":[7,0,0,354,82],
+"class_ogre_1_1_g_l3_plus_null_texture.html#ae0a0007de944eb3c2f933a372a752b35":[6,0,0,381,82],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ae229b1f58092109adef55bfc6f864d79":[7,0,0,354,101],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ae229b1f58092109adef55bfc6f864d79":[6,0,0,381,101],
-"class_ogre_1_1_g_l3_plus_null_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[7,0,0,354,91],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[6,0,0,381,91],
+"class_ogre_1_1_g_l3_plus_null_texture.html#ae272c029efa4b04406a58e01cd8ea7e8":[7,0,0,354,91],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[7,0,0,354,90],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ae32d1cfbbb44d87d698aae547ecda35f":[6,0,0,381,90],
-"class_ogre_1_1_g_l3_plus_null_texture.html#ae356913ccefbebc4f0119a0599a406fc":[6,0,0,381,95],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ae356913ccefbebc4f0119a0599a406fc":[7,0,0,354,95],
+"class_ogre_1_1_g_l3_plus_null_texture.html#ae356913ccefbebc4f0119a0599a406fc":[6,0,0,381,95],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ae67e44696cde3c7d4e8fec157ca4f498":[6,0,0,381,84],
 "class_ogre_1_1_g_l3_plus_null_texture.html#ae67e44696cde3c7d4e8fec157ca4f498":[7,0,0,354,84],
 "class_ogre_1_1_g_l3_plus_null_texture.html#aec390502f63927ed9470ba423ea66f64":[6,0,0,381,83],
@@ -224,8 +226,8 @@ var NAVTREEINDEX92 =
 "class_ogre_1_1_g_l3_plus_null_texture.html#aee52bded52fe34f8322ecd3fa1790028":[6,0,0,381,20],
 "class_ogre_1_1_g_l3_plus_null_texture.html#af745587ede1e8482b1edac167fbf82fd":[7,0,0,354,87],
 "class_ogre_1_1_g_l3_plus_null_texture.html#af745587ede1e8482b1edac167fbf82fd":[6,0,0,381,87],
-"class_ogre_1_1_g_l3_plus_null_texture.html#afcb4a61b965600a67ca2c2f060821db9":[6,0,0,381,4],
 "class_ogre_1_1_g_l3_plus_null_texture.html#afcb4a61b965600a67ca2c2f060821db9":[7,0,0,354,4],
+"class_ogre_1_1_g_l3_plus_null_texture.html#afcb4a61b965600a67ca2c2f060821db9":[6,0,0,381,4],
 "class_ogre_1_1_g_l3_plus_null_texture.html#afefa465095dd97cf22d0a43531171b51":[7,0,0,354,28],
 "class_ogre_1_1_g_l3_plus_null_texture.html#afefa465095dd97cf22d0a43531171b51":[6,0,0,381,28],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html":[6,0,0,382],
@@ -234,20 +236,18 @@ var NAVTREEINDEX92 =
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a03ae803c4754c6008fb5b898fb8090b8":[7,0,0,355,68],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a098a818a4d699ef9370c95b864a0f197":[7,0,0,355,41],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a098a818a4d699ef9370c95b864a0f197":[6,0,0,382,41],
-"class_ogre_1_1_g_l3_plus_null_texture_target.html#a0c00ca9d1ba7f3efc248ae86511fbff9":[6,0,0,382,56],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a0c00ca9d1ba7f3efc248ae86511fbff9":[7,0,0,355,56],
-"class_ogre_1_1_g_l3_plus_null_texture_target.html#a0d3f944eab02d9dccb9e937e7f534e10":[6,0,0,382,24],
+"class_ogre_1_1_g_l3_plus_null_texture_target.html#a0c00ca9d1ba7f3efc248ae86511fbff9":[6,0,0,382,56],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a0d3f944eab02d9dccb9e937e7f534e10":[7,0,0,355,24],
-"class_ogre_1_1_g_l3_plus_null_texture_target.html#a0ee2aaaebdf52b6c91910396a20d5a18":[6,0,0,382,36],
+"class_ogre_1_1_g_l3_plus_null_texture_target.html#a0d3f944eab02d9dccb9e937e7f534e10":[6,0,0,382,24],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a0ee2aaaebdf52b6c91910396a20d5a18":[7,0,0,355,36],
-"class_ogre_1_1_g_l3_plus_null_texture_target.html#a0f59de2e9d066fc59a11f7171782fbed":[6,0,0,382,70],
+"class_ogre_1_1_g_l3_plus_null_texture_target.html#a0ee2aaaebdf52b6c91910396a20d5a18":[6,0,0,382,36],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a0f59de2e9d066fc59a11f7171782fbed":[7,0,0,355,70],
+"class_ogre_1_1_g_l3_plus_null_texture_target.html#a0f59de2e9d066fc59a11f7171782fbed":[6,0,0,382,70],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a15f59cd1b4a2b2e65fcee349d78ae490":[7,0,0,355,1],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a15f59cd1b4a2b2e65fcee349d78ae490":[6,0,0,382,1],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a15f59cd1b4a2b2e65fcee349d78ae490a18416c60c9b82d928db766bef672ecea":[7,0,0,355,1,6],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a15f59cd1b4a2b2e65fcee349d78ae490a18416c60c9b82d928db766bef672ecea":[6,0,0,382,1,6],
-"class_ogre_1_1_g_l3_plus_null_texture_target.html#a15f59cd1b4a2b2e65fcee349d78ae490a19ef0adeaa177d49fc4ca4c9b87adec1":[7,0,0,355,1,5],
 "class_ogre_1_1_g_l3_plus_null_texture_target.html#a15f59cd1b4a2b2e65fcee349d78ae490a19ef0adeaa177d49fc4ca4c9b87adec1":[6,0,0,382,1,5],
-"class_ogre_1_1_g_l3_plus_null_texture_target.html#a15f59cd1b4a2b2e65fcee349d78ae490a1f0cd329c7ff6d5d81b2162c65d04afa":[7,0,0,355,1,1],
-"class_ogre_1_1_g_l3_plus_null_texture_target.html#a15f59cd1b4a2b2e65fcee349d78ae490a1f0cd329c7ff6d5d81b2162c65d04afa":[6,0,0,382,1,1]
+"class_ogre_1_1_g_l3_plus_null_texture_target.html#a15f59cd1b4a2b2e65fcee349d78ae490a19ef0adeaa177d49fc4ca4c9b87adec1":[7,0,0,355,1,5]
 };
