@@ -1,29 +1,31 @@
 var NAVTREEINDEX98 =
 {
+"class_ogre_1_1_g_l3_plus_staging_buffer.html#af337572731f4268bbfbb160f4f40a503":[6,0,0,394,1],
+"class_ogre_1_1_g_l3_plus_staging_buffer.html#af337572731f4268bbfbb160f4f40a503":[7,0,0,367,1],
 "class_ogre_1_1_g_l3_plus_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[7,0,0,367,31],
 "class_ogre_1_1_g_l3_plus_staging_buffer.html#afe091313c974edab09f0f9daabf8034d":[6,0,0,394,31],
-"class_ogre_1_1_g_l3_plus_staging_buffer.html#afe3554ae1d5eb60de3d68dc96e083905":[7,0,0,367,8],
 "class_ogre_1_1_g_l3_plus_staging_buffer.html#afe3554ae1d5eb60de3d68dc96e083905":[6,0,0,394,8],
-"class_ogre_1_1_g_l3_plus_staging_texture.html":[6,0,0,395],
+"class_ogre_1_1_g_l3_plus_staging_buffer.html#afe3554ae1d5eb60de3d68dc96e083905":[7,0,0,367,8],
 "class_ogre_1_1_g_l3_plus_staging_texture.html":[7,0,0,368],
+"class_ogre_1_1_g_l3_plus_staging_texture.html":[6,0,0,395],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a195c1c5759a448fe099e63b6996b5cb5":[6,0,0,395,23],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a195c1c5759a448fe099e63b6996b5cb5":[7,0,0,368,23],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,368,15],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,395,15],
-"class_ogre_1_1_g_l3_plus_staging_texture.html#a20b8f55c40f5a54344feb86af13bc7f6":[7,0,0,368,4],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a20b8f55c40f5a54344feb86af13bc7f6":[6,0,0,395,4],
+"class_ogre_1_1_g_l3_plus_staging_texture.html#a20b8f55c40f5a54344feb86af13bc7f6":[7,0,0,368,4],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a2c77f84776623ba4ed6d5e0cf29d2c57":[7,0,0,368,11],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a2c77f84776623ba4ed6d5e0cf29d2c57":[6,0,0,395,11],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a3b415effaa2eb00ce82916ee24b2e131":[7,0,0,368,10],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a3b415effaa2eb00ce82916ee24b2e131":[6,0,0,395,10],
-"class_ogre_1_1_g_l3_plus_staging_texture.html#a46ca3e0729b98381c5c54c49f74df811":[7,0,0,368,0],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a46ca3e0729b98381c5c54c49f74df811":[6,0,0,395,0],
-"class_ogre_1_1_g_l3_plus_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,395,17],
+"class_ogre_1_1_g_l3_plus_staging_texture.html#a46ca3e0729b98381c5c54c49f74df811":[7,0,0,368,0],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,368,17],
-"class_ogre_1_1_g_l3_plus_staging_texture.html#a63e494e2f4ba1c65ff3ea79e25bfbfc6":[7,0,0,368,8],
+"class_ogre_1_1_g_l3_plus_staging_texture.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,395,17],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a63e494e2f4ba1c65ff3ea79e25bfbfc6":[6,0,0,395,8],
-"class_ogre_1_1_g_l3_plus_staging_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,368,20],
+"class_ogre_1_1_g_l3_plus_staging_texture.html#a63e494e2f4ba1c65ff3ea79e25bfbfc6":[7,0,0,368,8],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,395,20],
+"class_ogre_1_1_g_l3_plus_staging_texture.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,368,20],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,395,13],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,368,13],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a854500b501208b6f28efc59e1f101146":[6,0,0,395,26],
@@ -38,26 +40,26 @@ var NAVTREEINDEX98 =
 "class_ogre_1_1_g_l3_plus_staging_texture.html#a9c55be7d477bda7d0e8616a45ac8611d":[6,0,0,395,5],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#aae1ad88bd15b342da7e2ed833ddbc211":[6,0,0,395,2],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#aae1ad88bd15b342da7e2ed833ddbc211":[7,0,0,368,2],
-"class_ogre_1_1_g_l3_plus_staging_texture.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,368,19],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,395,19],
+"class_ogre_1_1_g_l3_plus_staging_texture.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,368,19],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#ab434582807188a466ed8fa405b034da1":[7,0,0,368,6],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#ab434582807188a466ed8fa405b034da1":[6,0,0,395,6],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,395,14],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,368,14],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#acd9d671ef2194050f73ecccf31bba0a1":[7,0,0,368,1],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#acd9d671ef2194050f73ecccf31bba0a1":[6,0,0,395,1],
-"class_ogre_1_1_g_l3_plus_staging_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,395,18],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,368,18],
-"class_ogre_1_1_g_l3_plus_staging_texture.html#ad286f1352d21e74528e3bf096256535f":[6,0,0,395,24],
+"class_ogre_1_1_g_l3_plus_staging_texture.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,395,18],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#ad286f1352d21e74528e3bf096256535f":[7,0,0,368,24],
+"class_ogre_1_1_g_l3_plus_staging_texture.html#ad286f1352d21e74528e3bf096256535f":[6,0,0,395,24],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#ad34f6bc75407060643f55f4537a5ca6c":[7,0,0,368,3],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#ad34f6bc75407060643f55f4537a5ca6c":[6,0,0,395,3],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#adce32528577d71b228692df906ecd17c":[7,0,0,368,21],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#adce32528577d71b228692df906ecd17c":[6,0,0,395,21],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#adf5cc3adc54a4ab2ea4e83cde01b3398":[6,0,0,395,12],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#adf5cc3adc54a4ab2ea4e83cde01b3398":[7,0,0,368,12],
-"class_ogre_1_1_g_l3_plus_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,395,22],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,368,22],
+"class_ogre_1_1_g_l3_plus_staging_texture.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,395,22],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#af803a865afa4ea209315e55547cd8784":[6,0,0,395,7],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#af803a865afa4ea209315e55547cd8784":[7,0,0,368,7],
 "class_ogre_1_1_g_l3_plus_staging_texture.html#af880dfa4d3f849a20ffb03a4c248d997":[7,0,0,368,9],
@@ -66,40 +68,40 @@ var NAVTREEINDEX98 =
 "class_ogre_1_1_g_l3_plus_support.html":[6,0,0,396],
 "class_ogre_1_1_g_l3_plus_support.html#a00f443e800891f54ac1176072e99e3a5":[7,0,0,369,6],
 "class_ogre_1_1_g_l3_plus_support.html#a00f443e800891f54ac1176072e99e3a5":[6,0,0,396,6],
-"class_ogre_1_1_g_l3_plus_support.html#a1967867822fc80e81590ac9be066440b":[6,0,0,396,14],
 "class_ogre_1_1_g_l3_plus_support.html#a1967867822fc80e81590ac9be066440b":[7,0,0,369,14],
+"class_ogre_1_1_g_l3_plus_support.html#a1967867822fc80e81590ac9be066440b":[6,0,0,396,14],
 "class_ogre_1_1_g_l3_plus_support.html#a1c07a0e93c455b400a566562b481d24e":[7,0,0,369,17],
 "class_ogre_1_1_g_l3_plus_support.html#a1c07a0e93c455b400a566562b481d24e":[6,0,0,396,17],
-"class_ogre_1_1_g_l3_plus_support.html#a1ee2d0f263f8c15acd09e49f5cd73c97":[6,0,0,396,4],
 "class_ogre_1_1_g_l3_plus_support.html#a1ee2d0f263f8c15acd09e49f5cd73c97":[7,0,0,369,4],
-"class_ogre_1_1_g_l3_plus_support.html#a403f90553a4bb613ffb287b5484326bd":[7,0,0,369,2],
+"class_ogre_1_1_g_l3_plus_support.html#a1ee2d0f263f8c15acd09e49f5cd73c97":[6,0,0,396,4],
 "class_ogre_1_1_g_l3_plus_support.html#a403f90553a4bb613ffb287b5484326bd":[6,0,0,396,2],
-"class_ogre_1_1_g_l3_plus_support.html#a412221584c7c370d65551d2e162cc8b6":[7,0,0,369,8],
+"class_ogre_1_1_g_l3_plus_support.html#a403f90553a4bb613ffb287b5484326bd":[7,0,0,369,2],
 "class_ogre_1_1_g_l3_plus_support.html#a412221584c7c370d65551d2e162cc8b6":[6,0,0,396,8],
+"class_ogre_1_1_g_l3_plus_support.html#a412221584c7c370d65551d2e162cc8b6":[7,0,0,369,8],
 "class_ogre_1_1_g_l3_plus_support.html#a4f53bfb02b1f21018d2902d466c1208c":[6,0,0,396,3],
 "class_ogre_1_1_g_l3_plus_support.html#a4f53bfb02b1f21018d2902d466c1208c":[7,0,0,369,3],
-"class_ogre_1_1_g_l3_plus_support.html#a78d090a0e8e44d68594a8c4155cbf430":[7,0,0,369,20],
 "class_ogre_1_1_g_l3_plus_support.html#a78d090a0e8e44d68594a8c4155cbf430":[6,0,0,396,20],
+"class_ogre_1_1_g_l3_plus_support.html#a78d090a0e8e44d68594a8c4155cbf430":[7,0,0,369,20],
 "class_ogre_1_1_g_l3_plus_support.html#a813134d9af879a2c2e7e93b03379e513":[6,0,0,396,0],
 "class_ogre_1_1_g_l3_plus_support.html#a813134d9af879a2c2e7e93b03379e513":[7,0,0,369,0],
 "class_ogre_1_1_g_l3_plus_support.html#a8954a5a970c650fa6fd97e73f3428ef6":[7,0,0,369,15],
 "class_ogre_1_1_g_l3_plus_support.html#a8954a5a970c650fa6fd97e73f3428ef6":[6,0,0,396,15],
 "class_ogre_1_1_g_l3_plus_support.html#a9297ebdc8cbeb97bc01cb9c4e413df61":[7,0,0,369,22],
 "class_ogre_1_1_g_l3_plus_support.html#a9297ebdc8cbeb97bc01cb9c4e413df61":[6,0,0,396,22],
-"class_ogre_1_1_g_l3_plus_support.html#a994caaf31c75d253519b9d43c410281e":[7,0,0,369,1],
 "class_ogre_1_1_g_l3_plus_support.html#a994caaf31c75d253519b9d43c410281e":[6,0,0,396,1],
-"class_ogre_1_1_g_l3_plus_support.html#a99adef70272ec72c1d44943c43a27ab3":[7,0,0,369,7],
+"class_ogre_1_1_g_l3_plus_support.html#a994caaf31c75d253519b9d43c410281e":[7,0,0,369,1],
 "class_ogre_1_1_g_l3_plus_support.html#a99adef70272ec72c1d44943c43a27ab3":[6,0,0,396,7],
-"class_ogre_1_1_g_l3_plus_support.html#aa59e93bc2da16cb9b03d48c1cc90b444":[6,0,0,396,19],
+"class_ogre_1_1_g_l3_plus_support.html#a99adef70272ec72c1d44943c43a27ab3":[7,0,0,369,7],
 "class_ogre_1_1_g_l3_plus_support.html#aa59e93bc2da16cb9b03d48c1cc90b444":[7,0,0,369,19],
-"class_ogre_1_1_g_l3_plus_support.html#ab4968ac01e15a3397853e9f929574764":[6,0,0,396,21],
+"class_ogre_1_1_g_l3_plus_support.html#aa59e93bc2da16cb9b03d48c1cc90b444":[6,0,0,396,19],
 "class_ogre_1_1_g_l3_plus_support.html#ab4968ac01e15a3397853e9f929574764":[7,0,0,369,21],
-"class_ogre_1_1_g_l3_plus_support.html#ab4bd3f3ed2d900304219ccff511b45d1":[6,0,0,396,12],
+"class_ogre_1_1_g_l3_plus_support.html#ab4968ac01e15a3397853e9f929574764":[6,0,0,396,21],
 "class_ogre_1_1_g_l3_plus_support.html#ab4bd3f3ed2d900304219ccff511b45d1":[7,0,0,369,12],
-"class_ogre_1_1_g_l3_plus_support.html#abf5d077e3e006563d98c8e48ec773770":[7,0,0,369,5],
+"class_ogre_1_1_g_l3_plus_support.html#ab4bd3f3ed2d900304219ccff511b45d1":[6,0,0,396,12],
 "class_ogre_1_1_g_l3_plus_support.html#abf5d077e3e006563d98c8e48ec773770":[6,0,0,396,5],
-"class_ogre_1_1_g_l3_plus_support.html#ac262fc067886ba9dc316559667b5a6a5":[7,0,0,369,10],
+"class_ogre_1_1_g_l3_plus_support.html#abf5d077e3e006563d98c8e48ec773770":[7,0,0,369,5],
 "class_ogre_1_1_g_l3_plus_support.html#ac262fc067886ba9dc316559667b5a6a5":[6,0,0,396,10],
+"class_ogre_1_1_g_l3_plus_support.html#ac262fc067886ba9dc316559667b5a6a5":[7,0,0,369,10],
 "class_ogre_1_1_g_l3_plus_support.html#ad28d37f8a7d1ceaf175de66aab70497c":[7,0,0,369,11],
 "class_ogre_1_1_g_l3_plus_support.html#ad28d37f8a7d1ceaf175de66aab70497c":[6,0,0,396,11],
 "class_ogre_1_1_g_l3_plus_support.html#ad81bc23cd52d5ab7e62a25647cbae722":[6,0,0,396,16],
@@ -108,30 +110,30 @@ var NAVTREEINDEX98 =
 "class_ogre_1_1_g_l3_plus_support.html#ad97c5b4d8a1ac2b8a5e55f41bc3b8634":[7,0,0,369,9],
 "class_ogre_1_1_g_l3_plus_support.html#ae5eebd1e301e98a051389601418bb7ad":[7,0,0,369,13],
 "class_ogre_1_1_g_l3_plus_support.html#ae5eebd1e301e98a051389601418bb7ad":[6,0,0,396,13],
-"class_ogre_1_1_g_l3_plus_support.html#afc5a8ba353c6479ec2fab128cf736c90":[7,0,0,369,18],
 "class_ogre_1_1_g_l3_plus_support.html#afc5a8ba353c6479ec2fab128cf736c90":[6,0,0,396,18],
+"class_ogre_1_1_g_l3_plus_support.html#afc5a8ba353c6479ec2fab128cf736c90":[7,0,0,369,18],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html":[7,0,0,371],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html":[6,0,0,398],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[6,0,0,398,43],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[7,0,0,371,43],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a13201df5ef4b60c472c49075d5b8c5de":[7,0,0,371,15],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[6,0,0,398,43],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a13201df5ef4b60c472c49075d5b8c5de":[6,0,0,398,15],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[7,0,0,371,26],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a13201df5ef4b60c472c49075d5b8c5de":[7,0,0,371,15],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[6,0,0,398,26],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[6,0,0,398,16],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[7,0,0,371,26],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[7,0,0,371,16],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[6,0,0,398,16],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,398,32],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,371,32],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a1f35a4a63b023187026b9abc1c897a71":[7,0,0,371,9],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a1f35a4a63b023187026b9abc1c897a71":[6,0,0,398,9],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a22266b4e6f000971c16fdc9c8fd190e5":[7,0,0,371,1],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a22266b4e6f000971c16fdc9c8fd190e5":[6,0,0,398,1],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a22266b4e6f000971c16fdc9c8fd190e5":[7,0,0,371,1],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[6,0,0,398,29],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[7,0,0,371,29],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[7,0,0,371,17],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[6,0,0,398,17],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[7,0,0,371,25],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[7,0,0,371,17],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[6,0,0,398,25],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a3161f7d1ca4a5aa6705dea4efc0a58a8":[7,0,0,371,25],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a3d389b0aae18bb6dcb82af84c93b77de":[6,0,0,398,28],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a3d389b0aae18bb6dcb82af84c93b77de":[7,0,0,371,28],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a3ddfe01306e281ebed98044ce3deb55d":[6,0,0,398,12],
@@ -142,12 +144,12 @@ var NAVTREEINDEX98 =
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a4ad2e348af9d8a834cf4ae247039ad21":[7,0,0,371,13],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a4f31390a156614abd7ffe33b48af84b4":[7,0,0,371,24],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a4f31390a156614abd7ffe33b48af84b4":[6,0,0,398,24],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a50080eb729acd0c995606d512d5633c9":[6,0,0,398,19],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a50080eb729acd0c995606d512d5633c9":[7,0,0,371,19],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a50080eb729acd0c995606d512d5633c9":[6,0,0,398,19],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a542b46fc7a7cf5fe524cfc7b4b389ba9":[6,0,0,398,21],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a542b46fc7a7cf5fe524cfc7b4b389ba9":[7,0,0,371,21],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a564935579f2252627f46dff29142e7ff":[6,0,0,398,8],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a564935579f2252627f46dff29142e7ff":[7,0,0,371,8],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a564935579f2252627f46dff29142e7ff":[6,0,0,398,8],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a566014653e1b98b5ed24166f9e11bacd":[6,0,0,398,23],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a566014653e1b98b5ed24166f9e11bacd":[7,0,0,371,23],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,371,34],
@@ -160,58 +162,58 @@ var NAVTREEINDEX98 =
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a73e02f6b2fa2c16340c1a9359926b481":[6,0,0,398,42],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a7cfd9629389ccf2aedec4b37f5a1b403":[6,0,0,398,7],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a7cfd9629389ccf2aedec4b37f5a1b403":[7,0,0,371,7],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a80c6682bd4adc315782091679d230cee":[6,0,0,398,40],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a80c6682bd4adc315782091679d230cee":[7,0,0,371,40],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a80c6682bd4adc315782091679d230cee":[6,0,0,398,40],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a8357fe4fb4849772b94baa4bf47c7ded":[7,0,0,371,30],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a8357fe4fb4849772b94baa4bf47c7ded":[6,0,0,398,30],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a88d084d5c70dd74b385fe8ba97e0e4fe":[7,0,0,371,0],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a88d084d5c70dd74b385fe8ba97e0e4fe":[6,0,0,398,0],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a8fe6a1ecb4b3ab2b2a5208e9daeb4168":[6,0,0,398,6],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a8fe6a1ecb4b3ab2b2a5208e9daeb4168":[7,0,0,371,6],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,371,33],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a8fe6a1ecb4b3ab2b2a5208e9daeb4168":[6,0,0,398,6],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[6,0,0,398,33],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a93e6a86dde5483c053ca0f2a85bbfd6c":[7,0,0,371,33],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a95eb5e6b14dff4e029d541b9512bb702":[6,0,0,398,18],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#a95eb5e6b14dff4e029d541b9512bb702":[7,0,0,371,18],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aa551472605bf2223961e32133935680e":[7,0,0,371,10],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aa551472605bf2223961e32133935680e":[6,0,0,398,10],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aab43d8b311ecc13afa247051d394047c":[7,0,0,371,11],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aa551472605bf2223961e32133935680e":[7,0,0,371,10],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aab43d8b311ecc13afa247051d394047c":[6,0,0,398,11],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aac73dd5b3bfea12dca1c5a64e6e95c7a":[6,0,0,398,3],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aab43d8b311ecc13afa247051d394047c":[7,0,0,371,11],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aac73dd5b3bfea12dca1c5a64e6e95c7a":[7,0,0,371,3],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aac73dd5b3bfea12dca1c5a64e6e95c7a":[6,0,0,398,3],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aac7d5a7fc76d5e3086620800003e55b5":[7,0,0,371,27],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aac7d5a7fc76d5e3086620800003e55b5":[6,0,0,398,27],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,398,36],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#ab422c67a2c8844f410fe822a357cba3b":[7,0,0,371,36],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aba157f97e7a2c5d08ddda393aeb028f8":[6,0,0,398,41],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#ab422c67a2c8844f410fe822a357cba3b":[6,0,0,398,36],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aba157f97e7a2c5d08ddda393aeb028f8":[7,0,0,371,41],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aba157f97e7a2c5d08ddda393aeb028f8":[6,0,0,398,41],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#abc04452fbe82230e5097f68ba1f96571":[6,0,0,398,14],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#abc04452fbe82230e5097f68ba1f96571":[7,0,0,371,14],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,398,31],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#acb46d4b0a597156d9ba5abc39d127792":[7,0,0,371,31],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aceb93f9fe49eedbdbc91ea6eb5feed56":[6,0,0,398,5],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#acb46d4b0a597156d9ba5abc39d127792":[6,0,0,398,31],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aceb93f9fe49eedbdbc91ea6eb5feed56":[7,0,0,371,5],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,398,35],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aceb93f9fe49eedbdbc91ea6eb5feed56":[6,0,0,398,5],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[7,0,0,371,35],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#adce32528577d71b228692df906ecd17c":[7,0,0,371,38],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#ad1f1a983f9e2dfddee802c47bb0b1ca9":[6,0,0,398,35],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#adce32528577d71b228692df906ecd17c":[6,0,0,398,38],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#adce32528577d71b228692df906ecd17c":[7,0,0,371,38],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#ae566936e3e73ec9e5a582823e71856de":[7,0,0,371,2],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#ae566936e3e73ec9e5a582823e71856de":[6,0,0,398,2],
-"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,371,39],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aed1464ac3de21ff20db8f9f1f8608dc7":[6,0,0,398,39],
+"class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#aed1464ac3de21ff20db8f9f1f8608dc7":[7,0,0,371,39],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#af98ad9606c188cc815fc647a21f20498":[7,0,0,371,20],
 "class_ogre_1_1_g_l3_plus_tex_buffer_emulated_packed.html#af98ad9606c188cc815fc647a21f20498":[6,0,0,398,20],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html":[7,0,0,372],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html":[6,0,0,399],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[7,0,0,372,43],
+"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html":[7,0,0,372],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[6,0,0,399,43],
+"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a0c6fb3d387685e50e2b5069164b95e6b":[7,0,0,372,43],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[7,0,0,372,26],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a155f9b4ef9bc20239691a869d4daa08d":[6,0,0,399,26],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[6,0,0,399,16],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[7,0,0,372,16],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,372,32],
+"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a162e23ff6f3cb7f90ed129d3906c14e4":[6,0,0,399,16],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[6,0,0,399,32],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[7,0,0,372,9],
+"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a1c727e879a260c37b00ce5505fe8e144":[7,0,0,372,32],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[6,0,0,399,9],
+"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a1f35a4a63b023187026b9abc1c897a71":[7,0,0,372,9],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[7,0,0,372,29],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a24a2ccddbb2fc851304ae81eb78243ed":[6,0,0,399,29],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a29ff95c6bebe87dcfe2d43a02cc0ba6c":[6,0,0,399,17],
@@ -230,24 +232,22 @@ var NAVTREEINDEX98 =
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a50080eb729acd0c995606d512d5633c9":[6,0,0,399,19],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a542b46fc7a7cf5fe524cfc7b4b389ba9":[7,0,0,372,21],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a542b46fc7a7cf5fe524cfc7b4b389ba9":[6,0,0,399,21],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a564935579f2252627f46dff29142e7ff":[6,0,0,399,8],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a564935579f2252627f46dff29142e7ff":[7,0,0,372,8],
+"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a564935579f2252627f46dff29142e7ff":[6,0,0,399,8],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a566014653e1b98b5ed24166f9e11bacd":[7,0,0,372,23],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a566014653e1b98b5ed24166f9e11bacd":[6,0,0,399,23],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,399,34],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a595ea4c05da8aa987d3800e65d23355d":[7,0,0,372,34],
+"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a595ea4c05da8aa987d3800e65d23355d":[6,0,0,399,34],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[6,0,0,399,37],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a63fc6bdc2eb6aeac24898a77ec5e2023":[7,0,0,372,37],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a69984ccd67bf7c801cc33dd20780b581":[7,0,0,372,22],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a69984ccd67bf7c801cc33dd20780b581":[6,0,0,399,22],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a73e02f6b2fa2c16340c1a9359926b481":[7,0,0,372,42],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a73e02f6b2fa2c16340c1a9359926b481":[6,0,0,399,42],
+"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a73e02f6b2fa2c16340c1a9359926b481":[7,0,0,372,42],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a79c4dcc7cc8a14583ef60d194d800b50":[6,0,0,399,1],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a79c4dcc7cc8a14583ef60d194d800b50":[7,0,0,372,1],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a7cfd9629389ccf2aedec4b37f5a1b403":[7,0,0,372,7],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a7cfd9629389ccf2aedec4b37f5a1b403":[6,0,0,399,7],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a7eb357554b93ea4752da2ef323766f74":[7,0,0,372,14],
+"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a7cfd9629389ccf2aedec4b37f5a1b403":[7,0,0,372,7],
 "class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a7eb357554b93ea4752da2ef323766f74":[6,0,0,399,14],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a80c6682bd4adc315782091679d230cee":[7,0,0,372,40],
-"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a80c6682bd4adc315782091679d230cee":[6,0,0,399,40]
+"class_ogre_1_1_g_l3_plus_tex_buffer_packed.html#a7eb357554b93ea4752da2ef323766f74":[7,0,0,372,14]
 };
