@@ -1,6 +1,6 @@
 var searchData=
 [
-  ['lodstrategy_3a_3alodset_0',['lodstrategy::lodset',['../class_ogre_1_1_movable_object.html#a7ae9e10420b4c462fd91b7e5c54f0483',1,'Ogre::MovableObject::lodSet'],['../class_ogre_1_1_renderable.html#a7ae9e10420b4c462fd91b7e5c54f0483',1,'Ogre::Renderable::lodSet']]],
+  ['lodstrategy_3a_3alodset_0',['LodStrategy::lodSet',['../class_ogre_1_1_movable_object.html#a7ae9e10420b4c462fd91b7e5c54f0483',1,'Ogre::MovableObject::lodSet'],['../class_ogre_1_1_renderable.html#a7ae9e10420b4c462fd91b7e5c54f0483',1,'Ogre::Renderable::lodSet']]],
   ['lodstrategy_3a_3alodupdateimpl_1',['lodUpdateImpl',['../class_ogre_1_1_movable_object.html#a158e972be87282325850f001cee635a8',1,'Ogre::MovableObject']]],
   ['lwstring_2',['LwString',['../class_ogre_1_1_lw_const_string.html#ac94384c5c8f6128be4fbfb6d97257851',1,'Ogre::LwConstString']]]
 ];
