@@ -1,15 +1,15 @@
 var searchData=
 [
   ['uav_0',['Uav',['../struct_ogre_1_1_compute_property.html#a5503ecbcbeee97d79ef0b14c2cac9e85',1,'Ogre::ComputeProperty']]],
-  ['uavslot_1',['uavslot',['../struct_ogre_1_1_compositor_pass_def_1_1_uav_dependency.html#aab25d55f5aa42cf5023019852d31d703',1,'Ogre::CompositorPassDef::UavDependency::uavSlot'],['../struct_ogre_1_1_compositor_pass_uav_def_1_1_buffer_source.html#a77995f21324680367561115d74307193',1,'Ogre::CompositorPassUavDef::BufferSource::uavSlot'],['../struct_ogre_1_1_compositor_pass_uav_def_1_1_texture_source.html#af9042829bedad027e8d4e16b71a2410e',1,'Ogre::CompositorPassUavDef::TextureSource::uavSlot']]],
+  ['uavslot_1',['uavSlot',['../struct_ogre_1_1_compositor_pass_def_1_1_uav_dependency.html#aab25d55f5aa42cf5023019852d31d703',1,'Ogre::CompositorPassDef::UavDependency::uavSlot'],['../struct_ogre_1_1_compositor_pass_uav_def_1_1_texture_source.html#af9042829bedad027e8d4e16b71a2410e',1,'Ogre::CompositorPassUavDef::TextureSource::uavSlot'],['../struct_ogre_1_1_compositor_pass_uav_def_1_1_buffer_source.html#a77995f21324680367561115d74307193',1,'Ogre::CompositorPassUavDef::BufferSource::uavSlot']]],
   ['uintbuffersize_2',['uintBufferSize',['../struct_ogre_1_1_gpu_named_constants.html#aa78a9520e9515038318893626480112c',1,'Ogre::GpuNamedConstants']]],
   ['uncompressedsize_3',['uncompressedSize',['../struct_ogre_1_1_file_info.html#a66c7bf4f59feb619016a5c70e4ded4ee',1,'Ogre::FileInfo']]],
   ['uninitialized_5fcollapse_5fcost_4',['UNINITIALIZED_COLLAPSE_COST',['../struct_ogre_1_1_lod_data.html#af95ac40c4f3bdd402aa2e0cc1e25fc9c',1,'Ogre::LodData']]],
-  ['unit_5fscale_5',['unit_scale',['../class_ogre_1_1_array_vector3.html#a430a0a90f2cdab4764844a276636a2d9',1,'Ogre::ArrayVector3::UNIT_SCALE'],['../class_ogre_1_1_vector2.html#a165a67053e61b0733746453ce9ee5edb',1,'Ogre::Vector2::UNIT_SCALE'],['../class_ogre_1_1_vector3.html#a6a27e8a3a9156701f586afeed1516fb8',1,'Ogre::Vector3::UNIT_SCALE']]],
-  ['unit_5fx_6',['unit_x',['../class_ogre_1_1_array_vector3.html#a811d19510f8352453fa8f86d8c226a49',1,'Ogre::ArrayVector3::UNIT_X'],['../class_ogre_1_1_vector2.html#a1c2d210b2756d07375b0cf9f01835496',1,'Ogre::Vector2::UNIT_X'],['../class_ogre_1_1_vector3.html#a0c21d1f120c5eab83aa966e5de1df311',1,'Ogre::Vector3::UNIT_X']]],
-  ['unit_5fy_7',['unit_y',['../class_ogre_1_1_array_vector3.html#a6a152308d886080433232254917bb4bb',1,'Ogre::ArrayVector3::UNIT_Y'],['../class_ogre_1_1_vector2.html#ad20c8c58c9345a71743416bad82cb5e3',1,'Ogre::Vector2::UNIT_Y'],['../class_ogre_1_1_vector3.html#a8d1a1f7af535bcc8d9c78b1732bc1b90',1,'Ogre::Vector3::UNIT_Y']]],
-  ['unit_5fz_8',['unit_z',['../class_ogre_1_1_array_vector3.html#a1fcb417792cf81b60dcfaa0ec77b150f',1,'Ogre::ArrayVector3::UNIT_Z'],['../class_ogre_1_1_vector3.html#ad25aed2e9367cfa879d3e3c231c5a136',1,'Ogre::Vector3::UNIT_Z']]],
-  ['uoffset_9',['uoffset',['../struct_ogre_1_1_pbs_uv_atlas_params.html#ae3e62227806f0f245db9618bab213e70',1,'Ogre::PbsUvAtlasParams::uOffset'],['../struct_ogre_1_1_hlms_unlit_mobile_datablock_1_1_uv_atlas_params.html#a091bb9697df5e809531a630e33527778',1,'Ogre::HlmsUnlitMobileDatablock::UvAtlasParams::uOffset']]],
+  ['unit_5fscale_5',['UNIT_SCALE',['../class_ogre_1_1_array_vector3.html#a430a0a90f2cdab4764844a276636a2d9',1,'Ogre::ArrayVector3::UNIT_SCALE'],['../class_ogre_1_1_vector2.html#a165a67053e61b0733746453ce9ee5edb',1,'Ogre::Vector2::UNIT_SCALE'],['../class_ogre_1_1_vector3.html#a6a27e8a3a9156701f586afeed1516fb8',1,'Ogre::Vector3::UNIT_SCALE']]],
+  ['unit_5fx_6',['UNIT_X',['../class_ogre_1_1_array_vector3.html#a811d19510f8352453fa8f86d8c226a49',1,'Ogre::ArrayVector3::UNIT_X'],['../class_ogre_1_1_vector2.html#a1c2d210b2756d07375b0cf9f01835496',1,'Ogre::Vector2::UNIT_X'],['../class_ogre_1_1_vector3.html#a0c21d1f120c5eab83aa966e5de1df311',1,'Ogre::Vector3::UNIT_X']]],
+  ['unit_5fy_7',['UNIT_Y',['../class_ogre_1_1_array_vector3.html#a6a152308d886080433232254917bb4bb',1,'Ogre::ArrayVector3::UNIT_Y'],['../class_ogre_1_1_vector2.html#ad20c8c58c9345a71743416bad82cb5e3',1,'Ogre::Vector2::UNIT_Y'],['../class_ogre_1_1_vector3.html#a8d1a1f7af535bcc8d9c78b1732bc1b90',1,'Ogre::Vector3::UNIT_Y']]],
+  ['unit_5fz_8',['UNIT_Z',['../class_ogre_1_1_array_vector3.html#a1fcb417792cf81b60dcfaa0ec77b150f',1,'Ogre::ArrayVector3::UNIT_Z'],['../class_ogre_1_1_vector3.html#ad25aed2e9367cfa879d3e3c231c5a136',1,'Ogre::Vector3::UNIT_Z']]],
+  ['uoffset_9',['uOffset',['../struct_ogre_1_1_pbs_uv_atlas_params.html#ae3e62227806f0f245db9618bab213e70',1,'Ogre::PbsUvAtlasParams::uOffset'],['../struct_ogre_1_1_hlms_unlit_mobile_datablock_1_1_uv_atlas_params.html#a091bb9697df5e809531a630e33527778',1,'Ogre::HlmsUnlitMobileDatablock::UvAtlasParams::uOffset']]],
   ['updatefrom_10',['updateFrom',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#aeefacd1d618206fcb432ed947b58e06e',1,'Ogre::Volume::ChunkParameters']]],
   ['updateto_11',['updateTo',['../struct_ogre_1_1_volume_1_1_chunk_parameters.html#afe30999e8cc71a1f48d87d68bf43059d',1,'Ogre::Volume::ChunkParameters']]],
   ['usage_12',['usage',['../struct_ogre_1_1_vulkan_device_1_1_selected_queue.html#ad3b70ed4aed581a14a7eb46f9499222b',1,'Ogre::VulkanDevice::SelectedQueue']]],
@@ -38,7 +38,7 @@ var searchData=
   ['usetexturealpha_35',['UseTextureAlpha',['../struct_ogre_1_1_pbs_property.html#ab512ebe1ce98714f4ac942943c3d5c4c',1,'Ogre::PbsProperty']]],
   ['useuvbaking_36',['UseUvBaking',['../struct_ogre_1_1_hlms_base_prop.html#afc55cb97073522c4585321ad6ce83c5b',1,'Ogre::HlmsBaseProp']]],
   ['usevertexnormals_37',['useVertexNormals',['../struct_ogre_1_1_lod_config_1_1_advanced.html#aa510662a645fab3ef85ef4b1cde1a7a2',1,'Ogre::LodConfig::Advanced']]],
-  ['uvatlas_38',['uvatlas',['../struct_ogre_1_1_pbs_mobile_property.html#a888d7269bc4a8653824979f814fd5846',1,'Ogre::PbsMobileProperty::UvAtlas'],['../struct_ogre_1_1_unlit_mobile_prop.html#a985bb730dc4aca48ef9c30e015da8b57',1,'Ogre::UnlitMobileProp::UvAtlas']]],
+  ['uvatlas_38',['UvAtlas',['../struct_ogre_1_1_pbs_mobile_property.html#a888d7269bc4a8653824979f814fd5846',1,'Ogre::PbsMobileProperty::UvAtlas'],['../struct_ogre_1_1_unlit_mobile_prop.html#a985bb730dc4aca48ef9c30e015da8b57',1,'Ogre::UnlitMobileProp::UvAtlas']]],
   ['uvatlas0_39',['UvAtlas0',['../struct_ogre_1_1_unlit_mobile_prop.html#a49bb1dcfc1172c21faaafd92b548a51a',1,'Ogre::UnlitMobileProp']]],
   ['uvatlas1_40',['UvAtlas1',['../struct_ogre_1_1_unlit_mobile_prop.html#ab41a53b67e14fc9ad9c87b3420d96db6',1,'Ogre::UnlitMobileProp']]],
   ['uvatlas10_41',['UvAtlas10',['../struct_ogre_1_1_unlit_mobile_prop.html#ad2a43eea8886d2515156c12350244ef7',1,'Ogre::UnlitMobileProp']]],
@@ -66,16 +66,16 @@ var searchData=
   ['uvcount6_63',['UvCount6',['../struct_ogre_1_1_hlms_base_prop.html#a48af42a428f3b83fcce9488eda730004',1,'Ogre::HlmsBaseProp']]],
   ['uvcount7_64',['UvCount7',['../struct_ogre_1_1_hlms_base_prop.html#a6ed33d451345cc19508791f74adbc17c',1,'Ogre::HlmsBaseProp']]],
   ['uvcountptrs_65',['UvCountPtrs',['../struct_ogre_1_1_hlms_base_prop.html#ab098739635586c6b5d1af3c0fa993057',1,'Ogre::HlmsBaseProp']]],
-  ['uvdetail0_66',['uvdetail0',['../struct_ogre_1_1_pbs_property.html#a463687d18556ed70d35118e20f300ae8',1,'Ogre::PbsProperty::UvDetail0'],['../struct_ogre_1_1_pbs_mobile_property.html#a2a00954267871233a2c13b8e80da0320',1,'Ogre::PbsMobileProperty::UvDetail0']]],
-  ['uvdetail1_67',['uvdetail1',['../struct_ogre_1_1_pbs_property.html#a6cf101ce7617610c426ebed520dd1e91',1,'Ogre::PbsProperty::UvDetail1'],['../struct_ogre_1_1_pbs_mobile_property.html#a7cf9eada2ca8c5924c024bc0d230bf69',1,'Ogre::PbsMobileProperty::UvDetail1']]],
-  ['uvdetail2_68',['uvdetail2',['../struct_ogre_1_1_pbs_property.html#ad9a39c3d8effd030d15d4fd4b674e939',1,'Ogre::PbsProperty::UvDetail2'],['../struct_ogre_1_1_pbs_mobile_property.html#aef20e9f0cf4038f243a493562c528edd',1,'Ogre::PbsMobileProperty::UvDetail2']]],
-  ['uvdetail3_69',['uvdetail3',['../struct_ogre_1_1_pbs_property.html#afc29ed9c0743d0fe91aff5863ffe0a04',1,'Ogre::PbsProperty::UvDetail3'],['../struct_ogre_1_1_pbs_mobile_property.html#a28bf8525a7b5d0288abf46c8effbcd70',1,'Ogre::PbsMobileProperty::UvDetail3']]],
-  ['uvdetailnm0_70',['uvdetailnm0',['../struct_ogre_1_1_pbs_property.html#a4b4c51f8fd078119f40f4e3e06015462',1,'Ogre::PbsProperty::UvDetailNm0'],['../struct_ogre_1_1_pbs_mobile_property.html#ab368794cd70d249a1af1bbe07191c0d3',1,'Ogre::PbsMobileProperty::UvDetailNm0']]],
-  ['uvdetailnm1_71',['uvdetailnm1',['../struct_ogre_1_1_pbs_property.html#a0ff30f89ba8adb1e7dd93477f66ffb47',1,'Ogre::PbsProperty::UvDetailNm1'],['../struct_ogre_1_1_pbs_mobile_property.html#ae2065f5ea1292c3c6c223ce01a2ee9e8',1,'Ogre::PbsMobileProperty::UvDetailNm1']]],
-  ['uvdetailnm2_72',['uvdetailnm2',['../struct_ogre_1_1_pbs_property.html#aeea22df7402907173915502c489d9a9d',1,'Ogre::PbsProperty::UvDetailNm2'],['../struct_ogre_1_1_pbs_mobile_property.html#a877b6d30c8162923bc943ff98bc7014e',1,'Ogre::PbsMobileProperty::UvDetailNm2']]],
-  ['uvdetailnm3_73',['uvdetailnm3',['../struct_ogre_1_1_pbs_mobile_property.html#ae2ba7073c060b3ec0e687137def86ded',1,'Ogre::PbsMobileProperty::UvDetailNm3'],['../struct_ogre_1_1_pbs_property.html#a9ca13bcc5ae788d93d77c4c814ed3173',1,'Ogre::PbsProperty::UvDetailNm3']]],
-  ['uvdetailweight_74',['uvdetailweight',['../struct_ogre_1_1_pbs_property.html#aaa45f68c608f0005be3559d50196ea45',1,'Ogre::PbsProperty::UvDetailWeight'],['../struct_ogre_1_1_pbs_mobile_property.html#aeccf1651047633de46f6d6e54f168312',1,'Ogre::PbsMobileProperty::UvDetailWeight']]],
-  ['uvdiffuse_75',['uvdiffuse',['../struct_ogre_1_1_pbs_property.html#a36edaac4ed84336253dcf00ca19ef165',1,'Ogre::PbsProperty::UvDiffuse'],['../struct_ogre_1_1_pbs_mobile_property.html#a60b03b13bd9f716bd4b8cb18ab569d65',1,'Ogre::PbsMobileProperty::UvDiffuse']]],
+  ['uvdetail0_66',['UvDetail0',['../struct_ogre_1_1_pbs_property.html#a463687d18556ed70d35118e20f300ae8',1,'Ogre::PbsProperty::UvDetail0'],['../struct_ogre_1_1_pbs_mobile_property.html#a2a00954267871233a2c13b8e80da0320',1,'Ogre::PbsMobileProperty::UvDetail0']]],
+  ['uvdetail1_67',['UvDetail1',['../struct_ogre_1_1_pbs_property.html#a6cf101ce7617610c426ebed520dd1e91',1,'Ogre::PbsProperty::UvDetail1'],['../struct_ogre_1_1_pbs_mobile_property.html#a7cf9eada2ca8c5924c024bc0d230bf69',1,'Ogre::PbsMobileProperty::UvDetail1']]],
+  ['uvdetail2_68',['UvDetail2',['../struct_ogre_1_1_pbs_property.html#ad9a39c3d8effd030d15d4fd4b674e939',1,'Ogre::PbsProperty::UvDetail2'],['../struct_ogre_1_1_pbs_mobile_property.html#aef20e9f0cf4038f243a493562c528edd',1,'Ogre::PbsMobileProperty::UvDetail2']]],
+  ['uvdetail3_69',['UvDetail3',['../struct_ogre_1_1_pbs_property.html#afc29ed9c0743d0fe91aff5863ffe0a04',1,'Ogre::PbsProperty::UvDetail3'],['../struct_ogre_1_1_pbs_mobile_property.html#a28bf8525a7b5d0288abf46c8effbcd70',1,'Ogre::PbsMobileProperty::UvDetail3']]],
+  ['uvdetailnm0_70',['UvDetailNm0',['../struct_ogre_1_1_pbs_property.html#a4b4c51f8fd078119f40f4e3e06015462',1,'Ogre::PbsProperty::UvDetailNm0'],['../struct_ogre_1_1_pbs_mobile_property.html#ab368794cd70d249a1af1bbe07191c0d3',1,'Ogre::PbsMobileProperty::UvDetailNm0']]],
+  ['uvdetailnm1_71',['UvDetailNm1',['../struct_ogre_1_1_pbs_property.html#a0ff30f89ba8adb1e7dd93477f66ffb47',1,'Ogre::PbsProperty::UvDetailNm1'],['../struct_ogre_1_1_pbs_mobile_property.html#ae2065f5ea1292c3c6c223ce01a2ee9e8',1,'Ogre::PbsMobileProperty::UvDetailNm1']]],
+  ['uvdetailnm2_72',['UvDetailNm2',['../struct_ogre_1_1_pbs_property.html#aeea22df7402907173915502c489d9a9d',1,'Ogre::PbsProperty::UvDetailNm2'],['../struct_ogre_1_1_pbs_mobile_property.html#a877b6d30c8162923bc943ff98bc7014e',1,'Ogre::PbsMobileProperty::UvDetailNm2']]],
+  ['uvdetailnm3_73',['UvDetailNm3',['../struct_ogre_1_1_pbs_property.html#a9ca13bcc5ae788d93d77c4c814ed3173',1,'Ogre::PbsProperty::UvDetailNm3'],['../struct_ogre_1_1_pbs_mobile_property.html#ae2ba7073c060b3ec0e687137def86ded',1,'Ogre::PbsMobileProperty::UvDetailNm3']]],
+  ['uvdetailweight_74',['UvDetailWeight',['../struct_ogre_1_1_pbs_property.html#aaa45f68c608f0005be3559d50196ea45',1,'Ogre::PbsProperty::UvDetailWeight'],['../struct_ogre_1_1_pbs_mobile_property.html#aeccf1651047633de46f6d6e54f168312',1,'Ogre::PbsMobileProperty::UvDetailWeight']]],
+  ['uvdiffuse_75',['UvDiffuse',['../struct_ogre_1_1_pbs_property.html#a36edaac4ed84336253dcf00ca19ef165',1,'Ogre::PbsProperty::UvDiffuse'],['../struct_ogre_1_1_pbs_mobile_property.html#a60b03b13bd9f716bd4b8cb18ab569d65',1,'Ogre::PbsMobileProperty::UvDiffuse']]],
   ['uvdiffuse0_76',['UvDiffuse0',['../struct_ogre_1_1_unlit_property.html#a4a9d07c36bb9be02d6b72c1bdc407b25',1,'Ogre::UnlitProperty']]],
   ['uvdiffuse1_77',['UvDiffuse1',['../struct_ogre_1_1_unlit_property.html#a017189ec47ab23f487c8f641e6c4caad',1,'Ogre::UnlitProperty']]],
   ['uvdiffuse10_78',['UvDiffuse10',['../struct_ogre_1_1_unlit_property.html#a3064d90099b8960cc88ee448e86bdb13',1,'Ogre::UnlitProperty']]],
@@ -110,12 +110,12 @@ var searchData=
   ['uvdiffuseswizzle9_107',['UvDiffuseSwizzle9',['../struct_ogre_1_1_unlit_property.html#a2fd61aeb85206153008a9a1330055e65',1,'Ogre::UnlitProperty']]],
   ['uvemissive_108',['UvEmissive',['../struct_ogre_1_1_pbs_property.html#ab3bee700bb74eec0518bf4fe5d61d0fc',1,'Ogre::PbsProperty']]],
   ['uvlength_109',['uvLength',['../class_ogre_1_1_shadow_texture_definition.html#a6b5048cef58070a4608897ab718eb9c4',1,'Ogre::ShadowTextureDefinition']]],
-  ['uvnormal_110',['uvnormal',['../struct_ogre_1_1_pbs_property.html#a8535ff2f0757f3bb9f9bec6a974432e8',1,'Ogre::PbsProperty::UvNormal'],['../struct_ogre_1_1_pbs_mobile_property.html#adcb9b6ad6056869f47880cb1a093e8f4',1,'Ogre::PbsMobileProperty::UvNormal']]],
+  ['uvnormal_110',['UvNormal',['../struct_ogre_1_1_pbs_property.html#a8535ff2f0757f3bb9f9bec6a974432e8',1,'Ogre::PbsProperty::UvNormal'],['../struct_ogre_1_1_pbs_mobile_property.html#adcb9b6ad6056869f47880cb1a093e8f4',1,'Ogre::PbsMobileProperty::UvNormal']]],
   ['uvoffset_111',['uvOffset',['../class_ogre_1_1_shadow_texture_definition.html#a9415b07e2e36a433b61767818fa214d8',1,'Ogre::ShadowTextureDefinition']]],
   ['uvrect_112',['uvRect',['../struct_ogre_1_1_font_1_1_glyph_info.html#a46b20f8f199e3d2f698aa44a6553ab50',1,'Ogre::Font::GlyphInfo']]],
-  ['uvroughness_113',['uvroughness',['../struct_ogre_1_1_pbs_property.html#a6661e3fc093712a1267dcce3d5f1d7ac',1,'Ogre::PbsProperty::UvRoughness'],['../struct_ogre_1_1_pbs_mobile_property.html#a1b26e5dd827e0febcf98d7c722b52f85',1,'Ogre::PbsMobileProperty::UvRoughness']]],
-  ['uvsource_114',['uvsource',['../struct_ogre_1_1_pbs_mobile_shader_creation_data.html#a313e17e279cf50eb01c1a4aa0410a272',1,'Ogre::PbsMobileShaderCreationData::uvSource'],['../struct_ogre_1_1_unlit_property_1_1_diffuse_map_ptr.html#aec650b44d996e845b3b86ccb3a69e5e1',1,'Ogre::UnlitProperty::DiffuseMapPtr::uvSource']]],
-  ['uvsourceptrs_115',['uvsourceptrs',['../struct_ogre_1_1_pbs_property.html#a3775d430326255fd382d73fb205bcff8',1,'Ogre::PbsProperty::UvSourcePtrs'],['../struct_ogre_1_1_pbs_mobile_property.html#a127c6343bac97738e18cdc6918a973e2',1,'Ogre::PbsMobileProperty::UvSourcePtrs']]],
+  ['uvroughness_113',['UvRoughness',['../struct_ogre_1_1_pbs_property.html#a6661e3fc093712a1267dcce3d5f1d7ac',1,'Ogre::PbsProperty::UvRoughness'],['../struct_ogre_1_1_pbs_mobile_property.html#a1b26e5dd827e0febcf98d7c722b52f85',1,'Ogre::PbsMobileProperty::UvRoughness']]],
+  ['uvsource_114',['uvSource',['../struct_ogre_1_1_pbs_mobile_shader_creation_data.html#a313e17e279cf50eb01c1a4aa0410a272',1,'Ogre::PbsMobileShaderCreationData::uvSource'],['../struct_ogre_1_1_unlit_property_1_1_diffuse_map_ptr.html#aec650b44d996e845b3b86ccb3a69e5e1',1,'Ogre::UnlitProperty::DiffuseMapPtr::uvSource']]],
+  ['uvsourceptrs_115',['UvSourcePtrs',['../struct_ogre_1_1_pbs_property.html#a3775d430326255fd382d73fb205bcff8',1,'Ogre::PbsProperty::UvSourcePtrs'],['../struct_ogre_1_1_pbs_mobile_property.html#a127c6343bac97738e18cdc6918a973e2',1,'Ogre::PbsMobileProperty::UvSourcePtrs']]],
   ['uvsourceswizzle_116',['uvSourceSwizzle',['../struct_ogre_1_1_unlit_property_1_1_diffuse_map_ptr.html#ae35f9514e16f3a1985fd04c51a792b21',1,'Ogre::UnlitProperty::DiffuseMapPtr']]],
-  ['uvspecular_117',['uvspecular',['../struct_ogre_1_1_pbs_property.html#aaa78525e10627bb21169658c1b9799e6',1,'Ogre::PbsProperty::UvSpecular'],['../struct_ogre_1_1_pbs_mobile_property.html#ad1def7c4effec980996bbe4a51924e74',1,'Ogre::PbsMobileProperty::UvSpecular']]]
+  ['uvspecular_117',['UvSpecular',['../struct_ogre_1_1_pbs_property.html#aaa78525e10627bb21169658c1b9799e6',1,'Ogre::PbsProperty::UvSpecular'],['../struct_ogre_1_1_pbs_mobile_property.html#ad1def7c4effec980996bbe4a51924e74',1,'Ogre::PbsMobileProperty::UvSpecular']]]
 ];
